```@meta
EditURL = "../../../../../examples/quantum1d/2.haldane/main.jl"
```

[![](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/maartenvd/MPSKit.jl/gh-pages?filepath=dev/examples/quantum1d/2.haldane/main.ipynb)
[![](https://img.shields.io/badge/show-nbviewer-579ACA.svg)](https://nbviewer.jupyter.org/github/maartenvd/MPSKit.jl/blob/gh-pages/dev/examples/quantum1d/2.haldane/main.ipynb)
[![](https://img.shields.io/badge/download-project-orange)](https://minhaskamal.github.io/DownGit/#/home?url=https://github.com/maartenvd/MPSKit.jl/examples/tree/gh-pages/dev/examples/quantum1d/2.haldane)

# [The Haldane gap](@id demo_haldane)

In this tutorial we will calculate the Haldane gap (the energy gap in the ``S = 1`` Heisenberg model) in two different ways.
To follow the tutorial you need the following packages:

````julia
using MPSKit, MPSKitModels, TensorKit, Plots, Polynomials
````

The Heisenberg model is defined by the following hamiltonian:

```math
H = -J∑_{⟨i,j⟩} (X_i X_j + Y_i Y_j + Z_i Z_j)
```

This hamiltonian has an SU(2) symmetry, which we can enforce by using SU(2)-symmetric tensors:

````julia
H = heisenberg_XXX(ComplexF64, SU2Irrep; spin=1, J=1);
````

## Finite size extrapolation

We can start the analysis using finite-size methods.
The groundstate of this model can be approximated using finite MPS through the use of DMRG.

The typical way to find excited states is to minimize the energy while adding an error term
$$λ \left|gs\right> \left< gs\right|$$
Here we will instead use the [quasiparticle ansatz](https://journals.aps.org/prl/abstract/10.1103/PhysRevLett.111.080401).

In Steven White's original DMRG paper it was remarked that the ``S = 1`` excitations correspond to edge states, and that one should define the Haldane gap as the difference in energy between the ``S = 2`` and ``S = 1`` states.
This can be done as follows.

````julia
L = 10
physical_space = SU2Space(1 => 1)
virtual_space = SU2Space(0 => 12, 1 => 12, 2 => 5, 3 => 3)
ψ₀ = FiniteMPS(rand, ComplexF64, L, physical_space, virtual_space)
ψ, envs, delta = find_groundstate(ψ₀, H, DMRG(; verbose=false))
E₀ = real.(expectation_value(ψ, H))
En_1, st_1 = excitations(H, QuasiparticleAnsatz(), ψ, envs; sector=SU2Irrep(1))
En_2, st_2 = excitations(H, QuasiparticleAnsatz(), ψ, envs; sector=SU2Irrep(2))
ΔE_finite = real(En_2[1] - En_1[1])
````

````
0.7655030897750493
````

We can go even further and doublecheck the claim that ``S = 1`` is an edge excitation, by plotting the energy density.

````julia
p_density = plot(; xaxis="position", yaxis="energy density")
excited_1 = convert(FiniteMPS, st_1[1])
excited_2 = convert(FiniteMPS, st_2[1])
plot!(p_density, real.(expectation_value(excited_1, H) .- E₀) ./ L; label="S = 1")
plot!(p_density, real.(expectation_value(excited_2, H) .- E₀) ./ L; label="S = 2")
````

```@raw html
<?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="600" height="400" viewBox="0 0 2400 1600">
<defs>
  <clipPath id="clip670">
    <rect x="0" y="0" width="2400" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip670)" d="M0 1600 L2400 1600 L2400 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip671">
    <rect x="480" y="0" width="1681" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip670)" d="M309.866 1423.18 L2352.76 1423.18 L2352.76 47.2441 L309.866 47.2441  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip672">
    <rect x="309" y="47" width="2044" height="1377"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip672)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="581.823,1423.18 581.823,47.2441 "/>
<polyline clip-path="url(#clip672)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1010.1,1423.18 1010.1,47.2441 "/>
<polyline clip-path="url(#clip672)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1438.38,1423.18 1438.38,47.2441 "/>
<polyline clip-path="url(#clip672)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1866.66,1423.18 1866.66,47.2441 "/>
<polyline clip-path="url(#clip672)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2294.94,1423.18 2294.94,47.2441 "/>
<polyline clip-path="url(#clip670)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="309.866,1423.18 2352.76,1423.18 "/>
<polyline clip-path="url(#clip670)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="581.823,1423.18 581.823,1404.28 "/>
<polyline clip-path="url(#clip670)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1010.1,1423.18 1010.1,1404.28 "/>
<polyline clip-path="url(#clip670)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1438.38,1423.18 1438.38,1404.28 "/>
<polyline clip-path="url(#clip670)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1866.66,1423.18 1866.66,1404.28 "/>
<polyline clip-path="url(#clip670)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2294.94,1423.18 2294.94,1404.28 "/>
<path clip-path="url(#clip670)" d="M576.476 1481.64 L592.795 1481.64 L592.795 1485.58 L570.851 1485.58 L570.851 1481.64 Q573.513 1478.89 578.096 1474.26 Q582.702 1469.61 583.883 1468.27 Q586.128 1465.74 587.008 1464.01 Q587.911 1462.25 587.911 1460.56 Q587.911 1457.8 585.966 1456.07 Q584.045 1454.33 580.943 1454.33 Q578.744 1454.33 576.29 1455.09 Q573.86 1455.86 571.082 1457.41 L571.082 1452.69 Q573.906 1451.55 576.36 1450.97 Q578.814 1450.39 580.851 1450.39 Q586.221 1450.39 589.415 1453.08 Q592.61 1455.77 592.61 1460.26 Q592.61 1462.39 591.8 1464.31 Q591.013 1466.2 588.906 1468.8 Q588.327 1469.47 585.226 1472.69 Q582.124 1475.88 576.476 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M1013.11 1455.09 L1001.31 1473.54 L1013.11 1473.54 L1013.11 1455.09 M1011.88 1451.02 L1017.76 1451.02 L1017.76 1473.54 L1022.69 1473.54 L1022.69 1477.43 L1017.76 1477.43 L1017.76 1485.58 L1013.11 1485.58 L1013.11 1477.43 L997.509 1477.43 L997.509 1472.92 L1011.88 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M1438.79 1466.44 Q1435.64 1466.44 1433.79 1468.59 Q1431.96 1470.74 1431.96 1474.49 Q1431.96 1478.22 1433.79 1480.39 Q1435.64 1482.55 1438.79 1482.55 Q1441.93 1482.55 1443.76 1480.39 Q1445.61 1478.22 1445.61 1474.49 Q1445.61 1470.74 1443.76 1468.59 Q1441.93 1466.44 1438.79 1466.44 M1448.07 1451.78 L1448.07 1456.04 Q1446.31 1455.21 1444.5 1454.77 Q1442.72 1454.33 1440.96 1454.33 Q1436.33 1454.33 1433.88 1457.45 Q1431.45 1460.58 1431.1 1466.9 Q1432.47 1464.89 1434.53 1463.82 Q1436.59 1462.73 1439.06 1462.73 Q1444.27 1462.73 1447.28 1465.9 Q1450.31 1469.05 1450.31 1474.49 Q1450.31 1479.82 1447.17 1483.03 Q1444.02 1486.25 1438.79 1486.25 Q1432.79 1486.25 1429.62 1481.67 Q1426.45 1477.06 1426.45 1468.33 Q1426.45 1460.14 1430.34 1455.28 Q1434.23 1450.39 1440.78 1450.39 Q1442.54 1450.39 1444.32 1450.74 Q1446.12 1451.09 1448.07 1451.78 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M1866.66 1469.17 Q1863.33 1469.17 1861.4 1470.95 Q1859.51 1472.73 1859.51 1475.86 Q1859.51 1478.98 1861.4 1480.77 Q1863.33 1482.55 1866.66 1482.55 Q1869.99 1482.55 1871.91 1480.77 Q1873.84 1478.96 1873.84 1475.86 Q1873.84 1472.73 1871.91 1470.95 Q1870.02 1469.17 1866.66 1469.17 M1861.98 1467.18 Q1858.97 1466.44 1857.28 1464.38 Q1855.62 1462.32 1855.62 1459.35 Q1855.62 1455.21 1858.56 1452.8 Q1861.52 1450.39 1866.66 1450.39 Q1871.82 1450.39 1874.76 1452.8 Q1877.7 1455.21 1877.7 1459.35 Q1877.7 1462.32 1876.01 1464.38 Q1874.34 1466.44 1871.36 1467.18 Q1874.74 1467.96 1876.61 1470.26 Q1878.51 1472.55 1878.51 1475.86 Q1878.51 1480.88 1875.43 1483.57 Q1872.38 1486.25 1866.66 1486.25 Q1860.94 1486.25 1857.86 1483.57 Q1854.81 1480.88 1854.81 1475.86 Q1854.81 1472.55 1856.71 1470.26 Q1858.6 1467.96 1861.98 1467.18 M1860.27 1459.79 Q1860.27 1462.48 1861.94 1463.98 Q1863.63 1465.49 1866.66 1465.49 Q1869.67 1465.49 1871.36 1463.98 Q1873.07 1462.48 1873.07 1459.79 Q1873.07 1457.11 1871.36 1455.6 Q1869.67 1454.1 1866.66 1454.1 Q1863.63 1454.1 1861.94 1455.6 Q1860.27 1457.11 1860.27 1459.79 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M2269.63 1481.64 L2277.26 1481.64 L2277.26 1455.28 L2268.95 1456.95 L2268.95 1452.69 L2277.22 1451.02 L2281.89 1451.02 L2281.89 1481.64 L2289.53 1481.64 L2289.53 1485.58 L2269.63 1485.58 L2269.63 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M2308.98 1454.1 Q2305.37 1454.1 2303.54 1457.66 Q2301.73 1461.2 2301.73 1468.33 Q2301.73 1475.44 2303.54 1479.01 Q2305.37 1482.55 2308.98 1482.55 Q2312.61 1482.55 2314.42 1479.01 Q2316.25 1475.44 2316.25 1468.33 Q2316.25 1461.2 2314.42 1457.66 Q2312.61 1454.1 2308.98 1454.1 M2308.98 1450.39 Q2314.79 1450.39 2317.84 1455 Q2320.92 1459.58 2320.92 1468.33 Q2320.92 1477.06 2317.84 1481.67 Q2314.79 1486.25 2308.98 1486.25 Q2303.17 1486.25 2300.09 1481.67 Q2297.03 1477.06 2297.03 1468.33 Q2297.03 1459.58 2300.09 1455 Q2303.17 1450.39 2308.98 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M1213.83 1562.7 L1213.83 1581.6 L1207.94 1581.6 L1207.94 1532.4 L1213.83 1532.4 L1213.83 1537.81 Q1215.68 1534.62 1218.48 1533.1 Q1221.31 1531.54 1225.23 1531.54 Q1231.72 1531.54 1235.76 1536.69 Q1239.84 1541.85 1239.84 1550.25 Q1239.84 1558.65 1235.76 1563.81 Q1231.72 1568.97 1225.23 1568.97 Q1221.31 1568.97 1218.48 1567.44 Q1215.68 1565.88 1213.83 1562.7 M1233.76 1550.25 Q1233.76 1543.79 1231.08 1540.13 Q1228.44 1536.44 1223.79 1536.44 Q1219.15 1536.44 1216.47 1540.13 Q1213.83 1543.79 1213.83 1550.25 Q1213.83 1556.71 1216.47 1560.4 Q1219.15 1564.07 1223.79 1564.07 Q1228.44 1564.07 1231.08 1560.4 Q1233.76 1556.71 1233.76 1550.25 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M1263.36 1536.5 Q1258.65 1536.5 1255.91 1540.19 Q1253.17 1543.85 1253.17 1550.25 Q1253.17 1556.65 1255.88 1560.34 Q1258.61 1564 1263.36 1564 Q1268.04 1564 1270.77 1560.31 Q1273.51 1556.62 1273.51 1550.25 Q1273.51 1543.92 1270.77 1540.23 Q1268.04 1536.5 1263.36 1536.5 M1263.36 1531.54 Q1271 1531.54 1275.36 1536.5 Q1279.72 1541.47 1279.72 1550.25 Q1279.72 1559 1275.36 1564 Q1271 1568.97 1263.36 1568.97 Q1255.69 1568.97 1251.33 1564 Q1247 1559 1247 1550.25 Q1247 1541.47 1251.33 1536.5 Q1255.69 1531.54 1263.36 1531.54 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M1312.15 1533.45 L1312.15 1538.98 Q1309.67 1537.71 1306.99 1537.07 Q1304.32 1536.44 1301.46 1536.44 Q1297.1 1536.44 1294.9 1537.77 Q1292.73 1539.11 1292.73 1541.79 Q1292.73 1543.82 1294.29 1545 Q1295.85 1546.15 1300.56 1547.2 L1302.57 1547.64 Q1308.81 1548.98 1311.42 1551.43 Q1314.06 1553.85 1314.06 1558.21 Q1314.06 1563.17 1310.11 1566.07 Q1306.2 1568.97 1299.32 1568.97 Q1296.46 1568.97 1293.34 1568.39 Q1290.25 1567.85 1286.81 1566.74 L1286.81 1560.69 Q1290.06 1562.38 1293.21 1563.24 Q1296.36 1564.07 1299.45 1564.07 Q1303.59 1564.07 1305.82 1562.66 Q1308.04 1561.23 1308.04 1558.65 Q1308.04 1556.27 1306.42 1554.99 Q1304.83 1553.72 1299.39 1552.54 L1297.35 1552.07 Q1291.91 1550.92 1289.49 1548.56 Q1287.07 1546.18 1287.07 1542.04 Q1287.07 1537.01 1290.63 1534.27 Q1294.2 1531.54 1300.76 1531.54 Q1304 1531.54 1306.87 1532.01 Q1309.73 1532.49 1312.15 1533.45 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M1323.39 1532.4 L1329.24 1532.4 L1329.24 1568.04 L1323.39 1568.04 L1323.39 1532.4 M1323.39 1518.52 L1329.24 1518.52 L1329.24 1525.93 L1323.39 1525.93 L1323.39 1518.52 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M1347.29 1522.27 L1347.29 1532.4 L1359.35 1532.4 L1359.35 1536.95 L1347.29 1536.95 L1347.29 1556.3 Q1347.29 1560.66 1348.47 1561.9 Q1349.68 1563.14 1353.34 1563.14 L1359.35 1563.14 L1359.35 1568.04 L1353.34 1568.04 Q1346.56 1568.04 1343.98 1565.53 Q1341.4 1562.98 1341.4 1556.3 L1341.4 1536.95 L1337.1 1536.95 L1337.1 1532.4 L1341.4 1532.4 L1341.4 1522.27 L1347.29 1522.27 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M1367.05 1532.4 L1372.91 1532.4 L1372.91 1568.04 L1367.05 1568.04 L1367.05 1532.4 M1367.05 1518.52 L1372.91 1518.52 L1372.91 1525.93 L1367.05 1525.93 L1367.05 1518.52 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M1398.98 1536.5 Q1394.27 1536.5 1391.53 1540.19 Q1388.79 1543.85 1388.79 1550.25 Q1388.79 1556.65 1391.5 1560.34 Q1394.24 1564 1398.98 1564 Q1403.66 1564 1406.39 1560.31 Q1409.13 1556.62 1409.13 1550.25 Q1409.13 1543.92 1406.39 1540.23 Q1403.66 1536.5 1398.98 1536.5 M1398.98 1531.54 Q1406.62 1531.54 1410.98 1536.5 Q1415.34 1541.47 1415.34 1550.25 Q1415.34 1559 1410.98 1564 Q1406.62 1568.97 1398.98 1568.97 Q1391.31 1568.97 1386.95 1564 Q1382.62 1559 1382.62 1550.25 Q1382.62 1541.47 1386.95 1536.5 Q1391.31 1531.54 1398.98 1531.54 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M1454.68 1546.53 L1454.68 1568.04 L1448.82 1568.04 L1448.82 1546.72 Q1448.82 1541.66 1446.85 1539.14 Q1444.88 1536.63 1440.93 1536.63 Q1436.19 1536.63 1433.45 1539.65 Q1430.71 1542.68 1430.71 1547.9 L1430.71 1568.04 L1424.82 1568.04 L1424.82 1532.4 L1430.71 1532.4 L1430.71 1537.93 Q1432.81 1534.72 1435.64 1533.13 Q1438.51 1531.54 1442.23 1531.54 Q1448.38 1531.54 1451.53 1535.36 Q1454.68 1539.14 1454.68 1546.53 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip672)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="309.866,1179.76 2352.76,1179.76 "/>
<polyline clip-path="url(#clip672)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="309.866,883.412 2352.76,883.412 "/>
<polyline clip-path="url(#clip672)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="309.866,587.063 2352.76,587.063 "/>
<polyline clip-path="url(#clip672)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="309.866,290.714 2352.76,290.714 "/>
<polyline clip-path="url(#clip670)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="309.866,1423.18 309.866,47.2441 "/>
<polyline clip-path="url(#clip670)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="309.866,1179.76 328.763,1179.76 "/>
<polyline clip-path="url(#clip670)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="309.866,883.412 328.763,883.412 "/>
<polyline clip-path="url(#clip670)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="309.866,587.063 328.763,587.063 "/>
<polyline clip-path="url(#clip670)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="309.866,290.714 328.763,290.714 "/>
<path clip-path="url(#clip670)" d="M127.2 1165.56 Q123.589 1165.56 121.76 1169.12 Q119.955 1172.67 119.955 1179.8 Q119.955 1186.9 121.76 1190.47 Q123.589 1194.01 127.2 1194.01 Q130.834 1194.01 132.64 1190.47 Q134.468 1186.9 134.468 1179.8 Q134.468 1172.67 132.64 1169.12 Q130.834 1165.56 127.2 1165.56 M127.2 1161.86 Q133.01 1161.86 136.066 1166.46 Q139.144 1171.05 139.144 1179.8 Q139.144 1188.52 136.066 1193.13 Q133.01 1197.71 127.2 1197.71 Q121.39 1197.71 118.311 1193.13 Q115.256 1188.52 115.256 1179.8 Q115.256 1171.05 118.311 1166.46 Q121.39 1161.86 127.2 1161.86 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M147.362 1191.16 L152.246 1191.16 L152.246 1197.04 L147.362 1197.04 L147.362 1191.16 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M172.431 1165.56 Q168.82 1165.56 166.991 1169.12 Q165.186 1172.67 165.186 1179.8 Q165.186 1186.9 166.991 1190.47 Q168.82 1194.01 172.431 1194.01 Q176.065 1194.01 177.871 1190.47 Q179.7 1186.9 179.7 1179.8 Q179.7 1172.67 177.871 1169.12 Q176.065 1165.56 172.431 1165.56 M172.431 1161.86 Q178.241 1161.86 181.297 1166.46 Q184.376 1171.05 184.376 1179.8 Q184.376 1188.52 181.297 1193.13 Q178.241 1197.71 172.431 1197.71 Q166.621 1197.71 163.542 1193.13 Q160.487 1188.52 160.487 1179.8 Q160.487 1171.05 163.542 1166.46 Q166.621 1161.86 172.431 1161.86 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M202.593 1165.56 Q198.982 1165.56 197.153 1169.12 Q195.348 1172.67 195.348 1179.8 Q195.348 1186.9 197.153 1190.47 Q198.982 1194.01 202.593 1194.01 Q206.227 1194.01 208.033 1190.47 Q209.861 1186.9 209.861 1179.8 Q209.861 1172.67 208.033 1169.12 Q206.227 1165.56 202.593 1165.56 M202.593 1161.86 Q208.403 1161.86 211.459 1166.46 Q214.537 1171.05 214.537 1179.8 Q214.537 1188.52 211.459 1193.13 Q208.403 1197.71 202.593 1197.71 Q196.783 1197.71 193.704 1193.13 Q190.649 1188.52 190.649 1179.8 Q190.649 1171.05 193.704 1166.46 Q196.783 1161.86 202.593 1161.86 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M226.783 1193.11 L243.102 1193.11 L243.102 1197.04 L221.158 1197.04 L221.158 1193.11 Q223.82 1190.35 228.403 1185.72 Q233.01 1181.07 234.19 1179.73 Q236.435 1177.2 237.315 1175.47 Q238.218 1173.71 238.218 1172.02 Q238.218 1169.26 236.273 1167.53 Q234.352 1165.79 231.25 1165.79 Q229.051 1165.79 226.598 1166.56 Q224.167 1167.32 221.389 1168.87 L221.389 1164.15 Q224.213 1163.01 226.667 1162.44 Q229.121 1161.86 231.158 1161.86 Q236.528 1161.86 239.722 1164.54 Q242.917 1167.23 242.917 1171.72 Q242.917 1173.85 242.107 1175.77 Q241.32 1177.67 239.213 1180.26 Q238.634 1180.93 235.533 1184.15 Q232.431 1187.34 226.783 1193.11 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M252.963 1162.48 L271.32 1162.48 L271.32 1166.42 L257.246 1166.42 L257.246 1174.89 Q258.264 1174.54 259.283 1174.38 Q260.301 1174.19 261.32 1174.19 Q267.107 1174.19 270.486 1177.37 Q273.866 1180.54 273.866 1185.95 Q273.866 1191.53 270.394 1194.63 Q266.921 1197.71 260.602 1197.71 Q258.426 1197.71 256.158 1197.34 Q253.912 1196.97 251.505 1196.23 L251.505 1191.53 Q253.588 1192.67 255.81 1193.22 Q258.033 1193.78 260.509 1193.78 Q264.514 1193.78 266.852 1191.67 Q269.19 1189.56 269.19 1185.95 Q269.19 1182.34 266.852 1180.24 Q264.514 1178.13 260.509 1178.13 Q258.634 1178.13 256.759 1178.55 Q254.908 1178.96 252.963 1179.84 L252.963 1162.48 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M126.205 869.211 Q122.593 869.211 120.765 872.776 Q118.959 876.318 118.959 883.447 Q118.959 890.554 120.765 894.118 Q122.593 897.66 126.205 897.66 Q129.839 897.66 131.644 894.118 Q133.473 890.554 133.473 883.447 Q133.473 876.318 131.644 872.776 Q129.839 869.211 126.205 869.211 M126.205 865.507 Q132.015 865.507 135.07 870.114 Q138.149 874.697 138.149 883.447 Q138.149 892.174 135.07 896.78 Q132.015 901.364 126.205 901.364 Q120.394 901.364 117.316 896.78 Q114.26 892.174 114.26 883.447 Q114.26 874.697 117.316 870.114 Q120.394 865.507 126.205 865.507 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M146.366 894.813 L151.251 894.813 L151.251 900.692 L146.366 900.692 L146.366 894.813 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M171.436 869.211 Q167.825 869.211 165.996 872.776 Q164.19 876.318 164.19 883.447 Q164.19 890.554 165.996 894.118 Q167.825 897.66 171.436 897.66 Q175.07 897.66 176.876 894.118 Q178.704 890.554 178.704 883.447 Q178.704 876.318 176.876 872.776 Q175.07 869.211 171.436 869.211 M171.436 865.507 Q177.246 865.507 180.301 870.114 Q183.38 874.697 183.38 883.447 Q183.38 892.174 180.301 896.78 Q177.246 901.364 171.436 901.364 Q165.626 901.364 162.547 896.78 Q159.491 892.174 159.491 883.447 Q159.491 874.697 162.547 870.114 Q165.626 865.507 171.436 865.507 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M201.598 869.211 Q197.987 869.211 196.158 872.776 Q194.352 876.318 194.352 883.447 Q194.352 890.554 196.158 894.118 Q197.987 897.66 201.598 897.66 Q205.232 897.66 207.037 894.118 Q208.866 890.554 208.866 883.447 Q208.866 876.318 207.037 872.776 Q205.232 869.211 201.598 869.211 M201.598 865.507 Q207.408 865.507 210.463 870.114 Q213.542 874.697 213.542 883.447 Q213.542 892.174 210.463 896.78 Q207.408 901.364 201.598 901.364 Q195.787 901.364 192.709 896.78 Q189.653 892.174 189.653 883.447 Q189.653 874.697 192.709 870.114 Q195.787 865.507 201.598 865.507 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M221.806 866.132 L240.162 866.132 L240.162 870.068 L226.088 870.068 L226.088 878.54 Q227.107 878.193 228.125 878.031 Q229.144 877.845 230.162 877.845 Q235.949 877.845 239.329 881.017 Q242.709 884.188 242.709 889.605 Q242.709 895.183 239.236 898.285 Q235.764 901.364 229.445 901.364 Q227.269 901.364 225 900.993 Q222.755 900.623 220.348 899.882 L220.348 895.183 Q222.431 896.317 224.653 896.873 Q226.875 897.429 229.352 897.429 Q233.357 897.429 235.695 895.322 Q238.033 893.216 238.033 889.605 Q238.033 885.993 235.695 883.887 Q233.357 881.78 229.352 881.78 Q227.477 881.78 225.602 882.197 Q223.75 882.614 221.806 883.493 L221.806 866.132 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M261.921 869.211 Q258.31 869.211 256.482 872.776 Q254.676 876.318 254.676 883.447 Q254.676 890.554 256.482 894.118 Q258.31 897.66 261.921 897.66 Q265.556 897.66 267.361 894.118 Q269.19 890.554 269.19 883.447 Q269.19 876.318 267.361 872.776 Q265.556 869.211 261.921 869.211 M261.921 865.507 Q267.732 865.507 270.787 870.114 Q273.866 874.697 273.866 883.447 Q273.866 892.174 270.787 896.78 Q267.732 901.364 261.921 901.364 Q256.111 901.364 253.033 896.78 Q249.977 892.174 249.977 883.447 Q249.977 874.697 253.033 870.114 Q256.111 865.507 261.921 865.507 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M127.2 572.862 Q123.589 572.862 121.76 576.427 Q119.955 579.969 119.955 587.098 Q119.955 594.205 121.76 597.769 Q123.589 601.311 127.2 601.311 Q130.834 601.311 132.64 597.769 Q134.468 594.205 134.468 587.098 Q134.468 579.969 132.64 576.427 Q130.834 572.862 127.2 572.862 M127.2 569.158 Q133.01 569.158 136.066 573.765 Q139.144 578.348 139.144 587.098 Q139.144 595.825 136.066 600.431 Q133.01 605.015 127.2 605.015 Q121.39 605.015 118.311 600.431 Q115.256 595.825 115.256 587.098 Q115.256 578.348 118.311 573.765 Q121.39 569.158 127.2 569.158 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M147.362 598.464 L152.246 598.464 L152.246 604.343 L147.362 604.343 L147.362 598.464 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M172.431 572.862 Q168.82 572.862 166.991 576.427 Q165.186 579.969 165.186 587.098 Q165.186 594.205 166.991 597.769 Q168.82 601.311 172.431 601.311 Q176.065 601.311 177.871 597.769 Q179.7 594.205 179.7 587.098 Q179.7 579.969 177.871 576.427 Q176.065 572.862 172.431 572.862 M172.431 569.158 Q178.241 569.158 181.297 573.765 Q184.376 578.348 184.376 587.098 Q184.376 595.825 181.297 600.431 Q178.241 605.015 172.431 605.015 Q166.621 605.015 163.542 600.431 Q160.487 595.825 160.487 587.098 Q160.487 578.348 163.542 573.765 Q166.621 569.158 172.431 569.158 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M202.593 572.862 Q198.982 572.862 197.153 576.427 Q195.348 579.969 195.348 587.098 Q195.348 594.205 197.153 597.769 Q198.982 601.311 202.593 601.311 Q206.227 601.311 208.033 597.769 Q209.861 594.205 209.861 587.098 Q209.861 579.969 208.033 576.427 Q206.227 572.862 202.593 572.862 M202.593 569.158 Q208.403 569.158 211.459 573.765 Q214.537 578.348 214.537 587.098 Q214.537 595.825 211.459 600.431 Q208.403 605.015 202.593 605.015 Q196.783 605.015 193.704 600.431 Q190.649 595.825 190.649 587.098 Q190.649 578.348 193.704 573.765 Q196.783 569.158 202.593 569.158 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M221.574 569.783 L243.797 569.783 L243.797 571.774 L231.25 604.343 L226.366 604.343 L238.172 573.719 L221.574 573.719 L221.574 569.783 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M252.963 569.783 L271.32 569.783 L271.32 573.719 L257.246 573.719 L257.246 582.191 Q258.264 581.844 259.283 581.681 Q260.301 581.496 261.32 581.496 Q267.107 581.496 270.486 584.668 Q273.866 587.839 273.866 593.255 Q273.866 598.834 270.394 601.936 Q266.921 605.015 260.602 605.015 Q258.426 605.015 256.158 604.644 Q253.912 604.274 251.505 603.533 L251.505 598.834 Q253.588 599.968 255.81 600.524 Q258.033 601.08 260.509 601.08 Q264.514 601.08 266.852 598.973 Q269.19 596.867 269.19 593.255 Q269.19 589.644 266.852 587.538 Q264.514 585.431 260.509 585.431 Q258.634 585.431 256.759 585.848 Q254.908 586.265 252.963 587.144 L252.963 569.783 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M126.205 276.513 Q122.593 276.513 120.765 280.078 Q118.959 283.619 118.959 290.749 Q118.959 297.856 120.765 301.42 Q122.593 304.962 126.205 304.962 Q129.839 304.962 131.644 301.42 Q133.473 297.856 133.473 290.749 Q133.473 283.619 131.644 280.078 Q129.839 276.513 126.205 276.513 M126.205 272.809 Q132.015 272.809 135.07 277.416 Q138.149 281.999 138.149 290.749 Q138.149 299.476 135.07 304.082 Q132.015 308.666 126.205 308.666 Q120.394 308.666 117.316 304.082 Q114.26 299.476 114.26 290.749 Q114.26 281.999 117.316 277.416 Q120.394 272.809 126.205 272.809 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M146.366 302.115 L151.251 302.115 L151.251 307.994 L146.366 307.994 L146.366 302.115 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M171.436 276.513 Q167.825 276.513 165.996 280.078 Q164.19 283.619 164.19 290.749 Q164.19 297.856 165.996 301.42 Q167.825 304.962 171.436 304.962 Q175.07 304.962 176.876 301.42 Q178.704 297.856 178.704 290.749 Q178.704 283.619 176.876 280.078 Q175.07 276.513 171.436 276.513 M171.436 272.809 Q177.246 272.809 180.301 277.416 Q183.38 281.999 183.38 290.749 Q183.38 299.476 180.301 304.082 Q177.246 308.666 171.436 308.666 Q165.626 308.666 162.547 304.082 Q159.491 299.476 159.491 290.749 Q159.491 281.999 162.547 277.416 Q165.626 272.809 171.436 272.809 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M192.408 304.059 L200.047 304.059 L200.047 277.694 L191.737 279.36 L191.737 275.101 L200 273.434 L204.676 273.434 L204.676 304.059 L212.315 304.059 L212.315 307.994 L192.408 307.994 L192.408 304.059 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M231.76 276.513 Q228.148 276.513 226.32 280.078 Q224.514 283.619 224.514 290.749 Q224.514 297.856 226.32 301.42 Q228.148 304.962 231.76 304.962 Q235.394 304.962 237.199 301.42 Q239.028 297.856 239.028 290.749 Q239.028 283.619 237.199 280.078 Q235.394 276.513 231.76 276.513 M231.76 272.809 Q237.57 272.809 240.625 277.416 Q243.704 281.999 243.704 290.749 Q243.704 299.476 240.625 304.082 Q237.57 308.666 231.76 308.666 Q225.949 308.666 222.871 304.082 Q219.815 299.476 219.815 290.749 Q219.815 281.999 222.871 277.416 Q225.949 272.809 231.76 272.809 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M261.921 276.513 Q258.31 276.513 256.482 280.078 Q254.676 283.619 254.676 290.749 Q254.676 297.856 256.482 301.42 Q258.31 304.962 261.921 304.962 Q265.556 304.962 267.361 301.42 Q269.19 297.856 269.19 290.749 Q269.19 283.619 267.361 280.078 Q265.556 276.513 261.921 276.513 M261.921 272.809 Q267.732 272.809 270.787 277.416 Q273.866 281.999 273.866 290.749 Q273.866 299.476 270.787 304.082 Q267.732 308.666 261.921 308.666 Q256.111 308.666 253.033 304.082 Q249.977 299.476 249.977 290.749 Q249.977 281.999 253.033 277.416 Q256.111 272.809 261.921 272.809 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M44.7161 942.829 L47.5806 942.829 L47.5806 969.756 Q53.6281 969.374 56.8109 966.128 Q59.9619 962.85 59.9619 957.025 Q59.9619 953.651 59.1344 950.5 Q58.3069 947.317 56.6518 944.198 L62.1899 944.198 Q63.5267 947.349 64.227 950.659 Q64.9272 953.969 64.9272 957.375 Q64.9272 965.905 59.9619 970.902 Q54.9967 975.868 46.5303 975.868 Q37.7774 975.868 32.6531 971.157 Q27.4968 966.414 27.4968 958.394 Q27.4968 951.2 32.1438 947.031 Q36.7589 942.829 44.7161 942.829 M42.9973 948.686 Q38.1912 948.75 35.3266 951.391 Q32.4621 954.001 32.4621 958.33 Q32.4621 963.232 35.2312 966.192 Q38.0002 969.12 43.0292 969.565 L42.9973 948.686 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M42.4881 903.585 L64.0042 903.585 L64.0042 909.441 L42.679 909.441 Q37.6183 909.441 35.1038 911.415 Q32.5894 913.388 32.5894 917.335 Q32.5894 922.077 35.6131 924.815 Q38.6368 927.552 43.8567 927.552 L64.0042 927.552 L64.0042 933.44 L28.3562 933.44 L28.3562 927.552 L33.8944 927.552 Q30.6797 925.451 29.0883 922.618 Q27.4968 919.754 27.4968 916.03 Q27.4968 909.887 31.3163 906.736 Q35.1038 903.585 42.4881 903.585 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M44.7161 861.412 L47.5806 861.412 L47.5806 888.339 Q53.6281 887.957 56.8109 884.711 Q59.9619 881.432 59.9619 875.608 Q59.9619 872.234 59.1344 869.083 Q58.3069 865.9 56.6518 862.781 L62.1899 862.781 Q63.5267 865.932 64.227 869.242 Q64.9272 872.552 64.9272 875.958 Q64.9272 884.488 59.9619 889.485 Q54.9967 894.45 46.5303 894.45 Q37.7774 894.45 32.6531 889.739 Q27.4968 884.997 27.4968 876.976 Q27.4968 869.783 32.1438 865.613 Q36.7589 861.412 44.7161 861.412 M42.9973 867.269 Q38.1912 867.332 35.3266 869.974 Q32.4621 872.584 32.4621 876.913 Q32.4621 881.814 35.2312 884.774 Q38.0002 887.702 43.0292 888.148 L42.9973 867.269 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M33.8307 831.143 Q33.2578 832.13 33.0032 833.308 Q32.7167 834.453 32.7167 835.854 Q32.7167 840.819 35.9632 843.493 Q39.1779 846.134 45.2253 846.134 L64.0042 846.134 L64.0042 852.023 L28.3562 852.023 L28.3562 846.134 L33.8944 846.134 Q30.6479 844.288 29.0883 841.328 Q27.4968 838.368 27.4968 834.135 Q27.4968 833.53 27.5923 832.798 Q27.656 832.066 27.8151 831.175 L33.8307 831.143 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M45.7664 802.688 Q39.4007 802.688 35.8996 805.33 Q32.3984 807.94 32.3984 812.683 Q32.3984 817.393 35.8996 820.035 Q39.4007 822.645 45.7664 822.645 Q52.1003 822.645 55.6014 820.035 Q59.1026 817.393 59.1026 812.683 Q59.1026 807.94 55.6014 805.33 Q52.1003 802.688 45.7664 802.688 M59.58 796.832 Q68.683 796.832 73.1071 800.874 Q77.5631 804.916 77.5631 813.256 Q77.5631 816.343 77.0857 819.08 Q76.6401 821.817 75.6852 824.396 L69.9879 824.396 Q71.3884 821.817 72.0568 819.303 Q72.7252 816.788 72.7252 814.179 Q72.7252 808.418 69.7015 805.553 Q66.7096 802.688 60.6303 802.688 L57.7339 802.688 Q60.885 804.503 62.4446 807.335 Q64.0042 810.168 64.0042 814.115 Q64.0042 820.672 59.0071 824.682 Q54.01 828.692 45.7664 828.692 Q37.491 828.692 32.4939 824.682 Q27.4968 820.672 27.4968 814.115 Q27.4968 810.168 29.0564 807.335 Q30.616 804.503 33.7671 802.688 L28.3562 802.688 L28.3562 796.832 L59.58 796.832 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M67.3143 769.937 Q73.68 772.42 75.6216 774.775 Q77.5631 777.13 77.5631 781.077 L77.5631 785.756 L72.6615 785.756 L72.6615 782.318 Q72.6615 779.899 71.5157 778.562 Q70.3699 777.226 66.1048 775.602 L63.4312 774.552 L28.3562 788.97 L28.3562 782.764 L56.238 771.624 L28.3562 760.484 L28.3562 754.277 L67.3143 769.937 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M33.7671 702.015 L14.479 702.015 L14.479 696.158 L64.0042 696.158 L64.0042 702.015 L58.657 702.015 Q61.8398 703.861 63.3994 706.694 Q64.9272 709.495 64.9272 713.441 Q64.9272 719.902 59.771 723.976 Q54.6147 728.019 46.212 728.019 Q37.8093 728.019 32.6531 723.976 Q27.4968 719.902 27.4968 713.441 Q27.4968 709.495 29.0564 706.694 Q30.5842 703.861 33.7671 702.015 M46.212 721.971 Q52.6732 721.971 56.3653 719.33 Q60.0256 716.656 60.0256 712.009 Q60.0256 707.362 56.3653 704.688 Q52.6732 702.015 46.212 702.015 Q39.7508 702.015 36.0905 704.688 Q32.3984 707.362 32.3984 712.009 Q32.3984 716.656 36.0905 719.33 Q39.7508 721.971 46.212 721.971 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M44.7161 653.604 L47.5806 653.604 L47.5806 680.531 Q53.6281 680.149 56.8109 676.902 Q59.9619 673.624 59.9619 667.799 Q59.9619 664.425 59.1344 661.274 Q58.3069 658.091 56.6518 654.972 L62.1899 654.972 Q63.5267 658.123 64.227 661.433 Q64.9272 664.744 64.9272 668.149 Q64.9272 676.679 59.9619 681.676 Q54.9967 686.642 46.5303 686.642 Q37.7774 686.642 32.6531 681.931 Q27.4968 677.189 27.4968 669.168 Q27.4968 661.975 32.1438 657.805 Q36.7589 653.604 44.7161 653.604 M42.9973 659.46 Q38.1912 659.524 35.3266 662.165 Q32.4621 664.775 32.4621 669.104 Q32.4621 674.006 35.2312 676.966 Q38.0002 679.894 43.0292 680.34 L42.9973 659.46 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M42.4881 614.359 L64.0042 614.359 L64.0042 620.215 L42.679 620.215 Q37.6183 620.215 35.1038 622.189 Q32.5894 624.162 32.5894 628.109 Q32.5894 632.851 35.6131 635.589 Q38.6368 638.326 43.8567 638.326 L64.0042 638.326 L64.0042 644.214 L28.3562 644.214 L28.3562 638.326 L33.8944 638.326 Q30.6797 636.225 29.0883 633.392 Q27.4968 630.528 27.4968 626.804 Q27.4968 620.661 31.3163 617.51 Q35.1038 614.359 42.4881 614.359 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M29.4065 579.952 L34.9447 579.952 Q33.6716 582.435 33.035 585.109 Q32.3984 587.782 32.3984 590.647 Q32.3984 595.007 33.7352 597.203 Q35.072 599.368 37.7456 599.368 Q39.7826 599.368 40.9603 597.808 Q42.1061 596.249 43.1565 591.538 L43.6021 589.533 Q44.9389 583.294 47.3897 580.684 Q49.8086 578.043 54.1691 578.043 Q59.1344 578.043 62.0308 581.989 Q64.9272 585.904 64.9272 592.779 Q64.9272 595.644 64.3543 598.763 Q63.8132 601.85 62.6992 605.288 L56.6518 605.288 Q58.3387 602.041 59.198 598.89 Q60.0256 595.739 60.0256 592.652 Q60.0256 588.514 58.6251 586.286 Q57.1929 584.058 54.6147 584.058 Q52.2276 584.058 50.9545 585.682 Q49.6813 587.273 48.5037 592.716 L48.0262 594.753 Q46.8804 600.195 44.5251 602.614 Q42.138 605.033 38.0002 605.033 Q32.9713 605.033 30.2341 601.468 Q27.4968 597.904 27.4968 591.347 Q27.4968 588.1 27.9743 585.236 Q28.4517 582.371 29.4065 579.952 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M28.3562 568.717 L28.3562 562.86 L64.0042 562.86 L64.0042 568.717 L28.3562 568.717 M14.479 568.717 L14.479 562.86 L21.895 562.86 L21.895 568.717 L14.479 568.717 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M18.2347 544.814 L28.3562 544.814 L28.3562 532.751 L32.9077 532.751 L32.9077 544.814 L52.2594 544.814 Q56.6199 544.814 57.8613 543.636 Q59.1026 542.427 59.1026 538.766 L59.1026 532.751 L64.0042 532.751 L64.0042 538.766 Q64.0042 545.546 61.4897 548.124 Q58.9434 550.702 52.2594 550.702 L32.9077 550.702 L32.9077 554.999 L28.3562 554.999 L28.3562 550.702 L18.2347 550.702 L18.2347 544.814 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M67.3143 510.216 Q73.68 512.699 75.6216 515.054 Q77.5631 517.409 77.5631 521.356 L77.5631 526.035 L72.6615 526.035 L72.6615 522.597 Q72.6615 520.178 71.5157 518.842 Q70.3699 517.505 66.1048 515.882 L63.4312 514.831 L28.3562 529.25 L28.3562 523.043 L56.238 511.903 L28.3562 500.763 L28.3562 494.556 L67.3143 510.216 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip672)" style="stroke:#009af9; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="367.683,1099.43 581.823,1363.58 795.962,1347.07 1010.1,1366.35 1224.24,1384.24 1438.38,1384.24 1652.52,1366.35 1866.66,1347.07 2080.8,1363.58 2294.94,1099.43 "/>
<polyline clip-path="url(#clip672)" style="stroke:#e26f46; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="367.683,302.419 581.823,960.915 795.962,374.64 1010.1,299.386 1224.24,86.1857 1438.38,86.1857 1652.52,299.386 1866.66,374.64 2080.8,960.915 2294.94,302.419 "/>
<path clip-path="url(#clip670)" d="M1957.76 248.629 L2284.66 248.629 L2284.66 93.1086 L1957.76 93.1086  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<polyline clip-path="url(#clip670)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1957.76,248.629 2284.66,248.629 2284.66,93.1086 1957.76,93.1086 1957.76,248.629 "/>
<polyline clip-path="url(#clip670)" style="stroke:#009af9; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1980.45,144.949 2116.65,144.949 "/>
<path clip-path="url(#clip670)" d="M2161.59 128.803 L2161.59 133.363 Q2158.93 132.09 2156.57 131.465 Q2154.21 130.84 2152.01 130.84 Q2148.19 130.84 2146.1 132.321 Q2144.04 133.803 2144.04 136.534 Q2144.04 138.826 2145.41 140.007 Q2146.8 141.164 2150.64 141.882 L2153.47 142.46 Q2158.7 143.456 2161.17 145.979 Q2163.67 148.479 2163.67 152.692 Q2163.67 157.715 2160.29 160.307 Q2156.94 162.9 2150.43 162.9 Q2147.98 162.9 2145.2 162.344 Q2142.45 161.789 2139.48 160.701 L2139.48 155.886 Q2142.33 157.483 2145.06 158.293 Q2147.79 159.104 2150.43 159.104 Q2154.44 159.104 2156.61 157.53 Q2158.79 155.956 2158.79 153.039 Q2158.79 150.493 2157.22 149.057 Q2155.67 147.622 2152.1 146.905 L2149.25 146.349 Q2144.02 145.307 2141.68 143.085 Q2139.35 140.863 2139.35 136.905 Q2139.35 132.321 2142.56 129.682 Q2145.8 127.044 2151.48 127.044 Q2153.91 127.044 2156.43 127.483 Q2158.95 127.923 2161.59 128.803 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M2186.41 140.701 L2216.08 140.701 L2216.08 144.59 L2186.41 144.59 L2186.41 140.701 M2186.41 150.145 L2216.08 150.145 L2216.08 154.081 L2186.41 154.081 L2186.41 150.145 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M2242.05 158.293 L2249.69 158.293 L2249.69 131.928 L2241.38 133.595 L2241.38 129.335 L2249.65 127.669 L2254.32 127.669 L2254.32 158.293 L2261.96 158.293 L2261.96 162.229 L2242.05 162.229 L2242.05 158.293 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip670)" style="stroke:#e26f46; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1980.45,196.789 2116.65,196.789 "/>
<path clip-path="url(#clip670)" d="M2161.59 180.643 L2161.59 185.203 Q2158.93 183.93 2156.57 183.305 Q2154.21 182.68 2152.01 182.68 Q2148.19 182.68 2146.1 184.161 Q2144.04 185.643 2144.04 188.374 Q2144.04 190.666 2145.41 191.847 Q2146.8 193.004 2150.64 193.722 L2153.47 194.3 Q2158.7 195.296 2161.17 197.819 Q2163.67 200.319 2163.67 204.532 Q2163.67 209.555 2160.29 212.147 Q2156.94 214.74 2150.43 214.74 Q2147.98 214.74 2145.2 214.184 Q2142.45 213.629 2139.48 212.541 L2139.48 207.726 Q2142.33 209.323 2145.06 210.133 Q2147.79 210.944 2150.43 210.944 Q2154.44 210.944 2156.61 209.37 Q2158.79 207.796 2158.79 204.879 Q2158.79 202.333 2157.22 200.897 Q2155.67 199.462 2152.1 198.745 L2149.25 198.189 Q2144.02 197.147 2141.68 194.925 Q2139.35 192.703 2139.35 188.745 Q2139.35 184.161 2142.56 181.522 Q2145.8 178.884 2151.48 178.884 Q2153.91 178.884 2156.43 179.323 Q2158.95 179.763 2161.59 180.643 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M2186.41 192.541 L2216.08 192.541 L2216.08 196.43 L2186.41 196.43 L2186.41 192.541 M2186.41 201.985 L2216.08 201.985 L2216.08 205.921 L2186.41 205.921 L2186.41 201.985 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip670)" d="M2245.27 210.133 L2261.59 210.133 L2261.59 214.069 L2239.65 214.069 L2239.65 210.133 Q2242.31 207.379 2246.89 202.749 Q2251.5 198.096 2252.68 196.754 Q2254.92 194.231 2255.8 192.495 Q2256.71 190.735 2256.71 189.046 Q2256.71 186.291 2254.76 184.555 Q2252.84 182.819 2249.74 182.819 Q2247.54 182.819 2245.09 183.583 Q2242.66 184.347 2239.88 185.897 L2239.88 181.175 Q2242.7 180.041 2245.16 179.462 Q2247.61 178.884 2249.65 178.884 Q2255.02 178.884 2258.21 181.569 Q2261.41 184.254 2261.41 188.745 Q2261.41 190.874 2260.6 192.796 Q2259.81 194.694 2257.7 197.286 Q2257.12 197.958 2254.02 201.175 Q2250.92 204.37 2245.27 210.133 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /></svg>

```

Finally, we can obtain a value for the Haldane gap by extrapolating our results for different system sizes.

````julia
Ls = 12:4:30
ΔEs = map(Ls) do L
    @info "computing L = $L"
    ψ₀ = FiniteMPS(rand, ComplexF64, L, physical_space, virtual_space)
    ψ, envs, delta = find_groundstate(ψ₀, H, DMRG(; verbose=false))
    En_1, st_1 = excitations(H, QuasiparticleAnsatz(), ψ, envs; sector=SU2Irrep(1))
    En_2, st_2 = excitations(H, QuasiparticleAnsatz(), ψ, envs; sector=SU2Irrep(2))
    return real(En_2[1] - En_1[1])
end

f = fit(Ls .^ (-2), ΔEs, 1)
ΔE_extrapolated = f.coeffs[1]
````

````
0.4517340158583934
````

````julia
p_size_extrapolation = plot(; xaxis="L^(-2)", yaxis="ΔE", xlims=(0, 0.015))
plot!(p_size_extrapolation, Ls .^ (-2), ΔEs; seriestype=:scatter, label="numerical")
plot!(p_size_extrapolation, x -> f(x); label="fit")
````

```@raw html
<?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="600" height="400" viewBox="0 0 2400 1600">
<defs>
  <clipPath id="clip700">
    <rect x="0" y="0" width="2400" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip700)" d="M0 1600 L2400 1600 L2400 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip701">
    <rect x="480" y="0" width="1681" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip700)" d="M219.542 1423.18 L2352.76 1423.18 L2352.76 47.2441 L219.542 47.2441  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip702">
    <rect x="219" y="47" width="2134" height="1377"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip702)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.542,1423.18 219.542,47.2441 "/>
<polyline clip-path="url(#clip702)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="930.613,1423.18 930.613,47.2441 "/>
<polyline clip-path="url(#clip702)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1641.68,1423.18 1641.68,47.2441 "/>
<polyline clip-path="url(#clip702)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2352.76,1423.18 2352.76,47.2441 "/>
<polyline clip-path="url(#clip700)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.542,1423.18 2352.76,1423.18 "/>
<polyline clip-path="url(#clip700)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.542,1423.18 219.542,1404.28 "/>
<polyline clip-path="url(#clip700)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="930.613,1423.18 930.613,1404.28 "/>
<polyline clip-path="url(#clip700)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1641.68,1423.18 1641.68,1404.28 "/>
<polyline clip-path="url(#clip700)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2352.76,1423.18 2352.76,1404.28 "/>
<path clip-path="url(#clip700)" d="M166.765 1454.1 Q163.154 1454.1 161.325 1457.66 Q159.519 1461.2 159.519 1468.33 Q159.519 1475.44 161.325 1479.01 Q163.154 1482.55 166.765 1482.55 Q170.399 1482.55 172.204 1479.01 Q174.033 1475.44 174.033 1468.33 Q174.033 1461.2 172.204 1457.66 Q170.399 1454.1 166.765 1454.1 M166.765 1450.39 Q172.575 1450.39 175.63 1455 Q178.709 1459.58 178.709 1468.33 Q178.709 1477.06 175.63 1481.67 Q172.575 1486.25 166.765 1486.25 Q160.955 1486.25 157.876 1481.67 Q154.82 1477.06 154.82 1468.33 Q154.82 1459.58 157.876 1455 Q160.955 1450.39 166.765 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M186.927 1479.7 L191.811 1479.7 L191.811 1485.58 L186.927 1485.58 L186.927 1479.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M211.996 1454.1 Q208.385 1454.1 206.556 1457.66 Q204.751 1461.2 204.751 1468.33 Q204.751 1475.44 206.556 1479.01 Q208.385 1482.55 211.996 1482.55 Q215.63 1482.55 217.436 1479.01 Q219.264 1475.44 219.264 1468.33 Q219.264 1461.2 217.436 1457.66 Q215.63 1454.1 211.996 1454.1 M211.996 1450.39 Q217.806 1450.39 220.862 1455 Q223.94 1459.58 223.94 1468.33 Q223.94 1477.06 220.862 1481.67 Q217.806 1486.25 211.996 1486.25 Q206.186 1486.25 203.107 1481.67 Q200.052 1477.06 200.052 1468.33 Q200.052 1459.58 203.107 1455 Q206.186 1450.39 211.996 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M242.158 1454.1 Q238.547 1454.1 236.718 1457.66 Q234.912 1461.2 234.912 1468.33 Q234.912 1475.44 236.718 1479.01 Q238.547 1482.55 242.158 1482.55 Q245.792 1482.55 247.598 1479.01 Q249.426 1475.44 249.426 1468.33 Q249.426 1461.2 247.598 1457.66 Q245.792 1454.1 242.158 1454.1 M242.158 1450.39 Q247.968 1450.39 251.024 1455 Q254.102 1459.58 254.102 1468.33 Q254.102 1477.06 251.024 1481.67 Q247.968 1486.25 242.158 1486.25 Q236.348 1486.25 233.269 1481.67 Q230.213 1477.06 230.213 1468.33 Q230.213 1459.58 233.269 1455 Q236.348 1450.39 242.158 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M272.32 1454.1 Q268.709 1454.1 266.88 1457.66 Q265.074 1461.2 265.074 1468.33 Q265.074 1475.44 266.88 1479.01 Q268.709 1482.55 272.32 1482.55 Q275.954 1482.55 277.759 1479.01 Q279.588 1475.44 279.588 1468.33 Q279.588 1461.2 277.759 1457.66 Q275.954 1454.1 272.32 1454.1 M272.32 1450.39 Q278.13 1450.39 281.185 1455 Q284.264 1459.58 284.264 1468.33 Q284.264 1477.06 281.185 1481.67 Q278.13 1486.25 272.32 1486.25 Q266.51 1486.25 263.431 1481.67 Q260.375 1477.06 260.375 1468.33 Q260.375 1459.58 263.431 1455 Q266.51 1450.39 272.32 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M878.334 1454.1 Q874.723 1454.1 872.894 1457.66 Q871.088 1461.2 871.088 1468.33 Q871.088 1475.44 872.894 1479.01 Q874.723 1482.55 878.334 1482.55 Q881.968 1482.55 883.773 1479.01 Q885.602 1475.44 885.602 1468.33 Q885.602 1461.2 883.773 1457.66 Q881.968 1454.1 878.334 1454.1 M878.334 1450.39 Q884.144 1450.39 887.199 1455 Q890.278 1459.58 890.278 1468.33 Q890.278 1477.06 887.199 1481.67 Q884.144 1486.25 878.334 1486.25 Q872.523 1486.25 869.445 1481.67 Q866.389 1477.06 866.389 1468.33 Q866.389 1459.58 869.445 1455 Q872.523 1450.39 878.334 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M898.496 1479.7 L903.38 1479.7 L903.38 1485.58 L898.496 1485.58 L898.496 1479.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M923.565 1454.1 Q919.954 1454.1 918.125 1457.66 Q916.32 1461.2 916.32 1468.33 Q916.32 1475.44 918.125 1479.01 Q919.954 1482.55 923.565 1482.55 Q927.199 1482.55 929.005 1479.01 Q930.833 1475.44 930.833 1468.33 Q930.833 1461.2 929.005 1457.66 Q927.199 1454.1 923.565 1454.1 M923.565 1450.39 Q929.375 1450.39 932.431 1455 Q935.509 1459.58 935.509 1468.33 Q935.509 1477.06 932.431 1481.67 Q929.375 1486.25 923.565 1486.25 Q917.755 1486.25 914.676 1481.67 Q911.62 1477.06 911.62 1468.33 Q911.62 1459.58 914.676 1455 Q917.755 1450.39 923.565 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M953.727 1454.1 Q950.116 1454.1 948.287 1457.66 Q946.481 1461.2 946.481 1468.33 Q946.481 1475.44 948.287 1479.01 Q950.116 1482.55 953.727 1482.55 Q957.361 1482.55 959.167 1479.01 Q960.995 1475.44 960.995 1468.33 Q960.995 1461.2 959.167 1457.66 Q957.361 1454.1 953.727 1454.1 M953.727 1450.39 Q959.537 1450.39 962.592 1455 Q965.671 1459.58 965.671 1468.33 Q965.671 1477.06 962.592 1481.67 Q959.537 1486.25 953.727 1486.25 Q947.917 1486.25 944.838 1481.67 Q941.782 1477.06 941.782 1468.33 Q941.782 1459.58 944.838 1455 Q947.917 1450.39 953.727 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M973.935 1451.02 L992.291 1451.02 L992.291 1454.96 L978.217 1454.96 L978.217 1463.43 Q979.236 1463.08 980.254 1462.92 Q981.273 1462.73 982.291 1462.73 Q988.078 1462.73 991.458 1465.9 Q994.838 1469.08 994.838 1474.49 Q994.838 1480.07 991.365 1483.17 Q987.893 1486.25 981.574 1486.25 Q979.398 1486.25 977.129 1485.88 Q974.884 1485.51 972.477 1484.77 L972.477 1480.07 Q974.56 1481.2 976.782 1481.76 Q979.004 1482.32 981.481 1482.32 Q985.486 1482.32 987.824 1480.21 Q990.162 1478.1 990.162 1474.49 Q990.162 1470.88 987.824 1468.77 Q985.486 1466.67 981.481 1466.67 Q979.606 1466.67 977.731 1467.08 Q975.879 1467.5 973.935 1468.38 L973.935 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M1588.91 1454.1 Q1585.3 1454.1 1583.47 1457.66 Q1581.66 1461.2 1581.66 1468.33 Q1581.66 1475.44 1583.47 1479.01 Q1585.3 1482.55 1588.91 1482.55 Q1592.54 1482.55 1594.35 1479.01 Q1596.18 1475.44 1596.18 1468.33 Q1596.18 1461.2 1594.35 1457.66 Q1592.54 1454.1 1588.91 1454.1 M1588.91 1450.39 Q1594.72 1450.39 1597.77 1455 Q1600.85 1459.58 1600.85 1468.33 Q1600.85 1477.06 1597.77 1481.67 Q1594.72 1486.25 1588.91 1486.25 Q1583.1 1486.25 1580.02 1481.67 Q1576.96 1477.06 1576.96 1468.33 Q1576.96 1459.58 1580.02 1455 Q1583.1 1450.39 1588.91 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M1609.07 1479.7 L1613.95 1479.7 L1613.95 1485.58 L1609.07 1485.58 L1609.07 1479.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M1634.14 1454.1 Q1630.53 1454.1 1628.7 1457.66 Q1626.89 1461.2 1626.89 1468.33 Q1626.89 1475.44 1628.7 1479.01 Q1630.53 1482.55 1634.14 1482.55 Q1637.77 1482.55 1639.58 1479.01 Q1641.41 1475.44 1641.41 1468.33 Q1641.41 1461.2 1639.58 1457.66 Q1637.77 1454.1 1634.14 1454.1 M1634.14 1450.39 Q1639.95 1450.39 1643 1455 Q1646.08 1459.58 1646.08 1468.33 Q1646.08 1477.06 1643 1481.67 Q1639.95 1486.25 1634.14 1486.25 Q1628.33 1486.25 1625.25 1481.67 Q1622.19 1477.06 1622.19 1468.33 Q1622.19 1459.58 1625.25 1455 Q1628.33 1450.39 1634.14 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M1655.11 1481.64 L1662.75 1481.64 L1662.75 1455.28 L1654.44 1456.95 L1654.44 1452.69 L1662.7 1451.02 L1667.38 1451.02 L1667.38 1481.64 L1675.02 1481.64 L1675.02 1485.58 L1655.11 1485.58 L1655.11 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M1694.46 1454.1 Q1690.85 1454.1 1689.02 1457.66 Q1687.22 1461.2 1687.22 1468.33 Q1687.22 1475.44 1689.02 1479.01 Q1690.85 1482.55 1694.46 1482.55 Q1698.1 1482.55 1699.9 1479.01 Q1701.73 1475.44 1701.73 1468.33 Q1701.73 1461.2 1699.9 1457.66 Q1698.1 1454.1 1694.46 1454.1 M1694.46 1450.39 Q1700.27 1450.39 1703.33 1455 Q1706.41 1459.58 1706.41 1468.33 Q1706.41 1477.06 1703.33 1481.67 Q1700.27 1486.25 1694.46 1486.25 Q1688.65 1486.25 1685.57 1481.67 Q1682.52 1477.06 1682.52 1468.33 Q1682.52 1459.58 1685.57 1455 Q1688.65 1450.39 1694.46 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M2300.48 1454.1 Q2296.87 1454.1 2295.04 1457.66 Q2293.23 1461.2 2293.23 1468.33 Q2293.23 1475.44 2295.04 1479.01 Q2296.87 1482.55 2300.48 1482.55 Q2304.11 1482.55 2305.92 1479.01 Q2307.74 1475.44 2307.74 1468.33 Q2307.74 1461.2 2305.92 1457.66 Q2304.11 1454.1 2300.48 1454.1 M2300.48 1450.39 Q2306.29 1450.39 2309.34 1455 Q2312.42 1459.58 2312.42 1468.33 Q2312.42 1477.06 2309.34 1481.67 Q2306.29 1486.25 2300.48 1486.25 Q2294.67 1486.25 2291.59 1481.67 Q2288.53 1477.06 2288.53 1468.33 Q2288.53 1459.58 2291.59 1455 Q2294.67 1450.39 2300.48 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M2320.64 1479.7 L2325.52 1479.7 L2325.52 1485.58 L2320.64 1485.58 L2320.64 1479.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M2345.71 1454.1 Q2342.1 1454.1 2340.27 1457.66 Q2338.46 1461.2 2338.46 1468.33 Q2338.46 1475.44 2340.27 1479.01 Q2342.1 1482.55 2345.71 1482.55 Q2349.34 1482.55 2351.15 1479.01 Q2352.98 1475.44 2352.98 1468.33 Q2352.98 1461.2 2351.15 1457.66 Q2349.34 1454.1 2345.71 1454.1 M2345.71 1450.39 Q2351.52 1450.39 2354.57 1455 Q2357.65 1459.58 2357.65 1468.33 Q2357.65 1477.06 2354.57 1481.67 Q2351.52 1486.25 2345.71 1486.25 Q2339.9 1486.25 2336.82 1481.67 Q2333.76 1477.06 2333.76 1468.33 Q2333.76 1459.58 2336.82 1455 Q2339.9 1450.39 2345.71 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M2366.68 1481.64 L2374.32 1481.64 L2374.32 1455.28 L2366.01 1456.95 L2366.01 1452.69 L2374.27 1451.02 L2378.95 1451.02 L2378.95 1481.64 L2386.59 1481.64 L2386.59 1485.58 L2366.68 1485.58 L2366.68 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M2396.08 1451.02 L2414.43 1451.02 L2414.43 1454.96 L2400.36 1454.96 L2400.36 1463.43 Q2401.38 1463.08 2402.4 1462.92 Q2403.42 1462.73 2404.43 1462.73 Q2410.22 1462.73 2413.6 1465.9 Q2416.98 1469.08 2416.98 1474.49 Q2416.98 1480.07 2413.51 1483.17 Q2410.04 1486.25 2403.72 1486.25 Q2401.54 1486.25 2399.27 1485.88 Q2397.03 1485.51 2394.62 1484.77 L2394.62 1480.07 Q2396.7 1481.2 2398.92 1481.76 Q2401.15 1482.32 2403.62 1482.32 Q2407.63 1482.32 2409.97 1480.21 Q2412.3 1478.1 2412.3 1474.49 Q2412.3 1470.88 2409.97 1468.77 Q2407.63 1466.67 2403.62 1466.67 Q2401.75 1466.67 2399.87 1467.08 Q2398.02 1467.5 2396.08 1468.38 L2396.08 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M1188.75 1520.52 L1195.18 1520.52 L1195.18 1562.63 L1218.32 1562.63 L1218.32 1568.04 L1188.75 1568.04 L1188.75 1520.52 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M1249.1 1520.52 L1266.38 1538.25 L1259.99 1538.25 L1245.98 1525.68 L1231.98 1538.25 L1225.58 1538.25 L1242.86 1520.52 L1249.1 1520.52 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M1293.5 1518.58 Q1289.24 1525.9 1287.17 1533.06 Q1285.1 1540.23 1285.1 1547.58 Q1285.1 1554.93 1287.17 1562.16 Q1289.27 1569.35 1293.5 1576.64 L1288.41 1576.64 Q1283.63 1569.16 1281.25 1561.93 Q1278.89 1554.71 1278.89 1547.58 Q1278.89 1540.48 1281.25 1533.29 Q1283.6 1526.09 1288.41 1518.58 L1293.5 1518.58 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M1301.9 1547.58 L1319.06 1547.58 L1319.06 1552.8 L1301.9 1552.8 L1301.9 1547.58 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M1334.75 1562.63 L1357.19 1562.63 L1357.19 1568.04 L1327.02 1568.04 L1327.02 1562.63 Q1330.68 1558.85 1336.98 1552.48 Q1343.31 1546.08 1344.94 1544.24 Q1348.02 1540.77 1349.23 1538.38 Q1350.47 1535.96 1350.47 1533.64 Q1350.47 1529.85 1347.8 1527.46 Q1345.16 1525.08 1340.89 1525.08 Q1337.87 1525.08 1334.5 1526.13 Q1331.15 1527.18 1327.34 1529.31 L1327.34 1522.82 Q1331.22 1521.26 1334.59 1520.46 Q1337.97 1519.66 1340.77 1519.66 Q1348.15 1519.66 1352.54 1523.36 Q1356.94 1527.05 1356.94 1533.22 Q1356.94 1536.15 1355.82 1538.79 Q1354.74 1541.4 1351.84 1544.97 Q1351.05 1545.89 1346.78 1550.32 Q1342.52 1554.71 1334.75 1562.63 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M1368.94 1518.58 L1374.03 1518.58 Q1378.8 1526.09 1381.16 1533.29 Q1383.54 1540.48 1383.54 1547.58 Q1383.54 1554.71 1381.16 1561.93 Q1378.8 1569.16 1374.03 1576.64 L1368.94 1576.64 Q1373.17 1569.35 1375.24 1562.16 Q1377.34 1554.93 1377.34 1547.58 Q1377.34 1540.23 1375.24 1533.06 Q1373.17 1525.9 1368.94 1518.58 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip702)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.542,1266.1 2352.76,1266.1 "/>
<polyline clip-path="url(#clip702)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.542,1021.35 2352.76,1021.35 "/>
<polyline clip-path="url(#clip702)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.542,776.59 2352.76,776.59 "/>
<polyline clip-path="url(#clip702)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.542,531.834 2352.76,531.834 "/>
<polyline clip-path="url(#clip702)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.542,287.077 2352.76,287.077 "/>
<polyline clip-path="url(#clip700)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.542,1423.18 219.542,47.2441 "/>
<polyline clip-path="url(#clip700)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.542,1266.1 238.44,1266.1 "/>
<polyline clip-path="url(#clip700)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.542,1021.35 238.44,1021.35 "/>
<polyline clip-path="url(#clip700)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.542,776.59 238.44,776.59 "/>
<polyline clip-path="url(#clip700)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.542,531.834 238.44,531.834 "/>
<polyline clip-path="url(#clip700)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.542,287.077 238.44,287.077 "/>
<path clip-path="url(#clip700)" d="M127.362 1251.9 Q123.751 1251.9 121.922 1255.47 Q120.117 1259.01 120.117 1266.14 Q120.117 1273.25 121.922 1276.81 Q123.751 1280.35 127.362 1280.35 Q130.996 1280.35 132.802 1276.81 Q134.63 1273.25 134.63 1266.14 Q134.63 1259.01 132.802 1255.47 Q130.996 1251.9 127.362 1251.9 M127.362 1248.2 Q133.172 1248.2 136.228 1252.81 Q139.306 1257.39 139.306 1266.14 Q139.306 1274.87 136.228 1279.47 Q133.172 1284.06 127.362 1284.06 Q121.552 1284.06 118.473 1279.47 Q115.418 1274.87 115.418 1266.14 Q115.418 1257.39 118.473 1252.81 Q121.552 1248.2 127.362 1248.2 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M147.524 1277.5 L152.408 1277.5 L152.408 1283.38 L147.524 1283.38 L147.524 1277.5 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M162.64 1248.82 L180.996 1248.82 L180.996 1252.76 L166.922 1252.76 L166.922 1261.23 Q167.94 1260.88 168.959 1260.72 Q169.977 1260.54 170.996 1260.54 Q176.783 1260.54 180.163 1263.71 Q183.542 1266.88 183.542 1272.3 Q183.542 1277.87 180.07 1280.98 Q176.598 1284.06 170.278 1284.06 Q168.102 1284.06 165.834 1283.68 Q163.589 1283.31 161.181 1282.57 L161.181 1277.87 Q163.265 1279.01 165.487 1279.56 Q167.709 1280.12 170.186 1280.12 Q174.19 1280.12 176.528 1278.01 Q178.866 1275.91 178.866 1272.3 Q178.866 1268.68 176.528 1266.58 Q174.19 1264.47 170.186 1264.47 Q168.311 1264.47 166.436 1264.89 Q164.584 1265.31 162.64 1266.19 L162.64 1248.82 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M126.205 1007.15 Q122.593 1007.15 120.765 1010.71 Q118.959 1014.25 118.959 1021.38 Q118.959 1028.49 120.765 1032.05 Q122.593 1035.59 126.205 1035.59 Q129.839 1035.59 131.644 1032.05 Q133.473 1028.49 133.473 1021.38 Q133.473 1014.25 131.644 1010.71 Q129.839 1007.15 126.205 1007.15 M126.205 1003.44 Q132.015 1003.44 135.07 1008.05 Q138.149 1012.63 138.149 1021.38 Q138.149 1030.11 135.07 1034.72 Q132.015 1039.3 126.205 1039.3 Q120.394 1039.3 117.316 1034.72 Q114.26 1030.11 114.26 1021.38 Q114.26 1012.63 117.316 1008.05 Q120.394 1003.44 126.205 1003.44 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M146.366 1032.75 L151.251 1032.75 L151.251 1038.63 L146.366 1038.63 L146.366 1032.75 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M172.014 1019.48 Q168.866 1019.48 167.015 1021.64 Q165.186 1023.79 165.186 1027.54 Q165.186 1031.27 167.015 1033.44 Q168.866 1035.59 172.014 1035.59 Q175.163 1035.59 176.991 1033.44 Q178.843 1031.27 178.843 1027.54 Q178.843 1023.79 176.991 1021.64 Q175.163 1019.48 172.014 1019.48 M181.297 1004.83 L181.297 1009.09 Q179.538 1008.26 177.732 1007.82 Q175.95 1007.38 174.19 1007.38 Q169.561 1007.38 167.107 1010.5 Q164.677 1013.63 164.329 1019.95 Q165.695 1017.93 167.755 1016.87 Q169.815 1015.78 172.292 1015.78 Q177.501 1015.78 180.51 1018.95 Q183.542 1022.1 183.542 1027.54 Q183.542 1032.86 180.394 1036.08 Q177.246 1039.3 172.014 1039.3 Q166.019 1039.3 162.848 1034.72 Q159.677 1030.11 159.677 1021.38 Q159.677 1013.19 163.565 1008.33 Q167.454 1003.44 174.005 1003.44 Q175.764 1003.44 177.547 1003.79 Q179.352 1004.14 181.297 1004.83 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M127.269 762.389 Q123.658 762.389 121.83 765.954 Q120.024 769.496 120.024 776.625 Q120.024 783.732 121.83 787.296 Q123.658 790.838 127.269 790.838 Q130.904 790.838 132.709 787.296 Q134.538 783.732 134.538 776.625 Q134.538 769.496 132.709 765.954 Q130.904 762.389 127.269 762.389 M127.269 758.685 Q133.08 758.685 136.135 763.292 Q139.214 767.875 139.214 776.625 Q139.214 785.352 136.135 789.958 Q133.08 794.542 127.269 794.542 Q121.459 794.542 118.381 789.958 Q115.325 785.352 115.325 776.625 Q115.325 767.875 118.381 763.292 Q121.459 758.685 127.269 758.685 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M147.431 787.991 L152.316 787.991 L152.316 793.87 L147.431 793.87 L147.431 787.991 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M161.32 759.31 L183.542 759.31 L183.542 761.301 L170.996 793.87 L166.112 793.87 L177.917 763.246 L161.32 763.246 L161.32 759.31 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M126.459 517.632 Q122.848 517.632 121.019 521.197 Q119.214 524.739 119.214 531.868 Q119.214 538.975 121.019 542.54 Q122.848 546.081 126.459 546.081 Q130.093 546.081 131.899 542.54 Q133.728 538.975 133.728 531.868 Q133.728 524.739 131.899 521.197 Q130.093 517.632 126.459 517.632 M126.459 513.929 Q132.269 513.929 135.325 518.535 Q138.404 523.118 138.404 531.868 Q138.404 540.595 135.325 545.202 Q132.269 549.785 126.459 549.785 Q120.649 549.785 117.57 545.202 Q114.515 540.595 114.515 531.868 Q114.515 523.118 117.57 518.535 Q120.649 513.929 126.459 513.929 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M146.621 543.234 L151.505 543.234 L151.505 549.114 L146.621 549.114 L146.621 543.234 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M171.69 532.702 Q168.357 532.702 166.436 534.484 Q164.538 536.266 164.538 539.391 Q164.538 542.516 166.436 544.299 Q168.357 546.081 171.69 546.081 Q175.024 546.081 176.945 544.299 Q178.866 542.493 178.866 539.391 Q178.866 536.266 176.945 534.484 Q175.047 532.702 171.69 532.702 M167.015 530.711 Q164.005 529.97 162.315 527.91 Q160.649 525.85 160.649 522.887 Q160.649 518.743 163.589 516.336 Q166.552 513.929 171.69 513.929 Q176.852 513.929 179.792 516.336 Q182.732 518.743 182.732 522.887 Q182.732 525.85 181.042 527.91 Q179.376 529.97 176.389 530.711 Q179.769 531.498 181.644 533.79 Q183.542 536.081 183.542 539.391 Q183.542 544.415 180.464 547.1 Q177.408 549.785 171.69 549.785 Q165.973 549.785 162.894 547.1 Q159.839 544.415 159.839 539.391 Q159.839 536.081 161.737 533.79 Q163.635 531.498 167.015 530.711 M165.302 523.327 Q165.302 526.012 166.968 527.517 Q168.658 529.021 171.69 529.021 Q174.7 529.021 176.389 527.517 Q178.102 526.012 178.102 523.327 Q178.102 520.642 176.389 519.137 Q174.7 517.632 171.69 517.632 Q168.658 517.632 166.968 519.137 Q165.302 520.642 165.302 523.327 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M126.552 272.876 Q122.941 272.876 121.112 276.44 Q119.306 279.982 119.306 287.112 Q119.306 294.218 121.112 297.783 Q122.941 301.324 126.552 301.324 Q130.186 301.324 131.992 297.783 Q133.82 294.218 133.82 287.112 Q133.82 279.982 131.992 276.44 Q130.186 272.876 126.552 272.876 M126.552 269.172 Q132.362 269.172 135.417 273.778 Q138.496 278.362 138.496 287.112 Q138.496 295.838 135.417 300.445 Q132.362 305.028 126.552 305.028 Q120.742 305.028 117.663 300.445 Q114.607 295.838 114.607 287.112 Q114.607 278.362 117.663 273.778 Q120.742 269.172 126.552 269.172 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M146.714 298.477 L151.598 298.477 L151.598 304.357 L146.714 304.357 L146.714 298.477 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M161.922 303.639 L161.922 299.38 Q163.681 300.213 165.487 300.653 Q167.292 301.093 169.028 301.093 Q173.658 301.093 176.089 297.991 Q178.542 294.866 178.889 288.524 Q177.547 290.514 175.487 291.579 Q173.427 292.644 170.927 292.644 Q165.741 292.644 162.709 289.519 Q159.7 286.371 159.7 280.931 Q159.7 275.607 162.848 272.389 Q165.996 269.172 171.227 269.172 Q177.223 269.172 180.371 273.778 Q183.542 278.362 183.542 287.112 Q183.542 295.283 179.653 300.167 Q175.788 305.028 169.237 305.028 Q167.477 305.028 165.672 304.681 Q163.866 304.334 161.922 303.639 M171.227 288.987 Q174.376 288.987 176.204 286.834 Q178.056 284.681 178.056 280.931 Q178.056 277.204 176.204 275.051 Q174.376 272.876 171.227 272.876 Q168.079 272.876 166.227 275.051 Q164.399 277.204 164.399 280.931 Q164.399 284.681 166.227 286.834 Q168.079 288.987 171.227 288.987 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M22.818 753.991 L58.657 767.041 L58.657 740.909 L22.818 753.991 M64.0042 775.762 L16.4842 757.619 L16.4842 750.331 L64.0042 732.22 L64.0042 775.762 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M16.4842 725.281 L16.4842 695.235 L21.895 695.235 L21.895 718.852 L35.9632 718.852 L35.9632 696.222 L41.3741 696.222 L41.3741 718.852 L58.5933 718.852 L58.5933 694.662 L64.0042 694.662 L64.0042 725.281 L16.4842 725.281 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><circle clip-path="url(#clip702)" cx="1207.14" cy="796.84" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip702)" cx="775.067" cy="1022.72" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip702)" cx="575.078" cy="1154.23" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip702)" cx="466.442" cy="1237.65" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip702)" cx="400.938" cy="1293.8" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<polyline clip-path="url(#clip702)" style="stroke:#e26f46; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.542,1384.24 233.431,1375.79 361.849,1297.65 439.023,1250.69 504.272,1210.98 575.152,1167.85 640.496,1128.09 710.552,1085.46 791.719,1036.07 863.851,992.179 927.104,953.69 996.067,911.726 1065.44,869.513 1142.14,822.841 1215.12,778.434 1291,732.261 1354.87,693.393 1432.86,645.94 1504.3,602.47 1570.28,562.322 1637.11,521.653 1712.01,476.075 1779.89,434.773 1857.6,387.486 1929.55,343.703 2000.49,300.537 2069.37,258.627 2139.97,215.664 2217.33,168.592 2329.7,100.214 2352.76,86.1857 "/>
<path clip-path="url(#clip700)" d="M290.649 248.629 L731.608 248.629 L731.608 93.1086 L290.649 93.1086  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<polyline clip-path="url(#clip700)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="290.649,248.629 731.608,248.629 731.608,93.1086 290.649,93.1086 290.649,248.629 "/>
<circle clip-path="url(#clip700)" cx="385.459" cy="144.949" r="20.48" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="4.55111"/>
<path clip-path="url(#clip700)" d="M501.981 146.581 L501.981 162.229 L497.722 162.229 L497.722 146.719 Q497.722 143.039 496.287 141.21 Q494.852 139.382 491.981 139.382 Q488.532 139.382 486.541 141.581 Q484.551 143.78 484.551 147.576 L484.551 162.229 L480.268 162.229 L480.268 136.303 L484.551 136.303 L484.551 140.331 Q486.078 137.993 488.139 136.835 Q490.222 135.678 492.93 135.678 Q497.398 135.678 499.69 138.456 Q501.981 141.21 501.981 146.581 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M510.037 151.997 L510.037 136.303 L514.296 136.303 L514.296 151.835 Q514.296 155.516 515.731 157.368 Q517.166 159.196 520.037 159.196 Q523.486 159.196 525.476 156.997 Q527.49 154.798 527.49 151.002 L527.49 136.303 L531.75 136.303 L531.75 162.229 L527.49 162.229 L527.49 158.247 Q525.939 160.608 523.879 161.766 Q521.842 162.9 519.134 162.9 Q514.666 162.9 512.351 160.122 Q510.037 157.344 510.037 151.997 M520.754 135.678 L520.754 135.678 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M560.708 141.28 Q562.305 138.409 564.527 137.044 Q566.749 135.678 569.759 135.678 Q573.809 135.678 576.009 138.525 Q578.208 141.349 578.208 146.581 L578.208 162.229 L573.925 162.229 L573.925 146.719 Q573.925 142.993 572.606 141.187 Q571.286 139.382 568.578 139.382 Q565.268 139.382 563.347 141.581 Q561.425 143.78 561.425 147.576 L561.425 162.229 L557.143 162.229 L557.143 146.719 Q557.143 142.969 555.823 141.187 Q554.504 139.382 551.749 139.382 Q548.486 139.382 546.564 141.604 Q544.643 143.803 544.643 147.576 L544.643 162.229 L540.361 162.229 L540.361 136.303 L544.643 136.303 L544.643 140.331 Q546.101 137.946 548.138 136.812 Q550.175 135.678 552.976 135.678 Q555.8 135.678 557.768 137.113 Q559.759 138.548 560.708 141.28 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M608.879 148.201 L608.879 150.284 L589.296 150.284 Q589.573 154.682 591.934 156.997 Q594.319 159.289 598.555 159.289 Q601.008 159.289 603.3 158.687 Q605.615 158.085 607.883 156.881 L607.883 160.909 Q605.592 161.881 603.184 162.391 Q600.777 162.9 598.3 162.9 Q592.096 162.9 588.462 159.289 Q584.851 155.678 584.851 149.52 Q584.851 143.155 588.277 139.428 Q591.726 135.678 597.559 135.678 Q602.791 135.678 605.823 139.057 Q608.879 142.414 608.879 148.201 M604.619 146.951 Q604.573 143.456 602.652 141.372 Q600.754 139.289 597.606 139.289 Q594.041 139.289 591.888 141.303 Q589.758 143.317 589.434 146.974 L604.619 146.951 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M630.893 140.284 Q630.175 139.868 629.318 139.682 Q628.485 139.474 627.467 139.474 Q623.856 139.474 621.911 141.835 Q619.99 144.173 619.99 148.571 L619.99 162.229 L615.707 162.229 L615.707 136.303 L619.99 136.303 L619.99 140.331 Q621.332 137.969 623.485 136.835 Q625.638 135.678 628.717 135.678 Q629.156 135.678 629.689 135.747 Q630.221 135.794 630.869 135.909 L630.893 140.284 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M635.36 136.303 L639.619 136.303 L639.619 162.229 L635.36 162.229 L635.36 136.303 M635.36 126.21 L639.619 126.21 L639.619 131.604 L635.36 131.604 L635.36 126.21 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M667.189 137.298 L667.189 141.28 Q665.383 140.284 663.554 139.798 Q661.749 139.289 659.897 139.289 Q655.753 139.289 653.462 141.928 Q651.17 144.544 651.17 149.289 Q651.17 154.034 653.462 156.673 Q655.753 159.289 659.897 159.289 Q661.749 159.289 663.554 158.803 Q665.383 158.293 667.189 157.298 L667.189 161.233 Q665.406 162.067 663.485 162.483 Q661.587 162.9 659.434 162.9 Q653.578 162.9 650.129 159.219 Q646.679 155.539 646.679 149.289 Q646.679 142.946 650.152 139.312 Q653.647 135.678 659.712 135.678 Q661.679 135.678 663.554 136.095 Q665.429 136.488 667.189 137.298 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M686.378 149.196 Q681.216 149.196 679.226 150.377 Q677.235 151.557 677.235 154.405 Q677.235 156.673 678.716 158.016 Q680.221 159.335 682.79 159.335 Q686.332 159.335 688.462 156.835 Q690.614 154.312 690.614 150.145 L690.614 149.196 L686.378 149.196 M694.874 147.437 L694.874 162.229 L690.614 162.229 L690.614 158.293 Q689.156 160.655 686.98 161.789 Q684.804 162.9 681.656 162.9 Q677.675 162.9 675.314 160.678 Q672.976 158.432 672.976 154.682 Q672.976 150.307 675.892 148.085 Q678.832 145.863 684.642 145.863 L690.614 145.863 L690.614 145.446 Q690.614 142.507 688.67 140.909 Q686.749 139.289 683.253 139.289 Q681.031 139.289 678.925 139.821 Q676.818 140.354 674.874 141.419 L674.874 137.483 Q677.212 136.581 679.411 136.141 Q681.61 135.678 683.693 135.678 Q689.318 135.678 692.096 138.594 Q694.874 141.511 694.874 147.437 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M703.647 126.21 L707.906 126.21 L707.906 162.229 L703.647 162.229 L703.647 126.21 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip700)" style="stroke:#e26f46; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="314.352,196.789 456.566,196.789 "/>
<path clip-path="url(#clip700)" d="M496.773 178.05 L496.773 181.592 L492.699 181.592 Q490.407 181.592 489.504 182.518 Q488.625 183.444 488.625 185.851 L488.625 188.143 L495.639 188.143 L495.639 191.453 L488.625 191.453 L488.625 214.069 L484.342 214.069 L484.342 191.453 L480.268 191.453 L480.268 188.143 L484.342 188.143 L484.342 186.337 Q484.342 182.009 486.356 180.041 Q488.37 178.05 492.745 178.05 L496.773 178.05 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M500.338 188.143 L504.597 188.143 L504.597 214.069 L500.338 214.069 L500.338 188.143 M500.338 178.05 L504.597 178.05 L504.597 183.444 L500.338 183.444 L500.338 178.05 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip700)" d="M517.722 180.782 L517.722 188.143 L526.495 188.143 L526.495 191.453 L517.722 191.453 L517.722 205.527 Q517.722 208.698 518.578 209.601 Q519.458 210.504 522.12 210.504 L526.495 210.504 L526.495 214.069 L522.12 214.069 Q517.189 214.069 515.314 212.24 Q513.439 210.388 513.439 205.527 L513.439 191.453 L510.314 191.453 L510.314 188.143 L513.439 188.143 L513.439 180.782 L517.722 180.782 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /></svg>

```

## Thermodynamic limit

A much nicer way of obtaining the Haldane gap is by working directly in the thermodynamic limit.
As was already hinted at by the edge modes, this model is in a non-trivial SPT phase.
Thus, care must be taken when selecting the symmetry sectors.
The groundstate has half-integer edge modes, thus the virtual spaces must also all carry half-integer charges.

In contrast with the finite size case, we now should specify a momentum label to the excitations.
This way, it is possible to scan the dispersion relation over the entire momentum space.

````julia
virtual_space_inf = Rep[SU₂](1//2 => 16, 3//2 => 16, 5//2 => 8, 7//2 => 4)
ψ₀_inf = InfiniteMPS([physical_space], [virtual_space_inf])
ψ_inf, envs_inf, delta_inf = find_groundstate(ψ₀_inf, H)

kspace = range(0, π, 16)
Es, _ = excitations(H, QuasiparticleAnsatz(), kspace, ψ_inf, envs_inf; sector=SU2Irrep(1))

ΔE, idx = findmin(real.(Es))
println("minimum @k = $(kspace[idx]):\t ΔE = $(ΔE)")
````

````
┌ Info: VUMPS iteration:
│   iter = 1
│   ϵ = 0.04268530995297446
│   λ = -1.3963107162449016 + 3.507394027990607e-17im
└   Δt = 0.217011673
┌ Info: VUMPS iteration:
│   iter = 2
│   ϵ = 0.0008280539553330787
│   λ = -1.4014807405703544 + 3.7838655819744105e-17im
└   Δt = 0.073612697
┌ Info: VUMPS iteration:
│   iter = 3
│   ϵ = 8.594993596683212e-6
│   λ = -1.401484038606982 + 1.137870180023537e-16im
└   Δt = 0.097377017
┌ Info: VUMPS summary:
│   ϵ = 8.594993596683212e-6
│   λ = -1.401484038606982 + 1.137870180023537e-16im
└   Δt = 1.836941787
[ Info: CG: initializing with f = -1.401484038607, ‖∇f‖ = 3.3921e-05
[ Info: CG: iter    1: f = -1.401484038760, ‖∇f‖ = 3.0643e-05, α = 2.70e-01, β = 0.00e+00, nfg = 5
[ Info: CG: iter    2: f = -1.401484038901, ‖∇f‖ = 1.8481e-05, α = 2.58e-01, β = 7.16e-01, nfg = 2
[ Info: CG: iter    3: f = -1.401484038940, ‖∇f‖ = 9.8340e-06, α = 1.45e-01, β = 3.99e-01, nfg = 2
[ Info: CG: iter    4: f = -1.401484038955, ‖∇f‖ = 7.9721e-06, α = 2.07e-01, β = 3.01e-01, nfg = 2
[ Info: CG: iter    5: f = -1.401484038962, ‖∇f‖ = 4.6666e-06, α = 1.74e-01, β = 3.63e-01, nfg = 2
[ Info: CG: iter    6: f = -1.401484038965, ‖∇f‖ = 3.2472e-06, α = 1.80e-01, β = 3.98e-01, nfg = 2
[ Info: CG: iter    7: f = -1.401484038966, ‖∇f‖ = 2.0985e-06, α = 1.92e-01, β = 3.05e-01, nfg = 2
[ Info: CG: iter    8: f = -1.401484038967, ‖∇f‖ = 1.3631e-06, α = 1.51e-01, β = 4.00e-01, nfg = 2
[ Info: CG: iter    9: f = -1.401484038967, ‖∇f‖ = 9.4314e-07, α = 1.57e-01, β = 3.22e-01, nfg = 2
[ Info: CG: iter   10: f = -1.401484038967, ‖∇f‖ = 5.9640e-07, α = 1.91e-01, β = 3.04e-01, nfg = 2
[ Info: CG: iter   11: f = -1.401484038967, ‖∇f‖ = 4.1018e-07, α = 2.28e-01, β = 2.70e-01, nfg = 2
[ Info: CG: iter   12: f = -1.401484038967, ‖∇f‖ = 3.0584e-07, α = 2.26e-01, β = 4.23e-01, nfg = 2
[ Info: CG: iter   13: f = -1.401484038967, ‖∇f‖ = 1.9390e-07, α = 1.86e-01, β = 5.51e-01, nfg = 2
[ Info: CG: iter   14: f = -1.401484038967, ‖∇f‖ = 1.4295e-07, α = 1.84e-01, β = 4.12e-01, nfg = 2
[ Info: CG: iter   15: f = -1.401484038967, ‖∇f‖ = 1.3737e-07, α = 1.95e-01, β = 5.50e-01, nfg = 2
[ Info: CG: iter   16: f = -1.401484038967, ‖∇f‖ = 1.3177e-07, α = 3.57e-02, β = 1.43e+00, nfg = 2
[ Info: CG: iter   17: f = -1.401484038967, ‖∇f‖ = 7.5018e-08, α = 7.33e-02, β = 5.42e-01, nfg = 3
[ Info: CG: iter   18: f = -1.401484038967, ‖∇f‖ = 5.5263e-08, α = 1.78e-01, β = 1.81e-02, nfg = 3
[ Info: CG: iter   19: f = -1.401484038967, ‖∇f‖ = 3.6101e-08, α = 1.72e-01, β = 5.42e-01, nfg = 2
[ Info: CG: iter   20: f = -1.401484038967, ‖∇f‖ = 2.2078e-08, α = 1.72e-01, β = 4.29e-01, nfg = 2
[ Info: CG: iter   21: f = -1.401484038967, ‖∇f‖ = 1.4396e-08, α = 1.75e-01, β = 3.78e-01, nfg = 2
[ Info: CG: iter   22: f = -1.401484038967, ‖∇f‖ = 8.3158e-09, α = 1.67e-01, β = 4.44e-01, nfg = 2
[ Info: CG: iter   23: f = -1.401484038967, ‖∇f‖ = 5.0538e-09, α = 1.55e-01, β = 3.26e-01, nfg = 2
[ Info: CG: iter   24: f = -1.401484038967, ‖∇f‖ = 2.8922e-09, α = 1.82e-01, β = 3.38e-01, nfg = 2
[ Info: CG: iter   25: f = -1.401484038967, ‖∇f‖ = 2.1794e-09, α = 1.52e-01, β = 2.51e-01, nfg = 2
[ Info: CG: iter   26: f = -1.401484038967, ‖∇f‖ = 1.7251e-09, α = 2.00e-01, β = 6.36e-01, nfg = 2
[ Info: CG: iter   27: f = -1.401484038967, ‖∇f‖ = 1.3474e-09, α = 1.68e-01, β = 5.92e-01, nfg = 2
[ Info: CG: iter   28: f = -1.401484038967, ‖∇f‖ = 1.1966e-09, α = 1.50e-01, β = 1.54e-01, nfg = 2
[ Info: CG: iter   29: f = -1.401484038967, ‖∇f‖ = 9.2191e-10, α = 1.17e-01, β = 7.29e-01, nfg = 2
[ Info: CG: iter   30: f = -1.401484038967, ‖∇f‖ = 8.5490e-10, α = 1.24e-01, β = 6.32e-02, nfg = 2
[ Info: CG: iter   31: f = -1.401484038967, ‖∇f‖ = 1.0393e-09, α = 8.14e-02, β = 1.55e+00, nfg = 2
[ Info: CG: iter   32: f = -1.401484038967, ‖∇f‖ = 7.2909e-10, α = 1.03e-01, β = 1.98e-01, nfg = 2
[ Info: CG: iter   33: f = -1.401484038967, ‖∇f‖ = 1.0060e-09, α = 8.82e-02, β = 1.00e+00, nfg = 2
[ Info: CG: iter   34: f = -1.401484038967, ‖∇f‖ = 6.0933e-10, α = 2.01e-01, β = 6.24e-01, nfg = 3
[ Info: CG: iter   35: f = -1.401484038967, ‖∇f‖ = 8.4571e-10, α = 1.06e-01, β = 6.81e-02, nfg = 2
[ Info: CG: iter   36: f = -1.401484038967, ‖∇f‖ = 1.8576e-09, α = 8.83e-02, β = 1.65e+00, nfg = 2
[ Info: CG: iter   37: f = -1.401484038967, ‖∇f‖ = 1.3589e-09, α = 1.70e-03, β = 5.87e+00, nfg = 5
[ Info: CG: iter   38: f = -1.401484038967, ‖∇f‖ = 1.2674e-09, α = 4.66e-03, β = 1.38e+00, nfg = 4
[ Info: CG: iter   39: f = -1.401484038967, ‖∇f‖ = 6.7684e-10, α = 9.34e-02, β = 2.77e-02, nfg = 4
[ Info: CG: iter   40: f = -1.401484038967, ‖∇f‖ = 1.2855e-09, α = 3.84e-01, β = 3.34e-01, nfg = 3
[ Info: CG: iter   41: f = -1.401484038967, ‖∇f‖ = 1.7260e-09, α = 7.00e-02, β = 5.78e+00, nfg = 2
[ Info: CG: iter   42: f = -1.401484038967, ‖∇f‖ = 1.1149e-09, α = 1.14e-01, β = 2.58e-02, nfg = 2
[ Info: CG: iter   43: f = -1.401484038967, ‖∇f‖ = 1.2761e-09, α = 1.48e-01, β = 6.39e-01, nfg = 2
[ Info: CG: iter   44: f = -1.401484038967, ‖∇f‖ = 1.5957e-09, α = 1.32e-01, β = 2.04e-01, nfg = 2
[ Info: CG: iter   45: f = -1.401484038967, ‖∇f‖ = 1.3479e-09, α = 1.52e-01, β = 6.52e-01, nfg = 2
[ Info: CG: iter   46: f = -1.401484038967, ‖∇f‖ = 1.0654e-09, α = 1.29e-01, β = 6.60e-01, nfg = 2
[ Info: CG: iter   47: f = -1.401484038967, ‖∇f‖ = 1.0871e-09, α = 8.82e-02, β = 1.26e+00, nfg = 2
[ Info: CG: iter   48: f = -1.401484038967, ‖∇f‖ = 1.3893e-09, α = 2.46e-01, β = 1.07e-01, nfg = 3
[ Info: CG: iter   49: f = -1.401484038967, ‖∇f‖ = 9.0722e-10, α = 1.37e-01, β = 5.91e-02, nfg = 2
[ Info: CG: iter   50: f = -1.401484038967, ‖∇f‖ = 1.6769e-09, α = 3.40e-01, β = 2.94e-01, nfg = 3
[ Info: CG: iter   51: f = -1.401484038967, ‖∇f‖ = 1.7309e-09, α = 1.11e-04, β = 4.41e+01, nfg = 6
[ Info: CG: iter   52: f = -1.401484038967, ‖∇f‖ = 1.6321e-09, α = 2.25e-02, β = 2.40e-02, nfg = 5
[ Info: CG: iter   53: f = -1.401484038967, ‖∇f‖ = 7.7545e-10, α = 4.35e-02, β = 7.13e-01, nfg = 2
[ Info: CG: iter   54: f = -1.401484038967, ‖∇f‖ = 4.2970e-10, α = 3.82e-02, β = -2.20e-02, nfg = 2
[ Info: CG: iter   55: f = -1.401484038967, ‖∇f‖ = 4.3023e-10, α = 2.18e-01, β = 3.17e-01, nfg = 3
[ Info: CG: iter   56: f = -1.401484038967, ‖∇f‖ = 1.6354e-09, α = 1.26e-01, β = 9.35e-02, nfg = 2
[ Info: CG: iter   57: f = -1.401484038967, ‖∇f‖ = 1.0235e-09, α = 1.77e-02, β = 1.34e+01, nfg = 2
┌ Warning: resorting to η
└ @ OptimKit ~/.julia/packages/OptimKit/xpmbV/src/cg.jl:139
[ Info: CG: iter   58: f = -1.401484038967, ‖∇f‖ = 3.7642e-10, α = 9.19e-02, β = -3.24e-02, nfg = 3
[ Info: CG: iter   59: f = -1.401484038967, ‖∇f‖ = 1.4189e-09, α = 2.20e-01, β = 5.62e-02, nfg = 3
[ Info: CG: iter   60: f = -1.401484038967, ‖∇f‖ = 7.8601e-10, α = 1.93e-01, β = 4.07e-01, nfg = 2
[ Info: CG: iter   61: f = -1.401484038967, ‖∇f‖ = 2.8737e-10, α = 1.00e-01, β = 8.51e-02, nfg = 2
[ Info: CG: iter   62: f = -1.401484038967, ‖∇f‖ = 4.0880e-10, α = 9.49e-02, β = 1.02e-01, nfg = 2
[ Info: CG: iter   63: f = -1.401484038967, ‖∇f‖ = 1.1203e-09, α = 1.08e-01, β = 3.00e+00, nfg = 3
[ Info: CG: iter   64: f = -1.401484038967, ‖∇f‖ = 9.5431e-10, α = 1.30e-01, β = 6.25e-01, nfg = 2
[ Info: CG: iter   65: f = -1.401484038967, ‖∇f‖ = 1.1415e-09, α = 1.31e-02, β = 4.31e+00, nfg = 3
[ Info: CG: iter   66: f = -1.401484038967, ‖∇f‖ = 5.2798e-10, α = 1.00e-01, β = 5.47e-02, nfg = 3
[ Info: CG: iter   67: f = -1.401484038967, ‖∇f‖ = 1.5459e-09, α = 9.23e-02, β = 2.53e-01, nfg = 2
[ Info: CG: iter   68: f = -1.401484038967, ‖∇f‖ = 5.5356e-10, α = 1.90e-03, β = 1.36e+01, nfg = 4
[ Info: CG: iter   69: f = -1.401484038967, ‖∇f‖ = 1.1857e-09, α = 9.47e-03, β = 1.82e+00, nfg = 9
[ Info: CG: iter   70: f = -1.401484038967, ‖∇f‖ = 1.0343e-09, α = 8.10e-03, β = 2.76e-01, nfg = 2
┌ Warning: resorting to η
└ @ OptimKit ~/.julia/packages/OptimKit/xpmbV/src/cg.jl:139
[ Info: CG: iter   71: f = -1.401484038967, ‖∇f‖ = 9.0194e-10, α = 1.93e-01, β = -2.50e-02, nfg = 4
[ Info: CG: iter   72: f = -1.401484038967, ‖∇f‖ = 3.4115e-10, α = 9.30e-02, β = 1.06e-01, nfg = 2
[ Info: CG: iter   73: f = -1.401484038967, ‖∇f‖ = 6.5303e-10, α = 9.07e-02, β = 4.64e-02, nfg = 2
[ Info: CG: iter   74: f = -1.401484038967, ‖∇f‖ = 5.4406e-10, α = 2.84e-02, β = 2.85e+00, nfg = 2
[ Info: CG: iter   75: f = -1.401484038967, ‖∇f‖ = 2.9328e-10, α = 3.31e-02, β = -8.14e-03, nfg = 2
[ Info: CG: iter   76: f = -1.401484038967, ‖∇f‖ = 4.7569e-10, α = 4.18e-02, β = 2.55e-01, nfg = 3
[ Info: CG: iter   77: f = -1.401484038967, ‖∇f‖ = 7.9327e-10, α = 6.23e-02, β = 2.24e+00, nfg = 4
[ Info: CG: iter   78: f = -1.401484038967, ‖∇f‖ = 1.2080e-09, α = 9.75e-02, β = 1.65e+00, nfg = 2
[ Info: CG: iter   79: f = -1.401484038967, ‖∇f‖ = 3.9746e-10, α = 7.54e-02, β = 3.40e-01, nfg = 2
[ Info: CG: iter   80: f = -1.401484038967, ‖∇f‖ = 5.8161e-10, α = 1.19e-01, β = 7.86e-02, nfg = 2
[ Info: CG: iter   81: f = -1.401484038967, ‖∇f‖ = 7.7785e-10, α = 5.80e-02, β = 4.30e+00, nfg = 2
[ Info: CG: iter   82: f = -1.401484038967, ‖∇f‖ = 6.3982e-10, α = 4.03e-02, β = 4.35e-01, nfg = 2
[ Info: CG: iter   83: f = -1.401484038967, ‖∇f‖ = 4.3752e-10, α = 2.28e-01, β = 8.16e-02, nfg = 3
[ Info: CG: iter   84: f = -1.401484038967, ‖∇f‖ = 6.4306e-10, α = 1.54e-01, β = 2.06e-01, nfg = 2
[ Info: CG: iter   85: f = -1.401484038967, ‖∇f‖ = 7.7602e-10, α = 8.42e-03, β = 1.45e+01, nfg = 2
[ Info: CG: iter   86: f = -1.401484038967, ‖∇f‖ = 6.7718e-10, α = 4.21e-02, β = 1.08e-02, nfg = 3
[ Info: CG: iter   87: f = -1.401484038967, ‖∇f‖ = 7.2304e-10, α = 1.88e-01, β = 2.80e-01, nfg = 3
[ Info: CG: iter   88: f = -1.401484038967, ‖∇f‖ = 1.2551e-09, α = 1.72e-01, β = 1.37e+00, nfg = 4
[ Info: CG: iter   89: f = -1.401484038967, ‖∇f‖ = 5.7243e-10, α = 2.31e-02, β = 3.58e+00, nfg = 3
[ Info: CG: iter   90: f = -1.401484038967, ‖∇f‖ = 7.9892e-10, α = 6.35e-02, β = 9.88e-01, nfg = 5
[ Info: CG: iter   91: f = -1.401484038967, ‖∇f‖ = 1.2750e-09, α = 5.66e-02, β = 1.52e-01, nfg = 2
[ Info: CG: iter   92: f = -1.401484038967, ‖∇f‖ = 1.4482e-09, α = 8.28e-02, β = 7.76e-01, nfg = 2
[ Info: CG: iter   93: f = -1.401484038967, ‖∇f‖ = 1.3094e-09, α = 2.19e-01, β = 8.96e-01, nfg = 3
[ Info: CG: iter   94: f = -1.401484038967, ‖∇f‖ = 7.9592e-10, α = 1.72e-01, β = 1.90e-01, nfg = 2
[ Info: CG: iter   95: f = -1.401484038967, ‖∇f‖ = 5.4049e-10, α = 1.18e-01, β = 2.77e-01, nfg = 2
[ Info: CG: iter   96: f = -1.401484038967, ‖∇f‖ = 3.2057e-10, α = 1.09e-01, β = 3.66e-01, nfg = 2
[ Info: CG: iter   97: f = -1.401484038967, ‖∇f‖ = 7.3564e-10, α = 1.38e-01, β = 1.29e-01, nfg = 3
[ Info: CG: iter   98: f = -1.401484038967, ‖∇f‖ = 1.2590e-09, α = 4.31e-01, β = 1.22e+00, nfg = 3
[ Info: CG: iter   99: f = -1.401484038967, ‖∇f‖ = 6.6395e-10, α = 1.21e-01, β = 1.28e-01, nfg = 3
┌ Warning: CG: not converged to requested tol: f = -1.401484038967, ‖∇f‖ = 7.2158e-10
└ @ OptimKit ~/.julia/packages/OptimKit/xpmbV/src/cg.jl:103
[ Info: Found excitations for p = 1.6755160819145563
[ Info: Found excitations for p = 1.8849555921538759
[ Info: Found excitations for p = 3.141592653589793
[ Info: Found excitations for p = 2.5132741228718345
[ Info: Found excitations for p = 1.4660765716752369
[ Info: Found excitations for p = 1.2566370614359172
[ Info: Found excitations for p = 1.0471975511965976
[ Info: Found excitations for p = 2.0943951023931953
[ Info: Found excitations for p = 0.20943951023931953
[ Info: Found excitations for p = 0.6283185307179586
[ Info: Found excitations for p = 0.0
[ Info: Found excitations for p = 2.303834612632515
[ Info: Found excitations for p = 2.722713633111154
[ Info: Found excitations for p = 0.41887902047863906
[ Info: Found excitations for p = 2.9321531433504737
[ Info: Found excitations for p = 0.8377580409572781
minimum @k = 3.141592653589793:	 ΔE = 0.4104792482243034

````

````julia
plot(kspace, real.(Es); xaxis="momentum", yaxis="ΔE", label="S = 1")
````

```@raw html
<?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="600" height="400" viewBox="0 0 2400 1600">
<defs>
  <clipPath id="clip730">
    <rect x="0" y="0" width="2400" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip730)" d="M0 1600 L2400 1600 L2400 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip731">
    <rect x="480" y="0" width="1681" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip730)" d="M219.033 1423.18 L2352.76 1423.18 L2352.76 47.2441 L219.033 47.2441  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip732">
    <rect x="219" y="47" width="2135" height="1377"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip732)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="279.421,1423.18 279.421,47.2441 "/>
<polyline clip-path="url(#clip732)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="920.162,1423.18 920.162,47.2441 "/>
<polyline clip-path="url(#clip732)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1560.9,1423.18 1560.9,47.2441 "/>
<polyline clip-path="url(#clip732)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2201.64,1423.18 2201.64,47.2441 "/>
<polyline clip-path="url(#clip730)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.033,1423.18 2352.76,1423.18 "/>
<polyline clip-path="url(#clip730)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="279.421,1423.18 279.421,1404.28 "/>
<polyline clip-path="url(#clip730)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="920.162,1423.18 920.162,1404.28 "/>
<polyline clip-path="url(#clip730)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1560.9,1423.18 1560.9,1404.28 "/>
<polyline clip-path="url(#clip730)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2201.64,1423.18 2201.64,1404.28 "/>
<path clip-path="url(#clip730)" d="M279.421 1454.1 Q275.81 1454.1 273.982 1457.66 Q272.176 1461.2 272.176 1468.33 Q272.176 1475.44 273.982 1479.01 Q275.81 1482.55 279.421 1482.55 Q283.056 1482.55 284.861 1479.01 Q286.69 1475.44 286.69 1468.33 Q286.69 1461.2 284.861 1457.66 Q283.056 1454.1 279.421 1454.1 M279.421 1450.39 Q285.231 1450.39 288.287 1455 Q291.366 1459.58 291.366 1468.33 Q291.366 1477.06 288.287 1481.67 Q285.231 1486.25 279.421 1486.25 Q273.611 1486.25 270.532 1481.67 Q267.477 1477.06 267.477 1468.33 Q267.477 1459.58 270.532 1455 Q273.611 1450.39 279.421 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M910.544 1481.64 L918.183 1481.64 L918.183 1455.28 L909.873 1456.95 L909.873 1452.69 L918.137 1451.02 L922.812 1451.02 L922.812 1481.64 L930.451 1481.64 L930.451 1485.58 L910.544 1485.58 L910.544 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M1555.56 1481.64 L1571.87 1481.64 L1571.87 1485.58 L1549.93 1485.58 L1549.93 1481.64 Q1552.59 1478.89 1557.18 1474.26 Q1561.78 1469.61 1562.96 1468.27 Q1565.21 1465.74 1566.09 1464.01 Q1566.99 1462.25 1566.99 1460.56 Q1566.99 1457.8 1565.05 1456.07 Q1563.12 1454.33 1560.02 1454.33 Q1557.82 1454.33 1555.37 1455.09 Q1552.94 1455.86 1550.16 1457.41 L1550.16 1452.69 Q1552.99 1451.55 1555.44 1450.97 Q1557.89 1450.39 1559.93 1450.39 Q1565.3 1450.39 1568.5 1453.08 Q1571.69 1455.77 1571.69 1460.26 Q1571.69 1462.39 1570.88 1464.31 Q1570.09 1466.2 1567.99 1468.8 Q1567.41 1469.47 1564.31 1472.69 Q1561.2 1475.88 1555.56 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M2205.89 1466.95 Q2209.25 1467.66 2211.12 1469.93 Q2213.02 1472.2 2213.02 1475.53 Q2213.02 1480.65 2209.5 1483.45 Q2205.98 1486.25 2199.5 1486.25 Q2197.33 1486.25 2195.01 1485.81 Q2192.72 1485.39 2190.27 1484.54 L2190.27 1480.02 Q2192.21 1481.16 2194.53 1481.74 Q2196.84 1482.32 2199.36 1482.32 Q2203.76 1482.32 2206.05 1480.58 Q2208.37 1478.84 2208.37 1475.53 Q2208.37 1472.48 2206.22 1470.77 Q2204.09 1469.03 2200.27 1469.03 L2196.24 1469.03 L2196.24 1465.19 L2200.45 1465.19 Q2203.9 1465.19 2205.73 1463.82 Q2207.56 1462.43 2207.56 1459.84 Q2207.56 1457.18 2205.66 1455.77 Q2203.78 1454.33 2200.27 1454.33 Q2198.34 1454.33 2196.15 1454.75 Q2193.95 1455.16 2191.31 1456.04 L2191.31 1451.88 Q2193.97 1451.14 2196.28 1450.77 Q2198.62 1450.39 2200.68 1450.39 Q2206.01 1450.39 2209.11 1452.83 Q2212.21 1455.23 2212.21 1459.35 Q2212.21 1462.22 2210.57 1464.21 Q2208.92 1466.18 2205.89 1466.95 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M1130.27 1539.24 Q1132.46 1535.29 1135.52 1533.41 Q1138.58 1531.54 1142.71 1531.54 Q1148.28 1531.54 1151.31 1535.45 Q1154.33 1539.33 1154.33 1546.53 L1154.33 1568.04 L1148.44 1568.04 L1148.44 1546.72 Q1148.44 1541.59 1146.63 1539.11 Q1144.81 1536.63 1141.09 1536.63 Q1136.54 1536.63 1133.9 1539.65 Q1131.26 1542.68 1131.26 1547.9 L1131.26 1568.04 L1125.37 1568.04 L1125.37 1546.72 Q1125.37 1541.56 1123.55 1539.11 Q1121.74 1536.63 1117.95 1536.63 Q1113.46 1536.63 1110.82 1539.68 Q1108.18 1542.71 1108.18 1547.9 L1108.18 1568.04 L1102.29 1568.04 L1102.29 1532.4 L1108.18 1532.4 L1108.18 1537.93 Q1110.19 1534.66 1112.99 1533.1 Q1115.79 1531.54 1119.64 1531.54 Q1123.52 1531.54 1126.23 1533.51 Q1128.96 1535.48 1130.27 1539.24 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M1179.83 1536.5 Q1175.12 1536.5 1172.38 1540.19 Q1169.64 1543.85 1169.64 1550.25 Q1169.64 1556.65 1172.35 1560.34 Q1175.08 1564 1179.83 1564 Q1184.5 1564 1187.24 1560.31 Q1189.98 1556.62 1189.98 1550.25 Q1189.98 1543.92 1187.24 1540.23 Q1184.5 1536.5 1179.83 1536.5 M1179.83 1531.54 Q1187.46 1531.54 1191.83 1536.5 Q1196.19 1541.47 1196.19 1550.25 Q1196.19 1559 1191.83 1564 Q1187.46 1568.97 1179.83 1568.97 Q1172.16 1568.97 1167.79 1564 Q1163.47 1559 1163.47 1550.25 Q1163.47 1541.47 1167.79 1536.5 Q1172.16 1531.54 1179.83 1531.54 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M1233.65 1539.24 Q1235.84 1535.29 1238.9 1533.41 Q1241.96 1531.54 1246.09 1531.54 Q1251.66 1531.54 1254.69 1535.45 Q1257.71 1539.33 1257.71 1546.53 L1257.71 1568.04 L1251.82 1568.04 L1251.82 1546.72 Q1251.82 1541.59 1250.01 1539.11 Q1248.19 1536.63 1244.47 1536.63 Q1239.92 1536.63 1237.28 1539.65 Q1234.63 1542.68 1234.63 1547.9 L1234.63 1568.04 L1228.75 1568.04 L1228.75 1546.72 Q1228.75 1541.56 1226.93 1539.11 Q1225.12 1536.63 1221.33 1536.63 Q1216.84 1536.63 1214.2 1539.68 Q1211.56 1542.71 1211.56 1547.9 L1211.56 1568.04 L1205.67 1568.04 L1205.67 1532.4 L1211.56 1532.4 L1211.56 1537.93 Q1213.56 1534.66 1216.36 1533.1 Q1219.17 1531.54 1223.02 1531.54 Q1226.9 1531.54 1229.61 1533.51 Q1232.34 1535.48 1233.65 1539.24 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M1299.88 1548.76 L1299.88 1551.62 L1272.96 1551.62 Q1273.34 1557.67 1276.58 1560.85 Q1279.86 1564 1285.69 1564 Q1289.06 1564 1292.21 1563.17 Q1295.4 1562.35 1298.51 1560.69 L1298.51 1566.23 Q1295.36 1567.57 1292.05 1568.27 Q1288.74 1568.97 1285.34 1568.97 Q1276.81 1568.97 1271.81 1564 Q1266.85 1559.04 1266.85 1550.57 Q1266.85 1541.82 1271.56 1536.69 Q1276.3 1531.54 1284.32 1531.54 Q1291.51 1531.54 1295.68 1536.18 Q1299.88 1540.8 1299.88 1548.76 M1294.03 1547.04 Q1293.96 1542.23 1291.32 1539.37 Q1288.71 1536.5 1284.38 1536.5 Q1279.48 1536.5 1276.52 1539.27 Q1273.59 1542.04 1273.15 1547.07 L1294.03 1547.04 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M1339.13 1546.53 L1339.13 1568.04 L1333.27 1568.04 L1333.27 1546.72 Q1333.27 1541.66 1331.3 1539.14 Q1329.32 1536.63 1325.38 1536.63 Q1320.64 1536.63 1317.9 1539.65 Q1315.16 1542.68 1315.16 1547.9 L1315.16 1568.04 L1309.27 1568.04 L1309.27 1532.4 L1315.16 1532.4 L1315.16 1537.93 Q1317.26 1534.72 1320.09 1533.13 Q1322.96 1531.54 1326.68 1531.54 Q1332.83 1531.54 1335.98 1535.36 Q1339.13 1539.14 1339.13 1546.53 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M1356.6 1522.27 L1356.6 1532.4 L1368.66 1532.4 L1368.66 1536.95 L1356.6 1536.95 L1356.6 1556.3 Q1356.6 1560.66 1357.78 1561.9 Q1358.99 1563.14 1362.65 1563.14 L1368.66 1563.14 L1368.66 1568.04 L1362.65 1568.04 Q1355.87 1568.04 1353.29 1565.53 Q1350.71 1562.98 1350.71 1556.3 L1350.71 1536.95 L1346.42 1536.95 L1346.42 1532.4 L1350.71 1532.4 L1350.71 1522.27 L1356.6 1522.27 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M1375.76 1553.98 L1375.76 1532.4 L1381.62 1532.4 L1381.62 1553.75 Q1381.62 1558.81 1383.59 1561.36 Q1385.57 1563.87 1389.51 1563.87 Q1394.25 1563.87 1396.99 1560.85 Q1399.76 1557.83 1399.76 1552.61 L1399.76 1532.4 L1405.62 1532.4 L1405.62 1568.04 L1399.76 1568.04 L1399.76 1562.57 Q1397.63 1565.82 1394.8 1567.41 Q1391.99 1568.97 1388.27 1568.97 Q1382.13 1568.97 1378.95 1565.15 Q1375.76 1561.33 1375.76 1553.98 M1390.5 1531.54 L1390.5 1531.54 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M1445.43 1539.24 Q1447.63 1535.29 1450.69 1533.41 Q1453.74 1531.54 1457.88 1531.54 Q1463.45 1531.54 1466.47 1535.45 Q1469.5 1539.33 1469.5 1546.53 L1469.5 1568.04 L1463.61 1568.04 L1463.61 1546.72 Q1463.61 1541.59 1461.79 1539.11 Q1459.98 1536.63 1456.26 1536.63 Q1451.71 1536.63 1449.06 1539.65 Q1446.42 1542.68 1446.42 1547.9 L1446.42 1568.04 L1440.53 1568.04 L1440.53 1546.72 Q1440.53 1541.56 1438.72 1539.11 Q1436.9 1536.63 1433.12 1536.63 Q1428.63 1536.63 1425.99 1539.68 Q1423.35 1542.71 1423.35 1547.9 L1423.35 1568.04 L1417.46 1568.04 L1417.46 1532.4 L1423.35 1532.4 L1423.35 1537.93 Q1425.35 1534.66 1428.15 1533.1 Q1430.95 1531.54 1434.8 1531.54 Q1438.69 1531.54 1441.39 1533.51 Q1444.13 1535.48 1445.43 1539.24 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip732)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.033,1334.01 2352.76,1334.01 "/>
<polyline clip-path="url(#clip732)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.033,1053.45 2352.76,1053.45 "/>
<polyline clip-path="url(#clip732)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.033,772.889 2352.76,772.889 "/>
<polyline clip-path="url(#clip732)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.033,492.33 2352.76,492.33 "/>
<polyline clip-path="url(#clip732)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.033,211.771 2352.76,211.771 "/>
<polyline clip-path="url(#clip730)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.033,1423.18 219.033,47.2441 "/>
<polyline clip-path="url(#clip730)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.033,1334.01 237.931,1334.01 "/>
<polyline clip-path="url(#clip730)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.033,1053.45 237.931,1053.45 "/>
<polyline clip-path="url(#clip730)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.033,772.889 237.931,772.889 "/>
<polyline clip-path="url(#clip730)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.033,492.33 237.931,492.33 "/>
<polyline clip-path="url(#clip730)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.033,211.771 237.931,211.771 "/>
<path clip-path="url(#clip730)" d="M126.853 1319.81 Q123.242 1319.81 121.413 1323.37 Q119.607 1326.91 119.607 1334.04 Q119.607 1341.15 121.413 1344.71 Q123.242 1348.25 126.853 1348.25 Q130.487 1348.25 132.292 1344.71 Q134.121 1341.15 134.121 1334.04 Q134.121 1326.91 132.292 1323.37 Q130.487 1319.81 126.853 1319.81 M126.853 1316.1 Q132.663 1316.1 135.718 1320.71 Q138.797 1325.29 138.797 1334.04 Q138.797 1342.77 135.718 1347.37 Q132.663 1351.96 126.853 1351.96 Q121.043 1351.96 117.964 1347.37 Q114.908 1342.77 114.908 1334.04 Q114.908 1325.29 117.964 1320.71 Q121.043 1316.1 126.853 1316.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M147.015 1345.41 L151.899 1345.41 L151.899 1351.29 L147.015 1351.29 L147.015 1345.41 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M162.13 1316.73 L180.487 1316.73 L180.487 1320.66 L166.413 1320.66 L166.413 1329.13 Q167.431 1328.79 168.45 1328.62 Q169.468 1328.44 170.487 1328.44 Q176.274 1328.44 179.653 1331.61 Q183.033 1334.78 183.033 1340.2 Q183.033 1345.78 179.561 1348.88 Q176.089 1351.96 169.769 1351.96 Q167.593 1351.96 165.325 1351.59 Q163.079 1351.22 160.672 1350.48 L160.672 1345.78 Q162.755 1346.91 164.977 1347.47 Q167.2 1348.02 169.677 1348.02 Q173.681 1348.02 176.019 1345.92 Q178.357 1343.81 178.357 1340.2 Q178.357 1336.59 176.019 1334.48 Q173.681 1332.37 169.677 1332.37 Q167.802 1332.37 165.927 1332.79 Q164.075 1333.21 162.13 1334.09 L162.13 1316.73 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M116.668 1066.79 L124.306 1066.79 L124.306 1040.43 L115.996 1042.09 L115.996 1037.83 L124.26 1036.17 L128.936 1036.17 L128.936 1066.79 L136.575 1066.79 L136.575 1070.73 L116.668 1070.73 L116.668 1066.79 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M146.019 1064.85 L150.903 1064.85 L150.903 1070.73 L146.019 1070.73 L146.019 1064.85 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M171.089 1039.25 Q167.477 1039.25 165.649 1042.81 Q163.843 1046.35 163.843 1053.48 Q163.843 1060.59 165.649 1064.15 Q167.477 1067.7 171.089 1067.7 Q174.723 1067.7 176.528 1064.15 Q178.357 1060.59 178.357 1053.48 Q178.357 1046.35 176.528 1042.81 Q174.723 1039.25 171.089 1039.25 M171.089 1035.54 Q176.899 1035.54 179.954 1040.15 Q183.033 1044.73 183.033 1053.48 Q183.033 1062.21 179.954 1066.82 Q176.899 1071.4 171.089 1071.4 Q165.278 1071.4 162.2 1066.82 Q159.144 1062.21 159.144 1053.48 Q159.144 1044.73 162.2 1040.15 Q165.278 1035.54 171.089 1035.54 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M117.663 786.234 L125.302 786.234 L125.302 759.868 L116.992 761.535 L116.992 757.276 L125.255 755.609 L129.931 755.609 L129.931 786.234 L137.57 786.234 L137.57 790.169 L117.663 790.169 L117.663 786.234 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M147.015 784.289 L151.899 784.289 L151.899 790.169 L147.015 790.169 L147.015 784.289 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M162.13 755.609 L180.487 755.609 L180.487 759.544 L166.413 759.544 L166.413 768.016 Q167.431 767.669 168.45 767.507 Q169.468 767.322 170.487 767.322 Q176.274 767.322 179.653 770.493 Q183.033 773.664 183.033 779.081 Q183.033 784.66 179.561 787.761 Q176.089 790.84 169.769 790.84 Q167.593 790.84 165.325 790.47 Q163.079 790.099 160.672 789.359 L160.672 784.66 Q162.755 785.794 164.977 786.349 Q167.2 786.905 169.677 786.905 Q173.681 786.905 176.019 784.799 Q178.357 782.692 178.357 779.081 Q178.357 775.47 176.019 773.363 Q173.681 771.257 169.677 771.257 Q167.802 771.257 165.927 771.674 Q164.075 772.09 162.13 772.97 L162.13 755.609 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M119.885 505.675 L136.204 505.675 L136.204 509.61 L114.26 509.61 L114.26 505.675 Q116.922 502.92 121.505 498.291 Q126.112 493.638 127.292 492.295 Q129.538 489.772 130.417 488.036 Q131.32 486.277 131.32 484.587 Q131.32 481.832 129.376 480.096 Q127.455 478.36 124.353 478.36 Q122.154 478.36 119.7 479.124 Q117.269 479.888 114.492 481.439 L114.492 476.717 Q117.316 475.582 119.769 475.004 Q122.223 474.425 124.26 474.425 Q129.63 474.425 132.825 477.11 Q136.019 479.795 136.019 484.286 Q136.019 486.416 135.209 488.337 Q134.422 490.235 132.316 492.828 Q131.737 493.499 128.635 496.717 Q125.533 499.911 119.885 505.675 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M146.019 503.73 L150.903 503.73 L150.903 509.61 L146.019 509.61 L146.019 503.73 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M171.089 478.129 Q167.477 478.129 165.649 481.693 Q163.843 485.235 163.843 492.365 Q163.843 499.471 165.649 503.036 Q167.477 506.578 171.089 506.578 Q174.723 506.578 176.528 503.036 Q178.357 499.471 178.357 492.365 Q178.357 485.235 176.528 481.693 Q174.723 478.129 171.089 478.129 M171.089 474.425 Q176.899 474.425 179.954 479.031 Q183.033 483.615 183.033 492.365 Q183.033 501.092 179.954 505.698 Q176.899 510.281 171.089 510.281 Q165.278 510.281 162.2 505.698 Q159.144 501.092 159.144 492.365 Q159.144 483.615 162.2 479.031 Q165.278 474.425 171.089 474.425 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M120.88 225.116 L137.2 225.116 L137.2 229.051 L115.256 229.051 L115.256 225.116 Q117.918 222.361 122.501 217.732 Q127.107 213.079 128.288 211.736 Q130.533 209.213 131.413 207.477 Q132.316 205.718 132.316 204.028 Q132.316 201.273 130.371 199.537 Q128.45 197.801 125.348 197.801 Q123.149 197.801 120.695 198.565 Q118.265 199.329 115.487 200.88 L115.487 196.158 Q118.311 195.024 120.765 194.445 Q123.218 193.866 125.255 193.866 Q130.626 193.866 133.82 196.551 Q137.015 199.236 137.015 203.727 Q137.015 205.857 136.204 207.778 Q135.417 209.676 133.311 212.269 Q132.732 212.94 129.63 216.158 Q126.529 219.352 120.88 225.116 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M147.015 223.172 L151.899 223.172 L151.899 229.051 L147.015 229.051 L147.015 223.172 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M162.13 194.491 L180.487 194.491 L180.487 198.426 L166.413 198.426 L166.413 206.898 Q167.431 206.551 168.45 206.389 Q169.468 206.204 170.487 206.204 Q176.274 206.204 179.653 209.375 Q183.033 212.547 183.033 217.963 Q183.033 223.542 179.561 226.644 Q176.089 229.722 169.769 229.722 Q167.593 229.722 165.325 229.352 Q163.079 228.982 160.672 228.241 L160.672 223.542 Q162.755 224.676 164.977 225.232 Q167.2 225.787 169.677 225.787 Q173.681 225.787 176.019 223.681 Q178.357 221.574 178.357 217.963 Q178.357 214.352 176.019 212.246 Q173.681 210.139 169.677 210.139 Q167.802 210.139 165.927 210.556 Q164.075 210.973 162.13 211.852 L162.13 194.491 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M22.818 753.991 L58.657 767.041 L58.657 740.909 L22.818 753.991 M64.0042 775.762 L16.4842 757.619 L16.4842 750.331 L64.0042 732.22 L64.0042 775.762 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M16.4842 725.281 L16.4842 695.235 L21.895 695.235 L21.895 718.852 L35.9632 718.852 L35.9632 696.222 L41.3741 696.222 L41.3741 718.852 L58.5933 718.852 L58.5933 694.662 L64.0042 694.662 L64.0042 725.281 L16.4842 725.281 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip732)" style="stroke:#009af9; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="279.421,1128.19 413.618,1049.16 547.814,862.869 682.011,635.232 816.207,410.875 950.403,237.866 1084.6,128.406 1218.8,86.1857 1352.99,111.098 1487.19,199.062 1621.39,342.62 1755.58,532.111 1889.78,756.553 2023.97,1002.62 2158.17,1245.56 2292.37,1384.24 "/>
<path clip-path="url(#clip730)" d="M1945.64 196.789 L2281.63 196.789 L2281.63 93.1086 L1945.64 93.1086  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<polyline clip-path="url(#clip730)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1945.64,196.789 2281.63,196.789 2281.63,93.1086 1945.64,93.1086 1945.64,196.789 "/>
<polyline clip-path="url(#clip730)" style="stroke:#009af9; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1969.35,144.949 2111.6,144.949 "/>
<path clip-path="url(#clip730)" d="M2157.55 128.803 L2157.55 133.363 Q2154.89 132.09 2152.53 131.465 Q2150.17 130.84 2147.97 130.84 Q2144.15 130.84 2142.07 132.321 Q2140.01 133.803 2140.01 136.534 Q2140.01 138.826 2141.37 140.007 Q2142.76 141.164 2146.6 141.882 L2149.43 142.46 Q2154.66 143.456 2157.14 145.979 Q2159.64 148.479 2159.64 152.692 Q2159.64 157.715 2156.26 160.307 Q2152.9 162.9 2146.4 162.9 Q2143.94 162.9 2141.17 162.344 Q2138.41 161.789 2135.45 160.701 L2135.45 155.886 Q2138.29 157.483 2141.03 158.293 Q2143.76 159.104 2146.4 159.104 Q2150.4 159.104 2152.58 157.53 Q2154.75 155.956 2154.75 153.039 Q2154.75 150.493 2153.18 149.057 Q2151.63 147.622 2148.06 146.905 L2145.22 146.349 Q2139.98 145.307 2137.65 143.085 Q2135.31 140.863 2135.31 136.905 Q2135.31 132.321 2138.53 129.682 Q2141.77 127.044 2147.44 127.044 Q2149.87 127.044 2152.39 127.483 Q2154.92 127.923 2157.55 128.803 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M2182.37 140.701 L2212.04 140.701 L2212.04 144.59 L2182.37 144.59 L2182.37 140.701 M2182.37 150.145 L2212.04 150.145 L2212.04 154.081 L2182.37 154.081 L2182.37 150.145 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip730)" d="M2238.02 158.293 L2245.66 158.293 L2245.66 131.928 L2237.35 133.595 L2237.35 129.335 L2245.61 127.669 L2250.28 127.669 L2250.28 158.293 L2257.92 158.293 L2257.92 162.229 L2238.02 162.229 L2238.02 158.293 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /></svg>

```

---

*This page was generated using [Literate.jl](https://github.com/fredrikekre/Literate.jl).*

