```@meta
EditURL = "../../../../../examples/quantum1d/5.haldane-spt/main.jl"
```

[![](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/maartenvd/MPSKit.jl/gh-pages?filepath=dev/examples/quantum1d/5.haldane-spt/main.ipynb)
[![](https://img.shields.io/badge/show-nbviewer-579ACA.svg)](https://nbviewer.jupyter.org/github/maartenvd/MPSKit.jl/blob/gh-pages/dev/examples/quantum1d/5.haldane-spt/main.ipynb)
[![](https://img.shields.io/badge/download-project-orange)](https://minhaskamal.github.io/DownGit/#/home?url=https://github.com/maartenvd/MPSKit.jl/examples/tree/gh-pages/dev/examples/quantum1d/5.haldane-spt)

# [Spin 1 Heisenberg model](@id spin1heisenberg)

The quantum Heisenberg model is a model often used in the study of critical points and phase
transitions of magnetic systems, in which the spins are treated quantum mechanically. It
models magnetic interactions between neighbouring spins through the so-called Heisenberg
interaction term, which causes the spins to either align ($J > 0$) or anti-align ($J < 0$),
thus modeling a (anti-) ferromagnetic system. Here, we will focus on the case of $S = 1$,
with anti-ferromagnetic interactions.

```math
H = -J \sum_{\langle i, j \rangle} \vec{S}_i \cdot \vec{S}_j
```

Importantly, the Hamiltonian of the isotropic model is invariant under $SU(2)$ rotations,
which can be exploited to increase efficiency, as well as interpretability of the MPS
simulations. To see this, we can make use of the following derivation for the interaction
term:

```math
(\vec{S}_i + \vec{S}_j)^2 = \vec{S}_i^2 + 2 \vec{S}_i \cdot \vec{S}_j + \vec{S}_j^2
\implies \vec{S}_i \cdot \vec{S}_j = \frac{1}{2} \left( (\vec{S}_i + \vec{S}_j)^2 - \vec{S}_i^2 - \vec{S}_j^2 \right)
```

Here, we recognize the quadratic
[Casimir element](https://en.wikipedia.org/wiki/Casimir_element) $\vec{S}^2$, which commutes
with the elements of $SU(2)$. Consequently, the Hamiltonian also commutes with all elements
of $SU(2)$.

````julia
using TensorKit
using MPSKit
using Plots

casimir(s::SU2Irrep) = s.j * (s.j + 1)

function heisenberg_hamiltonian(; J = -1.0)
    s = SU2Irrep(1)
    ℋ = SU2Space(1 => 1)
    SS = TensorMap(zeros, ComplexF64, ℋ ⊗ ℋ ← ℋ ⊗ ℋ)
    for (S, data) in blocks(SS)
        data .= -0.5J * (casimir(S) - casimir(s) - casimir(s))
    end
    return MPOHamiltonian(SS)
end
H = heisenberg_hamiltonian();
````

## Symmetry-Protected Topological Order

The representations of $SU(2)$ possess additional structure, known as a
$\mathbb{Z}_2$-grading. This means, that they can be partitioned in integer $(+)$ and
half-integer $(-)$ spins, and the fusion rules will respect this grading. In other words,
the following table holds:

| $s_1$ | $s_2$ | $s_1 \otimes s_2$ |
| --- | --- | --- |
| $+$ | $+$ | $+$ |
| $+$ | $-$ | $-$ |
| $-$ | $+$ | $-$ |
| $-$ | $-$ | $+$ |

This has important consequences for the MPS representation of an $SU(2)$-symmetric state. If
the physical spin consists of only integer representations, this means that the left and
right virtual spaces of the MPS tensor belong to the same grading, i.e. are either both
integer, or both half-integer. Thus, naively constructing a MPS tensor which contains spins
from both classes, will necessarily be the direct sum of the two, which yields a
non-injective MPS.

```math
\ket{\psi} = \ket{\psi_+} \oplus \ket{\psi_-}
```

Because of this direct sum, many of the usual MPS algorithms will fail, as they typically
cannot deal with non-injective MPS. The resulting MPS will have multiple values of the
transfer matrix spectrum that have a magnitude close to 1, which is a clear sign of a
non-injective MPS.

````julia
ℋ = SU2Space(1 => 1)
V_wrong = SU2Space(0 => 8, 1//2 => 8, 1 => 3, 3//2 => 3)
ψ = InfiniteMPS(ℋ, V_wrong)
ψ, environments, δ = find_groundstate(ψ, H, VUMPS(; maxiter=10))
sectors = SU2Irrep[0, 1//2, 1, 3//2]
transferplot(ψ; sectors, title="Transfer matrix spectrum", legend=:outertop)
````

```@raw html
<?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="600" height="400" viewBox="0 0 2400 1600">
<defs>
  <clipPath id="clip190">
    <rect x="0" y="0" width="2400" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip190)" d="M0 1600 L2400 1600 L2400 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip191">
    <rect x="480" y="0" width="1681" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip190)" d="M219.866 1423.18 L2352.76 1423.18 L2352.76 425.996 L219.866 425.996  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip192">
    <rect x="219" y="425" width="2134" height="998"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip192)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="280.231,1423.18 280.231,425.996 "/>
<polyline clip-path="url(#clip192)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="615.591,1423.18 615.591,425.996 "/>
<polyline clip-path="url(#clip192)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="950.951,1423.18 950.951,425.996 "/>
<polyline clip-path="url(#clip192)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1286.31,1423.18 1286.31,425.996 "/>
<polyline clip-path="url(#clip192)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1621.67,1423.18 1621.67,425.996 "/>
<polyline clip-path="url(#clip192)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1957.03,1423.18 1957.03,425.996 "/>
<polyline clip-path="url(#clip192)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2292.39,1423.18 2292.39,425.996 "/>
<polyline clip-path="url(#clip190)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.866,1423.18 2352.76,1423.18 "/>
<polyline clip-path="url(#clip190)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="280.231,1423.18 280.231,1408.68 "/>
<polyline clip-path="url(#clip190)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="615.591,1423.18 615.591,1408.68 "/>
<polyline clip-path="url(#clip190)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="950.951,1423.18 950.951,1408.68 "/>
<polyline clip-path="url(#clip190)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1286.31,1423.18 1286.31,1408.68 "/>
<polyline clip-path="url(#clip190)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1621.67,1423.18 1621.67,1408.68 "/>
<polyline clip-path="url(#clip190)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1957.03,1423.18 1957.03,1408.68 "/>
<polyline clip-path="url(#clip190)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2292.39,1423.18 2292.39,1408.68 "/>
<path clip-path="url(#clip190)" d="M233.993 1454.1 Q230.382 1454.1 228.553 1457.66 Q226.748 1461.2 226.748 1468.33 Q226.748 1475.44 228.553 1479.01 Q230.382 1482.55 233.993 1482.55 Q237.627 1482.55 239.433 1479.01 Q241.261 1475.44 241.261 1468.33 Q241.261 1461.2 239.433 1457.66 Q237.627 1454.1 233.993 1454.1 M233.993 1450.39 Q239.803 1450.39 242.859 1455 Q245.937 1459.58 245.937 1468.33 Q245.937 1477.06 242.859 1481.67 Q239.803 1486.25 233.993 1486.25 Q228.183 1486.25 225.104 1481.67 Q222.049 1477.06 222.049 1468.33 Q222.049 1459.58 225.104 1455 Q228.183 1450.39 233.993 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M261.122 1451.02 L265.058 1451.02 L253.021 1489.98 L249.085 1489.98 L261.122 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M277.095 1451.02 L281.03 1451.02 L268.993 1489.98 L265.058 1489.98 L277.095 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M286.909 1481.64 L294.548 1481.64 L294.548 1455.28 L286.238 1456.95 L286.238 1452.69 L294.502 1451.02 L299.178 1451.02 L299.178 1481.64 L306.817 1481.64 L306.817 1485.58 L286.909 1485.58 L286.909 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M312.905 1459.65 L337.742 1459.65 L337.742 1463.91 L334.478 1463.91 L334.478 1479.84 Q334.478 1481.51 335.034 1482.25 Q335.613 1482.96 336.886 1482.96 Q337.233 1482.96 337.742 1482.92 Q338.252 1482.85 338.414 1482.83 L338.414 1485.9 Q337.603 1486.2 336.747 1486.34 Q335.89 1486.48 335.034 1486.48 Q332.256 1486.48 331.191 1484.98 Q330.127 1483.45 330.127 1479.38 L330.127 1463.91 L320.566 1463.91 L320.566 1485.58 L316.215 1485.58 L316.215 1463.91 L312.905 1463.91 L312.905 1459.65 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M559.121 1481.64 L566.76 1481.64 L566.76 1455.28 L558.45 1456.95 L558.45 1452.69 L566.714 1451.02 L571.39 1451.02 L571.39 1481.64 L579.029 1481.64 L579.029 1485.58 L559.121 1485.58 L559.121 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M595.441 1451.02 L599.376 1451.02 L587.339 1489.98 L583.404 1489.98 L595.441 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M611.413 1451.02 L615.348 1451.02 L603.311 1489.98 L599.376 1489.98 L611.413 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M634.584 1466.95 Q637.94 1467.66 639.815 1469.93 Q641.714 1472.2 641.714 1475.53 Q641.714 1480.65 638.195 1483.45 Q634.677 1486.25 628.195 1486.25 Q626.019 1486.25 623.704 1485.81 Q621.413 1485.39 618.959 1484.54 L618.959 1480.02 Q620.904 1481.16 623.218 1481.74 Q625.533 1482.32 628.056 1482.32 Q632.454 1482.32 634.746 1480.58 Q637.061 1478.84 637.061 1475.53 Q637.061 1472.48 634.908 1470.77 Q632.778 1469.03 628.959 1469.03 L624.931 1469.03 L624.931 1465.19 L629.144 1465.19 Q632.593 1465.19 634.422 1463.82 Q636.251 1462.43 636.251 1459.84 Q636.251 1457.18 634.353 1455.77 Q632.478 1454.33 628.959 1454.33 Q627.038 1454.33 624.839 1454.75 Q622.64 1455.16 620.001 1456.04 L620.001 1451.88 Q622.663 1451.14 624.978 1450.77 Q627.316 1450.39 629.376 1450.39 Q634.7 1450.39 637.802 1452.83 Q640.903 1455.23 640.903 1459.35 Q640.903 1462.22 639.26 1464.21 Q637.616 1466.18 634.584 1466.95 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M647.223 1459.65 L672.061 1459.65 L672.061 1463.91 L668.797 1463.91 L668.797 1479.84 Q668.797 1481.51 669.352 1482.25 Q669.931 1482.96 671.204 1482.96 Q671.551 1482.96 672.061 1482.92 Q672.57 1482.85 672.732 1482.83 L672.732 1485.9 Q671.922 1486.2 671.065 1486.34 Q670.209 1486.48 669.352 1486.48 Q666.575 1486.48 665.51 1484.98 Q664.445 1483.45 664.445 1479.38 L664.445 1463.91 L654.885 1463.91 L654.885 1485.58 L650.533 1485.58 L650.533 1463.91 L647.223 1463.91 L647.223 1459.65 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M898.567 1481.64 L914.886 1481.64 L914.886 1485.58 L892.942 1485.58 L892.942 1481.64 Q895.604 1478.89 900.187 1474.26 Q904.794 1469.61 905.974 1468.27 Q908.22 1465.74 909.099 1464.01 Q910.002 1462.25 910.002 1460.56 Q910.002 1457.8 908.058 1456.07 Q906.137 1454.33 903.035 1454.33 Q900.836 1454.33 898.382 1455.09 Q895.951 1455.86 893.174 1457.41 L893.174 1452.69 Q895.998 1451.55 898.451 1450.97 Q900.905 1450.39 902.942 1450.39 Q908.312 1450.39 911.507 1453.08 Q914.701 1455.77 914.701 1460.26 Q914.701 1462.39 913.891 1464.31 Q913.104 1466.2 910.998 1468.8 Q910.419 1469.47 907.317 1472.69 Q904.215 1475.88 898.567 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M931.669 1451.02 L935.604 1451.02 L923.567 1489.98 L919.632 1489.98 L931.669 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M947.641 1451.02 L951.576 1451.02 L939.539 1489.98 L935.604 1489.98 L947.641 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M970.812 1466.95 Q974.169 1467.66 976.044 1469.93 Q977.942 1472.2 977.942 1475.53 Q977.942 1480.65 974.423 1483.45 Q970.905 1486.25 964.423 1486.25 Q962.247 1486.25 959.933 1485.81 Q957.641 1485.39 955.187 1484.54 L955.187 1480.02 Q957.132 1481.16 959.446 1481.74 Q961.761 1482.32 964.284 1482.32 Q968.682 1482.32 970.974 1480.58 Q973.289 1478.84 973.289 1475.53 Q973.289 1472.48 971.136 1470.77 Q969.007 1469.03 965.187 1469.03 L961.159 1469.03 L961.159 1465.19 L965.372 1465.19 Q968.821 1465.19 970.65 1463.82 Q972.479 1462.43 972.479 1459.84 Q972.479 1457.18 970.581 1455.77 Q968.706 1454.33 965.187 1454.33 Q963.266 1454.33 961.067 1454.75 Q958.868 1455.16 956.229 1456.04 L956.229 1451.88 Q958.891 1451.14 961.206 1450.77 Q963.544 1450.39 965.604 1450.39 Q970.928 1450.39 974.03 1452.83 Q977.131 1455.23 977.131 1459.35 Q977.131 1462.22 975.488 1464.21 Q973.844 1466.18 970.812 1466.95 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M983.451 1459.65 L1008.29 1459.65 L1008.29 1463.91 L1005.02 1463.91 L1005.02 1479.84 Q1005.02 1481.51 1005.58 1482.25 Q1006.16 1482.96 1007.43 1482.96 Q1007.78 1482.96 1008.29 1482.92 Q1008.8 1482.85 1008.96 1482.83 L1008.96 1485.9 Q1008.15 1486.2 1007.29 1486.34 Q1006.44 1486.48 1005.58 1486.48 Q1002.8 1486.48 1001.74 1484.98 Q1000.67 1483.45 1000.67 1479.38 L1000.67 1463.91 L991.113 1463.91 L991.113 1485.58 L986.761 1485.58 L986.761 1463.91 L983.451 1463.91 L983.451 1459.65 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1229.84 1481.64 L1237.48 1481.64 L1237.48 1455.28 L1229.17 1456.95 L1229.17 1452.69 L1237.43 1451.02 L1242.11 1451.02 L1242.11 1481.64 L1249.75 1481.64 L1249.75 1485.58 L1229.84 1485.58 L1229.84 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1266.16 1451.02 L1270.1 1451.02 L1258.06 1489.98 L1254.12 1489.98 L1266.16 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1282.13 1451.02 L1286.07 1451.02 L1274.03 1489.98 L1270.1 1489.98 L1282.13 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1291.95 1481.64 L1299.59 1481.64 L1299.59 1455.28 L1291.28 1456.95 L1291.28 1452.69 L1299.54 1451.02 L1304.22 1451.02 L1304.22 1481.64 L1311.85 1481.64 L1311.85 1485.58 L1291.95 1485.58 L1291.95 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1317.94 1459.65 L1342.78 1459.65 L1342.78 1463.91 L1339.52 1463.91 L1339.52 1479.84 Q1339.52 1481.51 1340.07 1482.25 Q1340.65 1482.96 1341.92 1482.96 Q1342.27 1482.96 1342.78 1482.92 Q1343.29 1482.85 1343.45 1482.83 L1343.45 1485.9 Q1342.64 1486.2 1341.79 1486.34 Q1340.93 1486.48 1340.07 1486.48 Q1337.29 1486.48 1336.23 1484.98 Q1335.16 1483.45 1335.16 1479.38 L1335.16 1463.91 L1325.6 1463.91 L1325.6 1485.58 L1321.25 1485.58 L1321.25 1463.91 L1317.94 1463.91 L1317.94 1459.65 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1578.69 1455.09 L1566.88 1473.54 L1578.69 1473.54 L1578.69 1455.09 M1577.46 1451.02 L1583.34 1451.02 L1583.34 1473.54 L1588.27 1473.54 L1588.27 1477.43 L1583.34 1477.43 L1583.34 1485.58 L1578.69 1485.58 L1578.69 1477.43 L1563.08 1477.43 L1563.08 1472.92 L1577.46 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1602.97 1451.02 L1606.9 1451.02 L1594.87 1489.98 L1590.93 1489.98 L1602.97 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1618.94 1451.02 L1622.87 1451.02 L1610.84 1489.98 L1606.9 1489.98 L1618.94 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1642.11 1466.95 Q1645.47 1467.66 1647.34 1469.93 Q1649.24 1472.2 1649.24 1475.53 Q1649.24 1480.65 1645.72 1483.45 Q1642.2 1486.25 1635.72 1486.25 Q1633.55 1486.25 1631.23 1485.81 Q1628.94 1485.39 1626.49 1484.54 L1626.49 1480.02 Q1628.43 1481.16 1630.75 1481.74 Q1633.06 1482.32 1635.58 1482.32 Q1639.98 1482.32 1642.27 1480.58 Q1644.59 1478.84 1644.59 1475.53 Q1644.59 1472.48 1642.43 1470.77 Q1640.31 1469.03 1636.49 1469.03 L1632.46 1469.03 L1632.46 1465.19 L1636.67 1465.19 Q1640.12 1465.19 1641.95 1463.82 Q1643.78 1462.43 1643.78 1459.84 Q1643.78 1457.18 1641.88 1455.77 Q1640 1454.33 1636.49 1454.33 Q1634.56 1454.33 1632.37 1454.75 Q1630.17 1455.16 1627.53 1456.04 L1627.53 1451.88 Q1630.19 1451.14 1632.5 1450.77 Q1634.84 1450.39 1636.9 1450.39 Q1642.23 1450.39 1645.33 1452.83 Q1648.43 1455.23 1648.43 1459.35 Q1648.43 1462.22 1646.79 1464.21 Q1645.14 1466.18 1642.11 1466.95 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1654.75 1459.65 L1679.59 1459.65 L1679.59 1463.91 L1676.32 1463.91 L1676.32 1479.84 Q1676.32 1481.51 1676.88 1482.25 Q1677.46 1482.96 1678.73 1482.96 Q1679.08 1482.96 1679.59 1482.92 Q1680.1 1482.85 1680.26 1482.83 L1680.26 1485.9 Q1679.45 1486.2 1678.59 1486.34 Q1677.74 1486.48 1676.88 1486.48 Q1674.1 1486.48 1673.04 1484.98 Q1671.97 1483.45 1671.97 1479.38 L1671.97 1463.91 L1662.41 1463.91 L1662.41 1485.58 L1658.06 1485.58 L1658.06 1463.91 L1654.75 1463.91 L1654.75 1459.65 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1900.57 1451.02 L1918.93 1451.02 L1918.93 1454.96 L1904.86 1454.96 L1904.86 1463.43 Q1905.87 1463.08 1906.89 1462.92 Q1907.91 1462.73 1908.93 1462.73 Q1914.72 1462.73 1918.1 1465.9 Q1921.48 1469.08 1921.48 1474.49 Q1921.48 1480.07 1918 1483.17 Q1914.53 1486.25 1908.21 1486.25 Q1906.04 1486.25 1903.77 1485.88 Q1901.52 1485.51 1899.11 1484.77 L1899.11 1480.07 Q1901.2 1481.2 1903.42 1481.76 Q1905.64 1482.32 1908.12 1482.32 Q1912.12 1482.32 1914.46 1480.21 Q1916.8 1478.1 1916.8 1474.49 Q1916.8 1470.88 1914.46 1468.77 Q1912.12 1466.67 1908.12 1466.67 Q1906.24 1466.67 1904.37 1467.08 Q1902.52 1467.5 1900.57 1468.38 L1900.57 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1937.66 1451.02 L1941.59 1451.02 L1929.55 1489.98 L1925.62 1489.98 L1937.66 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1953.63 1451.02 L1957.56 1451.02 L1945.53 1489.98 L1941.59 1489.98 L1953.63 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1976.8 1466.95 Q1980.16 1467.66 1982.03 1469.93 Q1983.93 1472.2 1983.93 1475.53 Q1983.93 1480.65 1980.41 1483.45 Q1976.89 1486.25 1970.41 1486.25 Q1968.23 1486.25 1965.92 1485.81 Q1963.63 1485.39 1961.17 1484.54 L1961.17 1480.02 Q1963.12 1481.16 1965.43 1481.74 Q1967.75 1482.32 1970.27 1482.32 Q1974.67 1482.32 1976.96 1480.58 Q1979.28 1478.84 1979.28 1475.53 Q1979.28 1472.48 1977.12 1470.77 Q1974.99 1469.03 1971.17 1469.03 L1967.15 1469.03 L1967.15 1465.19 L1971.36 1465.19 Q1974.81 1465.19 1976.64 1463.82 Q1978.47 1462.43 1978.47 1459.84 Q1978.47 1457.18 1976.57 1455.77 Q1974.69 1454.33 1971.17 1454.33 Q1969.25 1454.33 1967.05 1454.75 Q1964.86 1455.16 1962.22 1456.04 L1962.22 1451.88 Q1964.88 1451.14 1967.19 1450.77 Q1969.53 1450.39 1971.59 1450.39 Q1976.92 1450.39 1980.02 1452.83 Q1983.12 1455.23 1983.12 1459.35 Q1983.12 1462.22 1981.48 1464.21 Q1979.83 1466.18 1976.8 1466.95 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1989.44 1459.65 L2014.28 1459.65 L2014.28 1463.91 L2011.01 1463.91 L2011.01 1479.84 Q2011.01 1481.51 2011.57 1482.25 Q2012.15 1482.96 2013.42 1482.96 Q2013.77 1482.96 2014.28 1482.92 Q2014.79 1482.85 2014.95 1482.83 L2014.95 1485.9 Q2014.14 1486.2 2013.28 1486.34 Q2012.42 1486.48 2011.57 1486.48 Q2008.79 1486.48 2007.73 1484.98 Q2006.66 1483.45 2006.66 1479.38 L2006.66 1463.91 L1997.1 1463.91 L1997.1 1485.58 L1992.75 1485.58 L1992.75 1463.91 L1989.44 1463.91 L1989.44 1459.65 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M2240.01 1481.64 L2256.33 1481.64 L2256.33 1485.58 L2234.38 1485.58 L2234.38 1481.64 Q2237.04 1478.89 2241.63 1474.26 Q2246.23 1469.61 2247.41 1468.27 Q2249.66 1465.74 2250.54 1464.01 Q2251.44 1462.25 2251.44 1460.56 Q2251.44 1457.8 2249.5 1456.07 Q2247.58 1454.33 2244.47 1454.33 Q2242.28 1454.33 2239.82 1455.09 Q2237.39 1455.86 2234.61 1457.41 L2234.61 1452.69 Q2237.44 1451.55 2239.89 1450.97 Q2242.35 1450.39 2244.38 1450.39 Q2249.75 1450.39 2252.95 1453.08 Q2256.14 1455.77 2256.14 1460.26 Q2256.14 1462.39 2255.33 1464.31 Q2254.54 1466.2 2252.44 1468.8 Q2251.86 1469.47 2248.76 1472.69 Q2245.66 1475.88 2240.01 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M2273.11 1451.02 L2277.04 1451.02 L2265.01 1489.98 L2261.07 1489.98 L2273.11 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M2289.08 1451.02 L2293.02 1451.02 L2280.98 1489.98 L2277.04 1489.98 L2289.08 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M2298.9 1481.64 L2306.53 1481.64 L2306.53 1455.28 L2298.22 1456.95 L2298.22 1452.69 L2306.49 1451.02 L2311.16 1451.02 L2311.16 1481.64 L2318.8 1481.64 L2318.8 1485.58 L2298.9 1485.58 L2298.9 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M2324.89 1459.65 L2349.73 1459.65 L2349.73 1463.91 L2346.46 1463.91 L2346.46 1479.84 Q2346.46 1481.51 2347.02 1482.25 Q2347.6 1482.96 2348.87 1482.96 Q2349.22 1482.96 2349.73 1482.92 Q2350.24 1482.85 2350.4 1482.83 L2350.4 1485.9 Q2349.59 1486.2 2348.73 1486.34 Q2347.88 1486.48 2347.02 1486.48 Q2344.24 1486.48 2343.18 1484.98 Q2342.11 1483.45 2342.11 1479.38 L2342.11 1463.91 L2332.55 1463.91 L2332.55 1485.58 L2328.2 1485.58 L2328.2 1463.91 L2324.89 1463.91 L2324.89 1459.65 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1296.43 1545.45 L1276.16 1545.45 Q1276.64 1554.96 1278.83 1559 Q1281.57 1563.97 1286.31 1563.97 Q1291.09 1563.97 1293.73 1558.97 Q1296.05 1554.58 1296.43 1545.45 M1296.34 1540.03 Q1295.45 1531 1293.73 1527.81 Q1290.99 1522.78 1286.31 1522.78 Q1281.44 1522.78 1278.86 1527.75 Q1276.83 1531.76 1276.22 1540.03 L1296.34 1540.03 M1286.31 1518.01 Q1293.95 1518.01 1298.31 1524.76 Q1302.67 1531.47 1302.67 1543.38 Q1302.67 1555.25 1298.31 1562 Q1293.95 1568.78 1286.31 1568.78 Q1278.64 1568.78 1274.31 1562 Q1269.95 1555.25 1269.95 1543.38 Q1269.95 1531.47 1274.31 1524.76 Q1278.64 1518.01 1286.31 1518.01 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip192)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.866,1268.34 2352.76,1268.34 "/>
<polyline clip-path="url(#clip192)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.866,1009.16 2352.76,1009.16 "/>
<polyline clip-path="url(#clip192)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.866,749.975 2352.76,749.975 "/>
<polyline clip-path="url(#clip192)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="219.866,490.792 2352.76,490.792 "/>
<polyline clip-path="url(#clip190)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.866,1423.18 219.866,425.996 "/>
<polyline clip-path="url(#clip190)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.866,1268.34 238.764,1268.34 "/>
<polyline clip-path="url(#clip190)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.866,1009.16 238.764,1009.16 "/>
<polyline clip-path="url(#clip190)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.866,749.975 238.764,749.975 "/>
<polyline clip-path="url(#clip190)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="219.866,490.792 238.764,490.792 "/>
<path clip-path="url(#clip190)" d="M126.205 1254.14 Q122.593 1254.14 120.765 1257.7 Q118.959 1261.25 118.959 1268.38 Q118.959 1275.48 120.765 1279.05 Q122.593 1282.59 126.205 1282.59 Q129.839 1282.59 131.644 1279.05 Q133.473 1275.48 133.473 1268.38 Q133.473 1261.25 131.644 1257.7 Q129.839 1254.14 126.205 1254.14 M126.205 1250.44 Q132.015 1250.44 135.07 1255.04 Q138.149 1259.63 138.149 1268.38 Q138.149 1277.1 135.07 1281.71 Q132.015 1286.29 126.205 1286.29 Q120.394 1286.29 117.316 1281.71 Q114.26 1277.1 114.26 1268.38 Q114.26 1259.63 117.316 1255.04 Q120.394 1250.44 126.205 1250.44 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M146.366 1279.74 L151.251 1279.74 L151.251 1285.62 L146.366 1285.62 L146.366 1279.74 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M174.283 1255.14 L162.477 1273.58 L174.283 1273.58 L174.283 1255.14 M173.056 1251.06 L178.936 1251.06 L178.936 1273.58 L183.866 1273.58 L183.866 1277.47 L178.936 1277.47 L178.936 1285.62 L174.283 1285.62 L174.283 1277.47 L158.681 1277.47 L158.681 1272.96 L173.056 1251.06 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M126.529 994.957 Q122.918 994.957 121.089 998.521 Q119.283 1002.06 119.283 1009.19 Q119.283 1016.3 121.089 1019.86 Q122.918 1023.41 126.529 1023.41 Q130.163 1023.41 131.968 1019.86 Q133.797 1016.3 133.797 1009.19 Q133.797 1002.06 131.968 998.521 Q130.163 994.957 126.529 994.957 M126.529 991.253 Q132.339 991.253 135.394 995.859 Q138.473 1000.44 138.473 1009.19 Q138.473 1017.92 135.394 1022.53 Q132.339 1027.11 126.529 1027.11 Q120.718 1027.11 117.64 1022.53 Q114.584 1017.92 114.584 1009.19 Q114.584 1000.44 117.64 995.859 Q120.718 991.253 126.529 991.253 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M146.691 1020.56 L151.575 1020.56 L151.575 1026.44 L146.691 1026.44 L146.691 1020.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M172.339 1007.29 Q169.19 1007.29 167.339 1009.45 Q165.51 1011.6 165.51 1015.35 Q165.51 1019.08 167.339 1021.25 Q169.19 1023.41 172.339 1023.41 Q175.487 1023.41 177.315 1021.25 Q179.167 1019.08 179.167 1015.35 Q179.167 1011.6 177.315 1009.45 Q175.487 1007.29 172.339 1007.29 M181.621 992.642 L181.621 996.901 Q179.862 996.068 178.056 995.628 Q176.274 995.188 174.514 995.188 Q169.885 995.188 167.431 998.313 Q165.001 1001.44 164.653 1007.76 Q166.019 1005.74 168.079 1004.68 Q170.139 1003.59 172.616 1003.59 Q177.825 1003.59 180.834 1006.76 Q183.866 1009.91 183.866 1015.35 Q183.866 1020.67 180.718 1023.89 Q177.57 1027.11 172.339 1027.11 Q166.343 1027.11 163.172 1022.53 Q160.001 1017.92 160.001 1009.19 Q160.001 1001 163.89 996.137 Q167.778 991.253 174.329 991.253 Q176.089 991.253 177.871 991.6 Q179.676 991.947 181.621 992.642 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M126.783 735.773 Q123.172 735.773 121.343 739.338 Q119.538 742.88 119.538 750.009 Q119.538 757.116 121.343 760.681 Q123.172 764.222 126.783 764.222 Q130.417 764.222 132.223 760.681 Q134.052 757.116 134.052 750.009 Q134.052 742.88 132.223 739.338 Q130.417 735.773 126.783 735.773 M126.783 732.07 Q132.593 732.07 135.649 736.676 Q138.728 741.259 138.728 750.009 Q138.728 758.736 135.649 763.343 Q132.593 767.926 126.783 767.926 Q120.973 767.926 117.894 763.343 Q114.839 758.736 114.839 750.009 Q114.839 741.259 117.894 736.676 Q120.973 732.07 126.783 732.07 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M146.945 761.375 L151.829 761.375 L151.829 767.255 L146.945 767.255 L146.945 761.375 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M172.014 750.843 Q168.681 750.843 166.76 752.625 Q164.862 754.408 164.862 757.533 Q164.862 760.657 166.76 762.44 Q168.681 764.222 172.014 764.222 Q175.348 764.222 177.269 762.44 Q179.19 760.634 179.19 757.533 Q179.19 754.408 177.269 752.625 Q175.371 750.843 172.014 750.843 M167.339 748.852 Q164.329 748.111 162.64 746.051 Q160.973 743.991 160.973 741.028 Q160.973 736.884 163.913 734.477 Q166.876 732.07 172.014 732.07 Q177.176 732.07 180.116 734.477 Q183.056 736.884 183.056 741.028 Q183.056 743.991 181.366 746.051 Q179.7 748.111 176.714 748.852 Q180.093 749.639 181.968 751.931 Q183.866 754.222 183.866 757.533 Q183.866 762.556 180.788 765.241 Q177.732 767.926 172.014 767.926 Q166.297 767.926 163.218 765.241 Q160.163 762.556 160.163 757.533 Q160.163 754.222 162.061 751.931 Q163.959 749.639 167.339 748.852 M165.626 741.468 Q165.626 744.153 167.292 745.658 Q168.982 747.162 172.014 747.162 Q175.024 747.162 176.714 745.658 Q178.426 744.153 178.426 741.468 Q178.426 738.783 176.714 737.278 Q175.024 735.773 172.014 735.773 Q168.982 735.773 167.292 737.278 Q165.626 738.783 165.626 741.468 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M117.501 504.136 L125.14 504.136 L125.14 477.771 L116.83 479.437 L116.83 475.178 L125.093 473.512 L129.769 473.512 L129.769 504.136 L137.408 504.136 L137.408 508.072 L117.501 508.072 L117.501 504.136 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M146.853 502.192 L151.737 502.192 L151.737 508.072 L146.853 508.072 L146.853 502.192 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M171.922 476.59 Q168.311 476.59 166.482 480.155 Q164.677 483.697 164.677 490.826 Q164.677 497.933 166.482 501.497 Q168.311 505.039 171.922 505.039 Q175.556 505.039 177.362 501.497 Q179.19 497.933 179.19 490.826 Q179.19 483.697 177.362 480.155 Q175.556 476.59 171.922 476.59 M171.922 472.887 Q177.732 472.887 180.788 477.493 Q183.866 482.076 183.866 490.826 Q183.866 499.553 180.788 504.159 Q177.732 508.743 171.922 508.743 Q166.112 508.743 163.033 504.159 Q159.978 499.553 159.978 490.826 Q159.978 482.076 163.033 477.493 Q166.112 472.887 171.922 472.887 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M33.8307 914.148 Q33.2578 915.135 33.0032 916.312 Q32.7167 917.458 32.7167 918.859 Q32.7167 923.824 35.9632 926.497 Q39.1779 929.139 45.2253 929.139 L64.0042 929.139 L64.0042 935.028 L28.3562 935.028 L28.3562 929.139 L33.8944 929.139 Q30.6479 927.293 29.0883 924.333 Q27.4968 921.373 27.4968 917.14 Q27.4968 916.535 27.5923 915.803 Q27.656 915.071 27.8151 914.18 L33.8307 914.148 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M765.041 12.096 L816.204 12.096 L816.204 18.9825 L794.734 18.9825 L794.734 72.576 L786.511 72.576 L786.511 18.9825 L765.041 18.9825 L765.041 12.096 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M837.876 34.1734 Q836.62 33.4443 835.121 33.1202 Q833.663 32.7556 831.881 32.7556 Q825.561 32.7556 822.158 36.8875 Q818.796 40.9789 818.796 48.6757 L818.796 72.576 L811.302 72.576 L811.302 27.2059 L818.796 27.2059 L818.796 34.2544 Q821.146 30.1225 824.913 28.1376 Q828.68 26.1121 834.068 26.1121 Q834.838 26.1121 835.77 26.2337 Q836.701 26.3147 837.835 26.5172 L837.876 34.1734 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M866.313 49.7694 Q857.28 49.7694 853.796 51.8354 Q850.312 53.9013 850.312 58.8839 Q850.312 62.8538 852.905 65.2034 Q855.538 67.5124 860.034 67.5124 Q866.232 67.5124 869.959 63.1374 Q873.726 58.7219 873.726 51.4303 L873.726 49.7694 L866.313 49.7694 M881.18 46.6907 L881.18 72.576 L873.726 72.576 L873.726 65.6895 Q871.174 69.8214 867.367 71.8063 Q863.559 73.7508 858.049 73.7508 Q851.082 73.7508 846.95 69.8619 Q842.859 65.9325 842.859 59.3701 Q842.859 51.7138 847.963 47.825 Q853.107 43.9361 863.275 43.9361 L873.726 43.9361 L873.726 43.2069 Q873.726 38.0623 870.324 35.2672 Q866.961 32.4315 860.845 32.4315 Q856.956 32.4315 853.269 33.3632 Q849.583 34.295 846.18 36.1584 L846.18 29.2718 Q850.272 27.692 854.12 26.9223 Q857.968 26.1121 861.614 26.1121 Q871.458 26.1121 876.319 31.2163 Q881.18 36.3204 881.18 46.6907 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M934.247 45.1919 L934.247 72.576 L926.793 72.576 L926.793 45.4349 Q926.793 38.994 924.282 35.7938 Q921.77 32.5936 916.747 32.5936 Q910.711 32.5936 907.227 36.4419 Q903.744 40.2903 903.744 46.9338 L903.744 72.576 L896.25 72.576 L896.25 27.2059 L903.744 27.2059 L903.744 34.2544 Q906.417 30.163 910.023 28.1376 Q913.668 26.1121 918.408 26.1121 Q926.226 26.1121 930.237 30.9732 Q934.247 35.7938 934.247 45.1919 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M978.037 28.5427 L978.037 35.5912 Q974.878 33.9709 971.475 33.1607 Q968.072 32.3505 964.426 32.3505 Q958.876 32.3505 956.081 34.0519 Q953.327 35.7533 953.327 39.156 Q953.327 41.7486 955.312 43.2475 Q957.297 44.7058 963.292 46.0426 L965.844 46.6097 Q973.784 48.3111 977.106 51.4303 Q980.468 54.509 980.468 60.0587 Q980.468 66.3781 975.445 70.0644 Q970.462 73.7508 961.712 73.7508 Q958.066 73.7508 954.096 73.0216 Q950.167 72.3329 945.792 70.9151 L945.792 63.2184 Q949.924 65.3654 953.934 66.4591 Q957.945 67.5124 961.874 67.5124 Q967.14 67.5124 969.976 65.73 Q972.812 63.9071 972.812 60.6258 Q972.812 57.5877 970.746 55.9673 Q968.72 54.3469 961.793 52.8481 L959.201 52.2405 Q952.274 50.7821 949.195 47.7845 Q946.116 44.7463 946.116 39.4801 Q946.116 33.0797 950.653 29.5959 Q955.19 26.1121 963.535 26.1121 Q967.667 26.1121 971.313 26.7198 Q974.959 27.3274 978.037 28.5427 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1015.31 9.54393 L1015.31 15.7418 L1008.18 15.7418 Q1004.17 15.7418 1002.59 17.3622 Q1001.05 18.9825 1001.05 23.1955 L1001.05 27.2059 L1013.32 27.2059 L1013.32 32.9987 L1001.05 32.9987 L1001.05 72.576 L993.552 72.576 L993.552 32.9987 L986.423 32.9987 L986.423 27.2059 L993.552 27.2059 L993.552 24.0462 Q993.552 16.471 997.077 13.0277 Q1000.6 9.54393 1008.26 9.54393 L1015.31 9.54393 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1060.35 48.0275 L1060.35 51.6733 L1026.08 51.6733 Q1026.57 59.3701 1030.7 63.421 Q1034.87 67.4314 1042.28 67.4314 Q1046.58 67.4314 1050.59 66.3781 Q1054.64 65.3249 1058.61 63.2184 L1058.61 70.267 Q1054.6 71.9684 1050.39 72.8596 Q1046.17 73.7508 1041.84 73.7508 Q1030.98 73.7508 1024.62 67.4314 Q1018.3 61.1119 1018.3 50.3365 Q1018.3 39.1965 1024.3 32.6746 Q1030.33 26.1121 1040.54 26.1121 Q1049.7 26.1121 1055 32.0264 Q1060.35 37.9003 1060.35 48.0275 M1052.9 45.84 Q1052.82 39.7232 1049.45 36.0774 Q1046.13 32.4315 1040.62 32.4315 Q1034.39 32.4315 1030.62 35.9558 Q1026.89 39.4801 1026.32 45.8805 L1052.9 45.84 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1098.88 34.1734 Q1097.62 33.4443 1096.12 33.1202 Q1094.66 32.7556 1092.88 32.7556 Q1086.56 32.7556 1083.16 36.8875 Q1079.8 40.9789 1079.8 48.6757 L1079.8 72.576 L1072.3 72.576 L1072.3 27.2059 L1079.8 27.2059 L1079.8 34.2544 Q1082.15 30.1225 1085.91 28.1376 Q1089.68 26.1121 1095.07 26.1121 Q1095.84 26.1121 1096.77 26.2337 Q1097.7 26.3147 1098.84 26.5172 L1098.88 34.1734 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1168.39 35.9153 Q1171.18 30.8922 1175.07 28.5022 Q1178.96 26.1121 1184.23 26.1121 Q1191.32 26.1121 1195.17 31.0947 Q1199.01 36.0368 1199.01 45.1919 L1199.01 72.576 L1191.52 72.576 L1191.52 45.4349 Q1191.52 38.913 1189.21 35.7533 Q1186.9 32.5936 1182.16 32.5936 Q1176.37 32.5936 1173.01 36.4419 Q1169.65 40.2903 1169.65 46.9338 L1169.65 72.576 L1162.15 72.576 L1162.15 45.4349 Q1162.15 38.8725 1159.84 35.7533 Q1157.53 32.5936 1152.71 32.5936 Q1147 32.5936 1143.64 36.4824 Q1140.28 40.3308 1140.28 46.9338 L1140.28 72.576 L1132.78 72.576 L1132.78 27.2059 L1140.28 27.2059 L1140.28 34.2544 Q1142.83 30.082 1146.39 28.0971 Q1149.96 26.1121 1154.86 26.1121 Q1159.8 26.1121 1163.24 28.6237 Q1166.73 31.1352 1168.39 35.9153 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1234.5 49.7694 Q1225.47 49.7694 1221.98 51.8354 Q1218.5 53.9013 1218.5 58.8839 Q1218.5 62.8538 1221.09 65.2034 Q1223.72 67.5124 1228.22 67.5124 Q1234.42 67.5124 1238.15 63.1374 Q1241.91 58.7219 1241.91 51.4303 L1241.91 49.7694 L1234.5 49.7694 M1249.37 46.6907 L1249.37 72.576 L1241.91 72.576 L1241.91 65.6895 Q1239.36 69.8214 1235.55 71.8063 Q1231.75 73.7508 1226.24 73.7508 Q1219.27 73.7508 1215.14 69.8619 Q1211.05 65.9325 1211.05 59.3701 Q1211.05 51.7138 1216.15 47.825 Q1221.29 43.9361 1231.46 43.9361 L1241.91 43.9361 L1241.91 43.2069 Q1241.91 38.0623 1238.51 35.2672 Q1235.15 32.4315 1229.03 32.4315 Q1225.14 32.4315 1221.46 33.3632 Q1217.77 34.295 1214.37 36.1584 L1214.37 29.2718 Q1218.46 27.692 1222.31 26.9223 Q1226.16 26.1121 1229.8 26.1121 Q1239.64 26.1121 1244.51 31.2163 Q1249.37 36.3204 1249.37 46.6907 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1272.09 14.324 L1272.09 27.2059 L1287.45 27.2059 L1287.45 32.9987 L1272.09 32.9987 L1272.09 57.6282 Q1272.09 63.1779 1273.59 64.7578 Q1275.13 66.3376 1279.79 66.3376 L1287.45 66.3376 L1287.45 72.576 L1279.79 72.576 Q1271.16 72.576 1267.88 69.3758 Q1264.6 66.1351 1264.6 57.6282 L1264.6 32.9987 L1259.13 32.9987 L1259.13 27.2059 L1264.6 27.2059 L1264.6 14.324 L1272.09 14.324 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1323.54 34.1734 Q1322.28 33.4443 1320.78 33.1202 Q1319.33 32.7556 1317.54 32.7556 Q1311.22 32.7556 1307.82 36.8875 Q1304.46 40.9789 1304.46 48.6757 L1304.46 72.576 L1296.96 72.576 L1296.96 27.2059 L1304.46 27.2059 L1304.46 34.2544 Q1306.81 30.1225 1310.58 28.1376 Q1314.34 26.1121 1319.73 26.1121 Q1320.5 26.1121 1321.43 26.2337 Q1322.36 26.3147 1323.5 26.5172 L1323.54 34.1734 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1331.36 27.2059 L1338.81 27.2059 L1338.81 72.576 L1331.36 72.576 L1331.36 27.2059 M1331.36 9.54393 L1338.81 9.54393 L1338.81 18.9825 L1331.36 18.9825 L1331.36 9.54393 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1392.12 27.2059 L1375.71 49.2833 L1392.97 72.576 L1384.18 72.576 L1370.97 54.752 L1357.77 72.576 L1348.98 72.576 L1366.6 48.8377 L1350.48 27.2059 L1359.27 27.2059 L1371.3 43.369 L1383.33 27.2059 L1392.12 27.2059 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1458.8 28.5427 L1458.8 35.5912 Q1455.64 33.9709 1452.24 33.1607 Q1448.83 32.3505 1445.19 32.3505 Q1439.64 32.3505 1436.84 34.0519 Q1434.09 35.7533 1434.09 39.156 Q1434.09 41.7486 1436.07 43.2475 Q1438.06 44.7058 1444.05 46.0426 L1446.61 46.6097 Q1454.55 48.3111 1457.87 51.4303 Q1461.23 54.509 1461.23 60.0587 Q1461.23 66.3781 1456.21 70.0644 Q1451.22 73.7508 1442.47 73.7508 Q1438.83 73.7508 1434.86 73.0216 Q1430.93 72.3329 1426.55 70.9151 L1426.55 63.2184 Q1430.69 65.3654 1434.7 66.4591 Q1438.71 67.5124 1442.64 67.5124 Q1447.9 67.5124 1450.74 65.73 Q1453.57 63.9071 1453.57 60.6258 Q1453.57 57.5877 1451.51 55.9673 Q1449.48 54.3469 1442.55 52.8481 L1439.96 52.2405 Q1433.03 50.7821 1429.96 47.7845 Q1426.88 44.7463 1426.88 39.4801 Q1426.88 33.0797 1431.41 29.5959 Q1435.95 26.1121 1444.3 26.1121 Q1448.43 26.1121 1452.07 26.7198 Q1455.72 27.3274 1458.8 28.5427 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1480.31 65.7705 L1480.31 89.8329 L1472.81 89.8329 L1472.81 27.2059 L1480.31 27.2059 L1480.31 34.0924 Q1482.66 30.0415 1486.22 28.0971 Q1489.83 26.1121 1494.81 26.1121 Q1503.07 26.1121 1508.22 32.6746 Q1513.4 39.2371 1513.4 49.9314 Q1513.4 60.6258 1508.22 67.1883 Q1503.07 73.7508 1494.81 73.7508 Q1489.83 73.7508 1486.22 71.8063 Q1482.66 69.8214 1480.31 65.7705 M1505.67 49.9314 Q1505.67 41.7081 1502.26 37.0496 Q1498.9 32.3505 1492.99 32.3505 Q1487.07 32.3505 1483.67 37.0496 Q1480.31 41.7081 1480.31 49.9314 Q1480.31 58.1548 1483.67 62.8538 Q1487.07 67.5124 1492.99 67.5124 Q1498.9 67.5124 1502.26 62.8538 Q1505.67 58.1548 1505.67 49.9314 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1564.57 48.0275 L1564.57 51.6733 L1530.3 51.6733 Q1530.78 59.3701 1534.92 63.421 Q1539.09 67.4314 1546.5 67.4314 Q1550.79 67.4314 1554.81 66.3781 Q1558.86 65.3249 1562.83 63.2184 L1562.83 70.267 Q1558.82 71.9684 1554.6 72.8596 Q1550.39 73.7508 1546.06 73.7508 Q1535.2 73.7508 1528.84 67.4314 Q1522.52 61.1119 1522.52 50.3365 Q1522.52 39.1965 1528.51 32.6746 Q1534.55 26.1121 1544.76 26.1121 Q1553.91 26.1121 1559.22 32.0264 Q1564.57 37.9003 1564.57 48.0275 M1557.11 45.84 Q1557.03 39.7232 1553.67 36.0774 Q1550.35 32.4315 1544.84 32.4315 Q1538.6 32.4315 1534.83 35.9558 Q1531.11 39.4801 1530.54 45.8805 L1557.11 45.84 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1609.45 28.9478 L1609.45 35.9153 Q1606.29 34.1734 1603.09 33.3227 Q1599.93 32.4315 1596.69 32.4315 Q1589.44 32.4315 1585.43 37.0496 Q1581.42 41.6271 1581.42 49.9314 Q1581.42 58.2358 1585.43 62.8538 Q1589.44 67.4314 1596.69 67.4314 Q1599.93 67.4314 1603.09 66.5807 Q1606.29 65.6895 1609.45 63.9476 L1609.45 70.8341 Q1606.33 72.2924 1602.97 73.0216 Q1599.65 73.7508 1595.88 73.7508 Q1585.63 73.7508 1579.6 67.3098 Q1573.56 60.8689 1573.56 49.9314 Q1573.56 38.832 1579.64 32.472 Q1585.75 26.1121 1596.37 26.1121 Q1599.81 26.1121 1603.09 26.8413 Q1606.37 27.5299 1609.45 28.9478 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1629.79 14.324 L1629.79 27.2059 L1645.14 27.2059 L1645.14 32.9987 L1629.79 32.9987 L1629.79 57.6282 Q1629.79 63.1779 1631.29 64.7578 Q1632.83 66.3376 1637.48 66.3376 L1645.14 66.3376 L1645.14 72.576 L1637.48 72.576 Q1628.86 72.576 1625.57 69.3758 Q1622.29 66.1351 1622.29 57.6282 L1622.29 32.9987 L1616.82 32.9987 L1616.82 27.2059 L1622.29 27.2059 L1622.29 14.324 L1629.79 14.324 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1681.23 34.1734 Q1679.98 33.4443 1678.48 33.1202 Q1677.02 32.7556 1675.24 32.7556 Q1668.92 32.7556 1665.52 36.8875 Q1662.15 40.9789 1662.15 48.6757 L1662.15 72.576 L1654.66 72.576 L1654.66 27.2059 L1662.15 27.2059 L1662.15 34.2544 Q1664.5 30.1225 1668.27 28.1376 Q1672.04 26.1121 1677.43 26.1121 Q1678.2 26.1121 1679.13 26.2337 Q1680.06 26.3147 1681.19 26.5172 L1681.23 34.1734 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1688.28 54.671 L1688.28 27.2059 L1695.74 27.2059 L1695.74 54.3874 Q1695.74 60.8284 1698.25 64.0691 Q1700.76 67.2693 1705.78 67.2693 Q1711.82 67.2693 1715.3 63.421 Q1718.83 59.5726 1718.83 52.9291 L1718.83 27.2059 L1726.28 27.2059 L1726.28 72.576 L1718.83 72.576 L1718.83 65.6084 Q1716.11 69.7404 1712.51 71.7658 Q1708.94 73.7508 1704.2 73.7508 Q1696.38 73.7508 1692.33 68.8897 Q1688.28 64.0286 1688.28 54.671 M1707.04 26.1121 L1707.04 26.1121 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1776.96 35.9153 Q1779.75 30.8922 1783.64 28.5022 Q1787.53 26.1121 1792.8 26.1121 Q1799.88 26.1121 1803.73 31.0947 Q1807.58 36.0368 1807.58 45.1919 L1807.58 72.576 L1800.09 72.576 L1800.09 45.4349 Q1800.09 38.913 1797.78 35.7533 Q1795.47 32.5936 1790.73 32.5936 Q1784.94 32.5936 1781.57 36.4419 Q1778.21 40.2903 1778.21 46.9338 L1778.21 72.576 L1770.72 72.576 L1770.72 45.4349 Q1770.72 38.8725 1768.41 35.7533 Q1766.1 32.5936 1761.28 32.5936 Q1755.57 32.5936 1752.21 36.4824 Q1748.84 40.3308 1748.84 46.9338 L1748.84 72.576 L1741.35 72.576 L1741.35 27.2059 L1748.84 27.2059 L1748.84 34.2544 Q1751.4 30.082 1754.96 28.0971 Q1758.52 26.1121 1763.43 26.1121 Q1768.37 26.1121 1771.81 28.6237 Q1775.3 31.1352 1776.96 35.9153 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><line clip-path="url(#clip192)" x1="280.231" y1="490.792" x2="280.231" y2="474.792" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="490.792" x2="264.231" y2="490.792" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="490.792" x2="280.231" y2="506.792" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="490.792" x2="296.231" y2="490.792" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="490.792" x2="280.231" y2="474.792" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="490.792" x2="264.231" y2="490.792" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="490.792" x2="280.231" y2="506.792" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="490.792" x2="296.231" y2="490.792" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1286.31" y1="600.983" x2="1286.31" y2="584.983" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1286.31" y1="600.983" x2="1270.31" y2="600.983" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1286.31" y1="600.983" x2="1286.31" y2="616.983" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1286.31" y1="600.983" x2="1302.31" y2="600.983" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="677.928" x2="280.231" y2="661.928" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="677.928" x2="264.231" y2="677.928" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="677.928" x2="280.231" y2="693.928" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="677.928" x2="296.231" y2="677.928" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2067.96" y1="828.047" x2="2067.96" y2="812.047" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2067.96" y1="828.047" x2="2051.96" y2="828.047" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2067.96" y1="828.047" x2="2067.96" y2="844.047" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2067.96" y1="828.047" x2="2083.96" y2="828.047" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="504.663" y1="828.047" x2="504.663" y2="812.047" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="504.663" y1="828.047" x2="488.663" y2="828.047" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="504.663" y1="828.047" x2="504.663" y2="844.047" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="504.663" y1="828.047" x2="520.663" y2="828.047" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="860.62" y1="953.801" x2="860.62" y2="937.801" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="860.62" y1="953.801" x2="844.62" y2="953.801" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="860.62" y1="953.801" x2="860.62" y2="969.801" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="860.62" y1="953.801" x2="876.62" y2="953.801" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1712" y1="953.801" x2="1712" y2="937.801" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1712" y1="953.801" x2="1696" y2="953.801" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1712" y1="953.801" x2="1712" y2="969.801" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1712" y1="953.801" x2="1728" y2="953.801" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2292.39" y1="1003.24" x2="2292.39" y2="987.241" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2292.39" y1="1003.24" x2="2276.39" y2="1003.24" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2292.39" y1="1003.24" x2="2292.39" y2="1019.24" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2292.39" y1="1003.24" x2="2308.39" y2="1003.24" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1286.31" y1="1075.24" x2="1286.31" y2="1059.24" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1286.31" y1="1075.24" x2="1270.31" y2="1075.24" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1286.31" y1="1075.24" x2="1286.31" y2="1091.24" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1286.31" y1="1075.24" x2="1302.31" y2="1075.24" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1802.08" y1="1102.97" x2="1802.08" y2="1086.97" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1802.08" y1="1102.97" x2="1786.08" y2="1102.97" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1802.08" y1="1102.97" x2="1802.08" y2="1118.97" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1802.08" y1="1102.97" x2="1818.08" y2="1102.97" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="770.546" y1="1102.97" x2="770.546" y2="1086.97" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="770.546" y1="1102.97" x2="754.546" y2="1102.97" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="770.546" y1="1102.97" x2="770.546" y2="1118.97" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="770.546" y1="1102.97" x2="786.546" y2="1102.97" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1015.41" y1="1103.92" x2="1015.41" y2="1087.92" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1015.41" y1="1103.92" x2="999.407" y2="1103.92" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1015.41" y1="1103.92" x2="1015.41" y2="1119.92" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1015.41" y1="1103.92" x2="1031.41" y2="1103.92" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1557.21" y1="1103.92" x2="1557.21" y2="1087.92" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1557.21" y1="1103.92" x2="1541.21" y2="1103.92" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1557.21" y1="1103.92" x2="1557.21" y2="1119.92" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1557.21" y1="1103.92" x2="1573.21" y2="1103.92" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2013.47" y1="1115.55" x2="2013.47" y2="1099.55" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2013.47" y1="1115.55" x2="1997.47" y2="1115.55" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2013.47" y1="1115.55" x2="2013.47" y2="1131.55" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2013.47" y1="1115.55" x2="2029.47" y2="1115.55" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="559.15" y1="1115.55" x2="559.15" y2="1099.55" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="559.15" y1="1115.55" x2="543.15" y2="1115.55" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="559.15" y1="1115.55" x2="559.15" y2="1131.55" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="559.15" y1="1115.55" x2="575.15" y2="1115.55" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1230.29" y1="1129.93" x2="1230.29" y2="1113.93" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1230.29" y1="1129.93" x2="1214.29" y2="1129.93" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1230.29" y1="1129.93" x2="1230.29" y2="1145.93" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1230.29" y1="1129.93" x2="1246.29" y2="1129.93" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1342.33" y1="1129.93" x2="1342.33" y2="1113.93" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1342.33" y1="1129.93" x2="1326.33" y2="1129.93" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1342.33" y1="1129.93" x2="1342.33" y2="1145.93" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1342.33" y1="1129.93" x2="1358.33" y2="1129.93" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="931.552" y1="1144.61" x2="931.552" y2="1128.61" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="931.552" y1="1144.61" x2="915.552" y2="1144.61" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="931.552" y1="1144.61" x2="931.552" y2="1160.61" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="931.552" y1="1144.61" x2="947.552" y2="1144.61" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1641.07" y1="1144.61" x2="1641.07" y2="1128.61" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1641.07" y1="1144.61" x2="1625.07" y2="1144.61" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1641.07" y1="1144.61" x2="1641.07" y2="1160.61" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1641.07" y1="1144.61" x2="1657.07" y2="1144.61" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2181.97" y1="1165.38" x2="2181.97" y2="1149.38" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2181.97" y1="1165.38" x2="2165.97" y2="1165.38" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2181.97" y1="1165.38" x2="2181.97" y2="1181.38" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2181.97" y1="1165.38" x2="2197.97" y2="1165.38" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="390.648" y1="1165.38" x2="390.648" y2="1149.38" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="390.648" y1="1165.38" x2="374.648" y2="1165.38" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="390.648" y1="1165.38" x2="390.648" y2="1181.38" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="390.648" y1="1165.38" x2="406.648" y2="1165.38" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<circle clip-path="url(#clip192)" cx="1541.83" cy="687.107" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="1030.8" cy="687.107" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="499.453" cy="703.429" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="2073.17" cy="703.429" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="854.559" cy="724.902" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="1718.06" cy="724.902" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="793.542" cy="864.814" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="1779.08" cy="864.814" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="1490.03" cy="946.306" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="1082.59" cy="946.306" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="546.61" cy="1041.86" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="2026.01" cy="1041.86" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="2207.08" cy="1103.22" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="365.544" cy="1103.22" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="1139" cy="1126.58" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="1433.62" cy="1126.58" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="534.253" cy="1139.5" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="2038.37" cy="1139.5" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="1922.08" cy="1154.49" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip192)" cx="650.539" cy="1154.49" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<line clip-path="url(#clip192)" x1="280.231" y1="736.443" x2="280.231" y2="720.443" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="736.443" x2="264.231" y2="736.443" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="736.443" x2="280.231" y2="752.443" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="736.443" x2="296.231" y2="736.443" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2292.39" y1="765.204" x2="2292.39" y2="749.204" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2292.39" y1="765.204" x2="2276.39" y2="765.204" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2292.39" y1="765.204" x2="2292.39" y2="781.204" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2292.39" y1="765.204" x2="2308.39" y2="765.204" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1005.89" y1="808.714" x2="1005.89" y2="792.714" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1005.89" y1="808.714" x2="989.893" y2="808.714" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1005.89" y1="808.714" x2="1005.89" y2="824.714" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1005.89" y1="808.714" x2="1021.89" y2="808.714" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1566.73" y1="808.714" x2="1566.73" y2="792.714" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1566.73" y1="808.714" x2="1550.73" y2="808.714" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1566.73" y1="808.714" x2="1566.73" y2="824.714" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1566.73" y1="808.714" x2="1582.73" y2="808.714" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1891.16" y1="898.022" x2="1891.16" y2="882.022" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1891.16" y1="898.022" x2="1875.16" y2="898.022" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1891.16" y1="898.022" x2="1891.16" y2="914.022" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1891.16" y1="898.022" x2="1907.16" y2="898.022" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="681.461" y1="898.022" x2="681.461" y2="882.022" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="681.461" y1="898.022" x2="665.461" y2="898.022" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="681.461" y1="898.022" x2="681.461" y2="914.022" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="681.461" y1="898.022" x2="697.461" y2="898.022" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1361.5" y1="950.363" x2="1361.5" y2="934.363" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1361.5" y1="950.363" x2="1345.5" y2="950.363" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1361.5" y1="950.363" x2="1361.5" y2="966.363" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1361.5" y1="950.363" x2="1377.5" y2="950.363" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1211.12" y1="950.363" x2="1211.12" y2="934.363" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1211.12" y1="950.363" x2="1195.12" y2="950.363" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1211.12" y1="950.363" x2="1211.12" y2="966.363" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1211.12" y1="950.363" x2="1227.12" y2="950.363" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1375.7" y1="951.278" x2="1375.7" y2="935.278" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1375.7" y1="951.278" x2="1359.7" y2="951.278" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1375.7" y1="951.278" x2="1375.7" y2="967.278" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1375.7" y1="951.278" x2="1391.7" y2="951.278" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1196.93" y1="951.278" x2="1196.93" y2="935.278" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1196.93" y1="951.278" x2="1180.93" y2="951.278" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1196.93" y1="951.278" x2="1196.93" y2="967.278" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1196.93" y1="951.278" x2="1212.93" y2="951.278" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1302.19" y1="987.267" x2="1302.19" y2="971.267" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1302.19" y1="987.267" x2="1286.19" y2="987.267" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1302.19" y1="987.267" x2="1302.19" y2="1003.27" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1302.19" y1="987.267" x2="1318.19" y2="987.267" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1270.43" y1="987.267" x2="1270.43" y2="971.267" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1270.43" y1="987.267" x2="1254.43" y2="987.267" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1270.43" y1="987.267" x2="1270.43" y2="1003.27" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1270.43" y1="987.267" x2="1286.43" y2="987.267" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="1009.48" x2="280.231" y2="993.483" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="1009.48" x2="264.231" y2="1009.48" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="1009.48" x2="280.231" y2="1025.48" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="280.231" y1="1009.48" x2="296.231" y2="1009.48" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1664.21" y1="1019.27" x2="1664.21" y2="1003.27" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1664.21" y1="1019.27" x2="1648.21" y2="1019.27" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1664.21" y1="1019.27" x2="1664.21" y2="1035.27" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1664.21" y1="1019.27" x2="1680.21" y2="1019.27" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="908.409" y1="1019.27" x2="908.409" y2="1003.27" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="908.409" y1="1019.27" x2="892.409" y2="1019.27" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="908.409" y1="1019.27" x2="908.409" y2="1035.27" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="908.409" y1="1019.27" x2="924.409" y2="1019.27" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="439.574" y1="1031.48" x2="439.574" y2="1015.48" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="439.574" y1="1031.48" x2="423.574" y2="1031.48" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="439.574" y1="1031.48" x2="439.574" y2="1047.48" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="439.574" y1="1031.48" x2="455.574" y2="1031.48" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2133.05" y1="1031.48" x2="2133.05" y2="1015.48" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2133.05" y1="1031.48" x2="2117.05" y2="1031.48" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2133.05" y1="1031.48" x2="2133.05" y2="1047.48" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="2133.05" y1="1031.48" x2="2149.05" y2="1031.48" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1109.09" y1="1044.78" x2="1109.09" y2="1028.78" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1109.09" y1="1044.78" x2="1093.09" y2="1044.78" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1109.09" y1="1044.78" x2="1109.09" y2="1060.78" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1109.09" y1="1044.78" x2="1125.09" y2="1044.78" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1463.54" y1="1044.78" x2="1463.54" y2="1028.78" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1463.54" y1="1044.78" x2="1447.54" y2="1044.78" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1463.54" y1="1044.78" x2="1463.54" y2="1060.78" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="1463.54" y1="1044.78" x2="1479.54" y2="1044.78" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="471.569" y1="1066.85" x2="471.569" y2="1050.85" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="471.569" y1="1066.85" x2="455.569" y2="1066.85" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="471.569" y1="1066.85" x2="471.569" y2="1082.85" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip192)" x1="471.569" y1="1066.85" x2="487.569" y2="1066.85" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<path clip-path="url(#clip192)" d="M978.491 823.013 L962.491 839.013 L978.491 855.013 L994.491 839.013 L978.491 823.013 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M1594.13 823.013 L1578.13 839.013 L1594.13 855.013 L1610.13 839.013 L1594.13 823.013 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M470.964 900.126 L454.964 916.126 L470.964 932.126 L486.964 916.126 L470.964 900.126 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M2101.66 900.126 L2085.66 916.126 L2101.66 932.126 L2117.66 916.126 L2101.66 900.126 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M1347.32 979.24 L1331.32 995.24 L1347.32 1011.24 L1363.32 995.24 L1347.32 979.24 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M1225.3 979.24 L1209.3 995.24 L1225.3 1011.24 L1241.3 995.24 L1225.3 979.24 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M420.62 1077.01 L404.62 1093.01 L420.62 1109.01 L436.62 1093.01 L420.62 1077.01 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M2152 1077.01 L2136 1093.01 L2152 1109.01 L2168 1093.01 L2152 1077.01 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M2174.73 1303.85 L2158.73 1319.85 L2174.73 1335.85 L2190.73 1319.85 L2174.73 1303.85 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M397.89 1303.85 L381.89 1319.85 L397.89 1335.85 L413.89 1319.85 L397.89 1303.85 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M562.429 1318.38 L546.429 1334.38 L562.429 1350.38 L578.429 1334.38 L562.429 1318.38 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M2010.19 1318.38 L1994.19 1334.38 L2010.19 1350.38 L2026.19 1334.38 L2010.19 1318.38 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M1252.57 1321.12 L1236.57 1337.12 L1252.57 1353.12 L1268.57 1337.12 L1252.57 1321.12 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M1320.05 1321.12 L1304.05 1337.12 L1320.05 1353.12 L1336.05 1337.12 L1320.05 1321.12 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M897.49 1377.87 L881.49 1393.87 L897.49 1409.87 L913.49 1393.87 L897.49 1377.87 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M1675.13 1377.87 L1659.13 1393.87 L1675.13 1409.87 L1691.13 1393.87 L1675.13 1377.87 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M1589.99 1389.41 L1573.99 1405.41 L1589.99 1421.41 L1605.99 1405.41 L1589.99 1389.41 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M982.634 1389.41 L966.634 1405.41 L982.634 1421.41 L998.634 1405.41 L982.634 1389.41 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M2033.79 1407.18 L2017.79 1423.18 L2033.79 1439.18 L2049.79 1423.18 L2033.79 1407.18 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip192)" d="M538.834 1407.18 L522.834 1423.18 L538.834 1439.18 L554.834 1423.18 L538.834 1407.18 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip190)" d="M1011.82 382.672 L1560.8 382.672 L1560.8 123.472 L1011.82 123.472  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<polyline clip-path="url(#clip190)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1011.82,382.672 1560.8,382.672 1560.8,123.472 1011.82,123.472 1011.82,382.672 "/>
<line clip-path="url(#clip190)" x1="1106.62" y1="175.312" x2="1106.62" y2="152.557" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip190)" x1="1106.62" y1="175.312" x2="1083.86" y2="175.312" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip190)" x1="1106.62" y1="175.312" x2="1106.62" y2="198.068" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip190)" x1="1106.62" y1="175.312" x2="1129.37" y2="175.312" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<path clip-path="url(#clip190)" d="M1201.41 158.032 L1206.09 158.032 L1206.09 192.592 L1201.41 192.592 L1201.41 158.032 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1230.23 170.648 Q1229.51 170.231 1228.66 170.046 Q1227.82 169.838 1226.8 169.838 Q1223.19 169.838 1221.25 172.199 Q1219.33 174.537 1219.33 178.935 L1219.33 192.592 L1215.04 192.592 L1215.04 166.666 L1219.33 166.666 L1219.33 170.694 Q1220.67 168.333 1222.82 167.199 Q1224.98 166.041 1228.05 166.041 Q1228.49 166.041 1229.03 166.111 Q1229.56 166.157 1230.21 166.273 L1230.23 170.648 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1248.89 170.648 Q1248.17 170.231 1247.31 170.046 Q1246.48 169.838 1245.46 169.838 Q1241.85 169.838 1239.91 172.199 Q1237.98 174.537 1237.98 178.935 L1237.98 192.592 L1233.7 192.592 L1233.7 166.666 L1237.98 166.666 L1237.98 170.694 Q1239.33 168.333 1241.48 167.199 Q1243.63 166.041 1246.71 166.041 Q1247.15 166.041 1247.68 166.111 Q1248.22 166.157 1248.86 166.273 L1248.89 170.648 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1274.49 178.564 L1274.49 180.648 L1254.91 180.648 Q1255.18 185.046 1257.54 187.361 Q1259.93 189.652 1264.16 189.652 Q1266.62 189.652 1268.91 189.05 Q1271.22 188.449 1273.49 187.245 L1273.49 191.273 Q1271.2 192.245 1268.79 192.754 Q1266.39 193.263 1263.91 193.263 Q1257.71 193.263 1254.07 189.652 Q1250.46 186.041 1250.46 179.884 Q1250.46 173.518 1253.89 169.791 Q1257.34 166.041 1263.17 166.041 Q1268.4 166.041 1271.43 169.421 Q1274.49 172.777 1274.49 178.564 M1270.23 177.314 Q1270.18 173.819 1268.26 171.736 Q1266.36 169.652 1263.22 169.652 Q1259.65 169.652 1257.5 171.666 Q1255.37 173.68 1255.04 177.338 L1270.23 177.314 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1285.6 188.703 L1285.6 202.453 L1281.32 202.453 L1281.32 166.666 L1285.6 166.666 L1285.6 170.602 Q1286.94 168.287 1288.98 167.176 Q1291.04 166.041 1293.89 166.041 Q1298.61 166.041 1301.55 169.791 Q1304.51 173.541 1304.51 179.652 Q1304.51 185.763 1301.55 189.513 Q1298.61 193.263 1293.89 193.263 Q1291.04 193.263 1288.98 192.152 Q1286.94 191.018 1285.6 188.703 M1300.09 179.652 Q1300.09 174.953 1298.15 172.291 Q1296.22 169.606 1292.85 169.606 Q1289.47 169.606 1287.52 172.291 Q1285.6 174.953 1285.6 179.652 Q1285.6 184.351 1287.52 187.037 Q1289.47 189.699 1292.85 189.699 Q1296.22 189.699 1298.15 187.037 Q1300.09 184.351 1300.09 179.652 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1311.18 156.574 L1320.99 156.574 L1320.99 159.884 L1315.44 159.884 L1315.44 195.532 L1320.99 195.532 L1320.99 198.842 L1311.18 198.842 L1311.18 156.574 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1350.97 159.166 L1350.97 163.727 Q1348.31 162.453 1345.95 161.828 Q1343.59 161.203 1341.39 161.203 Q1337.57 161.203 1335.48 162.685 Q1333.42 164.166 1333.42 166.898 Q1333.42 169.189 1334.79 170.37 Q1336.18 171.527 1340.02 172.245 L1342.84 172.824 Q1348.08 173.819 1350.55 176.342 Q1353.05 178.842 1353.05 183.055 Q1353.05 188.078 1349.67 190.671 Q1346.32 193.263 1339.81 193.263 Q1337.36 193.263 1334.58 192.708 Q1331.83 192.152 1328.86 191.064 L1328.86 186.25 Q1331.71 187.847 1334.44 188.657 Q1337.17 189.467 1339.81 189.467 Q1343.82 189.467 1345.99 187.893 Q1348.17 186.319 1348.17 183.402 Q1348.17 180.856 1346.59 179.421 Q1345.04 177.986 1341.48 177.268 L1338.63 176.713 Q1333.4 175.671 1331.06 173.449 Q1328.72 171.226 1328.72 167.268 Q1328.72 162.685 1331.94 160.046 Q1335.18 157.407 1340.85 157.407 Q1343.28 157.407 1345.81 157.847 Q1348.33 158.287 1350.97 159.166 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1359.81 158.032 L1364.51 158.032 L1364.51 179.027 Q1364.51 184.583 1366.53 187.037 Q1368.54 189.467 1373.05 189.467 Q1377.54 189.467 1379.56 187.037 Q1381.57 184.583 1381.57 179.027 L1381.57 158.032 L1386.27 158.032 L1386.27 179.606 Q1386.27 186.365 1382.91 189.814 Q1379.58 193.263 1373.05 193.263 Q1366.5 193.263 1363.15 189.814 Q1359.81 186.365 1359.81 179.606 L1359.81 158.032 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1396.59 189.953 L1406.41 189.953 L1406.41 192.592 L1392.57 192.592 L1392.57 190.046 Q1393.35 189.328 1394.81 188.032 Q1402.78 180.972 1402.78 178.796 Q1402.78 177.268 1401.57 176.342 Q1400.37 175.393 1398.4 175.393 Q1397.2 175.393 1395.78 175.81 Q1394.37 176.203 1392.71 177.014 L1392.71 174.166 Q1394.49 173.518 1396.02 173.194 Q1397.57 172.87 1398.89 172.87 Q1402.24 172.87 1404.26 174.398 Q1406.27 175.926 1406.27 178.426 Q1406.27 181.643 1398.61 188.217 Q1397.31 189.328 1396.59 189.953 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1423.82 156.574 L1423.82 198.842 L1414 198.842 L1414 195.532 L1419.53 195.532 L1419.53 159.884 L1414 159.884 L1414 156.574 L1423.82 156.574 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1442.59 156.62 Q1439.49 161.944 1437.98 167.152 Q1436.48 172.361 1436.48 177.708 Q1436.48 183.055 1437.98 188.31 Q1439.51 193.541 1442.59 198.842 L1438.89 198.842 Q1435.41 193.402 1433.68 188.148 Q1431.96 182.893 1431.96 177.708 Q1431.96 172.546 1433.68 167.314 Q1435.39 162.083 1438.89 156.62 L1442.59 156.62 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1461.46 161.111 Q1457.84 161.111 1456.02 164.676 Q1454.21 168.217 1454.21 175.347 Q1454.21 182.453 1456.02 186.018 Q1457.84 189.56 1461.46 189.56 Q1465.09 189.56 1466.9 186.018 Q1468.72 182.453 1468.72 175.347 Q1468.72 168.217 1466.9 164.676 Q1465.09 161.111 1461.46 161.111 M1461.46 157.407 Q1467.27 157.407 1470.32 162.014 Q1473.4 166.597 1473.4 175.347 Q1473.4 184.074 1470.32 188.68 Q1467.27 193.263 1461.46 193.263 Q1455.65 193.263 1452.57 188.68 Q1449.51 184.074 1449.51 175.347 Q1449.51 166.597 1452.57 162.014 Q1455.65 157.407 1461.46 157.407 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1480.34 156.62 L1484.05 156.62 Q1487.52 162.083 1489.23 167.314 Q1490.97 172.546 1490.97 177.708 Q1490.97 182.893 1489.23 188.148 Q1487.52 193.402 1484.05 198.842 L1480.34 198.842 Q1483.42 193.541 1484.93 188.31 Q1486.46 183.055 1486.46 177.708 Q1486.46 172.361 1484.93 167.152 Q1483.42 161.944 1480.34 156.62 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><circle clip-path="url(#clip190)" cx="1106.62" cy="227.152" r="20.48" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="4.55111"/>
<path clip-path="url(#clip190)" d="M1201.41 209.872 L1206.09 209.872 L1206.09 244.432 L1201.41 244.432 L1201.41 209.872 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1230.23 222.488 Q1229.51 222.071 1228.66 221.886 Q1227.82 221.678 1226.8 221.678 Q1223.19 221.678 1221.25 224.039 Q1219.33 226.377 1219.33 230.775 L1219.33 244.432 L1215.04 244.432 L1215.04 218.506 L1219.33 218.506 L1219.33 222.534 Q1220.67 220.173 1222.82 219.039 Q1224.98 217.881 1228.05 217.881 Q1228.49 217.881 1229.03 217.951 Q1229.56 217.997 1230.21 218.113 L1230.23 222.488 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1248.89 222.488 Q1248.17 222.071 1247.31 221.886 Q1246.48 221.678 1245.46 221.678 Q1241.85 221.678 1239.91 224.039 Q1237.98 226.377 1237.98 230.775 L1237.98 244.432 L1233.7 244.432 L1233.7 218.506 L1237.98 218.506 L1237.98 222.534 Q1239.33 220.173 1241.48 219.039 Q1243.63 217.881 1246.71 217.881 Q1247.15 217.881 1247.68 217.951 Q1248.22 217.997 1248.86 218.113 L1248.89 222.488 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1274.49 230.404 L1274.49 232.488 L1254.91 232.488 Q1255.18 236.886 1257.54 239.201 Q1259.93 241.492 1264.16 241.492 Q1266.62 241.492 1268.91 240.89 Q1271.22 240.289 1273.49 239.085 L1273.49 243.113 Q1271.2 244.085 1268.79 244.594 Q1266.39 245.103 1263.91 245.103 Q1257.71 245.103 1254.07 241.492 Q1250.46 237.881 1250.46 231.724 Q1250.46 225.358 1253.89 221.631 Q1257.34 217.881 1263.17 217.881 Q1268.4 217.881 1271.43 221.261 Q1274.49 224.617 1274.49 230.404 M1270.23 229.154 Q1270.18 225.659 1268.26 223.576 Q1266.36 221.492 1263.22 221.492 Q1259.65 221.492 1257.5 223.506 Q1255.37 225.52 1255.04 229.178 L1270.23 229.154 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1285.6 240.543 L1285.6 254.293 L1281.32 254.293 L1281.32 218.506 L1285.6 218.506 L1285.6 222.442 Q1286.94 220.127 1288.98 219.016 Q1291.04 217.881 1293.89 217.881 Q1298.61 217.881 1301.55 221.631 Q1304.51 225.381 1304.51 231.492 Q1304.51 237.603 1301.55 241.353 Q1298.61 245.103 1293.89 245.103 Q1291.04 245.103 1288.98 243.992 Q1286.94 242.858 1285.6 240.543 M1300.09 231.492 Q1300.09 226.793 1298.15 224.131 Q1296.22 221.446 1292.85 221.446 Q1289.47 221.446 1287.52 224.131 Q1285.6 226.793 1285.6 231.492 Q1285.6 236.191 1287.52 238.877 Q1289.47 241.539 1292.85 241.539 Q1296.22 241.539 1298.15 238.877 Q1300.09 236.191 1300.09 231.492 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1311.18 208.414 L1320.99 208.414 L1320.99 211.724 L1315.44 211.724 L1315.44 247.372 L1320.99 247.372 L1320.99 250.682 L1311.18 250.682 L1311.18 208.414 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1350.97 211.006 L1350.97 215.567 Q1348.31 214.293 1345.95 213.668 Q1343.59 213.043 1341.39 213.043 Q1337.57 213.043 1335.48 214.525 Q1333.42 216.006 1333.42 218.738 Q1333.42 221.029 1334.79 222.21 Q1336.18 223.367 1340.02 224.085 L1342.84 224.664 Q1348.08 225.659 1350.55 228.182 Q1353.05 230.682 1353.05 234.895 Q1353.05 239.918 1349.67 242.511 Q1346.32 245.103 1339.81 245.103 Q1337.36 245.103 1334.58 244.548 Q1331.83 243.992 1328.86 242.904 L1328.86 238.09 Q1331.71 239.687 1334.44 240.497 Q1337.17 241.307 1339.81 241.307 Q1343.82 241.307 1345.99 239.733 Q1348.17 238.159 1348.17 235.242 Q1348.17 232.696 1346.59 231.261 Q1345.04 229.826 1341.48 229.108 L1338.63 228.553 Q1333.4 227.511 1331.06 225.289 Q1328.72 223.066 1328.72 219.108 Q1328.72 214.525 1331.94 211.886 Q1335.18 209.247 1340.85 209.247 Q1343.28 209.247 1345.81 209.687 Q1348.33 210.127 1350.97 211.006 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1359.81 209.872 L1364.51 209.872 L1364.51 230.867 Q1364.51 236.423 1366.53 238.877 Q1368.54 241.307 1373.05 241.307 Q1377.54 241.307 1379.56 238.877 Q1381.57 236.423 1381.57 230.867 L1381.57 209.872 L1386.27 209.872 L1386.27 231.446 Q1386.27 238.205 1382.91 241.654 Q1379.58 245.103 1373.05 245.103 Q1366.5 245.103 1363.15 241.654 Q1359.81 238.205 1359.81 231.446 L1359.81 209.872 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1396.59 241.793 L1406.41 241.793 L1406.41 244.432 L1392.57 244.432 L1392.57 241.886 Q1393.35 241.168 1394.81 239.872 Q1402.78 232.812 1402.78 230.636 Q1402.78 229.108 1401.57 228.182 Q1400.37 227.233 1398.4 227.233 Q1397.2 227.233 1395.78 227.65 Q1394.37 228.043 1392.71 228.854 L1392.71 226.006 Q1394.49 225.358 1396.02 225.034 Q1397.57 224.71 1398.89 224.71 Q1402.24 224.71 1404.26 226.238 Q1406.27 227.766 1406.27 230.266 Q1406.27 233.483 1398.61 240.057 Q1397.31 241.168 1396.59 241.793 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1423.82 208.414 L1423.82 250.682 L1414 250.682 L1414 247.372 L1419.53 247.372 L1419.53 211.724 L1414 211.724 L1414 208.414 L1423.82 208.414 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1442.59 208.46 Q1439.49 213.784 1437.98 218.992 Q1436.48 224.201 1436.48 229.548 Q1436.48 234.895 1437.98 240.15 Q1439.51 245.381 1442.59 250.682 L1438.89 250.682 Q1435.41 245.242 1433.68 239.988 Q1431.96 234.733 1431.96 229.548 Q1431.96 224.386 1433.68 219.154 Q1435.39 213.923 1438.89 208.46 L1442.59 208.46 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1452.27 240.497 L1459.9 240.497 L1459.9 214.131 L1451.59 215.798 L1451.59 211.539 L1459.86 209.872 L1464.53 209.872 L1464.53 240.497 L1472.17 240.497 L1472.17 244.432 L1452.27 244.432 L1452.27 240.497 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1488.58 209.872 L1492.52 209.872 L1480.48 248.83 L1476.55 248.83 L1488.58 209.872 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1501.62 240.497 L1517.94 240.497 L1517.94 244.432 L1495.99 244.432 L1495.99 240.497 Q1498.65 237.742 1503.24 233.113 Q1507.84 228.46 1509.02 227.117 Q1511.27 224.594 1512.15 222.858 Q1513.05 221.099 1513.05 219.409 Q1513.05 216.654 1511.11 214.918 Q1509.19 213.182 1506.08 213.182 Q1503.89 213.182 1501.43 213.946 Q1499 214.71 1496.22 216.261 L1496.22 211.539 Q1499.05 210.405 1501.5 209.826 Q1503.96 209.247 1505.99 209.247 Q1511.36 209.247 1514.56 211.932 Q1517.75 214.617 1517.75 219.108 Q1517.75 221.238 1516.94 223.159 Q1516.15 225.057 1514.05 227.65 Q1513.47 228.321 1510.37 231.539 Q1507.27 234.733 1501.62 240.497 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1526.48 208.46 L1530.18 208.46 Q1533.65 213.923 1535.37 219.154 Q1537.1 224.386 1537.1 229.548 Q1537.1 234.733 1535.37 239.988 Q1533.65 245.242 1530.18 250.682 L1526.48 250.682 Q1529.56 245.381 1531.06 240.15 Q1532.59 234.895 1532.59 229.548 Q1532.59 224.201 1531.06 218.992 Q1529.56 213.784 1526.48 208.46 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><line clip-path="url(#clip190)" x1="1106.62" y1="278.992" x2="1106.62" y2="256.237" style="stroke:#3da44d; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip190)" x1="1106.62" y1="278.992" x2="1083.86" y2="278.992" style="stroke:#3da44d; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip190)" x1="1106.62" y1="278.992" x2="1106.62" y2="301.748" style="stroke:#3da44d; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip190)" x1="1106.62" y1="278.992" x2="1129.37" y2="278.992" style="stroke:#3da44d; stroke-width:4.55111; stroke-opacity:1"/>
<path clip-path="url(#clip190)" d="M1201.41 261.712 L1206.09 261.712 L1206.09 296.272 L1201.41 296.272 L1201.41 261.712 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1230.23 274.328 Q1229.51 273.911 1228.66 273.726 Q1227.82 273.518 1226.8 273.518 Q1223.19 273.518 1221.25 275.879 Q1219.33 278.217 1219.33 282.615 L1219.33 296.272 L1215.04 296.272 L1215.04 270.346 L1219.33 270.346 L1219.33 274.374 Q1220.67 272.013 1222.82 270.879 Q1224.98 269.721 1228.05 269.721 Q1228.49 269.721 1229.03 269.791 Q1229.56 269.837 1230.21 269.953 L1230.23 274.328 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1248.89 274.328 Q1248.17 273.911 1247.31 273.726 Q1246.48 273.518 1245.46 273.518 Q1241.85 273.518 1239.91 275.879 Q1237.98 278.217 1237.98 282.615 L1237.98 296.272 L1233.7 296.272 L1233.7 270.346 L1237.98 270.346 L1237.98 274.374 Q1239.33 272.013 1241.48 270.879 Q1243.63 269.721 1246.71 269.721 Q1247.15 269.721 1247.68 269.791 Q1248.22 269.837 1248.86 269.953 L1248.89 274.328 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1274.49 282.244 L1274.49 284.328 L1254.91 284.328 Q1255.18 288.726 1257.54 291.041 Q1259.93 293.332 1264.16 293.332 Q1266.62 293.332 1268.91 292.73 Q1271.22 292.129 1273.49 290.925 L1273.49 294.953 Q1271.2 295.925 1268.79 296.434 Q1266.39 296.943 1263.91 296.943 Q1257.71 296.943 1254.07 293.332 Q1250.46 289.721 1250.46 283.564 Q1250.46 277.198 1253.89 273.471 Q1257.34 269.721 1263.17 269.721 Q1268.4 269.721 1271.43 273.101 Q1274.49 276.457 1274.49 282.244 M1270.23 280.994 Q1270.18 277.499 1268.26 275.416 Q1266.36 273.332 1263.22 273.332 Q1259.65 273.332 1257.5 275.346 Q1255.37 277.36 1255.04 281.018 L1270.23 280.994 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1285.6 292.383 L1285.6 306.133 L1281.32 306.133 L1281.32 270.346 L1285.6 270.346 L1285.6 274.282 Q1286.94 271.967 1288.98 270.856 Q1291.04 269.721 1293.89 269.721 Q1298.61 269.721 1301.55 273.471 Q1304.51 277.221 1304.51 283.332 Q1304.51 289.443 1301.55 293.193 Q1298.61 296.943 1293.89 296.943 Q1291.04 296.943 1288.98 295.832 Q1286.94 294.698 1285.6 292.383 M1300.09 283.332 Q1300.09 278.633 1298.15 275.971 Q1296.22 273.286 1292.85 273.286 Q1289.47 273.286 1287.52 275.971 Q1285.6 278.633 1285.6 283.332 Q1285.6 288.031 1287.52 290.717 Q1289.47 293.379 1292.85 293.379 Q1296.22 293.379 1298.15 290.717 Q1300.09 288.031 1300.09 283.332 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1311.18 260.254 L1320.99 260.254 L1320.99 263.564 L1315.44 263.564 L1315.44 299.212 L1320.99 299.212 L1320.99 302.522 L1311.18 302.522 L1311.18 260.254 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1350.97 262.846 L1350.97 267.407 Q1348.31 266.133 1345.95 265.508 Q1343.59 264.883 1341.39 264.883 Q1337.57 264.883 1335.48 266.365 Q1333.42 267.846 1333.42 270.578 Q1333.42 272.869 1334.79 274.05 Q1336.18 275.207 1340.02 275.925 L1342.84 276.504 Q1348.08 277.499 1350.55 280.022 Q1353.05 282.522 1353.05 286.735 Q1353.05 291.758 1349.67 294.351 Q1346.32 296.943 1339.81 296.943 Q1337.36 296.943 1334.58 296.388 Q1331.83 295.832 1328.86 294.744 L1328.86 289.93 Q1331.71 291.527 1334.44 292.337 Q1337.17 293.147 1339.81 293.147 Q1343.82 293.147 1345.99 291.573 Q1348.17 289.999 1348.17 287.082 Q1348.17 284.536 1346.59 283.101 Q1345.04 281.666 1341.48 280.948 L1338.63 280.393 Q1333.4 279.351 1331.06 277.129 Q1328.72 274.906 1328.72 270.948 Q1328.72 266.365 1331.94 263.726 Q1335.18 261.087 1340.85 261.087 Q1343.28 261.087 1345.81 261.527 Q1348.33 261.967 1350.97 262.846 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1359.81 261.712 L1364.51 261.712 L1364.51 282.707 Q1364.51 288.263 1366.53 290.717 Q1368.54 293.147 1373.05 293.147 Q1377.54 293.147 1379.56 290.717 Q1381.57 288.263 1381.57 282.707 L1381.57 261.712 L1386.27 261.712 L1386.27 283.286 Q1386.27 290.045 1382.91 293.494 Q1379.58 296.943 1373.05 296.943 Q1366.5 296.943 1363.15 293.494 Q1359.81 290.045 1359.81 283.286 L1359.81 261.712 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1396.59 293.633 L1406.41 293.633 L1406.41 296.272 L1392.57 296.272 L1392.57 293.726 Q1393.35 293.008 1394.81 291.712 Q1402.78 284.652 1402.78 282.476 Q1402.78 280.948 1401.57 280.022 Q1400.37 279.073 1398.4 279.073 Q1397.2 279.073 1395.78 279.49 Q1394.37 279.883 1392.71 280.694 L1392.71 277.846 Q1394.49 277.198 1396.02 276.874 Q1397.57 276.55 1398.89 276.55 Q1402.24 276.55 1404.26 278.078 Q1406.27 279.606 1406.27 282.106 Q1406.27 285.323 1398.61 291.897 Q1397.31 293.008 1396.59 293.633 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1423.82 260.254 L1423.82 302.522 L1414 302.522 L1414 299.212 L1419.53 299.212 L1419.53 263.564 L1414 263.564 L1414 260.254 L1423.82 260.254 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1442.59 260.3 Q1439.49 265.624 1437.98 270.832 Q1436.48 276.041 1436.48 281.388 Q1436.48 286.735 1437.98 291.99 Q1439.51 297.221 1442.59 302.522 L1438.89 302.522 Q1435.41 297.082 1433.68 291.828 Q1431.96 286.573 1431.96 281.388 Q1431.96 276.226 1433.68 270.994 Q1435.39 265.763 1438.89 260.3 L1442.59 260.3 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1452.27 292.337 L1459.9 292.337 L1459.9 265.971 L1451.59 267.638 L1451.59 263.379 L1459.86 261.712 L1464.53 261.712 L1464.53 292.337 L1472.17 292.337 L1472.17 296.272 L1452.27 296.272 L1452.27 292.337 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1480.34 260.3 L1484.05 260.3 Q1487.52 265.763 1489.23 270.994 Q1490.97 276.226 1490.97 281.388 Q1490.97 286.573 1489.23 291.828 Q1487.52 297.082 1484.05 302.522 L1480.34 302.522 Q1483.42 297.221 1484.93 291.99 Q1486.46 286.735 1486.46 281.388 Q1486.46 276.041 1484.93 270.832 Q1483.42 265.624 1480.34 260.3 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1106.62 308.077 L1083.86 330.832 L1106.62 353.588 L1129.37 330.832 L1106.62 308.077 Z" fill="#c271d2" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="4.55111"/>
<path clip-path="url(#clip190)" d="M1201.41 313.552 L1206.09 313.552 L1206.09 348.112 L1201.41 348.112 L1201.41 313.552 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1230.23 326.168 Q1229.51 325.751 1228.66 325.566 Q1227.82 325.358 1226.8 325.358 Q1223.19 325.358 1221.25 327.719 Q1219.33 330.057 1219.33 334.455 L1219.33 348.112 L1215.04 348.112 L1215.04 322.186 L1219.33 322.186 L1219.33 326.214 Q1220.67 323.853 1222.82 322.719 Q1224.98 321.561 1228.05 321.561 Q1228.49 321.561 1229.03 321.631 Q1229.56 321.677 1230.21 321.793 L1230.23 326.168 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1248.89 326.168 Q1248.17 325.751 1247.31 325.566 Q1246.48 325.358 1245.46 325.358 Q1241.85 325.358 1239.91 327.719 Q1237.98 330.057 1237.98 334.455 L1237.98 348.112 L1233.7 348.112 L1233.7 322.186 L1237.98 322.186 L1237.98 326.214 Q1239.33 323.853 1241.48 322.719 Q1243.63 321.561 1246.71 321.561 Q1247.15 321.561 1247.68 321.631 Q1248.22 321.677 1248.86 321.793 L1248.89 326.168 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1274.49 334.084 L1274.49 336.168 L1254.91 336.168 Q1255.18 340.566 1257.54 342.881 Q1259.93 345.172 1264.16 345.172 Q1266.62 345.172 1268.91 344.57 Q1271.22 343.969 1273.49 342.765 L1273.49 346.793 Q1271.2 347.765 1268.79 348.274 Q1266.39 348.783 1263.91 348.783 Q1257.71 348.783 1254.07 345.172 Q1250.46 341.561 1250.46 335.404 Q1250.46 329.038 1253.89 325.311 Q1257.34 321.561 1263.17 321.561 Q1268.4 321.561 1271.43 324.941 Q1274.49 328.297 1274.49 334.084 M1270.23 332.834 Q1270.18 329.339 1268.26 327.256 Q1266.36 325.172 1263.22 325.172 Q1259.65 325.172 1257.5 327.186 Q1255.37 329.2 1255.04 332.858 L1270.23 332.834 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1285.6 344.223 L1285.6 357.973 L1281.32 357.973 L1281.32 322.186 L1285.6 322.186 L1285.6 326.122 Q1286.94 323.807 1288.98 322.696 Q1291.04 321.561 1293.89 321.561 Q1298.61 321.561 1301.55 325.311 Q1304.51 329.061 1304.51 335.172 Q1304.51 341.283 1301.55 345.033 Q1298.61 348.783 1293.89 348.783 Q1291.04 348.783 1288.98 347.672 Q1286.94 346.538 1285.6 344.223 M1300.09 335.172 Q1300.09 330.473 1298.15 327.811 Q1296.22 325.126 1292.85 325.126 Q1289.47 325.126 1287.52 327.811 Q1285.6 330.473 1285.6 335.172 Q1285.6 339.871 1287.52 342.557 Q1289.47 345.219 1292.85 345.219 Q1296.22 345.219 1298.15 342.557 Q1300.09 339.871 1300.09 335.172 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1311.18 312.094 L1320.99 312.094 L1320.99 315.404 L1315.44 315.404 L1315.44 351.052 L1320.99 351.052 L1320.99 354.362 L1311.18 354.362 L1311.18 312.094 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1350.97 314.686 L1350.97 319.247 Q1348.31 317.973 1345.95 317.348 Q1343.59 316.723 1341.39 316.723 Q1337.57 316.723 1335.48 318.205 Q1333.42 319.686 1333.42 322.418 Q1333.42 324.709 1334.79 325.89 Q1336.18 327.047 1340.02 327.765 L1342.84 328.344 Q1348.08 329.339 1350.55 331.862 Q1353.05 334.362 1353.05 338.575 Q1353.05 343.598 1349.67 346.191 Q1346.32 348.783 1339.81 348.783 Q1337.36 348.783 1334.58 348.228 Q1331.83 347.672 1328.86 346.584 L1328.86 341.77 Q1331.71 343.367 1334.44 344.177 Q1337.17 344.987 1339.81 344.987 Q1343.82 344.987 1345.99 343.413 Q1348.17 341.839 1348.17 338.922 Q1348.17 336.376 1346.59 334.941 Q1345.04 333.506 1341.48 332.788 L1338.63 332.233 Q1333.4 331.191 1331.06 328.969 Q1328.72 326.746 1328.72 322.788 Q1328.72 318.205 1331.94 315.566 Q1335.18 312.927 1340.85 312.927 Q1343.28 312.927 1345.81 313.367 Q1348.33 313.807 1350.97 314.686 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1359.81 313.552 L1364.51 313.552 L1364.51 334.547 Q1364.51 340.103 1366.53 342.557 Q1368.54 344.987 1373.05 344.987 Q1377.54 344.987 1379.56 342.557 Q1381.57 340.103 1381.57 334.547 L1381.57 313.552 L1386.27 313.552 L1386.27 335.126 Q1386.27 341.885 1382.91 345.334 Q1379.58 348.783 1373.05 348.783 Q1366.5 348.783 1363.15 345.334 Q1359.81 341.885 1359.81 335.126 L1359.81 313.552 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1396.59 345.473 L1406.41 345.473 L1406.41 348.112 L1392.57 348.112 L1392.57 345.566 Q1393.35 344.848 1394.81 343.552 Q1402.78 336.492 1402.78 334.316 Q1402.78 332.788 1401.57 331.862 Q1400.37 330.913 1398.4 330.913 Q1397.2 330.913 1395.78 331.33 Q1394.37 331.723 1392.71 332.534 L1392.71 329.686 Q1394.49 329.038 1396.02 328.714 Q1397.57 328.39 1398.89 328.39 Q1402.24 328.39 1404.26 329.918 Q1406.27 331.446 1406.27 333.946 Q1406.27 337.163 1398.61 343.737 Q1397.31 344.848 1396.59 345.473 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1423.82 312.094 L1423.82 354.362 L1414 354.362 L1414 351.052 L1419.53 351.052 L1419.53 315.404 L1414 315.404 L1414 312.094 L1423.82 312.094 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1442.59 312.14 Q1439.49 317.464 1437.98 322.672 Q1436.48 327.881 1436.48 333.228 Q1436.48 338.575 1437.98 343.83 Q1439.51 349.061 1442.59 354.362 L1438.89 354.362 Q1435.41 348.922 1433.68 343.668 Q1431.96 338.413 1431.96 333.228 Q1431.96 328.066 1433.68 322.834 Q1435.39 317.603 1438.89 312.14 L1442.59 312.14 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1465.62 329.478 Q1468.98 330.196 1470.85 332.464 Q1472.75 334.733 1472.75 338.066 Q1472.75 343.182 1469.23 345.983 Q1465.71 348.783 1459.23 348.783 Q1457.06 348.783 1454.74 348.344 Q1452.45 347.927 1450 347.07 L1450 342.557 Q1451.94 343.691 1454.26 344.27 Q1456.57 344.848 1459.09 344.848 Q1463.49 344.848 1465.78 343.112 Q1468.1 341.376 1468.1 338.066 Q1468.1 335.01 1465.95 333.297 Q1463.82 331.561 1460 331.561 L1455.97 331.561 L1455.97 327.719 L1460.18 327.719 Q1463.63 327.719 1465.46 326.353 Q1467.29 324.964 1467.29 322.372 Q1467.29 319.71 1465.39 318.297 Q1463.52 316.862 1460 316.862 Q1458.08 316.862 1455.88 317.279 Q1453.68 317.696 1451.04 318.575 L1451.04 314.409 Q1453.7 313.668 1456.02 313.297 Q1458.35 312.927 1460.41 312.927 Q1465.74 312.927 1468.84 315.358 Q1471.94 317.765 1471.94 321.885 Q1471.94 324.756 1470.3 326.746 Q1468.65 328.714 1465.62 329.478 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1488.58 313.552 L1492.52 313.552 L1480.48 352.51 L1476.55 352.51 L1488.58 313.552 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1501.62 344.177 L1517.94 344.177 L1517.94 348.112 L1495.99 348.112 L1495.99 344.177 Q1498.65 341.422 1503.24 336.793 Q1507.84 332.14 1509.02 330.797 Q1511.27 328.274 1512.15 326.538 Q1513.05 324.779 1513.05 323.089 Q1513.05 320.334 1511.11 318.598 Q1509.19 316.862 1506.08 316.862 Q1503.89 316.862 1501.43 317.626 Q1499 318.39 1496.22 319.941 L1496.22 315.219 Q1499.05 314.085 1501.5 313.506 Q1503.96 312.927 1505.99 312.927 Q1511.36 312.927 1514.56 315.612 Q1517.75 318.297 1517.75 322.788 Q1517.75 324.918 1516.94 326.839 Q1516.15 328.737 1514.05 331.33 Q1513.47 332.001 1510.37 335.219 Q1507.27 338.413 1501.62 344.177 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip190)" d="M1526.48 312.14 L1530.18 312.14 Q1533.65 317.603 1535.37 322.834 Q1537.1 328.066 1537.1 333.228 Q1537.1 338.413 1535.37 343.668 Q1533.65 348.922 1530.18 354.362 L1526.48 354.362 Q1529.56 349.061 1531.06 343.83 Q1532.59 338.575 1532.59 333.228 Q1532.59 327.881 1531.06 322.672 Q1529.56 317.464 1526.48 312.14 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /></svg>

```

Nevertheless, using the symmetry, this can be remedied rather easily, by imposing the
groundstate to belong to a single class, and comparing the results. We can readily obtain 3
different criteria for determining the SPT phase of the groundstate.

Firstly, we can compare variational energies for states of similar bond dimensions. As we
expect the state of the wrong SPT phase to have to expend some of its expressiveness in
correcting the SPT, it should have a harder time reaching lower energies.

Secondly, when inspecting the spectrum of the transfer matrix, we should see that the wrong
SPT phase has a dominant value that is not in the trivial sector, which leads to a
non-injective MPS.

Finally, the entanglement spectrum of the wrong SPT phase will show degeneracies of all
singular values, which can again be attributed to an attempt to mimick the spectrum of the
right SPT phase.

````julia
V_plus = SU2Space(0 => 10, 1 => 5, 2 => 3)
ψ_plus = InfiniteMPS(ℋ, V_plus)
ψ_plus, = find_groundstate(ψ_plus, H, VUMPS(; maxiter=100))
E_plus = expectation_value(ψ_plus, H)
````

````
1-element PeriodicArray{ComplexF64, 1}:
 -1.4014193313393022 + 8.598537433654346e-17im
````

````julia
V_minus = SU2Space(1//2 => 10, 3//2 => 5, 5//2 => 3)
ψ_minus = InfiniteMPS(ℋ, V_minus)
ψ_minus, = find_groundstate(ψ_minus, H, VUMPS(; maxiter=100))
E_minus = expectation_value(ψ_minus, H)
````

````
1-element PeriodicArray{ComplexF64, 1}:
 -1.4014839739630842 + 3.894494160949478e-17im
````

````julia
transferp_plus = transferplot(
    ψ_plus; sectors=SU2Irrep[0, 1, 2], title="ψ_plus", legend=:outertop
)
transferp_minus = transferplot(
    ψ_minus; sectors=SU2Irrep[0, 1, 2], title="ψ_minus", legend=:outertop
)
plot(transferp_plus, transferp_minus; layout=(1, 2), size=(800, 400))
````

```@raw html
<?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="800" height="400" viewBox="0 0 3200 1600">
<defs>
  <clipPath id="clip220">
    <rect x="0" y="0" width="3200" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip220)" d="M0 1600 L3200 1600 L3200 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip221">
    <rect x="640" y="0" width="2241" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip220)" d="M215.986 1443.7 L1552.76 1443.7 L1552.76 360.224 L215.986 360.224  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip222">
    <rect x="215" y="360" width="1338" height="1084"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip222)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="253.819,1443.7 253.819,360.224 "/>
<polyline clip-path="url(#clip222)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="464.003,1443.7 464.003,360.224 "/>
<polyline clip-path="url(#clip222)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="674.187,1443.7 674.187,360.224 "/>
<polyline clip-path="url(#clip222)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="884.371,1443.7 884.371,360.224 "/>
<polyline clip-path="url(#clip222)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1094.55,1443.7 1094.55,360.224 "/>
<polyline clip-path="url(#clip222)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1304.74,1443.7 1304.74,360.224 "/>
<polyline clip-path="url(#clip222)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1514.92,1443.7 1514.92,360.224 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="215.986,1443.7 1552.76,1443.7 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="253.819,1443.7 253.819,1428.37 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="464.003,1443.7 464.003,1428.37 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="674.187,1443.7 674.187,1428.37 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="884.371,1443.7 884.371,1428.37 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1094.55,1443.7 1094.55,1428.37 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1304.74,1443.7 1304.74,1428.37 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1514.92,1443.7 1514.92,1428.37 "/>
<path clip-path="url(#clip220)" d="M207.581 1481.02 Q203.97 1481.02 202.141 1484.58 Q200.336 1488.12 200.336 1495.25 Q200.336 1502.36 202.141 1505.93 Q203.97 1509.47 207.581 1509.47 Q211.215 1509.47 213.021 1505.93 Q214.85 1502.36 214.85 1495.25 Q214.85 1488.12 213.021 1484.58 Q211.215 1481.02 207.581 1481.02 M207.581 1477.31 Q213.391 1477.31 216.447 1481.92 Q219.526 1486.5 219.526 1495.25 Q219.526 1503.98 216.447 1508.59 Q213.391 1513.17 207.581 1513.17 Q201.771 1513.17 198.692 1508.59 Q195.637 1503.98 195.637 1495.25 Q195.637 1486.5 198.692 1481.92 Q201.771 1477.31 207.581 1477.31 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M234.711 1477.94 L238.646 1477.94 L226.609 1516.9 L222.674 1516.9 L234.711 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M250.683 1477.94 L254.618 1477.94 L242.581 1516.9 L238.646 1516.9 L250.683 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M260.498 1508.56 L268.136 1508.56 L268.136 1482.2 L259.826 1483.87 L259.826 1479.61 L268.09 1477.94 L272.766 1477.94 L272.766 1508.56 L280.405 1508.56 L280.405 1512.5 L260.498 1512.5 L260.498 1508.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M286.493 1486.57 L311.331 1486.57 L311.331 1490.83 L308.067 1490.83 L308.067 1506.76 Q308.067 1508.43 308.622 1509.17 Q309.201 1509.88 310.474 1509.88 Q310.821 1509.88 311.331 1509.84 Q311.84 1509.77 312.002 1509.75 L312.002 1512.82 Q311.192 1513.12 310.335 1513.26 Q309.479 1513.4 308.622 1513.4 Q305.845 1513.4 304.78 1511.9 Q303.715 1510.37 303.715 1506.3 L303.715 1490.83 L294.155 1490.83 L294.155 1512.5 L289.803 1512.5 L289.803 1490.83 L286.493 1490.83 L286.493 1486.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M407.534 1508.56 L415.173 1508.56 L415.173 1482.2 L406.862 1483.87 L406.862 1479.61 L415.126 1477.94 L419.802 1477.94 L419.802 1508.56 L427.441 1508.56 L427.441 1512.5 L407.534 1512.5 L407.534 1508.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M443.853 1477.94 L447.788 1477.94 L435.751 1516.9 L431.816 1516.9 L443.853 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M459.825 1477.94 L463.76 1477.94 L451.723 1516.9 L447.788 1516.9 L459.825 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M482.996 1493.87 Q486.353 1494.58 488.228 1496.85 Q490.126 1499.12 490.126 1502.45 Q490.126 1507.57 486.607 1510.37 Q483.089 1513.17 476.607 1513.17 Q474.431 1513.17 472.117 1512.73 Q469.825 1512.31 467.371 1511.46 L467.371 1506.94 Q469.316 1508.08 471.631 1508.66 Q473.945 1509.24 476.468 1509.24 Q480.867 1509.24 483.158 1507.5 Q485.473 1505.76 485.473 1502.45 Q485.473 1499.4 483.32 1497.69 Q481.191 1495.95 477.371 1495.95 L473.344 1495.95 L473.344 1492.11 L477.556 1492.11 Q481.005 1492.11 482.834 1490.74 Q484.663 1489.35 484.663 1486.76 Q484.663 1484.1 482.765 1482.69 Q480.89 1481.25 477.371 1481.25 Q475.45 1481.25 473.251 1481.67 Q471.052 1482.08 468.413 1482.96 L468.413 1478.8 Q471.075 1478.06 473.39 1477.69 Q475.728 1477.31 477.788 1477.31 Q483.112 1477.31 486.214 1479.75 Q489.316 1482.15 489.316 1486.27 Q489.316 1489.14 487.672 1491.13 Q486.029 1493.1 482.996 1493.87 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M495.635 1486.57 L520.473 1486.57 L520.473 1490.83 L517.209 1490.83 L517.209 1506.76 Q517.209 1508.43 517.765 1509.17 Q518.343 1509.88 519.616 1509.88 Q519.964 1509.88 520.473 1509.84 Q520.982 1509.77 521.144 1509.75 L521.144 1512.82 Q520.334 1513.12 519.478 1513.26 Q518.621 1513.4 517.765 1513.4 Q514.987 1513.4 513.922 1511.9 Q512.857 1510.37 512.857 1506.3 L512.857 1490.83 L503.297 1490.83 L503.297 1512.5 L498.945 1512.5 L498.945 1490.83 L495.635 1490.83 L495.635 1486.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M621.803 1508.56 L638.123 1508.56 L638.123 1512.5 L616.178 1512.5 L616.178 1508.56 Q618.84 1505.81 623.424 1501.18 Q628.03 1496.53 629.211 1495.19 Q631.456 1492.66 632.336 1490.93 Q633.238 1489.17 633.238 1487.48 Q633.238 1484.72 631.294 1482.99 Q629.373 1481.25 626.271 1481.25 Q624.072 1481.25 621.618 1482.01 Q619.187 1482.78 616.41 1484.33 L616.41 1479.61 Q619.234 1478.47 621.687 1477.89 Q624.141 1477.31 626.178 1477.31 Q631.549 1477.31 634.743 1480 Q637.937 1482.69 637.937 1487.18 Q637.937 1489.31 637.127 1491.23 Q636.34 1493.12 634.234 1495.72 Q633.655 1496.39 630.553 1499.61 Q627.451 1502.8 621.803 1508.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M654.905 1477.94 L658.84 1477.94 L646.803 1516.9 L642.868 1516.9 L654.905 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M670.877 1477.94 L674.812 1477.94 L662.775 1516.9 L658.84 1516.9 L670.877 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M694.048 1493.87 Q697.405 1494.58 699.28 1496.85 Q701.178 1499.12 701.178 1502.45 Q701.178 1507.57 697.659 1510.37 Q694.141 1513.17 687.659 1513.17 Q685.483 1513.17 683.169 1512.73 Q680.877 1512.31 678.423 1511.46 L678.423 1506.94 Q680.368 1508.08 682.683 1508.66 Q684.997 1509.24 687.52 1509.24 Q691.919 1509.24 694.21 1507.5 Q696.525 1505.76 696.525 1502.45 Q696.525 1499.4 694.372 1497.69 Q692.243 1495.95 688.423 1495.95 L684.395 1495.95 L684.395 1492.11 L688.608 1492.11 Q692.057 1492.11 693.886 1490.74 Q695.715 1489.35 695.715 1486.76 Q695.715 1484.1 693.817 1482.69 Q691.942 1481.25 688.423 1481.25 Q686.502 1481.25 684.303 1481.67 Q682.104 1482.08 679.465 1482.96 L679.465 1478.8 Q682.127 1478.06 684.442 1477.69 Q686.78 1477.31 688.84 1477.31 Q694.164 1477.31 697.266 1479.75 Q700.368 1482.15 700.368 1486.27 Q700.368 1489.14 698.724 1491.13 Q697.081 1493.1 694.048 1493.87 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M706.687 1486.57 L731.525 1486.57 L731.525 1490.83 L728.261 1490.83 L728.261 1506.76 Q728.261 1508.43 728.817 1509.17 Q729.395 1509.88 730.668 1509.88 Q731.016 1509.88 731.525 1509.84 Q732.034 1509.77 732.196 1509.75 L732.196 1512.82 Q731.386 1513.12 730.529 1513.26 Q729.673 1513.4 728.817 1513.4 Q726.039 1513.4 724.974 1511.9 Q723.909 1510.37 723.909 1506.3 L723.909 1490.83 L714.349 1490.83 L714.349 1512.5 L709.997 1512.5 L709.997 1490.83 L706.687 1490.83 L706.687 1486.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M827.901 1508.56 L835.54 1508.56 L835.54 1482.2 L827.23 1483.87 L827.23 1479.61 L835.494 1477.94 L840.17 1477.94 L840.17 1508.56 L847.809 1508.56 L847.809 1512.5 L827.901 1512.5 L827.901 1508.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M864.221 1477.94 L868.156 1477.94 L856.119 1516.9 L852.184 1516.9 L864.221 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M880.193 1477.94 L884.128 1477.94 L872.091 1516.9 L868.156 1516.9 L880.193 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M890.008 1508.56 L897.646 1508.56 L897.646 1482.2 L889.336 1483.87 L889.336 1479.61 L897.6 1477.94 L902.276 1477.94 L902.276 1508.56 L909.915 1508.56 L909.915 1512.5 L890.008 1512.5 L890.008 1508.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M916.003 1486.57 L940.841 1486.57 L940.841 1490.83 L937.577 1490.83 L937.577 1506.76 Q937.577 1508.43 938.132 1509.17 Q938.711 1509.88 939.984 1509.88 Q940.331 1509.88 940.841 1509.84 Q941.35 1509.77 941.512 1509.75 L941.512 1512.82 Q940.702 1513.12 939.845 1513.26 Q938.989 1513.4 938.132 1513.4 Q935.355 1513.4 934.29 1511.9 Q933.225 1510.37 933.225 1506.3 L933.225 1490.83 L923.665 1490.83 L923.665 1512.5 L919.313 1512.5 L919.313 1490.83 L916.003 1490.83 L916.003 1486.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1051.57 1482.01 L1039.76 1500.46 L1051.57 1500.46 L1051.57 1482.01 M1050.34 1477.94 L1056.22 1477.94 L1056.22 1500.46 L1061.15 1500.46 L1061.15 1504.35 L1056.22 1504.35 L1056.22 1512.5 L1051.57 1512.5 L1051.57 1504.35 L1035.97 1504.35 L1035.97 1499.84 L1050.34 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1075.85 1477.94 L1079.79 1477.94 L1067.75 1516.9 L1063.81 1516.9 L1075.85 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1091.82 1477.94 L1095.76 1477.94 L1083.72 1516.9 L1079.79 1516.9 L1091.82 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1114.99 1493.87 Q1118.35 1494.58 1120.23 1496.85 Q1122.12 1499.12 1122.12 1502.45 Q1122.12 1507.57 1118.61 1510.37 Q1115.09 1513.17 1108.61 1513.17 Q1106.43 1513.17 1104.12 1512.73 Q1101.82 1512.31 1099.37 1511.46 L1099.37 1506.94 Q1101.31 1508.08 1103.63 1508.66 Q1105.94 1509.24 1108.47 1509.24 Q1112.87 1509.24 1115.16 1507.5 Q1117.47 1505.76 1117.47 1502.45 Q1117.47 1499.4 1115.32 1497.69 Q1113.19 1495.95 1109.37 1495.95 L1105.34 1495.95 L1105.34 1492.11 L1109.55 1492.11 Q1113 1492.11 1114.83 1490.74 Q1116.66 1489.35 1116.66 1486.76 Q1116.66 1484.1 1114.76 1482.69 Q1112.89 1481.25 1109.37 1481.25 Q1107.45 1481.25 1105.25 1481.67 Q1103.05 1482.08 1100.41 1482.96 L1100.41 1478.8 Q1103.07 1478.06 1105.39 1477.69 Q1107.73 1477.31 1109.79 1477.31 Q1115.11 1477.31 1118.21 1479.75 Q1121.31 1482.15 1121.31 1486.27 Q1121.31 1489.14 1119.67 1491.13 Q1118.03 1493.1 1114.99 1493.87 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1127.63 1486.57 L1152.47 1486.57 L1152.47 1490.83 L1149.21 1490.83 L1149.21 1506.76 Q1149.21 1508.43 1149.76 1509.17 Q1150.34 1509.88 1151.61 1509.88 Q1151.96 1509.88 1152.47 1509.84 Q1152.98 1509.77 1153.14 1509.75 L1153.14 1512.82 Q1152.33 1513.12 1151.48 1513.26 Q1150.62 1513.4 1149.76 1513.4 Q1146.99 1513.4 1145.92 1511.9 Q1144.86 1510.37 1144.86 1506.3 L1144.86 1490.83 L1135.3 1490.83 L1135.3 1512.5 L1130.94 1512.5 L1130.94 1490.83 L1127.63 1490.83 L1127.63 1486.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1248.28 1477.94 L1266.64 1477.94 L1266.64 1481.88 L1252.56 1481.88 L1252.56 1490.35 Q1253.58 1490 1254.6 1489.84 Q1255.62 1489.65 1256.64 1489.65 Q1262.42 1489.65 1265.8 1492.82 Q1269.18 1496 1269.18 1501.41 Q1269.18 1506.99 1265.71 1510.09 Q1262.24 1513.17 1255.92 1513.17 Q1253.74 1513.17 1251.48 1512.8 Q1249.23 1512.43 1246.82 1511.69 L1246.82 1506.99 Q1248.91 1508.12 1251.13 1508.68 Q1253.35 1509.24 1255.83 1509.24 Q1259.83 1509.24 1262.17 1507.13 Q1264.51 1505.02 1264.51 1501.41 Q1264.51 1497.8 1262.17 1495.69 Q1259.83 1493.59 1255.83 1493.59 Q1253.95 1493.59 1252.08 1494 Q1250.23 1494.42 1248.28 1495.3 L1248.28 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1285.36 1477.94 L1289.3 1477.94 L1277.26 1516.9 L1273.33 1516.9 L1285.36 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1301.34 1477.94 L1305.27 1477.94 L1293.23 1516.9 L1289.3 1516.9 L1301.34 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1324.51 1493.87 Q1327.86 1494.58 1329.74 1496.85 Q1331.64 1499.12 1331.64 1502.45 Q1331.64 1507.57 1328.12 1510.37 Q1324.6 1513.17 1318.12 1513.17 Q1315.94 1513.17 1313.63 1512.73 Q1311.34 1512.31 1308.88 1511.46 L1308.88 1506.94 Q1310.83 1508.08 1313.14 1508.66 Q1315.46 1509.24 1317.98 1509.24 Q1322.38 1509.24 1324.67 1507.5 Q1326.98 1505.76 1326.98 1502.45 Q1326.98 1499.4 1324.83 1497.69 Q1322.7 1495.95 1318.88 1495.95 L1314.85 1495.95 L1314.85 1492.11 L1319.07 1492.11 Q1322.52 1492.11 1324.35 1490.74 Q1326.17 1489.35 1326.17 1486.76 Q1326.17 1484.1 1324.28 1482.69 Q1322.4 1481.25 1318.88 1481.25 Q1316.96 1481.25 1314.76 1481.67 Q1312.56 1482.08 1309.92 1482.96 L1309.92 1478.8 Q1312.59 1478.06 1314.9 1477.69 Q1317.24 1477.31 1319.3 1477.31 Q1324.62 1477.31 1327.72 1479.75 Q1330.83 1482.15 1330.83 1486.27 Q1330.83 1489.14 1329.18 1491.13 Q1327.54 1493.1 1324.51 1493.87 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1337.15 1486.57 L1361.98 1486.57 L1361.98 1490.83 L1358.72 1490.83 L1358.72 1506.76 Q1358.72 1508.43 1359.28 1509.17 Q1359.85 1509.88 1361.13 1509.88 Q1361.47 1509.88 1361.98 1509.84 Q1362.49 1509.77 1362.66 1509.75 L1362.66 1512.82 Q1361.85 1513.12 1360.99 1513.26 Q1360.13 1513.4 1359.28 1513.4 Q1356.5 1513.4 1355.43 1511.9 Q1354.37 1510.37 1354.37 1506.3 L1354.37 1490.83 L1344.81 1490.83 L1344.81 1512.5 L1340.46 1512.5 L1340.46 1490.83 L1337.15 1490.83 L1337.15 1486.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1462.54 1508.56 L1478.86 1508.56 L1478.86 1512.5 L1456.91 1512.5 L1456.91 1508.56 Q1459.58 1505.81 1464.16 1501.18 Q1468.77 1496.53 1469.95 1495.19 Q1472.19 1492.66 1473.07 1490.93 Q1473.97 1489.17 1473.97 1487.48 Q1473.97 1484.72 1472.03 1482.99 Q1470.11 1481.25 1467.01 1481.25 Q1464.81 1481.25 1462.35 1482.01 Q1459.92 1482.78 1457.15 1484.33 L1457.15 1479.61 Q1459.97 1478.47 1462.42 1477.89 Q1464.88 1477.31 1466.91 1477.31 Q1472.28 1477.31 1475.48 1480 Q1478.67 1482.69 1478.67 1487.18 Q1478.67 1489.31 1477.86 1491.23 Q1477.08 1493.12 1474.97 1495.72 Q1474.39 1496.39 1471.29 1499.61 Q1468.19 1502.8 1462.54 1508.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1495.64 1477.94 L1499.58 1477.94 L1487.54 1516.9 L1483.6 1516.9 L1495.64 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1511.61 1477.94 L1515.55 1477.94 L1503.51 1516.9 L1499.58 1516.9 L1511.61 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1521.43 1508.56 L1529.07 1508.56 L1529.07 1482.2 L1520.76 1483.87 L1520.76 1479.61 L1529.02 1477.94 L1533.7 1477.94 L1533.7 1508.56 L1541.33 1508.56 L1541.33 1512.5 L1521.43 1512.5 L1521.43 1508.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1547.42 1486.57 L1572.26 1486.57 L1572.26 1490.83 L1569 1490.83 L1569 1506.76 Q1569 1508.43 1569.55 1509.17 Q1570.13 1509.88 1571.4 1509.88 Q1571.75 1509.88 1572.26 1509.84 Q1572.77 1509.77 1572.93 1509.75 L1572.93 1512.82 Q1572.12 1513.12 1571.27 1513.26 Q1570.41 1513.4 1569.55 1513.4 Q1566.77 1513.4 1565.71 1511.9 Q1564.64 1510.37 1564.64 1506.3 L1564.64 1490.83 L1555.08 1490.83 L1555.08 1512.5 L1550.73 1512.5 L1550.73 1490.83 L1547.42 1490.83 L1547.42 1486.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M894.493 1577.97 L874.218 1577.97 Q874.695 1587.48 876.891 1591.52 Q879.629 1596.49 884.371 1596.49 Q889.145 1596.49 891.787 1591.49 Q894.111 1587.1 894.493 1577.97 M894.397 1572.55 Q893.506 1563.52 891.787 1560.33 Q889.05 1555.3 884.371 1555.3 Q879.501 1555.3 876.923 1560.27 Q874.886 1564.28 874.281 1572.55 L894.397 1572.55 M884.371 1550.53 Q892.01 1550.53 896.37 1557.28 Q900.731 1563.99 900.731 1575.9 Q900.731 1587.77 896.37 1594.52 Q892.01 1601.3 884.371 1601.3 Q876.7 1601.3 872.372 1594.52 Q868.011 1587.77 868.011 1575.9 Q868.011 1563.99 872.372 1557.28 Q876.7 1550.53 884.371 1550.53 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip222)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="215.986,1348 1552.76,1348 "/>
<polyline clip-path="url(#clip222)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="215.986,1115.58 1552.76,1115.58 "/>
<polyline clip-path="url(#clip222)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="215.986,883.164 1552.76,883.164 "/>
<polyline clip-path="url(#clip222)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="215.986,650.746 1552.76,650.746 "/>
<polyline clip-path="url(#clip222)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="215.986,418.328 1552.76,418.328 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="215.986,1443.7 215.986,360.224 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="215.986,1348 234.884,1348 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="215.986,1115.58 234.884,1115.58 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="215.986,883.164 234.884,883.164 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="215.986,650.746 234.884,650.746 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="215.986,418.328 234.884,418.328 "/>
<path clip-path="url(#clip220)" d="M112.408 1333.8 Q108.797 1333.8 106.968 1337.36 Q105.163 1340.91 105.163 1348.04 Q105.163 1355.14 106.968 1358.71 Q108.797 1362.25 112.408 1362.25 Q116.042 1362.25 117.848 1358.71 Q119.676 1355.14 119.676 1348.04 Q119.676 1340.91 117.848 1337.36 Q116.042 1333.8 112.408 1333.8 M112.408 1330.1 Q118.218 1330.1 121.274 1334.7 Q124.352 1339.29 124.352 1348.04 Q124.352 1356.76 121.274 1361.37 Q118.218 1365.95 112.408 1365.95 Q106.598 1365.95 103.519 1361.37 Q100.463 1356.76 100.463 1348.04 Q100.463 1339.29 103.519 1334.7 Q106.598 1330.1 112.408 1330.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M132.57 1359.4 L137.454 1359.4 L137.454 1365.28 L132.57 1365.28 L132.57 1359.4 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M151.667 1361.35 L167.986 1361.35 L167.986 1365.28 L146.042 1365.28 L146.042 1361.35 Q148.704 1358.59 153.287 1353.96 Q157.894 1349.31 159.074 1347.97 Q161.32 1345.44 162.199 1343.71 Q163.102 1341.95 163.102 1340.26 Q163.102 1337.5 161.158 1335.77 Q159.236 1334.03 156.134 1334.03 Q153.935 1334.03 151.482 1334.79 Q149.051 1335.56 146.273 1337.11 L146.273 1332.39 Q149.097 1331.25 151.551 1330.67 Q154.005 1330.1 156.042 1330.1 Q161.412 1330.1 164.607 1332.78 Q167.801 1335.47 167.801 1339.96 Q167.801 1342.09 166.991 1344.01 Q166.204 1345.91 164.097 1348.5 Q163.519 1349.17 160.417 1352.39 Q157.315 1355.58 151.667 1361.35 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M110.325 1101.38 Q106.713 1101.38 104.885 1104.95 Q103.079 1108.49 103.079 1115.62 Q103.079 1122.72 104.885 1126.29 Q106.713 1129.83 110.325 1129.83 Q113.959 1129.83 115.764 1126.29 Q117.593 1122.72 117.593 1115.62 Q117.593 1108.49 115.764 1104.95 Q113.959 1101.38 110.325 1101.38 M110.325 1097.68 Q116.135 1097.68 119.19 1102.28 Q122.269 1106.87 122.269 1115.62 Q122.269 1124.34 119.19 1128.95 Q116.135 1133.53 110.325 1133.53 Q104.514 1133.53 101.436 1128.95 Q98.3802 1124.34 98.3802 1115.62 Q98.3802 1106.87 101.436 1102.28 Q104.514 1097.68 110.325 1097.68 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M130.486 1126.98 L135.371 1126.98 L135.371 1132.86 L130.486 1132.86 L130.486 1126.98 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M158.403 1102.38 L146.597 1120.83 L158.403 1120.83 L158.403 1102.38 M157.176 1098.3 L163.056 1098.3 L163.056 1120.83 L167.986 1120.83 L167.986 1124.71 L163.056 1124.71 L163.056 1132.86 L158.403 1132.86 L158.403 1124.71 L142.801 1124.71 L142.801 1120.2 L157.176 1098.3 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M110.649 868.963 Q107.038 868.963 105.209 872.528 Q103.403 876.07 103.403 883.199 Q103.403 890.306 105.209 893.87 Q107.038 897.412 110.649 897.412 Q114.283 897.412 116.088 893.87 Q117.917 890.306 117.917 883.199 Q117.917 876.07 116.088 872.528 Q114.283 868.963 110.649 868.963 M110.649 865.259 Q116.459 865.259 119.514 869.866 Q122.593 874.449 122.593 883.199 Q122.593 891.926 119.514 896.532 Q116.459 901.116 110.649 901.116 Q104.838 901.116 101.76 896.532 Q98.7042 891.926 98.7042 883.199 Q98.7042 874.449 101.76 869.866 Q104.838 865.259 110.649 865.259 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M130.811 894.565 L135.695 894.565 L135.695 900.444 L130.811 900.444 L130.811 894.565 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M156.459 881.301 Q153.31 881.301 151.459 883.454 Q149.63 885.607 149.63 889.357 Q149.63 893.083 151.459 895.259 Q153.31 897.412 156.459 897.412 Q159.607 897.412 161.435 895.259 Q163.287 893.083 163.287 889.357 Q163.287 885.607 161.435 883.454 Q159.607 881.301 156.459 881.301 M165.741 866.648 L165.741 870.908 Q163.982 870.074 162.176 869.634 Q160.394 869.195 158.634 869.195 Q154.005 869.195 151.551 872.32 Q149.121 875.445 148.773 881.764 Q150.139 879.75 152.199 878.685 Q154.259 877.597 156.736 877.597 Q161.945 877.597 164.954 880.769 Q167.986 883.917 167.986 889.357 Q167.986 894.681 164.838 897.898 Q161.69 901.116 156.459 901.116 Q150.463 901.116 147.292 896.532 Q144.121 891.926 144.121 883.199 Q144.121 875.005 148.01 870.144 Q151.898 865.259 158.449 865.259 Q160.209 865.259 161.991 865.607 Q163.796 865.954 165.741 866.648 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M110.903 636.545 Q107.292 636.545 105.463 640.11 Q103.658 643.651 103.658 650.781 Q103.658 657.887 105.463 661.452 Q107.292 664.994 110.903 664.994 Q114.537 664.994 116.343 661.452 Q118.172 657.887 118.172 650.781 Q118.172 643.651 116.343 640.11 Q114.537 636.545 110.903 636.545 M110.903 632.841 Q116.713 632.841 119.769 637.448 Q122.848 642.031 122.848 650.781 Q122.848 659.508 119.769 664.114 Q116.713 668.698 110.903 668.698 Q105.093 668.698 102.014 664.114 Q98.9589 659.508 98.9589 650.781 Q98.9589 642.031 102.014 637.448 Q105.093 632.841 110.903 632.841 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M131.065 662.147 L135.949 662.147 L135.949 668.026 L131.065 668.026 L131.065 662.147 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M156.134 651.614 Q152.801 651.614 150.88 653.397 Q148.982 655.179 148.982 658.304 Q148.982 661.429 150.88 663.212 Q152.801 664.994 156.134 664.994 Q159.468 664.994 161.389 663.212 Q163.31 661.406 163.31 658.304 Q163.31 655.179 161.389 653.397 Q159.491 651.614 156.134 651.614 M151.459 649.624 Q148.449 648.883 146.76 646.823 Q145.093 644.763 145.093 641.8 Q145.093 637.656 148.033 635.249 Q150.996 632.841 156.134 632.841 Q161.296 632.841 164.236 635.249 Q167.176 637.656 167.176 641.8 Q167.176 644.763 165.486 646.823 Q163.82 648.883 160.834 649.624 Q164.213 650.411 166.088 652.702 Q167.986 654.994 167.986 658.304 Q167.986 663.327 164.908 666.012 Q161.852 668.698 156.134 668.698 Q150.417 668.698 147.338 666.012 Q144.283 663.327 144.283 658.304 Q144.283 654.994 146.181 652.702 Q148.079 650.411 151.459 649.624 M149.746 642.239 Q149.746 644.925 151.412 646.429 Q153.102 647.934 156.134 647.934 Q159.144 647.934 160.834 646.429 Q162.546 644.925 162.546 642.239 Q162.546 639.554 160.834 638.05 Q159.144 636.545 156.134 636.545 Q153.102 636.545 151.412 638.05 Q149.746 639.554 149.746 642.239 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M101.621 431.673 L109.26 431.673 L109.26 405.307 L100.95 406.974 L100.95 402.715 L109.213 401.048 L113.889 401.048 L113.889 431.673 L121.528 431.673 L121.528 435.608 L101.621 435.608 L101.621 431.673 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M130.973 429.729 L135.857 429.729 L135.857 435.608 L130.973 435.608 L130.973 429.729 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M156.042 404.127 Q152.431 404.127 150.602 407.692 Q148.797 411.233 148.797 418.363 Q148.797 425.469 150.602 429.034 Q152.431 432.576 156.042 432.576 Q159.676 432.576 161.482 429.034 Q163.31 425.469 163.31 418.363 Q163.31 411.233 161.482 407.692 Q159.676 404.127 156.042 404.127 M156.042 400.423 Q161.852 400.423 164.908 405.03 Q167.986 409.613 167.986 418.363 Q167.986 427.09 164.908 431.696 Q161.852 436.28 156.042 436.28 Q150.232 436.28 147.153 431.696 Q144.098 427.09 144.098 418.363 Q144.098 409.613 147.153 405.03 Q150.232 400.423 156.042 400.423 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M5.95071 891.522 Q5.37779 892.509 5.12317 893.686 Q4.83671 894.832 4.83671 896.233 Q4.83671 901.198 8.08322 903.871 Q11.2979 906.513 17.3453 906.513 L36.1242 906.513 L36.1242 912.402 L0.4762 912.402 L0.4762 906.513 L6.01437 906.513 Q2.76785 904.667 1.20826 901.707 Q-0.38317 898.747 -0.38317 894.514 Q-0.38317 893.909 -0.287684 893.177 Q-0.224027 892.445 -0.0648847 891.554 L5.95071 891.522 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M773.802 73.5887 Q764.444 72.0899 760.11 68.1605 Q754.803 63.3399 754.803 53.4962 L754.803 27.2059 L762.338 27.2059 L762.338 53.2127 Q762.338 60.6258 765.781 63.7045 Q768.779 66.3781 773.802 66.9452 L773.802 27.2059 L781.215 27.2059 L781.215 66.9047 Q786.521 66.3376 789.236 63.664 Q792.679 60.2613 792.679 53.1722 L792.679 27.2059 L800.214 27.2059 L800.214 53.4557 Q800.214 63.664 794.907 68.12 Q790.127 72.1304 781.215 73.5482 L781.215 89.8329 L773.802 89.8329 L773.802 73.5887 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M847.285 86.3491 L847.285 92.1419 L804.183 92.1419 L804.183 86.3491 L847.285 86.3491 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M861.504 65.7705 L861.504 89.8329 L854.01 89.8329 L854.01 27.2059 L861.504 27.2059 L861.504 34.0924 Q863.853 30.0415 867.418 28.0971 Q871.023 26.1121 876.006 26.1121 Q884.27 26.1121 889.414 32.6746 Q894.6 39.2371 894.6 49.9314 Q894.6 60.6258 889.414 67.1883 Q884.27 73.7508 876.006 73.7508 Q871.023 73.7508 867.418 71.8063 Q863.853 69.8214 861.504 65.7705 M886.862 49.9314 Q886.862 41.7081 883.46 37.0496 Q880.097 32.3505 874.183 32.3505 Q868.269 32.3505 864.866 37.0496 Q861.504 41.7081 861.504 49.9314 Q861.504 58.1548 864.866 62.8538 Q868.269 67.5124 874.183 67.5124 Q880.097 67.5124 883.46 62.8538 Q886.862 58.1548 886.862 49.9314 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M906.955 9.54393 L914.409 9.54393 L914.409 72.576 L906.955 72.576 L906.955 9.54393 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M929.235 54.671 L929.235 27.2059 L936.689 27.2059 L936.689 54.3874 Q936.689 60.8284 939.2 64.0691 Q941.712 67.2693 946.735 67.2693 Q952.771 67.2693 956.254 63.421 Q959.779 59.5726 959.779 52.9291 L959.779 27.2059 L967.232 27.2059 L967.232 72.576 L959.779 72.576 L959.779 65.6084 Q957.065 69.7404 953.459 71.7658 Q949.894 73.7508 945.155 73.7508 Q937.337 73.7508 933.286 68.8897 Q929.235 64.0286 929.235 54.671 M947.991 26.1121 L947.991 26.1121 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1011.51 28.5427 L1011.51 35.5912 Q1008.35 33.9709 1004.95 33.1607 Q1001.54 32.3505 997.898 32.3505 Q992.348 32.3505 989.553 34.0519 Q986.798 35.7533 986.798 39.156 Q986.798 41.7486 988.783 43.2475 Q990.768 44.7058 996.763 46.0426 L999.315 46.6097 Q1007.26 48.3111 1010.58 51.4303 Q1013.94 54.509 1013.94 60.0587 Q1013.94 66.3781 1008.92 70.0644 Q1003.93 73.7508 995.184 73.7508 Q991.538 73.7508 987.568 73.0216 Q983.638 72.3329 979.264 70.9151 L979.264 63.2184 Q983.395 65.3654 987.406 66.4591 Q991.416 67.5124 995.346 67.5124 Q1000.61 67.5124 1003.45 65.73 Q1006.28 63.9071 1006.28 60.6258 Q1006.28 57.5877 1004.22 55.9673 Q1002.19 54.3469 995.265 52.8481 L992.672 52.2405 Q985.745 50.7821 982.666 47.7845 Q979.588 44.7463 979.588 39.4801 Q979.588 33.0797 984.125 29.5959 Q988.662 26.1121 997.006 26.1121 Q1001.14 26.1121 1004.78 26.7198 Q1008.43 27.3274 1011.51 28.5427 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><line clip-path="url(#clip222)" x1="253.819" y1="418.328" x2="253.819" y2="402.328" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="418.328" x2="237.819" y2="418.328" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="418.328" x2="253.819" y2="434.328" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="418.328" x2="269.819" y2="418.328" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="642.799" x2="884.371" y2="626.799" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="642.799" x2="868.371" y2="642.799" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="642.799" x2="884.371" y2="658.799" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="642.799" x2="900.371" y2="642.799" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="780.846" x2="884.371" y2="764.846" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="780.846" x2="868.371" y2="780.846" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="780.846" x2="884.371" y2="796.846" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="780.846" x2="900.371" y2="780.846" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="903.914" x2="253.819" y2="887.914" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="903.914" x2="237.819" y2="903.914" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="903.914" x2="253.819" y2="919.914" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="903.914" x2="269.819" y2="903.914" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="996.02" x2="884.371" y2="980.02" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="996.02" x2="868.371" y2="996.02" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="996.02" x2="884.371" y2="1012.02" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="996.02" x2="900.371" y2="996.02" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1052.52" x2="1514.92" y2="1036.52" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1052.52" x2="1498.92" y2="1052.52" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1052.52" x2="1514.92" y2="1068.52" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1052.52" x2="1530.92" y2="1052.52" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1072.48" x2="1514.92" y2="1056.48" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1072.48" x2="1498.92" y2="1072.48" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1072.48" x2="1514.92" y2="1088.48" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1072.48" x2="1530.92" y2="1072.48" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1172.63" x2="1514.92" y2="1156.63" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1172.63" x2="1498.92" y2="1172.63" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1172.63" x2="1514.92" y2="1188.63" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1172.63" x2="1530.92" y2="1172.63" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1178.31" x2="884.371" y2="1162.31" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1178.31" x2="868.371" y2="1178.31" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1178.31" x2="884.371" y2="1194.31" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1178.31" x2="900.371" y2="1178.31" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1252.49" x2="884.371" y2="1236.49" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1252.49" x2="868.371" y2="1252.49" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1252.49" x2="884.371" y2="1268.49" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1252.49" x2="900.371" y2="1252.49" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1281.65" x2="1514.92" y2="1265.65" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1281.65" x2="1498.92" y2="1281.65" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1281.65" x2="1514.92" y2="1297.65" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1281.65" x2="1530.92" y2="1281.65" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1301.5" x2="1514.92" y2="1285.5" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1301.5" x2="1498.92" y2="1301.5" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1301.5" x2="1514.92" y2="1317.5" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1301.5" x2="1530.92" y2="1301.5" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1331.99" x2="253.819" y2="1315.99" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1331.99" x2="237.819" y2="1331.99" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1331.99" x2="253.819" y2="1347.99" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1331.99" x2="269.819" y2="1331.99" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1335.19" x2="884.371" y2="1319.19" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1335.19" x2="868.371" y2="1335.19" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1335.19" x2="884.371" y2="1351.19" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1335.19" x2="900.371" y2="1335.19" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1344.76" x2="884.371" y2="1328.76" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1344.76" x2="868.371" y2="1344.76" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1344.76" x2="884.371" y2="1360.76" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1344.76" x2="900.371" y2="1344.76" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1358.45" x2="884.371" y2="1342.45" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1358.45" x2="868.371" y2="1358.45" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1358.45" x2="884.371" y2="1374.45" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1358.45" x2="900.371" y2="1358.45" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1363.7" x2="884.371" y2="1347.7" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1363.7" x2="868.371" y2="1363.7" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1363.7" x2="884.371" y2="1379.7" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1363.7" x2="900.371" y2="1363.7" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1416.08" x2="253.819" y2="1400.08" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1416.08" x2="237.819" y2="1416.08" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1416.08" x2="253.819" y2="1432.08" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1416.08" x2="269.819" y2="1416.08" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1421.63" x2="1514.92" y2="1405.63" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1421.63" x2="1498.92" y2="1421.63" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1421.63" x2="1514.92" y2="1437.63" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1421.63" x2="1530.92" y2="1421.63" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1425.61" x2="884.371" y2="1409.61" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1425.61" x2="868.371" y2="1425.61" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1425.61" x2="884.371" y2="1441.61" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1425.61" x2="900.371" y2="1425.61" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1443.7" x2="253.819" y2="1427.7" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1443.7" x2="237.819" y2="1443.7" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1443.7" x2="253.819" y2="1459.7" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1443.7" x2="269.819" y2="1443.7" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<circle clip-path="url(#clip222)" cx="253.819" cy="418.339" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="884.371" cy="651.295" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="884.371" cy="661.72" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="884.371" cy="812.874" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="884.371" cy="847.04" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="253.819" cy="914.789" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="253.819" cy="932.456" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="253.819" cy="957.861" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="253.819" cy="1055.85" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="884.371" cy="1058.98" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="1514.92" cy="1105.87" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="884.371" cy="1113.25" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="253.819" cy="1136.8" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="1514.92" cy="1169.96" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="253.819" cy="1183.1" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="884.371" cy="1190.37" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="253.819" cy="1201.24" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="884.371" cy="1204.97" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="884.371" cy="1256.32" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip222)" cx="884.371" cy="1257.93" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<line clip-path="url(#clip222)" x1="884.371" y1="675.919" x2="884.371" y2="659.919" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="675.919" x2="868.371" y2="675.919" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="675.919" x2="884.371" y2="691.919" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="675.919" x2="900.371" y2="675.919" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="896.098" x2="884.371" y2="880.098" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="896.098" x2="868.371" y2="896.098" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="896.098" x2="884.371" y2="912.098" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="896.098" x2="900.371" y2="896.098" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="957.121" x2="1514.92" y2="941.121" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="957.121" x2="1498.92" y2="957.121" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="957.121" x2="1514.92" y2="973.121" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="957.121" x2="1530.92" y2="957.121" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="958.755" x2="1514.92" y2="942.755" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="958.755" x2="1498.92" y2="958.755" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="958.755" x2="1514.92" y2="974.755" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="958.755" x2="1530.92" y2="958.755" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1000.97" x2="253.819" y2="984.974" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1000.97" x2="237.819" y2="1000.97" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1000.97" x2="253.819" y2="1016.97" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1000.97" x2="269.819" y2="1000.97" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1176.7" x2="253.819" y2="1160.7" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1176.7" x2="237.819" y2="1176.7" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1176.7" x2="253.819" y2="1192.7" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1176.7" x2="269.819" y2="1176.7" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1192.29" x2="884.371" y2="1176.29" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1192.29" x2="868.371" y2="1192.29" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1192.29" x2="884.371" y2="1208.29" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1192.29" x2="900.371" y2="1192.29" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1195.93" x2="1514.92" y2="1179.93" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1195.93" x2="1498.92" y2="1195.93" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1195.93" x2="1514.92" y2="1211.93" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1195.93" x2="1530.92" y2="1195.93" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1228.51" x2="884.371" y2="1212.51" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1228.51" x2="868.371" y2="1228.51" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1228.51" x2="884.371" y2="1244.51" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1228.51" x2="900.371" y2="1228.51" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1237.52" x2="253.819" y2="1221.52" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1237.52" x2="237.819" y2="1237.52" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1237.52" x2="253.819" y2="1253.52" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1237.52" x2="269.819" y2="1237.52" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1239.57" x2="1514.92" y2="1223.57" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1239.57" x2="1498.92" y2="1239.57" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1239.57" x2="1514.92" y2="1255.57" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1239.57" x2="1530.92" y2="1239.57" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1252.99" x2="884.371" y2="1236.99" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1252.99" x2="868.371" y2="1252.99" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1252.99" x2="884.371" y2="1268.99" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1252.99" x2="900.371" y2="1252.99" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1271.23" x2="884.371" y2="1255.23" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1271.23" x2="868.371" y2="1271.23" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1271.23" x2="884.371" y2="1287.23" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1271.23" x2="900.371" y2="1271.23" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1287.66" x2="884.371" y2="1271.66" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1287.66" x2="868.371" y2="1287.66" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1287.66" x2="884.371" y2="1303.66" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1287.66" x2="900.371" y2="1287.66" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1296" x2="884.371" y2="1280" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1296" x2="868.371" y2="1296" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1296" x2="884.371" y2="1312" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1296" x2="900.371" y2="1296" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1307.58" x2="1514.92" y2="1291.58" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1307.58" x2="1498.92" y2="1307.58" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1307.58" x2="1514.92" y2="1323.58" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="1514.92" y1="1307.58" x2="1530.92" y2="1307.58" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1317.02" x2="253.819" y2="1301.02" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1317.02" x2="237.819" y2="1317.02" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1317.02" x2="253.819" y2="1333.02" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1317.02" x2="269.819" y2="1317.02" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1392.15" x2="884.371" y2="1376.15" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1392.15" x2="868.371" y2="1392.15" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1392.15" x2="884.371" y2="1408.15" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1392.15" x2="900.371" y2="1392.15" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1412.51" x2="253.819" y2="1396.51" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1412.51" x2="237.819" y2="1412.51" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1412.51" x2="253.819" y2="1428.51" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="253.819" y1="1412.51" x2="269.819" y2="1412.51" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1412.68" x2="884.371" y2="1396.68" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1412.68" x2="868.371" y2="1412.68" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1412.68" x2="884.371" y2="1428.68" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip222)" x1="884.371" y1="1412.68" x2="900.371" y2="1412.68" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<path clip-path="url(#clip220)" d="M672.753 315.712 L1095.99 315.712 L1095.99 108.352 L672.753 108.352  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="672.753,315.712 1095.99,315.712 1095.99,108.352 672.753,108.352 672.753,315.712 "/>
<line clip-path="url(#clip220)" x1="732.165" y1="160.192" x2="732.165" y2="137.437" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip220)" x1="732.165" y1="160.192" x2="709.41" y2="160.192" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip220)" x1="732.165" y1="160.192" x2="732.165" y2="182.948" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip220)" x1="732.165" y1="160.192" x2="754.921" y2="160.192" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<path clip-path="url(#clip220)" d="M791.577 142.912 L796.253 142.912 L796.253 177.472 L791.577 177.472 L791.577 142.912 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M820.397 155.528 Q819.679 155.111 818.822 154.926 Q817.989 154.718 816.971 154.718 Q813.36 154.718 811.415 157.079 Q809.494 159.417 809.494 163.815 L809.494 177.472 L805.211 177.472 L805.211 151.546 L809.494 151.546 L809.494 155.574 Q810.836 153.213 812.989 152.079 Q815.142 150.921 818.221 150.921 Q818.66 150.921 819.193 150.991 Q819.725 151.037 820.373 151.153 L820.397 155.528 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M839.054 155.528 Q838.336 155.111 837.48 154.926 Q836.646 154.718 835.628 154.718 Q832.017 154.718 830.072 157.079 Q828.151 159.417 828.151 163.815 L828.151 177.472 L823.869 177.472 L823.869 151.546 L828.151 151.546 L828.151 155.574 Q829.494 153.213 831.646 152.079 Q833.799 150.921 836.878 150.921 Q837.318 150.921 837.85 150.991 Q838.383 151.037 839.031 151.153 L839.054 155.528 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M864.656 163.444 L864.656 165.528 L845.072 165.528 Q845.35 169.926 847.711 172.241 Q850.095 174.532 854.332 174.532 Q856.785 174.532 859.077 173.93 Q861.392 173.329 863.66 172.125 L863.66 176.153 Q861.369 177.125 858.961 177.634 Q856.554 178.143 854.077 178.143 Q847.873 178.143 844.239 174.532 Q840.628 170.921 840.628 164.764 Q840.628 158.398 844.054 154.671 Q847.503 150.921 853.336 150.921 Q858.568 150.921 861.6 154.301 Q864.656 157.657 864.656 163.444 M860.396 162.194 Q860.35 158.699 858.429 156.616 Q856.531 154.532 853.382 154.532 Q849.818 154.532 847.665 156.546 Q845.535 158.56 845.211 162.218 L860.396 162.194 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M875.767 173.583 L875.767 187.333 L871.484 187.333 L871.484 151.546 L875.767 151.546 L875.767 155.482 Q877.109 153.167 879.146 152.056 Q881.206 150.921 884.054 150.921 Q888.776 150.921 891.716 154.671 Q894.679 158.421 894.679 164.532 Q894.679 170.643 891.716 174.393 Q888.776 178.143 884.054 178.143 Q881.206 178.143 879.146 177.032 Q877.109 175.898 875.767 173.583 M890.257 164.532 Q890.257 159.833 888.313 157.171 Q886.392 154.486 883.012 154.486 Q879.632 154.486 877.688 157.171 Q875.767 159.833 875.767 164.532 Q875.767 169.231 877.688 171.917 Q879.632 174.579 883.012 174.579 Q886.392 174.579 888.313 171.917 Q890.257 169.231 890.257 164.532 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M901.345 141.454 L911.16 141.454 L911.16 144.764 L905.604 144.764 L905.604 180.412 L911.16 180.412 L911.16 183.722 L901.345 183.722 L901.345 141.454 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M941.137 144.046 L941.137 148.607 Q938.475 147.333 936.114 146.708 Q933.752 146.083 931.553 146.083 Q927.734 146.083 925.651 147.565 Q923.59 149.046 923.59 151.778 Q923.59 154.069 924.956 155.25 Q926.345 156.407 930.188 157.125 L933.012 157.704 Q938.243 158.699 940.72 161.222 Q943.22 163.722 943.22 167.935 Q943.22 172.958 939.84 175.551 Q936.484 178.143 929.979 178.143 Q927.526 178.143 924.748 177.588 Q921.993 177.032 919.03 175.944 L919.03 171.13 Q921.877 172.727 924.609 173.537 Q927.34 174.347 929.979 174.347 Q933.984 174.347 936.16 172.773 Q938.336 171.199 938.336 168.282 Q938.336 165.736 936.762 164.301 Q935.211 162.866 931.646 162.148 L928.799 161.593 Q923.567 160.551 921.229 158.329 Q918.891 156.106 918.891 152.148 Q918.891 147.565 922.109 144.926 Q925.35 142.287 931.021 142.287 Q933.451 142.287 935.975 142.727 Q938.498 143.167 941.137 144.046 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M949.979 142.912 L954.678 142.912 L954.678 163.907 Q954.678 169.463 956.692 171.917 Q958.706 174.347 963.22 174.347 Q967.711 174.347 969.724 171.917 Q971.738 169.463 971.738 163.907 L971.738 142.912 L976.437 142.912 L976.437 164.486 Q976.437 171.245 973.081 174.694 Q969.748 178.143 963.22 178.143 Q956.669 178.143 953.312 174.694 Q949.979 171.245 949.979 164.486 L949.979 142.912 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M986.761 174.833 L996.576 174.833 L996.576 177.472 L982.734 177.472 L982.734 174.926 Q983.521 174.208 984.979 172.912 Q992.942 165.852 992.942 163.676 Q992.942 162.148 991.738 161.222 Q990.535 160.273 988.567 160.273 Q987.363 160.273 985.951 160.69 Q984.539 161.083 982.873 161.894 L982.873 159.046 Q984.655 158.398 986.183 158.074 Q987.734 157.75 989.053 157.75 Q992.41 157.75 994.423 159.278 Q996.437 160.806 996.437 163.306 Q996.437 166.523 988.775 173.097 Q987.479 174.208 986.761 174.833 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1013.98 141.454 L1013.98 183.722 L1004.17 183.722 L1004.17 180.412 L1009.7 180.412 L1009.7 144.764 L1004.17 144.764 L1004.17 141.454 L1013.98 141.454 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1032.76 141.5 Q1029.65 146.824 1028.15 152.032 Q1026.65 157.241 1026.65 162.588 Q1026.65 167.935 1028.15 173.19 Q1029.68 178.421 1032.76 183.722 L1029.05 183.722 Q1025.58 178.282 1023.84 173.028 Q1022.13 167.773 1022.13 162.588 Q1022.13 157.426 1023.84 152.194 Q1025.56 146.963 1029.05 141.5 L1032.76 141.5 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1051.62 145.991 Q1048.01 145.991 1046.18 149.556 Q1044.38 153.097 1044.38 160.227 Q1044.38 167.333 1046.18 170.898 Q1048.01 174.44 1051.62 174.44 Q1055.26 174.44 1057.06 170.898 Q1058.89 167.333 1058.89 160.227 Q1058.89 153.097 1057.06 149.556 Q1055.26 145.991 1051.62 145.991 M1051.62 142.287 Q1057.43 142.287 1060.49 146.894 Q1063.57 151.477 1063.57 160.227 Q1063.57 168.954 1060.49 173.56 Q1057.43 178.143 1051.62 178.143 Q1045.81 178.143 1042.73 173.56 Q1039.68 168.954 1039.68 160.227 Q1039.68 151.477 1042.73 146.894 Q1045.81 142.287 1051.62 142.287 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1070.51 141.5 L1074.21 141.5 Q1077.69 146.963 1079.4 152.194 Q1081.14 157.426 1081.14 162.588 Q1081.14 167.773 1079.4 173.028 Q1077.69 178.282 1074.21 183.722 L1070.51 183.722 Q1073.59 178.421 1075.09 173.19 Q1076.62 167.935 1076.62 162.588 Q1076.62 157.241 1075.09 152.032 Q1073.59 146.824 1070.51 141.5 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><circle clip-path="url(#clip220)" cx="732.165" cy="212.032" r="20.48" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="4.55111"/>
<path clip-path="url(#clip220)" d="M791.577 194.752 L796.253 194.752 L796.253 229.312 L791.577 229.312 L791.577 194.752 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M820.397 207.368 Q819.679 206.951 818.822 206.766 Q817.989 206.558 816.971 206.558 Q813.36 206.558 811.415 208.919 Q809.494 211.257 809.494 215.655 L809.494 229.312 L805.211 229.312 L805.211 203.386 L809.494 203.386 L809.494 207.414 Q810.836 205.053 812.989 203.919 Q815.142 202.761 818.221 202.761 Q818.66 202.761 819.193 202.831 Q819.725 202.877 820.373 202.993 L820.397 207.368 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M839.054 207.368 Q838.336 206.951 837.48 206.766 Q836.646 206.558 835.628 206.558 Q832.017 206.558 830.072 208.919 Q828.151 211.257 828.151 215.655 L828.151 229.312 L823.869 229.312 L823.869 203.386 L828.151 203.386 L828.151 207.414 Q829.494 205.053 831.646 203.919 Q833.799 202.761 836.878 202.761 Q837.318 202.761 837.85 202.831 Q838.383 202.877 839.031 202.993 L839.054 207.368 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M864.656 215.284 L864.656 217.368 L845.072 217.368 Q845.35 221.766 847.711 224.081 Q850.095 226.372 854.332 226.372 Q856.785 226.372 859.077 225.77 Q861.392 225.169 863.66 223.965 L863.66 227.993 Q861.369 228.965 858.961 229.474 Q856.554 229.983 854.077 229.983 Q847.873 229.983 844.239 226.372 Q840.628 222.761 840.628 216.604 Q840.628 210.238 844.054 206.511 Q847.503 202.761 853.336 202.761 Q858.568 202.761 861.6 206.141 Q864.656 209.497 864.656 215.284 M860.396 214.034 Q860.35 210.539 858.429 208.456 Q856.531 206.372 853.382 206.372 Q849.818 206.372 847.665 208.386 Q845.535 210.4 845.211 214.058 L860.396 214.034 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M875.767 225.423 L875.767 239.173 L871.484 239.173 L871.484 203.386 L875.767 203.386 L875.767 207.322 Q877.109 205.007 879.146 203.896 Q881.206 202.761 884.054 202.761 Q888.776 202.761 891.716 206.511 Q894.679 210.261 894.679 216.372 Q894.679 222.483 891.716 226.233 Q888.776 229.983 884.054 229.983 Q881.206 229.983 879.146 228.872 Q877.109 227.738 875.767 225.423 M890.257 216.372 Q890.257 211.673 888.313 209.011 Q886.392 206.326 883.012 206.326 Q879.632 206.326 877.688 209.011 Q875.767 211.673 875.767 216.372 Q875.767 221.071 877.688 223.757 Q879.632 226.419 883.012 226.419 Q886.392 226.419 888.313 223.757 Q890.257 221.071 890.257 216.372 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M901.345 193.294 L911.16 193.294 L911.16 196.604 L905.604 196.604 L905.604 232.252 L911.16 232.252 L911.16 235.562 L901.345 235.562 L901.345 193.294 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M941.137 195.886 L941.137 200.447 Q938.475 199.173 936.114 198.548 Q933.752 197.923 931.553 197.923 Q927.734 197.923 925.651 199.405 Q923.59 200.886 923.59 203.618 Q923.59 205.909 924.956 207.09 Q926.345 208.247 930.188 208.965 L933.012 209.544 Q938.243 210.539 940.72 213.062 Q943.22 215.562 943.22 219.775 Q943.22 224.798 939.84 227.391 Q936.484 229.983 929.979 229.983 Q927.526 229.983 924.748 229.428 Q921.993 228.872 919.03 227.784 L919.03 222.97 Q921.877 224.567 924.609 225.377 Q927.34 226.187 929.979 226.187 Q933.984 226.187 936.16 224.613 Q938.336 223.039 938.336 220.122 Q938.336 217.576 936.762 216.141 Q935.211 214.706 931.646 213.988 L928.799 213.433 Q923.567 212.391 921.229 210.169 Q918.891 207.946 918.891 203.988 Q918.891 199.405 922.109 196.766 Q925.35 194.127 931.021 194.127 Q933.451 194.127 935.975 194.567 Q938.498 195.007 941.137 195.886 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M949.979 194.752 L954.678 194.752 L954.678 215.747 Q954.678 221.303 956.692 223.757 Q958.706 226.187 963.22 226.187 Q967.711 226.187 969.724 223.757 Q971.738 221.303 971.738 215.747 L971.738 194.752 L976.437 194.752 L976.437 216.326 Q976.437 223.085 973.081 226.534 Q969.748 229.983 963.22 229.983 Q956.669 229.983 953.312 226.534 Q949.979 223.085 949.979 216.326 L949.979 194.752 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M986.761 226.673 L996.576 226.673 L996.576 229.312 L982.734 229.312 L982.734 226.766 Q983.521 226.048 984.979 224.752 Q992.942 217.692 992.942 215.516 Q992.942 213.988 991.738 213.062 Q990.535 212.113 988.567 212.113 Q987.363 212.113 985.951 212.53 Q984.539 212.923 982.873 213.734 L982.873 210.886 Q984.655 210.238 986.183 209.914 Q987.734 209.59 989.053 209.59 Q992.41 209.59 994.423 211.118 Q996.437 212.646 996.437 215.146 Q996.437 218.363 988.775 224.937 Q987.479 226.048 986.761 226.673 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1013.98 193.294 L1013.98 235.562 L1004.17 235.562 L1004.17 232.252 L1009.7 232.252 L1009.7 196.604 L1004.17 196.604 L1004.17 193.294 L1013.98 193.294 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1032.76 193.34 Q1029.65 198.664 1028.15 203.872 Q1026.65 209.081 1026.65 214.428 Q1026.65 219.775 1028.15 225.03 Q1029.68 230.261 1032.76 235.562 L1029.05 235.562 Q1025.58 230.122 1023.84 224.868 Q1022.13 219.613 1022.13 214.428 Q1022.13 209.266 1023.84 204.034 Q1025.56 198.803 1029.05 193.34 L1032.76 193.34 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1042.43 225.377 L1050.07 225.377 L1050.07 199.011 L1041.76 200.678 L1041.76 196.419 L1050.02 194.752 L1054.7 194.752 L1054.7 225.377 L1062.34 225.377 L1062.34 229.312 L1042.43 229.312 L1042.43 225.377 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1070.51 193.34 L1074.21 193.34 Q1077.69 198.803 1079.4 204.034 Q1081.14 209.266 1081.14 214.428 Q1081.14 219.613 1079.4 224.868 Q1077.69 230.122 1074.21 235.562 L1070.51 235.562 Q1073.59 230.261 1075.09 225.03 Q1076.62 219.775 1076.62 214.428 Q1076.62 209.081 1075.09 203.872 Q1073.59 198.664 1070.51 193.34 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><line clip-path="url(#clip220)" x1="732.165" y1="263.872" x2="732.165" y2="241.117" style="stroke:#3da44d; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip220)" x1="732.165" y1="263.872" x2="709.41" y2="263.872" style="stroke:#3da44d; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip220)" x1="732.165" y1="263.872" x2="732.165" y2="286.628" style="stroke:#3da44d; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip220)" x1="732.165" y1="263.872" x2="754.921" y2="263.872" style="stroke:#3da44d; stroke-width:4.55111; stroke-opacity:1"/>
<path clip-path="url(#clip220)" d="M791.577 246.592 L796.253 246.592 L796.253 281.152 L791.577 281.152 L791.577 246.592 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M820.397 259.208 Q819.679 258.791 818.822 258.606 Q817.989 258.398 816.971 258.398 Q813.36 258.398 811.415 260.759 Q809.494 263.097 809.494 267.495 L809.494 281.152 L805.211 281.152 L805.211 255.226 L809.494 255.226 L809.494 259.254 Q810.836 256.893 812.989 255.759 Q815.142 254.601 818.221 254.601 Q818.66 254.601 819.193 254.671 Q819.725 254.717 820.373 254.833 L820.397 259.208 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M839.054 259.208 Q838.336 258.791 837.48 258.606 Q836.646 258.398 835.628 258.398 Q832.017 258.398 830.072 260.759 Q828.151 263.097 828.151 267.495 L828.151 281.152 L823.869 281.152 L823.869 255.226 L828.151 255.226 L828.151 259.254 Q829.494 256.893 831.646 255.759 Q833.799 254.601 836.878 254.601 Q837.318 254.601 837.85 254.671 Q838.383 254.717 839.031 254.833 L839.054 259.208 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M864.656 267.124 L864.656 269.208 L845.072 269.208 Q845.35 273.606 847.711 275.921 Q850.095 278.212 854.332 278.212 Q856.785 278.212 859.077 277.61 Q861.392 277.009 863.66 275.805 L863.66 279.833 Q861.369 280.805 858.961 281.314 Q856.554 281.823 854.077 281.823 Q847.873 281.823 844.239 278.212 Q840.628 274.601 840.628 268.444 Q840.628 262.078 844.054 258.351 Q847.503 254.601 853.336 254.601 Q858.568 254.601 861.6 257.981 Q864.656 261.337 864.656 267.124 M860.396 265.874 Q860.35 262.379 858.429 260.296 Q856.531 258.212 853.382 258.212 Q849.818 258.212 847.665 260.226 Q845.535 262.24 845.211 265.898 L860.396 265.874 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M875.767 277.263 L875.767 291.013 L871.484 291.013 L871.484 255.226 L875.767 255.226 L875.767 259.162 Q877.109 256.847 879.146 255.736 Q881.206 254.601 884.054 254.601 Q888.776 254.601 891.716 258.351 Q894.679 262.101 894.679 268.212 Q894.679 274.323 891.716 278.073 Q888.776 281.823 884.054 281.823 Q881.206 281.823 879.146 280.712 Q877.109 279.578 875.767 277.263 M890.257 268.212 Q890.257 263.513 888.313 260.851 Q886.392 258.166 883.012 258.166 Q879.632 258.166 877.688 260.851 Q875.767 263.513 875.767 268.212 Q875.767 272.911 877.688 275.597 Q879.632 278.259 883.012 278.259 Q886.392 278.259 888.313 275.597 Q890.257 272.911 890.257 268.212 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M901.345 245.134 L911.16 245.134 L911.16 248.444 L905.604 248.444 L905.604 284.092 L911.16 284.092 L911.16 287.402 L901.345 287.402 L901.345 245.134 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M941.137 247.726 L941.137 252.287 Q938.475 251.013 936.114 250.388 Q933.752 249.763 931.553 249.763 Q927.734 249.763 925.651 251.245 Q923.59 252.726 923.59 255.458 Q923.59 257.749 924.956 258.93 Q926.345 260.087 930.188 260.805 L933.012 261.384 Q938.243 262.379 940.72 264.902 Q943.22 267.402 943.22 271.615 Q943.22 276.638 939.84 279.231 Q936.484 281.823 929.979 281.823 Q927.526 281.823 924.748 281.268 Q921.993 280.712 919.03 279.624 L919.03 274.81 Q921.877 276.407 924.609 277.217 Q927.34 278.027 929.979 278.027 Q933.984 278.027 936.16 276.453 Q938.336 274.879 938.336 271.962 Q938.336 269.416 936.762 267.981 Q935.211 266.546 931.646 265.828 L928.799 265.273 Q923.567 264.231 921.229 262.009 Q918.891 259.786 918.891 255.828 Q918.891 251.245 922.109 248.606 Q925.35 245.967 931.021 245.967 Q933.451 245.967 935.975 246.407 Q938.498 246.847 941.137 247.726 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M949.979 246.592 L954.678 246.592 L954.678 267.587 Q954.678 273.143 956.692 275.597 Q958.706 278.027 963.22 278.027 Q967.711 278.027 969.724 275.597 Q971.738 273.143 971.738 267.587 L971.738 246.592 L976.437 246.592 L976.437 268.166 Q976.437 274.925 973.081 278.374 Q969.748 281.823 963.22 281.823 Q956.669 281.823 953.312 278.374 Q949.979 274.925 949.979 268.166 L949.979 246.592 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M986.761 278.513 L996.576 278.513 L996.576 281.152 L982.734 281.152 L982.734 278.606 Q983.521 277.888 984.979 276.592 Q992.942 269.532 992.942 267.356 Q992.942 265.828 991.738 264.902 Q990.535 263.953 988.567 263.953 Q987.363 263.953 985.951 264.37 Q984.539 264.763 982.873 265.574 L982.873 262.726 Q984.655 262.078 986.183 261.754 Q987.734 261.43 989.053 261.43 Q992.41 261.43 994.423 262.958 Q996.437 264.486 996.437 266.986 Q996.437 270.203 988.775 276.777 Q987.479 277.888 986.761 278.513 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1013.98 245.134 L1013.98 287.402 L1004.17 287.402 L1004.17 284.092 L1009.7 284.092 L1009.7 248.444 L1004.17 248.444 L1004.17 245.134 L1013.98 245.134 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1032.76 245.18 Q1029.65 250.504 1028.15 255.712 Q1026.65 260.921 1026.65 266.268 Q1026.65 271.615 1028.15 276.87 Q1029.68 282.101 1032.76 287.402 L1029.05 287.402 Q1025.58 281.962 1023.84 276.708 Q1022.13 271.453 1022.13 266.268 Q1022.13 261.106 1023.84 255.874 Q1025.56 250.643 1029.05 245.18 L1032.76 245.18 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1045.65 277.217 L1061.97 277.217 L1061.97 281.152 L1040.02 281.152 L1040.02 277.217 Q1042.69 274.462 1047.27 269.833 Q1051.88 265.18 1053.06 263.837 Q1055.3 261.314 1056.18 259.578 Q1057.09 257.819 1057.09 256.129 Q1057.09 253.374 1055.14 251.638 Q1053.22 249.902 1050.12 249.902 Q1047.92 249.902 1045.46 250.666 Q1043.03 251.43 1040.26 252.981 L1040.26 248.259 Q1043.08 247.125 1045.53 246.546 Q1047.99 245.967 1050.02 245.967 Q1055.4 245.967 1058.59 248.652 Q1061.78 251.337 1061.78 255.828 Q1061.78 257.958 1060.97 259.879 Q1060.19 261.777 1058.08 264.37 Q1057.5 265.041 1054.4 268.259 Q1051.3 271.453 1045.65 277.217 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1070.51 245.18 L1074.21 245.18 Q1077.69 250.643 1079.4 255.874 Q1081.14 261.106 1081.14 266.268 Q1081.14 271.453 1079.4 276.708 Q1077.69 281.962 1074.21 287.402 L1070.51 287.402 Q1073.59 282.101 1075.09 276.87 Q1076.62 271.615 1076.62 266.268 Q1076.62 260.921 1075.09 255.712 Q1073.59 250.504 1070.51 245.18 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1815.99 1443.7 L3152.76 1443.7 L3152.76 360.224 L1815.99 360.224  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip223">
    <rect x="1815" y="360" width="1338" height="1084"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip223)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1853.82,1443.7 1853.82,360.224 "/>
<polyline clip-path="url(#clip223)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2064,1443.7 2064,360.224 "/>
<polyline clip-path="url(#clip223)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2274.19,1443.7 2274.19,360.224 "/>
<polyline clip-path="url(#clip223)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2484.37,1443.7 2484.37,360.224 "/>
<polyline clip-path="url(#clip223)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2694.55,1443.7 2694.55,360.224 "/>
<polyline clip-path="url(#clip223)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2904.74,1443.7 2904.74,360.224 "/>
<polyline clip-path="url(#clip223)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="3114.92,1443.7 3114.92,360.224 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1815.99,1443.7 3152.76,1443.7 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1853.82,1443.7 1853.82,1428.37 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2064,1443.7 2064,1428.37 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2274.19,1443.7 2274.19,1428.37 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2484.37,1443.7 2484.37,1428.37 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2694.55,1443.7 2694.55,1428.37 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2904.74,1443.7 2904.74,1428.37 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="3114.92,1443.7 3114.92,1428.37 "/>
<path clip-path="url(#clip220)" d="M1807.58 1481.02 Q1803.97 1481.02 1802.14 1484.58 Q1800.34 1488.12 1800.34 1495.25 Q1800.34 1502.36 1802.14 1505.93 Q1803.97 1509.47 1807.58 1509.47 Q1811.22 1509.47 1813.02 1505.93 Q1814.85 1502.36 1814.85 1495.25 Q1814.85 1488.12 1813.02 1484.58 Q1811.22 1481.02 1807.58 1481.02 M1807.58 1477.31 Q1813.39 1477.31 1816.45 1481.92 Q1819.53 1486.5 1819.53 1495.25 Q1819.53 1503.98 1816.45 1508.59 Q1813.39 1513.17 1807.58 1513.17 Q1801.77 1513.17 1798.69 1508.59 Q1795.64 1503.98 1795.64 1495.25 Q1795.64 1486.5 1798.69 1481.92 Q1801.77 1477.31 1807.58 1477.31 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1834.71 1477.94 L1838.65 1477.94 L1826.61 1516.9 L1822.67 1516.9 L1834.71 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1850.68 1477.94 L1854.62 1477.94 L1842.58 1516.9 L1838.65 1516.9 L1850.68 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1860.5 1508.56 L1868.14 1508.56 L1868.14 1482.2 L1859.83 1483.87 L1859.83 1479.61 L1868.09 1477.94 L1872.77 1477.94 L1872.77 1508.56 L1880.4 1508.56 L1880.4 1512.5 L1860.5 1512.5 L1860.5 1508.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1886.49 1486.57 L1911.33 1486.57 L1911.33 1490.83 L1908.07 1490.83 L1908.07 1506.76 Q1908.07 1508.43 1908.62 1509.17 Q1909.2 1509.88 1910.47 1509.88 Q1910.82 1509.88 1911.33 1509.84 Q1911.84 1509.77 1912 1509.75 L1912 1512.82 Q1911.19 1513.12 1910.34 1513.26 Q1909.48 1513.4 1908.62 1513.4 Q1905.84 1513.4 1904.78 1511.9 Q1903.71 1510.37 1903.71 1506.3 L1903.71 1490.83 L1894.15 1490.83 L1894.15 1512.5 L1889.8 1512.5 L1889.8 1490.83 L1886.49 1490.83 L1886.49 1486.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2007.53 1508.56 L2015.17 1508.56 L2015.17 1482.2 L2006.86 1483.87 L2006.86 1479.61 L2015.13 1477.94 L2019.8 1477.94 L2019.8 1508.56 L2027.44 1508.56 L2027.44 1512.5 L2007.53 1512.5 L2007.53 1508.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2043.85 1477.94 L2047.79 1477.94 L2035.75 1516.9 L2031.82 1516.9 L2043.85 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2059.83 1477.94 L2063.76 1477.94 L2051.72 1516.9 L2047.79 1516.9 L2059.83 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2083 1493.87 Q2086.35 1494.58 2088.23 1496.85 Q2090.13 1499.12 2090.13 1502.45 Q2090.13 1507.57 2086.61 1510.37 Q2083.09 1513.17 2076.61 1513.17 Q2074.43 1513.17 2072.12 1512.73 Q2069.83 1512.31 2067.37 1511.46 L2067.37 1506.94 Q2069.32 1508.08 2071.63 1508.66 Q2073.95 1509.24 2076.47 1509.24 Q2080.87 1509.24 2083.16 1507.5 Q2085.47 1505.76 2085.47 1502.45 Q2085.47 1499.4 2083.32 1497.69 Q2081.19 1495.95 2077.37 1495.95 L2073.34 1495.95 L2073.34 1492.11 L2077.56 1492.11 Q2081.01 1492.11 2082.83 1490.74 Q2084.66 1489.35 2084.66 1486.76 Q2084.66 1484.1 2082.76 1482.69 Q2080.89 1481.25 2077.37 1481.25 Q2075.45 1481.25 2073.25 1481.67 Q2071.05 1482.08 2068.41 1482.96 L2068.41 1478.8 Q2071.07 1478.06 2073.39 1477.69 Q2075.73 1477.31 2077.79 1477.31 Q2083.11 1477.31 2086.21 1479.75 Q2089.32 1482.15 2089.32 1486.27 Q2089.32 1489.14 2087.67 1491.13 Q2086.03 1493.1 2083 1493.87 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2095.64 1486.57 L2120.47 1486.57 L2120.47 1490.83 L2117.21 1490.83 L2117.21 1506.76 Q2117.21 1508.43 2117.76 1509.17 Q2118.34 1509.88 2119.62 1509.88 Q2119.96 1509.88 2120.47 1509.84 Q2120.98 1509.77 2121.14 1509.75 L2121.14 1512.82 Q2120.33 1513.12 2119.48 1513.26 Q2118.62 1513.4 2117.76 1513.4 Q2114.99 1513.4 2113.92 1511.9 Q2112.86 1510.37 2112.86 1506.3 L2112.86 1490.83 L2103.3 1490.83 L2103.3 1512.5 L2098.95 1512.5 L2098.95 1490.83 L2095.64 1490.83 L2095.64 1486.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2221.8 1508.56 L2238.12 1508.56 L2238.12 1512.5 L2216.18 1512.5 L2216.18 1508.56 Q2218.84 1505.81 2223.42 1501.18 Q2228.03 1496.53 2229.21 1495.19 Q2231.46 1492.66 2232.34 1490.93 Q2233.24 1489.17 2233.24 1487.48 Q2233.24 1484.72 2231.29 1482.99 Q2229.37 1481.25 2226.27 1481.25 Q2224.07 1481.25 2221.62 1482.01 Q2219.19 1482.78 2216.41 1484.33 L2216.41 1479.61 Q2219.23 1478.47 2221.69 1477.89 Q2224.14 1477.31 2226.18 1477.31 Q2231.55 1477.31 2234.74 1480 Q2237.94 1482.69 2237.94 1487.18 Q2237.94 1489.31 2237.13 1491.23 Q2236.34 1493.12 2234.23 1495.72 Q2233.65 1496.39 2230.55 1499.61 Q2227.45 1502.8 2221.8 1508.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2254.9 1477.94 L2258.84 1477.94 L2246.8 1516.9 L2242.87 1516.9 L2254.9 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2270.88 1477.94 L2274.81 1477.94 L2262.78 1516.9 L2258.84 1516.9 L2270.88 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2294.05 1493.87 Q2297.4 1494.58 2299.28 1496.85 Q2301.18 1499.12 2301.18 1502.45 Q2301.18 1507.57 2297.66 1510.37 Q2294.14 1513.17 2287.66 1513.17 Q2285.48 1513.17 2283.17 1512.73 Q2280.88 1512.31 2278.42 1511.46 L2278.42 1506.94 Q2280.37 1508.08 2282.68 1508.66 Q2285 1509.24 2287.52 1509.24 Q2291.92 1509.24 2294.21 1507.5 Q2296.53 1505.76 2296.53 1502.45 Q2296.53 1499.4 2294.37 1497.69 Q2292.24 1495.95 2288.42 1495.95 L2284.4 1495.95 L2284.4 1492.11 L2288.61 1492.11 Q2292.06 1492.11 2293.89 1490.74 Q2295.71 1489.35 2295.71 1486.76 Q2295.71 1484.1 2293.82 1482.69 Q2291.94 1481.25 2288.42 1481.25 Q2286.5 1481.25 2284.3 1481.67 Q2282.1 1482.08 2279.46 1482.96 L2279.46 1478.8 Q2282.13 1478.06 2284.44 1477.69 Q2286.78 1477.31 2288.84 1477.31 Q2294.16 1477.31 2297.27 1479.75 Q2300.37 1482.15 2300.37 1486.27 Q2300.37 1489.14 2298.72 1491.13 Q2297.08 1493.1 2294.05 1493.87 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2306.69 1486.57 L2331.52 1486.57 L2331.52 1490.83 L2328.26 1490.83 L2328.26 1506.76 Q2328.26 1508.43 2328.82 1509.17 Q2329.4 1509.88 2330.67 1509.88 Q2331.02 1509.88 2331.52 1509.84 Q2332.03 1509.77 2332.2 1509.75 L2332.2 1512.82 Q2331.39 1513.12 2330.53 1513.26 Q2329.67 1513.4 2328.82 1513.4 Q2326.04 1513.4 2324.97 1511.9 Q2323.91 1510.37 2323.91 1506.3 L2323.91 1490.83 L2314.35 1490.83 L2314.35 1512.5 L2310 1512.5 L2310 1490.83 L2306.69 1490.83 L2306.69 1486.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2427.9 1508.56 L2435.54 1508.56 L2435.54 1482.2 L2427.23 1483.87 L2427.23 1479.61 L2435.49 1477.94 L2440.17 1477.94 L2440.17 1508.56 L2447.81 1508.56 L2447.81 1512.5 L2427.9 1512.5 L2427.9 1508.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2464.22 1477.94 L2468.16 1477.94 L2456.12 1516.9 L2452.18 1516.9 L2464.22 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2480.19 1477.94 L2484.13 1477.94 L2472.09 1516.9 L2468.16 1516.9 L2480.19 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2490.01 1508.56 L2497.65 1508.56 L2497.65 1482.2 L2489.34 1483.87 L2489.34 1479.61 L2497.6 1477.94 L2502.28 1477.94 L2502.28 1508.56 L2509.91 1508.56 L2509.91 1512.5 L2490.01 1512.5 L2490.01 1508.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2516 1486.57 L2540.84 1486.57 L2540.84 1490.83 L2537.58 1490.83 L2537.58 1506.76 Q2537.58 1508.43 2538.13 1509.17 Q2538.71 1509.88 2539.98 1509.88 Q2540.33 1509.88 2540.84 1509.84 Q2541.35 1509.77 2541.51 1509.75 L2541.51 1512.82 Q2540.7 1513.12 2539.85 1513.26 Q2538.99 1513.4 2538.13 1513.4 Q2535.35 1513.4 2534.29 1511.9 Q2533.22 1510.37 2533.22 1506.3 L2533.22 1490.83 L2523.66 1490.83 L2523.66 1512.5 L2519.31 1512.5 L2519.31 1490.83 L2516 1490.83 L2516 1486.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2651.57 1482.01 L2639.76 1500.46 L2651.57 1500.46 L2651.57 1482.01 M2650.34 1477.94 L2656.22 1477.94 L2656.22 1500.46 L2661.15 1500.46 L2661.15 1504.35 L2656.22 1504.35 L2656.22 1512.5 L2651.57 1512.5 L2651.57 1504.35 L2635.97 1504.35 L2635.97 1499.84 L2650.34 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2675.85 1477.94 L2679.79 1477.94 L2667.75 1516.9 L2663.81 1516.9 L2675.85 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2691.82 1477.94 L2695.76 1477.94 L2683.72 1516.9 L2679.79 1516.9 L2691.82 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2714.99 1493.87 Q2718.35 1494.58 2720.23 1496.85 Q2722.12 1499.12 2722.12 1502.45 Q2722.12 1507.57 2718.61 1510.37 Q2715.09 1513.17 2708.61 1513.17 Q2706.43 1513.17 2704.12 1512.73 Q2701.82 1512.31 2699.37 1511.46 L2699.37 1506.94 Q2701.31 1508.08 2703.63 1508.66 Q2705.94 1509.24 2708.47 1509.24 Q2712.87 1509.24 2715.16 1507.5 Q2717.47 1505.76 2717.47 1502.45 Q2717.47 1499.4 2715.32 1497.69 Q2713.19 1495.95 2709.37 1495.95 L2705.34 1495.95 L2705.34 1492.11 L2709.55 1492.11 Q2713 1492.11 2714.83 1490.74 Q2716.66 1489.35 2716.66 1486.76 Q2716.66 1484.1 2714.76 1482.69 Q2712.89 1481.25 2709.37 1481.25 Q2707.45 1481.25 2705.25 1481.67 Q2703.05 1482.08 2700.41 1482.96 L2700.41 1478.8 Q2703.07 1478.06 2705.39 1477.69 Q2707.73 1477.31 2709.79 1477.31 Q2715.11 1477.31 2718.21 1479.75 Q2721.31 1482.15 2721.31 1486.27 Q2721.31 1489.14 2719.67 1491.13 Q2718.03 1493.1 2714.99 1493.87 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2727.63 1486.57 L2752.47 1486.57 L2752.47 1490.83 L2749.21 1490.83 L2749.21 1506.76 Q2749.21 1508.43 2749.76 1509.17 Q2750.34 1509.88 2751.61 1509.88 Q2751.96 1509.88 2752.47 1509.84 Q2752.98 1509.77 2753.14 1509.75 L2753.14 1512.82 Q2752.33 1513.12 2751.48 1513.26 Q2750.62 1513.4 2749.76 1513.4 Q2746.99 1513.4 2745.92 1511.9 Q2744.86 1510.37 2744.86 1506.3 L2744.86 1490.83 L2735.3 1490.83 L2735.3 1512.5 L2730.94 1512.5 L2730.94 1490.83 L2727.63 1490.83 L2727.63 1486.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2848.28 1477.94 L2866.64 1477.94 L2866.64 1481.88 L2852.56 1481.88 L2852.56 1490.35 Q2853.58 1490 2854.6 1489.84 Q2855.62 1489.65 2856.64 1489.65 Q2862.42 1489.65 2865.8 1492.82 Q2869.18 1496 2869.18 1501.41 Q2869.18 1506.99 2865.71 1510.09 Q2862.24 1513.17 2855.92 1513.17 Q2853.74 1513.17 2851.48 1512.8 Q2849.23 1512.43 2846.82 1511.69 L2846.82 1506.99 Q2848.91 1508.12 2851.13 1508.68 Q2853.35 1509.24 2855.83 1509.24 Q2859.83 1509.24 2862.17 1507.13 Q2864.51 1505.02 2864.51 1501.41 Q2864.51 1497.8 2862.17 1495.69 Q2859.83 1493.59 2855.83 1493.59 Q2853.95 1493.59 2852.08 1494 Q2850.23 1494.42 2848.28 1495.3 L2848.28 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2885.36 1477.94 L2889.3 1477.94 L2877.26 1516.9 L2873.33 1516.9 L2885.36 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2901.34 1477.94 L2905.27 1477.94 L2893.23 1516.9 L2889.3 1516.9 L2901.34 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2924.51 1493.87 Q2927.86 1494.58 2929.74 1496.85 Q2931.64 1499.12 2931.64 1502.45 Q2931.64 1507.57 2928.12 1510.37 Q2924.6 1513.17 2918.12 1513.17 Q2915.94 1513.17 2913.63 1512.73 Q2911.34 1512.31 2908.88 1511.46 L2908.88 1506.94 Q2910.83 1508.08 2913.14 1508.66 Q2915.46 1509.24 2917.98 1509.24 Q2922.38 1509.24 2924.67 1507.5 Q2926.98 1505.76 2926.98 1502.45 Q2926.98 1499.4 2924.83 1497.69 Q2922.7 1495.95 2918.88 1495.95 L2914.85 1495.95 L2914.85 1492.11 L2919.07 1492.11 Q2922.52 1492.11 2924.35 1490.74 Q2926.17 1489.35 2926.17 1486.76 Q2926.17 1484.1 2924.28 1482.69 Q2922.4 1481.25 2918.88 1481.25 Q2916.96 1481.25 2914.76 1481.67 Q2912.56 1482.08 2909.92 1482.96 L2909.92 1478.8 Q2912.59 1478.06 2914.9 1477.69 Q2917.24 1477.31 2919.3 1477.31 Q2924.62 1477.31 2927.72 1479.75 Q2930.83 1482.15 2930.83 1486.27 Q2930.83 1489.14 2929.18 1491.13 Q2927.54 1493.1 2924.51 1493.87 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2937.15 1486.57 L2961.98 1486.57 L2961.98 1490.83 L2958.72 1490.83 L2958.72 1506.76 Q2958.72 1508.43 2959.28 1509.17 Q2959.85 1509.88 2961.13 1509.88 Q2961.47 1509.88 2961.98 1509.84 Q2962.49 1509.77 2962.66 1509.75 L2962.66 1512.82 Q2961.85 1513.12 2960.99 1513.26 Q2960.13 1513.4 2959.28 1513.4 Q2956.5 1513.4 2955.43 1511.9 Q2954.37 1510.37 2954.37 1506.3 L2954.37 1490.83 L2944.81 1490.83 L2944.81 1512.5 L2940.46 1512.5 L2940.46 1490.83 L2937.15 1490.83 L2937.15 1486.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M3062.54 1508.56 L3078.86 1508.56 L3078.86 1512.5 L3056.91 1512.5 L3056.91 1508.56 Q3059.58 1505.81 3064.16 1501.18 Q3068.77 1496.53 3069.95 1495.19 Q3072.19 1492.66 3073.07 1490.93 Q3073.97 1489.17 3073.97 1487.48 Q3073.97 1484.72 3072.03 1482.99 Q3070.11 1481.25 3067.01 1481.25 Q3064.81 1481.25 3062.35 1482.01 Q3059.92 1482.78 3057.15 1484.33 L3057.15 1479.61 Q3059.97 1478.47 3062.42 1477.89 Q3064.88 1477.31 3066.91 1477.31 Q3072.28 1477.31 3075.48 1480 Q3078.67 1482.69 3078.67 1487.18 Q3078.67 1489.31 3077.86 1491.23 Q3077.08 1493.12 3074.97 1495.72 Q3074.39 1496.39 3071.29 1499.61 Q3068.19 1502.8 3062.54 1508.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M3095.64 1477.94 L3099.58 1477.94 L3087.54 1516.9 L3083.6 1516.9 L3095.64 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M3111.61 1477.94 L3115.55 1477.94 L3103.51 1516.9 L3099.58 1516.9 L3111.61 1477.94 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M3121.43 1508.56 L3129.07 1508.56 L3129.07 1482.2 L3120.76 1483.87 L3120.76 1479.61 L3129.02 1477.94 L3133.7 1477.94 L3133.7 1508.56 L3141.33 1508.56 L3141.33 1512.5 L3121.43 1512.5 L3121.43 1508.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M3147.42 1486.57 L3172.26 1486.57 L3172.26 1490.83 L3169 1490.83 L3169 1506.76 Q3169 1508.43 3169.55 1509.17 Q3170.13 1509.88 3171.4 1509.88 Q3171.75 1509.88 3172.26 1509.84 Q3172.77 1509.77 3172.93 1509.75 L3172.93 1512.82 Q3172.12 1513.12 3171.27 1513.26 Q3170.41 1513.4 3169.55 1513.4 Q3166.77 1513.4 3165.71 1511.9 Q3164.64 1510.37 3164.64 1506.3 L3164.64 1490.83 L3155.08 1490.83 L3155.08 1512.5 L3150.73 1512.5 L3150.73 1490.83 L3147.42 1490.83 L3147.42 1486.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2494.49 1577.97 L2474.22 1577.97 Q2474.7 1587.48 2476.89 1591.52 Q2479.63 1596.49 2484.37 1596.49 Q2489.15 1596.49 2491.79 1591.49 Q2494.11 1587.1 2494.49 1577.97 M2494.4 1572.55 Q2493.51 1563.52 2491.79 1560.33 Q2489.05 1555.3 2484.37 1555.3 Q2479.5 1555.3 2476.92 1560.27 Q2474.89 1564.28 2474.28 1572.55 L2494.4 1572.55 M2484.37 1550.53 Q2492.01 1550.53 2496.37 1557.28 Q2500.73 1563.99 2500.73 1575.9 Q2500.73 1587.77 2496.37 1594.52 Q2492.01 1601.3 2484.37 1601.3 Q2476.7 1601.3 2472.37 1594.52 Q2468.01 1587.77 2468.01 1575.9 Q2468.01 1563.99 2472.37 1557.28 Q2476.7 1550.53 2484.37 1550.53 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip223)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1815.99,1379.22 3152.76,1379.22 "/>
<polyline clip-path="url(#clip223)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1815.99,1139.45 3152.76,1139.45 "/>
<polyline clip-path="url(#clip223)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1815.99,899.69 3152.76,899.69 "/>
<polyline clip-path="url(#clip223)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1815.99,659.927 3152.76,659.927 "/>
<polyline clip-path="url(#clip223)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1815.99,420.164 3152.76,420.164 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1815.99,1443.7 1815.99,360.224 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1815.99,1379.22 1834.88,1379.22 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1815.99,1139.45 1834.88,1139.45 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1815.99,899.69 1834.88,899.69 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1815.99,659.927 1834.88,659.927 "/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1815.99,420.164 1834.88,420.164 "/>
<path clip-path="url(#clip220)" d="M1712.41 1365.01 Q1708.8 1365.01 1706.97 1368.58 Q1705.16 1372.12 1705.16 1379.25 Q1705.16 1386.36 1706.97 1389.92 Q1708.8 1393.46 1712.41 1393.46 Q1716.04 1393.46 1717.85 1389.92 Q1719.68 1386.36 1719.68 1379.25 Q1719.68 1372.12 1717.85 1368.58 Q1716.04 1365.01 1712.41 1365.01 M1712.41 1361.31 Q1718.22 1361.31 1721.27 1365.92 Q1724.35 1370.5 1724.35 1379.25 Q1724.35 1387.98 1721.27 1392.58 Q1718.22 1397.17 1712.41 1397.17 Q1706.6 1397.17 1703.52 1392.58 Q1700.46 1387.98 1700.46 1379.25 Q1700.46 1370.5 1703.52 1365.92 Q1706.6 1361.31 1712.41 1361.31 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1732.57 1390.62 L1737.45 1390.62 L1737.45 1396.5 L1732.57 1396.5 L1732.57 1390.62 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1751.67 1392.56 L1767.99 1392.56 L1767.99 1396.5 L1746.04 1396.5 L1746.04 1392.56 Q1748.7 1389.81 1753.29 1385.18 Q1757.89 1380.52 1759.07 1379.18 Q1761.32 1376.66 1762.2 1374.92 Q1763.1 1373.16 1763.1 1371.47 Q1763.1 1368.72 1761.16 1366.98 Q1759.24 1365.25 1756.13 1365.25 Q1753.94 1365.25 1751.48 1366.01 Q1749.05 1366.77 1746.27 1368.32 L1746.27 1363.6 Q1749.1 1362.47 1751.55 1361.89 Q1754 1361.31 1756.04 1361.31 Q1761.41 1361.31 1764.61 1364 Q1767.8 1366.68 1767.8 1371.17 Q1767.8 1373.3 1766.99 1375.22 Q1766.2 1377.12 1764.1 1379.71 Q1763.52 1380.38 1760.42 1383.6 Q1757.32 1386.8 1751.67 1392.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1710.32 1125.25 Q1706.71 1125.25 1704.88 1128.82 Q1703.08 1132.36 1703.08 1139.49 Q1703.08 1146.59 1704.88 1150.16 Q1706.71 1153.7 1710.32 1153.7 Q1713.96 1153.7 1715.76 1150.16 Q1717.59 1146.59 1717.59 1139.49 Q1717.59 1132.36 1715.76 1128.82 Q1713.96 1125.25 1710.32 1125.25 M1710.32 1121.55 Q1716.13 1121.55 1719.19 1126.15 Q1722.27 1130.74 1722.27 1139.49 Q1722.27 1148.21 1719.19 1152.82 Q1716.13 1157.4 1710.32 1157.4 Q1704.51 1157.4 1701.44 1152.82 Q1698.38 1148.21 1698.38 1139.49 Q1698.38 1130.74 1701.44 1126.15 Q1704.51 1121.55 1710.32 1121.55 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1730.49 1150.85 L1735.37 1150.85 L1735.37 1156.73 L1730.49 1156.73 L1730.49 1150.85 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1758.4 1126.25 L1746.6 1144.7 L1758.4 1144.7 L1758.4 1126.25 M1757.18 1122.17 L1763.06 1122.17 L1763.06 1144.7 L1767.99 1144.7 L1767.99 1148.58 L1763.06 1148.58 L1763.06 1156.73 L1758.4 1156.73 L1758.4 1148.58 L1742.8 1148.58 L1742.8 1144.07 L1757.18 1122.17 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1710.65 885.489 Q1707.04 885.489 1705.21 889.053 Q1703.4 892.595 1703.4 899.725 Q1703.4 906.831 1705.21 910.396 Q1707.04 913.938 1710.65 913.938 Q1714.28 913.938 1716.09 910.396 Q1717.92 906.831 1717.92 899.725 Q1717.92 892.595 1716.09 889.053 Q1714.28 885.489 1710.65 885.489 M1710.65 881.785 Q1716.46 881.785 1719.51 886.391 Q1722.59 890.975 1722.59 899.725 Q1722.59 908.452 1719.51 913.058 Q1716.46 917.641 1710.65 917.641 Q1704.84 917.641 1701.76 913.058 Q1698.7 908.452 1698.7 899.725 Q1698.7 890.975 1701.76 886.391 Q1704.84 881.785 1710.65 881.785 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1730.81 911.09 L1735.69 911.09 L1735.69 916.97 L1730.81 916.97 L1730.81 911.09 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1756.46 897.827 Q1753.31 897.827 1751.46 899.979 Q1749.63 902.132 1749.63 905.882 Q1749.63 909.609 1751.46 911.785 Q1753.31 913.938 1756.46 913.938 Q1759.61 913.938 1761.44 911.785 Q1763.29 909.609 1763.29 905.882 Q1763.29 902.132 1761.44 899.979 Q1759.61 897.827 1756.46 897.827 M1765.74 883.174 L1765.74 887.433 Q1763.98 886.6 1762.18 886.16 Q1760.39 885.72 1758.63 885.72 Q1754 885.72 1751.55 888.845 Q1749.12 891.97 1748.77 898.29 Q1750.14 896.276 1752.2 895.211 Q1754.26 894.123 1756.74 894.123 Q1761.94 894.123 1764.95 897.294 Q1767.99 900.442 1767.99 905.882 Q1767.99 911.206 1764.84 914.424 Q1761.69 917.641 1756.46 917.641 Q1750.46 917.641 1747.29 913.058 Q1744.12 908.452 1744.12 899.725 Q1744.12 891.53 1748.01 886.669 Q1751.9 881.785 1758.45 881.785 Q1760.21 881.785 1761.99 882.132 Q1763.8 882.479 1765.74 883.174 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1710.9 645.726 Q1707.29 645.726 1705.46 649.291 Q1703.66 652.832 1703.66 659.962 Q1703.66 667.068 1705.46 670.633 Q1707.29 674.175 1710.9 674.175 Q1714.54 674.175 1716.34 670.633 Q1718.17 667.068 1718.17 659.962 Q1718.17 652.832 1716.34 649.291 Q1714.54 645.726 1710.9 645.726 M1710.9 642.022 Q1716.71 642.022 1719.77 646.629 Q1722.85 651.212 1722.85 659.962 Q1722.85 668.689 1719.77 673.295 Q1716.71 677.878 1710.9 677.878 Q1705.09 677.878 1702.01 673.295 Q1698.96 668.689 1698.96 659.962 Q1698.96 651.212 1702.01 646.629 Q1705.09 642.022 1710.9 642.022 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1731.07 671.328 L1735.95 671.328 L1735.95 677.207 L1731.07 677.207 L1731.07 671.328 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1756.13 660.795 Q1752.8 660.795 1750.88 662.578 Q1748.98 664.36 1748.98 667.485 Q1748.98 670.61 1750.88 672.392 Q1752.8 674.175 1756.13 674.175 Q1759.47 674.175 1761.39 672.392 Q1763.31 670.587 1763.31 667.485 Q1763.31 664.36 1761.39 662.578 Q1759.49 660.795 1756.13 660.795 M1751.46 658.805 Q1748.45 658.064 1746.76 656.004 Q1745.09 653.943 1745.09 650.98 Q1745.09 646.837 1748.03 644.43 Q1751 642.022 1756.13 642.022 Q1761.3 642.022 1764.24 644.43 Q1767.18 646.837 1767.18 650.98 Q1767.18 653.943 1765.49 656.004 Q1763.82 658.064 1760.83 658.805 Q1764.21 659.592 1766.09 661.883 Q1767.99 664.175 1767.99 667.485 Q1767.99 672.508 1764.91 675.193 Q1761.85 677.878 1756.13 677.878 Q1750.42 677.878 1747.34 675.193 Q1744.28 672.508 1744.28 667.485 Q1744.28 664.175 1746.18 661.883 Q1748.08 659.592 1751.46 658.805 M1749.75 651.42 Q1749.75 654.105 1751.41 655.61 Q1753.1 657.115 1756.13 657.115 Q1759.14 657.115 1760.83 655.61 Q1762.55 654.105 1762.55 651.42 Q1762.55 648.735 1760.83 647.231 Q1759.14 645.726 1756.13 645.726 Q1753.1 645.726 1751.41 647.231 Q1749.75 648.735 1749.75 651.42 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1701.62 433.509 L1709.26 433.509 L1709.26 407.144 L1700.95 408.81 L1700.95 404.551 L1709.21 402.884 L1713.89 402.884 L1713.89 433.509 L1721.53 433.509 L1721.53 437.444 L1701.62 437.444 L1701.62 433.509 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1730.97 431.565 L1735.86 431.565 L1735.86 437.444 L1730.97 437.444 L1730.97 431.565 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1756.04 405.963 Q1752.43 405.963 1750.6 409.528 Q1748.8 413.07 1748.8 420.199 Q1748.8 427.306 1750.6 430.87 Q1752.43 434.412 1756.04 434.412 Q1759.68 434.412 1761.48 430.87 Q1763.31 427.306 1763.31 420.199 Q1763.31 413.07 1761.48 409.528 Q1759.68 405.963 1756.04 405.963 M1756.04 402.259 Q1761.85 402.259 1764.91 406.866 Q1767.99 411.449 1767.99 420.199 Q1767.99 428.926 1764.91 433.532 Q1761.85 438.116 1756.04 438.116 Q1750.23 438.116 1747.15 433.532 Q1744.1 428.926 1744.1 420.199 Q1744.1 411.449 1747.15 406.866 Q1750.23 402.259 1756.04 402.259 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M1605.95 891.522 Q1605.38 892.509 1605.12 893.686 Q1604.84 894.832 1604.84 896.233 Q1604.84 901.198 1608.08 903.871 Q1611.3 906.513 1617.35 906.513 L1636.12 906.513 L1636.12 912.402 L1600.48 912.402 L1600.48 906.513 L1606.01 906.513 Q1602.77 904.667 1601.21 901.707 Q1599.62 898.747 1599.62 894.514 Q1599.62 893.909 1599.71 893.177 Q1599.78 892.445 1599.94 891.554 L1605.95 891.522 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2333.43 73.5887 Q2324.08 72.0899 2319.74 68.1605 Q2314.44 63.3399 2314.44 53.4962 L2314.44 27.2059 L2321.97 27.2059 L2321.97 53.2127 Q2321.97 60.6258 2325.41 63.7045 Q2328.41 66.3781 2333.43 66.9452 L2333.43 27.2059 L2340.85 27.2059 L2340.85 66.9047 Q2346.15 66.3376 2348.87 63.664 Q2352.31 60.2613 2352.31 53.1722 L2352.31 27.2059 L2359.85 27.2059 L2359.85 53.4557 Q2359.85 63.664 2354.54 68.12 Q2349.76 72.1304 2340.85 73.5482 L2340.85 89.8329 L2333.43 89.8329 L2333.43 73.5887 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2406.92 86.3491 L2406.92 92.1419 L2363.82 92.1419 L2363.82 86.3491 L2406.92 86.3491 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2449.25 35.9153 Q2452.04 30.8922 2455.93 28.5022 Q2459.82 26.1121 2465.09 26.1121 Q2472.18 26.1121 2476.03 31.0947 Q2479.87 36.0368 2479.87 45.1919 L2479.87 72.576 L2472.38 72.576 L2472.38 45.4349 Q2472.38 38.913 2470.07 35.7533 Q2467.76 32.5936 2463.02 32.5936 Q2457.23 32.5936 2453.87 36.4419 Q2450.51 40.2903 2450.51 46.9338 L2450.51 72.576 L2443.01 72.576 L2443.01 45.4349 Q2443.01 38.8725 2440.7 35.7533 Q2438.39 32.5936 2433.57 32.5936 Q2427.86 32.5936 2424.5 36.4824 Q2421.14 40.3308 2421.14 46.9338 L2421.14 72.576 L2413.64 72.576 L2413.64 27.2059 L2421.14 27.2059 L2421.14 34.2544 Q2423.69 30.082 2427.25 28.0971 Q2430.82 26.1121 2435.72 26.1121 Q2440.66 26.1121 2444.11 28.6237 Q2447.59 31.1352 2449.25 35.9153 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2494.74 27.2059 L2502.2 27.2059 L2502.2 72.576 L2494.74 72.576 L2494.74 27.2059 M2494.74 9.54393 L2502.2 9.54393 L2502.2 18.9825 L2494.74 18.9825 L2494.74 9.54393 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2555.5 45.1919 L2555.5 72.576 L2548.05 72.576 L2548.05 45.4349 Q2548.05 38.994 2545.54 35.7938 Q2543.03 32.5936 2538.01 32.5936 Q2531.97 32.5936 2528.49 36.4419 Q2525 40.2903 2525 46.9338 L2525 72.576 L2517.51 72.576 L2517.51 27.2059 L2525 27.2059 L2525 34.2544 Q2527.68 30.163 2531.28 28.1376 Q2534.93 26.1121 2539.67 26.1121 Q2547.48 26.1121 2551.49 30.9732 Q2555.5 35.7938 2555.5 45.1919 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2569.6 54.671 L2569.6 27.2059 L2577.06 27.2059 L2577.06 54.3874 Q2577.06 60.8284 2579.57 64.0691 Q2582.08 67.2693 2587.1 67.2693 Q2593.14 67.2693 2596.62 63.421 Q2600.15 59.5726 2600.15 52.9291 L2600.15 27.2059 L2607.6 27.2059 L2607.6 72.576 L2600.15 72.576 L2600.15 65.6084 Q2597.43 69.7404 2593.83 71.7658 Q2590.26 73.7508 2585.52 73.7508 Q2577.7 73.7508 2573.65 68.8897 Q2569.6 64.0286 2569.6 54.671 M2588.36 26.1121 L2588.36 26.1121 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2651.88 28.5427 L2651.88 35.5912 Q2648.72 33.9709 2645.31 33.1607 Q2641.91 32.3505 2638.26 32.3505 Q2632.72 32.3505 2629.92 34.0519 Q2627.17 35.7533 2627.17 39.156 Q2627.17 41.7486 2629.15 43.2475 Q2631.14 44.7058 2637.13 46.0426 L2639.68 46.6097 Q2647.62 48.3111 2650.94 51.4303 Q2654.31 54.509 2654.31 60.0587 Q2654.31 66.3781 2649.28 70.0644 Q2644.3 73.7508 2635.55 73.7508 Q2631.91 73.7508 2627.94 73.0216 Q2624.01 72.3329 2619.63 70.9151 L2619.63 63.2184 Q2623.76 65.3654 2627.77 66.4591 Q2631.78 67.5124 2635.71 67.5124 Q2640.98 67.5124 2643.81 65.73 Q2646.65 63.9071 2646.65 60.6258 Q2646.65 57.5877 2644.58 55.9673 Q2642.56 54.3469 2635.63 52.8481 L2633.04 52.2405 Q2626.11 50.7821 2623.03 47.7845 Q2619.95 44.7463 2619.95 39.4801 Q2619.95 33.0797 2624.49 29.5959 Q2629.03 26.1121 2637.37 26.1121 Q2641.51 26.1121 2645.15 26.7198 Q2648.8 27.3274 2651.88 28.5427 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><line clip-path="url(#clip223)" x1="1853.82" y1="420.164" x2="1853.82" y2="404.164" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="420.164" x2="1837.82" y2="420.164" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="420.164" x2="1853.82" y2="436.164" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="420.164" x2="1869.82" y2="420.164" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="882.87" x2="3114.92" y2="866.87" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="882.87" x2="3098.92" y2="882.87" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="882.87" x2="3114.92" y2="898.87" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="882.87" x2="3130.92" y2="882.87" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="987.928" x2="1853.82" y2="971.928" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="987.928" x2="1837.82" y2="987.928" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="987.928" x2="1853.82" y2="1003.93" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="987.928" x2="1869.82" y2="987.928" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1043.03" x2="3114.92" y2="1027.03" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1043.03" x2="3098.92" y2="1043.03" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1043.03" x2="3114.92" y2="1059.03" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1043.03" x2="3130.92" y2="1043.03" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1122.28" x2="1853.82" y2="1106.28" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1122.28" x2="1837.82" y2="1122.28" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1122.28" x2="1853.82" y2="1138.28" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1122.28" x2="1869.82" y2="1122.28" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1128.86" x2="2484.37" y2="1112.86" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1128.86" x2="2468.37" y2="1128.86" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1128.86" x2="2484.37" y2="1144.86" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1128.86" x2="2500.37" y2="1128.86" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1154.91" x2="1853.82" y2="1138.91" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1154.91" x2="1837.82" y2="1154.91" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1154.91" x2="1853.82" y2="1170.91" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1154.91" x2="1869.82" y2="1154.91" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1269.19" x2="3114.92" y2="1253.19" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1269.19" x2="3098.92" y2="1269.19" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1269.19" x2="3114.92" y2="1285.19" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1269.19" x2="3130.92" y2="1269.19" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1276.06" x2="2484.37" y2="1260.06" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1276.06" x2="2468.37" y2="1276.06" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1276.06" x2="2484.37" y2="1292.06" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1276.06" x2="2500.37" y2="1276.06" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1281.41" x2="3114.92" y2="1265.41" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1281.41" x2="3098.92" y2="1281.41" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1281.41" x2="3114.92" y2="1297.41" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1281.41" x2="3130.92" y2="1281.41" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1285.89" x2="2484.37" y2="1269.89" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1285.89" x2="2468.37" y2="1285.89" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1285.89" x2="2484.37" y2="1301.89" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1285.89" x2="2500.37" y2="1285.89" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1300.87" x2="1853.82" y2="1284.87" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1300.87" x2="1837.82" y2="1300.87" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1300.87" x2="1853.82" y2="1316.87" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1300.87" x2="1869.82" y2="1300.87" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1318.68" x2="2484.37" y2="1302.68" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1318.68" x2="2468.37" y2="1318.68" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1318.68" x2="2484.37" y2="1334.68" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1318.68" x2="2500.37" y2="1318.68" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1353.02" x2="1853.82" y2="1337.02" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1353.02" x2="1837.82" y2="1353.02" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1353.02" x2="1853.82" y2="1369.02" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1353.02" x2="1869.82" y2="1353.02" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1377.1" x2="3114.92" y2="1361.1" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1377.1" x2="3098.92" y2="1377.1" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1377.1" x2="3114.92" y2="1393.1" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1377.1" x2="3130.92" y2="1377.1" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1393.08" x2="2484.37" y2="1377.08" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1393.08" x2="2468.37" y2="1393.08" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1393.08" x2="2484.37" y2="1409.08" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1393.08" x2="2500.37" y2="1393.08" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1400.53" x2="1853.82" y2="1384.53" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1400.53" x2="1837.82" y2="1400.53" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1400.53" x2="1853.82" y2="1416.53" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1400.53" x2="1869.82" y2="1400.53" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1425.77" x2="3114.92" y2="1409.77" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1425.77" x2="3098.92" y2="1425.77" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1425.77" x2="3114.92" y2="1441.77" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1425.77" x2="3130.92" y2="1425.77" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1430.73" x2="2484.37" y2="1414.73" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1430.73" x2="2468.37" y2="1430.73" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1430.73" x2="2484.37" y2="1446.73" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1430.73" x2="2500.37" y2="1430.73" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1437.19" x2="3114.92" y2="1421.19" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1437.19" x2="3098.92" y2="1437.19" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1437.19" x2="3114.92" y2="1453.19" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1437.19" x2="3130.92" y2="1437.19" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1443.7" x2="1853.82" y2="1427.7" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1443.7" x2="1837.82" y2="1443.7" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1443.7" x2="1853.82" y2="1459.7" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1443.7" x2="1869.82" y2="1443.7" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<circle clip-path="url(#clip223)" cx="2484.37" cy="630.717" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="2484.37" cy="713.047" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="2484.37" cy="848.587" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="3114.92" cy="860.886" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="3114.92" cy="1006.2" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="1853.82" cy="1011.99" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="2484.37" cy="1026.86" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="2484.37" cy="1126.24" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="2484.37" cy="1135.24" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="2484.37" cy="1142.72" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="1853.82" cy="1174.67" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="1853.82" cy="1192.41" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="2484.37" cy="1217.84" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="3114.92" cy="1217.87" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="2484.37" cy="1245.67" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="2484.37" cy="1270.29" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="2484.37" cy="1277.47" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="2484.37" cy="1286.13" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="2484.37" cy="1301.34" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip223)" cx="2484.37" cy="1302.06" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="861.208" x2="1853.82" y2="845.208" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="861.208" x2="1837.82" y2="861.208" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="861.208" x2="1853.82" y2="877.208" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="861.208" x2="1869.82" y2="861.208" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="977.071" x2="1853.82" y2="961.071" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="977.071" x2="1837.82" y2="977.071" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="977.071" x2="1853.82" y2="993.071" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="977.071" x2="1869.82" y2="977.071" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1025.46" x2="3114.92" y2="1009.46" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1025.46" x2="3098.92" y2="1025.46" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1025.46" x2="3114.92" y2="1041.46" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1025.46" x2="3130.92" y2="1025.46" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1120.45" x2="2484.37" y2="1104.45" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1120.45" x2="2468.37" y2="1120.45" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1120.45" x2="2484.37" y2="1136.45" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1120.45" x2="2500.37" y2="1120.45" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1127.22" x2="2484.37" y2="1111.22" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1127.22" x2="2468.37" y2="1127.22" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1127.22" x2="2484.37" y2="1143.22" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1127.22" x2="2500.37" y2="1127.22" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1138.92" x2="1853.82" y2="1122.92" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1138.92" x2="1837.82" y2="1138.92" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1138.92" x2="1853.82" y2="1154.92" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1138.92" x2="1869.82" y2="1138.92" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1190.08" x2="1853.82" y2="1174.08" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1190.08" x2="1837.82" y2="1190.08" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1190.08" x2="1853.82" y2="1206.08" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1190.08" x2="1869.82" y2="1190.08" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1220.18" x2="1853.82" y2="1204.18" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1220.18" x2="1837.82" y2="1220.18" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1220.18" x2="1853.82" y2="1236.18" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1220.18" x2="1869.82" y2="1220.18" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1276.64" x2="2484.37" y2="1260.64" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1276.64" x2="2468.37" y2="1276.64" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1276.64" x2="2484.37" y2="1292.64" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1276.64" x2="2500.37" y2="1276.64" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1278.74" x2="2484.37" y2="1262.74" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1278.74" x2="2468.37" y2="1278.74" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1278.74" x2="2484.37" y2="1294.74" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1278.74" x2="2500.37" y2="1278.74" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1291.07" x2="2484.37" y2="1275.07" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1291.07" x2="2468.37" y2="1291.07" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1291.07" x2="2484.37" y2="1307.07" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1291.07" x2="2500.37" y2="1291.07" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1299.33" x2="2484.37" y2="1283.33" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1299.33" x2="2468.37" y2="1299.33" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1299.33" x2="2484.37" y2="1315.33" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1299.33" x2="2500.37" y2="1299.33" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1311.13" x2="3114.92" y2="1295.13" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1311.13" x2="3098.92" y2="1311.13" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1311.13" x2="3114.92" y2="1327.13" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1311.13" x2="3130.92" y2="1311.13" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1329.79" x2="2484.37" y2="1313.79" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1329.79" x2="2468.37" y2="1329.79" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1329.79" x2="2484.37" y2="1345.79" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1329.79" x2="2500.37" y2="1329.79" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1335.19" x2="2484.37" y2="1319.19" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1335.19" x2="2468.37" y2="1335.19" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1335.19" x2="2484.37" y2="1351.19" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="2484.37" y1="1335.19" x2="2500.37" y2="1335.19" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1354.5" x2="1853.82" y2="1338.5" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1354.5" x2="1837.82" y2="1354.5" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1354.5" x2="1853.82" y2="1370.5" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1354.5" x2="1869.82" y2="1354.5" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1354.69" x2="3114.92" y2="1338.69" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1354.69" x2="3098.92" y2="1354.69" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1354.69" x2="3114.92" y2="1370.69" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1354.69" x2="3130.92" y2="1354.69" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1361.87" x2="1853.82" y2="1345.87" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1361.87" x2="1837.82" y2="1361.87" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1361.87" x2="1853.82" y2="1377.87" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1361.87" x2="1869.82" y2="1361.87" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1369.97" x2="1853.82" y2="1353.97" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1369.97" x2="1837.82" y2="1369.97" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1369.97" x2="1853.82" y2="1385.97" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="1853.82" y1="1369.97" x2="1869.82" y2="1369.97" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1383.51" x2="3114.92" y2="1367.51" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1383.51" x2="3098.92" y2="1383.51" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1383.51" x2="3114.92" y2="1399.51" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip223)" x1="3114.92" y1="1383.51" x2="3130.92" y2="1383.51" style="stroke:#3da44d; stroke-width:3.2; stroke-opacity:1"/>
<path clip-path="url(#clip220)" d="M2272.75 315.712 L2695.99 315.712 L2695.99 108.352 L2272.75 108.352  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<polyline clip-path="url(#clip220)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2272.75,315.712 2695.99,315.712 2695.99,108.352 2272.75,108.352 2272.75,315.712 "/>
<line clip-path="url(#clip220)" x1="2332.17" y1="160.192" x2="2332.17" y2="137.437" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip220)" x1="2332.17" y1="160.192" x2="2309.41" y2="160.192" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip220)" x1="2332.17" y1="160.192" x2="2332.17" y2="182.948" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip220)" x1="2332.17" y1="160.192" x2="2354.92" y2="160.192" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<path clip-path="url(#clip220)" d="M2391.58 142.912 L2396.25 142.912 L2396.25 177.472 L2391.58 177.472 L2391.58 142.912 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2420.4 155.528 Q2419.68 155.111 2418.82 154.926 Q2417.99 154.718 2416.97 154.718 Q2413.36 154.718 2411.42 157.079 Q2409.49 159.417 2409.49 163.815 L2409.49 177.472 L2405.21 177.472 L2405.21 151.546 L2409.49 151.546 L2409.49 155.574 Q2410.84 153.213 2412.99 152.079 Q2415.14 150.921 2418.22 150.921 Q2418.66 150.921 2419.19 150.991 Q2419.73 151.037 2420.37 151.153 L2420.4 155.528 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2439.05 155.528 Q2438.34 155.111 2437.48 154.926 Q2436.65 154.718 2435.63 154.718 Q2432.02 154.718 2430.07 157.079 Q2428.15 159.417 2428.15 163.815 L2428.15 177.472 L2423.87 177.472 L2423.87 151.546 L2428.15 151.546 L2428.15 155.574 Q2429.49 153.213 2431.65 152.079 Q2433.8 150.921 2436.88 150.921 Q2437.32 150.921 2437.85 150.991 Q2438.38 151.037 2439.03 151.153 L2439.05 155.528 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2464.66 163.444 L2464.66 165.528 L2445.07 165.528 Q2445.35 169.926 2447.71 172.241 Q2450.1 174.532 2454.33 174.532 Q2456.79 174.532 2459.08 173.93 Q2461.39 173.329 2463.66 172.125 L2463.66 176.153 Q2461.37 177.125 2458.96 177.634 Q2456.55 178.143 2454.08 178.143 Q2447.87 178.143 2444.24 174.532 Q2440.63 170.921 2440.63 164.764 Q2440.63 158.398 2444.05 154.671 Q2447.5 150.921 2453.34 150.921 Q2458.57 150.921 2461.6 154.301 Q2464.66 157.657 2464.66 163.444 M2460.4 162.194 Q2460.35 158.699 2458.43 156.616 Q2456.53 154.532 2453.38 154.532 Q2449.82 154.532 2447.66 156.546 Q2445.54 158.56 2445.21 162.218 L2460.4 162.194 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2475.77 173.583 L2475.77 187.333 L2471.48 187.333 L2471.48 151.546 L2475.77 151.546 L2475.77 155.482 Q2477.11 153.167 2479.15 152.056 Q2481.21 150.921 2484.05 150.921 Q2488.78 150.921 2491.72 154.671 Q2494.68 158.421 2494.68 164.532 Q2494.68 170.643 2491.72 174.393 Q2488.78 178.143 2484.05 178.143 Q2481.21 178.143 2479.15 177.032 Q2477.11 175.898 2475.77 173.583 M2490.26 164.532 Q2490.26 159.833 2488.31 157.171 Q2486.39 154.486 2483.01 154.486 Q2479.63 154.486 2477.69 157.171 Q2475.77 159.833 2475.77 164.532 Q2475.77 169.231 2477.69 171.917 Q2479.63 174.579 2483.01 174.579 Q2486.39 174.579 2488.31 171.917 Q2490.26 169.231 2490.26 164.532 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2501.35 141.454 L2511.16 141.454 L2511.16 144.764 L2505.6 144.764 L2505.6 180.412 L2511.16 180.412 L2511.16 183.722 L2501.35 183.722 L2501.35 141.454 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2541.14 144.046 L2541.14 148.607 Q2538.47 147.333 2536.11 146.708 Q2533.75 146.083 2531.55 146.083 Q2527.73 146.083 2525.65 147.565 Q2523.59 149.046 2523.59 151.778 Q2523.59 154.069 2524.96 155.25 Q2526.35 156.407 2530.19 157.125 L2533.01 157.704 Q2538.24 158.699 2540.72 161.222 Q2543.22 163.722 2543.22 167.935 Q2543.22 172.958 2539.84 175.551 Q2536.48 178.143 2529.98 178.143 Q2527.53 178.143 2524.75 177.588 Q2521.99 177.032 2519.03 175.944 L2519.03 171.13 Q2521.88 172.727 2524.61 173.537 Q2527.34 174.347 2529.98 174.347 Q2533.98 174.347 2536.16 172.773 Q2538.34 171.199 2538.34 168.282 Q2538.34 165.736 2536.76 164.301 Q2535.21 162.866 2531.65 162.148 L2528.8 161.593 Q2523.57 160.551 2521.23 158.329 Q2518.89 156.106 2518.89 152.148 Q2518.89 147.565 2522.11 144.926 Q2525.35 142.287 2531.02 142.287 Q2533.45 142.287 2535.97 142.727 Q2538.5 143.167 2541.14 144.046 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2549.98 142.912 L2554.68 142.912 L2554.68 163.907 Q2554.68 169.463 2556.69 171.917 Q2558.71 174.347 2563.22 174.347 Q2567.71 174.347 2569.72 171.917 Q2571.74 169.463 2571.74 163.907 L2571.74 142.912 L2576.44 142.912 L2576.44 164.486 Q2576.44 171.245 2573.08 174.694 Q2569.75 178.143 2563.22 178.143 Q2556.67 178.143 2553.31 174.694 Q2549.98 171.245 2549.98 164.486 L2549.98 142.912 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2586.76 174.833 L2596.58 174.833 L2596.58 177.472 L2582.73 177.472 L2582.73 174.926 Q2583.52 174.208 2584.98 172.912 Q2592.94 165.852 2592.94 163.676 Q2592.94 162.148 2591.74 161.222 Q2590.53 160.273 2588.57 160.273 Q2587.36 160.273 2585.95 160.69 Q2584.54 161.083 2582.87 161.894 L2582.87 159.046 Q2584.65 158.398 2586.18 158.074 Q2587.73 157.75 2589.05 157.75 Q2592.41 157.75 2594.42 159.278 Q2596.44 160.806 2596.44 163.306 Q2596.44 166.523 2588.78 173.097 Q2587.48 174.208 2586.76 174.833 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2613.98 141.454 L2613.98 183.722 L2604.17 183.722 L2604.17 180.412 L2609.7 180.412 L2609.7 144.764 L2604.17 144.764 L2604.17 141.454 L2613.98 141.454 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2632.76 141.5 Q2629.65 146.824 2628.15 152.032 Q2626.65 157.241 2626.65 162.588 Q2626.65 167.935 2628.15 173.19 Q2629.68 178.421 2632.76 183.722 L2629.05 183.722 Q2625.58 178.282 2623.84 173.028 Q2622.13 167.773 2622.13 162.588 Q2622.13 157.426 2623.84 152.194 Q2625.56 146.963 2629.05 141.5 L2632.76 141.5 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2651.62 145.991 Q2648.01 145.991 2646.18 149.556 Q2644.38 153.097 2644.38 160.227 Q2644.38 167.333 2646.18 170.898 Q2648.01 174.44 2651.62 174.44 Q2655.26 174.44 2657.06 170.898 Q2658.89 167.333 2658.89 160.227 Q2658.89 153.097 2657.06 149.556 Q2655.26 145.991 2651.62 145.991 M2651.62 142.287 Q2657.43 142.287 2660.49 146.894 Q2663.57 151.477 2663.57 160.227 Q2663.57 168.954 2660.49 173.56 Q2657.43 178.143 2651.62 178.143 Q2645.81 178.143 2642.73 173.56 Q2639.68 168.954 2639.68 160.227 Q2639.68 151.477 2642.73 146.894 Q2645.81 142.287 2651.62 142.287 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2670.51 141.5 L2674.21 141.5 Q2677.69 146.963 2679.4 152.194 Q2681.14 157.426 2681.14 162.588 Q2681.14 167.773 2679.4 173.028 Q2677.69 178.282 2674.21 183.722 L2670.51 183.722 Q2673.59 178.421 2675.09 173.19 Q2676.62 167.935 2676.62 162.588 Q2676.62 157.241 2675.09 152.032 Q2673.59 146.824 2670.51 141.5 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><circle clip-path="url(#clip220)" cx="2332.17" cy="212.032" r="20.48" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="4.55111"/>
<path clip-path="url(#clip220)" d="M2391.58 194.752 L2396.25 194.752 L2396.25 229.312 L2391.58 229.312 L2391.58 194.752 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2420.4 207.368 Q2419.68 206.951 2418.82 206.766 Q2417.99 206.558 2416.97 206.558 Q2413.36 206.558 2411.42 208.919 Q2409.49 211.257 2409.49 215.655 L2409.49 229.312 L2405.21 229.312 L2405.21 203.386 L2409.49 203.386 L2409.49 207.414 Q2410.84 205.053 2412.99 203.919 Q2415.14 202.761 2418.22 202.761 Q2418.66 202.761 2419.19 202.831 Q2419.73 202.877 2420.37 202.993 L2420.4 207.368 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2439.05 207.368 Q2438.34 206.951 2437.48 206.766 Q2436.65 206.558 2435.63 206.558 Q2432.02 206.558 2430.07 208.919 Q2428.15 211.257 2428.15 215.655 L2428.15 229.312 L2423.87 229.312 L2423.87 203.386 L2428.15 203.386 L2428.15 207.414 Q2429.49 205.053 2431.65 203.919 Q2433.8 202.761 2436.88 202.761 Q2437.32 202.761 2437.85 202.831 Q2438.38 202.877 2439.03 202.993 L2439.05 207.368 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2464.66 215.284 L2464.66 217.368 L2445.07 217.368 Q2445.35 221.766 2447.71 224.081 Q2450.1 226.372 2454.33 226.372 Q2456.79 226.372 2459.08 225.77 Q2461.39 225.169 2463.66 223.965 L2463.66 227.993 Q2461.37 228.965 2458.96 229.474 Q2456.55 229.983 2454.08 229.983 Q2447.87 229.983 2444.24 226.372 Q2440.63 222.761 2440.63 216.604 Q2440.63 210.238 2444.05 206.511 Q2447.5 202.761 2453.34 202.761 Q2458.57 202.761 2461.6 206.141 Q2464.66 209.497 2464.66 215.284 M2460.4 214.034 Q2460.35 210.539 2458.43 208.456 Q2456.53 206.372 2453.38 206.372 Q2449.82 206.372 2447.66 208.386 Q2445.54 210.4 2445.21 214.058 L2460.4 214.034 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2475.77 225.423 L2475.77 239.173 L2471.48 239.173 L2471.48 203.386 L2475.77 203.386 L2475.77 207.322 Q2477.11 205.007 2479.15 203.896 Q2481.21 202.761 2484.05 202.761 Q2488.78 202.761 2491.72 206.511 Q2494.68 210.261 2494.68 216.372 Q2494.68 222.483 2491.72 226.233 Q2488.78 229.983 2484.05 229.983 Q2481.21 229.983 2479.15 228.872 Q2477.11 227.738 2475.77 225.423 M2490.26 216.372 Q2490.26 211.673 2488.31 209.011 Q2486.39 206.326 2483.01 206.326 Q2479.63 206.326 2477.69 209.011 Q2475.77 211.673 2475.77 216.372 Q2475.77 221.071 2477.69 223.757 Q2479.63 226.419 2483.01 226.419 Q2486.39 226.419 2488.31 223.757 Q2490.26 221.071 2490.26 216.372 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2501.35 193.294 L2511.16 193.294 L2511.16 196.604 L2505.6 196.604 L2505.6 232.252 L2511.16 232.252 L2511.16 235.562 L2501.35 235.562 L2501.35 193.294 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2541.14 195.886 L2541.14 200.447 Q2538.47 199.173 2536.11 198.548 Q2533.75 197.923 2531.55 197.923 Q2527.73 197.923 2525.65 199.405 Q2523.59 200.886 2523.59 203.618 Q2523.59 205.909 2524.96 207.09 Q2526.35 208.247 2530.19 208.965 L2533.01 209.544 Q2538.24 210.539 2540.72 213.062 Q2543.22 215.562 2543.22 219.775 Q2543.22 224.798 2539.84 227.391 Q2536.48 229.983 2529.98 229.983 Q2527.53 229.983 2524.75 229.428 Q2521.99 228.872 2519.03 227.784 L2519.03 222.97 Q2521.88 224.567 2524.61 225.377 Q2527.34 226.187 2529.98 226.187 Q2533.98 226.187 2536.16 224.613 Q2538.34 223.039 2538.34 220.122 Q2538.34 217.576 2536.76 216.141 Q2535.21 214.706 2531.65 213.988 L2528.8 213.433 Q2523.57 212.391 2521.23 210.169 Q2518.89 207.946 2518.89 203.988 Q2518.89 199.405 2522.11 196.766 Q2525.35 194.127 2531.02 194.127 Q2533.45 194.127 2535.97 194.567 Q2538.5 195.007 2541.14 195.886 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2549.98 194.752 L2554.68 194.752 L2554.68 215.747 Q2554.68 221.303 2556.69 223.757 Q2558.71 226.187 2563.22 226.187 Q2567.71 226.187 2569.72 223.757 Q2571.74 221.303 2571.74 215.747 L2571.74 194.752 L2576.44 194.752 L2576.44 216.326 Q2576.44 223.085 2573.08 226.534 Q2569.75 229.983 2563.22 229.983 Q2556.67 229.983 2553.31 226.534 Q2549.98 223.085 2549.98 216.326 L2549.98 194.752 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2586.76 226.673 L2596.58 226.673 L2596.58 229.312 L2582.73 229.312 L2582.73 226.766 Q2583.52 226.048 2584.98 224.752 Q2592.94 217.692 2592.94 215.516 Q2592.94 213.988 2591.74 213.062 Q2590.53 212.113 2588.57 212.113 Q2587.36 212.113 2585.95 212.53 Q2584.54 212.923 2582.87 213.734 L2582.87 210.886 Q2584.65 210.238 2586.18 209.914 Q2587.73 209.59 2589.05 209.59 Q2592.41 209.59 2594.42 211.118 Q2596.44 212.646 2596.44 215.146 Q2596.44 218.363 2588.78 224.937 Q2587.48 226.048 2586.76 226.673 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2613.98 193.294 L2613.98 235.562 L2604.17 235.562 L2604.17 232.252 L2609.7 232.252 L2609.7 196.604 L2604.17 196.604 L2604.17 193.294 L2613.98 193.294 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2632.76 193.34 Q2629.65 198.664 2628.15 203.872 Q2626.65 209.081 2626.65 214.428 Q2626.65 219.775 2628.15 225.03 Q2629.68 230.261 2632.76 235.562 L2629.05 235.562 Q2625.58 230.122 2623.84 224.868 Q2622.13 219.613 2622.13 214.428 Q2622.13 209.266 2623.84 204.034 Q2625.56 198.803 2629.05 193.34 L2632.76 193.34 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2642.43 225.377 L2650.07 225.377 L2650.07 199.011 L2641.76 200.678 L2641.76 196.419 L2650.02 194.752 L2654.7 194.752 L2654.7 225.377 L2662.34 225.377 L2662.34 229.312 L2642.43 229.312 L2642.43 225.377 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2670.51 193.34 L2674.21 193.34 Q2677.69 198.803 2679.4 204.034 Q2681.14 209.266 2681.14 214.428 Q2681.14 219.613 2679.4 224.868 Q2677.69 230.122 2674.21 235.562 L2670.51 235.562 Q2673.59 230.261 2675.09 225.03 Q2676.62 219.775 2676.62 214.428 Q2676.62 209.081 2675.09 203.872 Q2673.59 198.664 2670.51 193.34 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><line clip-path="url(#clip220)" x1="2332.17" y1="263.872" x2="2332.17" y2="241.117" style="stroke:#3da44d; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip220)" x1="2332.17" y1="263.872" x2="2309.41" y2="263.872" style="stroke:#3da44d; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip220)" x1="2332.17" y1="263.872" x2="2332.17" y2="286.628" style="stroke:#3da44d; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip220)" x1="2332.17" y1="263.872" x2="2354.92" y2="263.872" style="stroke:#3da44d; stroke-width:4.55111; stroke-opacity:1"/>
<path clip-path="url(#clip220)" d="M2391.58 246.592 L2396.25 246.592 L2396.25 281.152 L2391.58 281.152 L2391.58 246.592 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2420.4 259.208 Q2419.68 258.791 2418.82 258.606 Q2417.99 258.398 2416.97 258.398 Q2413.36 258.398 2411.42 260.759 Q2409.49 263.097 2409.49 267.495 L2409.49 281.152 L2405.21 281.152 L2405.21 255.226 L2409.49 255.226 L2409.49 259.254 Q2410.84 256.893 2412.99 255.759 Q2415.14 254.601 2418.22 254.601 Q2418.66 254.601 2419.19 254.671 Q2419.73 254.717 2420.37 254.833 L2420.4 259.208 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2439.05 259.208 Q2438.34 258.791 2437.48 258.606 Q2436.65 258.398 2435.63 258.398 Q2432.02 258.398 2430.07 260.759 Q2428.15 263.097 2428.15 267.495 L2428.15 281.152 L2423.87 281.152 L2423.87 255.226 L2428.15 255.226 L2428.15 259.254 Q2429.49 256.893 2431.65 255.759 Q2433.8 254.601 2436.88 254.601 Q2437.32 254.601 2437.85 254.671 Q2438.38 254.717 2439.03 254.833 L2439.05 259.208 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2464.66 267.124 L2464.66 269.208 L2445.07 269.208 Q2445.35 273.606 2447.71 275.921 Q2450.1 278.212 2454.33 278.212 Q2456.79 278.212 2459.08 277.61 Q2461.39 277.009 2463.66 275.805 L2463.66 279.833 Q2461.37 280.805 2458.96 281.314 Q2456.55 281.823 2454.08 281.823 Q2447.87 281.823 2444.24 278.212 Q2440.63 274.601 2440.63 268.444 Q2440.63 262.078 2444.05 258.351 Q2447.5 254.601 2453.34 254.601 Q2458.57 254.601 2461.6 257.981 Q2464.66 261.337 2464.66 267.124 M2460.4 265.874 Q2460.35 262.379 2458.43 260.296 Q2456.53 258.212 2453.38 258.212 Q2449.82 258.212 2447.66 260.226 Q2445.54 262.24 2445.21 265.898 L2460.4 265.874 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2475.77 277.263 L2475.77 291.013 L2471.48 291.013 L2471.48 255.226 L2475.77 255.226 L2475.77 259.162 Q2477.11 256.847 2479.15 255.736 Q2481.21 254.601 2484.05 254.601 Q2488.78 254.601 2491.72 258.351 Q2494.68 262.101 2494.68 268.212 Q2494.68 274.323 2491.72 278.073 Q2488.78 281.823 2484.05 281.823 Q2481.21 281.823 2479.15 280.712 Q2477.11 279.578 2475.77 277.263 M2490.26 268.212 Q2490.26 263.513 2488.31 260.851 Q2486.39 258.166 2483.01 258.166 Q2479.63 258.166 2477.69 260.851 Q2475.77 263.513 2475.77 268.212 Q2475.77 272.911 2477.69 275.597 Q2479.63 278.259 2483.01 278.259 Q2486.39 278.259 2488.31 275.597 Q2490.26 272.911 2490.26 268.212 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2501.35 245.134 L2511.16 245.134 L2511.16 248.444 L2505.6 248.444 L2505.6 284.092 L2511.16 284.092 L2511.16 287.402 L2501.35 287.402 L2501.35 245.134 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2541.14 247.726 L2541.14 252.287 Q2538.47 251.013 2536.11 250.388 Q2533.75 249.763 2531.55 249.763 Q2527.73 249.763 2525.65 251.245 Q2523.59 252.726 2523.59 255.458 Q2523.59 257.749 2524.96 258.93 Q2526.35 260.087 2530.19 260.805 L2533.01 261.384 Q2538.24 262.379 2540.72 264.902 Q2543.22 267.402 2543.22 271.615 Q2543.22 276.638 2539.84 279.231 Q2536.48 281.823 2529.98 281.823 Q2527.53 281.823 2524.75 281.268 Q2521.99 280.712 2519.03 279.624 L2519.03 274.81 Q2521.88 276.407 2524.61 277.217 Q2527.34 278.027 2529.98 278.027 Q2533.98 278.027 2536.16 276.453 Q2538.34 274.879 2538.34 271.962 Q2538.34 269.416 2536.76 267.981 Q2535.21 266.546 2531.65 265.828 L2528.8 265.273 Q2523.57 264.231 2521.23 262.009 Q2518.89 259.786 2518.89 255.828 Q2518.89 251.245 2522.11 248.606 Q2525.35 245.967 2531.02 245.967 Q2533.45 245.967 2535.97 246.407 Q2538.5 246.847 2541.14 247.726 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2549.98 246.592 L2554.68 246.592 L2554.68 267.587 Q2554.68 273.143 2556.69 275.597 Q2558.71 278.027 2563.22 278.027 Q2567.71 278.027 2569.72 275.597 Q2571.74 273.143 2571.74 267.587 L2571.74 246.592 L2576.44 246.592 L2576.44 268.166 Q2576.44 274.925 2573.08 278.374 Q2569.75 281.823 2563.22 281.823 Q2556.67 281.823 2553.31 278.374 Q2549.98 274.925 2549.98 268.166 L2549.98 246.592 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2586.76 278.513 L2596.58 278.513 L2596.58 281.152 L2582.73 281.152 L2582.73 278.606 Q2583.52 277.888 2584.98 276.592 Q2592.94 269.532 2592.94 267.356 Q2592.94 265.828 2591.74 264.902 Q2590.53 263.953 2588.57 263.953 Q2587.36 263.953 2585.95 264.37 Q2584.54 264.763 2582.87 265.574 L2582.87 262.726 Q2584.65 262.078 2586.18 261.754 Q2587.73 261.43 2589.05 261.43 Q2592.41 261.43 2594.42 262.958 Q2596.44 264.486 2596.44 266.986 Q2596.44 270.203 2588.78 276.777 Q2587.48 277.888 2586.76 278.513 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2613.98 245.134 L2613.98 287.402 L2604.17 287.402 L2604.17 284.092 L2609.7 284.092 L2609.7 248.444 L2604.17 248.444 L2604.17 245.134 L2613.98 245.134 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2632.76 245.18 Q2629.65 250.504 2628.15 255.712 Q2626.65 260.921 2626.65 266.268 Q2626.65 271.615 2628.15 276.87 Q2629.68 282.101 2632.76 287.402 L2629.05 287.402 Q2625.58 281.962 2623.84 276.708 Q2622.13 271.453 2622.13 266.268 Q2622.13 261.106 2623.84 255.874 Q2625.56 250.643 2629.05 245.18 L2632.76 245.18 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2645.65 277.217 L2661.97 277.217 L2661.97 281.152 L2640.02 281.152 L2640.02 277.217 Q2642.69 274.462 2647.27 269.833 Q2651.88 265.18 2653.06 263.837 Q2655.3 261.314 2656.18 259.578 Q2657.09 257.819 2657.09 256.129 Q2657.09 253.374 2655.14 251.638 Q2653.22 249.902 2650.12 249.902 Q2647.92 249.902 2645.46 250.666 Q2643.03 251.43 2640.26 252.981 L2640.26 248.259 Q2643.08 247.125 2645.53 246.546 Q2647.99 245.967 2650.02 245.967 Q2655.4 245.967 2658.59 248.652 Q2661.78 251.337 2661.78 255.828 Q2661.78 257.958 2660.97 259.879 Q2660.19 261.777 2658.08 264.37 Q2657.5 265.041 2654.4 268.259 Q2651.3 271.453 2645.65 277.217 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip220)" d="M2670.51 245.18 L2674.21 245.18 Q2677.69 250.643 2679.4 255.874 Q2681.14 261.106 2681.14 266.268 Q2681.14 271.453 2679.4 276.708 Q2677.69 281.962 2674.21 287.402 L2670.51 287.402 Q2673.59 282.101 2675.09 276.87 Q2676.62 271.615 2676.62 266.268 Q2676.62 260.921 2675.09 255.712 Q2673.59 250.504 2670.51 245.18 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /></svg>

```

````julia
entanglementp_plus = entanglementplot(ψ_plus; title="ψ_plus", legend=:outertop)
entanglementp_minus = entanglementplot(ψ_minus; title="ψ_minus", legend=:outertop)
plot(entanglementp_plus, entanglementp_minus; layout=(1, 2), size=(800, 400))
````

```@raw html
<?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="800" height="400" viewBox="0 0 3200 1600">
<defs>
  <clipPath id="clip250">
    <rect x="0" y="0" width="3200" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip250)" d="M0 1600 L3200 1600 L3200 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip251">
    <rect x="640" y="0" width="2241" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip250)" d="M196.574 1332.61 L1552.3 1332.61 L1552.3 408.361 L196.574 408.361  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip252">
    <rect x="196" y="408" width="1357" height="925"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip252)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="234.944,1332.61 234.944,408.361 "/>
<polyline clip-path="url(#clip252)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="661.271,1332.61 661.271,408.361 "/>
<polyline clip-path="url(#clip252)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1087.6,1332.61 1087.6,408.361 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="196.574,1332.61 1552.3,1332.61 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.944,1332.61 234.944,1346.87 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="661.271,1332.61 661.271,1346.87 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1087.6,1332.61 1087.6,1346.87 "/>
<path clip-path="url(#clip250)" d="M17.9761 1581.86 L21.2825 1578.56 L45.7201 1603 L42.4137 1606.3 L17.9761 1581.86 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M47.2751 1570.41 Q46.473 1570.62 45.7365 1571.09 Q44.9999 1571.54 44.2797 1572.26 Q41.7263 1574.81 42.0209 1577.85 Q42.3155 1580.87 45.4255 1583.98 L55.0827 1593.63 L52.0545 1596.66 L33.7222 1578.33 L36.7504 1575.3 L39.5984 1578.15 Q38.8782 1575.53 39.5984 1573.21 Q40.3022 1570.87 42.4792 1568.69 Q42.7902 1568.38 43.2158 1568.05 Q43.625 1567.71 44.1651 1567.33 L47.2751 1570.41 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M60.4678 1557.21 Q59.6657 1557.43 58.9292 1557.9 Q58.1926 1558.34 57.4724 1559.06 Q54.919 1561.62 55.2136 1564.66 Q55.5082 1567.67 58.6182 1570.78 L68.2754 1580.44 L65.2473 1583.47 L46.915 1565.14 L49.9431 1562.11 L52.7911 1564.96 Q52.0709 1562.34 52.7911 1560.01 Q53.4949 1557.67 55.6719 1555.5 Q55.9829 1555.18 56.4085 1554.86 Q56.8177 1554.51 57.3578 1554.14 L60.4678 1557.21 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M84.1688 1544.71 L85.6419 1546.18 L71.7945 1560.03 Q75.1009 1562.94 78.4072 1562.91 Q81.7136 1562.84 84.709 1559.85 Q86.444 1558.11 87.6389 1556.07 Q88.8501 1554.01 89.603 1551.55 L92.4511 1554.4 Q91.5181 1556.71 90.1759 1558.77 Q88.8337 1560.83 87.0823 1562.58 Q82.6957 1566.97 77.5725 1566.99 Q72.4656 1566.99 68.1117 1562.63 Q63.6104 1558.13 63.3977 1553.07 Q63.1849 1547.98 67.3096 1543.86 Q71.0088 1540.16 75.5428 1540.4 Q80.0768 1540.62 84.1688 1544.71 M80.2732 1546.84 Q77.7689 1544.4 74.9372 1544.28 Q72.1219 1544.15 69.8958 1546.38 Q67.3751 1548.9 67.2769 1551.85 Q67.1951 1554.78 69.5521 1557.59 L80.2732 1546.84 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M99.1947 1544.02 L108.917 1553.74 L105.889 1556.77 L80.5842 1531.47 L83.6123 1528.44 L86.3949 1531.22 Q85.7074 1528.64 86.3621 1526.41 Q87.0169 1524.15 89.0301 1522.14 Q92.3692 1518.8 97.0996 1519.37 Q101.846 1519.93 106.168 1524.25 Q110.489 1528.57 111.045 1533.32 Q111.618 1538.05 108.279 1541.39 Q106.266 1543.4 104.023 1544.07 Q101.781 1544.71 99.1947 1544.02 M103.041 1527.38 Q99.7185 1524.05 96.4613 1523.55 Q93.204 1523 90.8143 1525.39 Q88.4245 1527.78 88.9483 1531.06 Q89.4721 1534.3 92.7948 1537.62 Q96.1175 1540.94 99.3748 1541.48 Q102.632 1541.99 105.022 1539.6 Q107.412 1537.21 106.888 1533.97 Q106.364 1530.7 103.041 1527.38 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M94.5626 1503.22 L101.503 1496.28 L103.843 1498.62 L99.9149 1502.54 L125.122 1527.75 L129.05 1523.82 L131.391 1526.16 L124.451 1533.1 L94.5626 1503.22 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M124.533 1476.91 L127.757 1480.14 Q124.975 1481.12 122.863 1482.35 Q120.752 1483.57 119.197 1485.13 Q116.496 1487.83 116.07 1490.35 Q115.661 1492.85 117.593 1494.79 Q119.213 1496.41 121.013 1496.28 Q122.814 1496.11 126.038 1493.9 L128.445 1492.31 Q132.848 1489.32 136.383 1489.35 Q139.919 1489.35 142.898 1492.33 Q146.45 1495.88 145.893 1500.11 Q145.353 1504.31 140.753 1508.91 Q139.018 1510.65 136.661 1512.22 Q134.321 1513.77 131.456 1515.1 L128.052 1511.69 Q131.194 1510.81 133.699 1509.45 Q136.203 1508.09 138.069 1506.23 Q140.901 1503.4 141.326 1500.74 Q141.752 1498.09 139.689 1496.03 Q137.889 1494.23 135.761 1494.33 Q133.65 1494.41 130.622 1496.42 L128.215 1498.04 Q123.78 1501.01 120.555 1501.09 Q117.331 1501.17 114.532 1498.37 Q111.291 1495.13 111.7 1490.99 Q112.126 1486.83 116.136 1482.82 Q117.854 1481.1 119.95 1479.63 Q122.045 1478.16 124.533 1476.91 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M129.983 1469.86 L133.306 1466.53 L148.152 1481.38 Q152.08 1485.31 155.239 1485.62 Q158.382 1485.91 161.574 1482.72 Q164.749 1479.55 164.454 1476.4 Q164.143 1473.25 160.215 1469.32 L145.369 1454.47 L148.692 1451.15 L163.947 1466.4 Q168.727 1471.18 168.792 1476 Q168.874 1480.79 164.258 1485.41 Q159.626 1490.04 154.814 1489.97 Q150.018 1489.89 145.238 1485.11 L129.983 1469.86 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M178.564 1466.42 L185.504 1459.48 L187.37 1461.35 L177.582 1471.13 L175.781 1469.33 Q175.83 1468.27 175.945 1466.32 Q176.583 1455.7 175.045 1454.16 Q173.964 1453.08 172.458 1453.28 Q170.936 1453.46 169.545 1454.85 Q168.694 1455.7 167.99 1456.99 Q167.27 1458.27 166.664 1460.02 L164.651 1458.01 Q165.453 1456.29 166.304 1454.98 Q167.172 1453.65 168.105 1452.72 Q170.478 1450.35 172.982 1450 Q175.487 1449.66 177.254 1451.43 Q179.53 1453.7 178.76 1463.77 Q178.629 1465.47 178.564 1466.42 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M174.21 1423.57 L204.098 1453.46 L197.158 1460.4 L194.817 1458.06 L198.729 1454.14 L173.522 1428.94 L169.61 1432.85 L167.27 1430.51 L174.21 1423.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M187.517 1410.33 Q189.088 1416.28 191.707 1421.03 Q194.326 1425.78 198.107 1429.56 Q201.888 1433.34 206.668 1435.99 Q211.447 1438.61 217.373 1440.18 L214.754 1442.8 Q208.452 1441.41 203.509 1438.92 Q198.582 1436.42 194.916 1432.75 Q191.265 1429.1 188.777 1424.19 Q186.29 1419.28 184.898 1412.95 L187.517 1410.33 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M204.033 1400.16 Q201.479 1402.72 202.707 1406.53 Q203.934 1410.31 208.976 1415.35 Q214.001 1420.38 217.798 1421.62 Q221.596 1422.83 224.149 1420.28 Q226.719 1417.71 225.491 1413.93 Q224.264 1410.11 219.239 1405.09 Q214.197 1400.05 210.4 1398.84 Q206.602 1397.59 204.033 1400.16 M201.414 1397.54 Q205.522 1393.43 210.94 1394.53 Q216.358 1395.6 222.545 1401.78 Q228.716 1407.95 229.796 1413.39 Q230.876 1418.79 226.768 1422.9 Q222.66 1427.01 217.242 1425.94 Q211.824 1424.85 205.653 1418.67 Q199.466 1412.49 198.386 1407.09 Q197.305 1401.65 201.414 1397.54 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M214.214 1383.63 L216.832 1381.01 Q223.151 1382.42 228.061 1384.91 Q232.988 1387.38 236.638 1391.03 Q240.304 1394.7 242.792 1399.64 Q245.297 1404.57 246.688 1410.87 L244.069 1413.49 Q242.498 1407.56 239.862 1402.8 Q237.227 1398 233.446 1394.22 Q229.665 1390.44 224.902 1387.84 Q220.155 1385.22 214.214 1383.63 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M444.303 1581.86 L447.61 1578.56 L472.047 1603 L468.741 1606.3 L444.303 1581.86 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M473.602 1570.41 Q472.8 1570.62 472.064 1571.09 Q471.327 1571.54 470.607 1572.26 Q468.054 1574.81 468.348 1577.85 Q468.643 1580.87 471.753 1583.98 L481.41 1593.63 L478.382 1596.66 L460.05 1578.33 L463.078 1575.3 L465.926 1578.15 Q465.205 1575.53 465.926 1573.21 Q466.63 1570.87 468.806 1568.69 Q469.117 1568.38 469.543 1568.05 Q469.952 1567.71 470.492 1567.33 L473.602 1570.41 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M486.795 1557.21 Q485.993 1557.43 485.256 1557.9 Q484.52 1558.34 483.8 1559.06 Q481.246 1561.62 481.541 1564.66 Q481.836 1567.67 484.945 1570.78 L494.603 1580.44 L491.575 1583.47 L473.242 1565.14 L476.27 1562.11 L479.118 1564.96 Q478.398 1562.34 479.118 1560.01 Q479.822 1557.67 481.999 1555.5 Q482.31 1555.18 482.736 1554.86 Q483.145 1554.51 483.685 1554.14 L486.795 1557.21 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M510.496 1544.71 L511.969 1546.18 L498.122 1560.03 Q501.428 1562.94 504.735 1562.91 Q508.041 1562.84 511.036 1559.85 Q512.771 1558.11 513.966 1556.07 Q515.177 1554.01 515.93 1551.55 L518.778 1554.4 Q517.845 1556.71 516.503 1558.77 Q515.161 1560.83 513.41 1562.58 Q509.023 1566.97 503.9 1566.99 Q498.793 1566.99 494.439 1562.63 Q489.938 1558.13 489.725 1553.07 Q489.512 1547.98 493.637 1543.86 Q497.336 1540.16 501.87 1540.4 Q506.404 1540.62 510.496 1544.71 M506.6 1546.84 Q504.096 1544.4 501.264 1544.28 Q498.449 1544.15 496.223 1546.38 Q493.702 1548.9 493.604 1551.85 Q493.522 1554.78 495.879 1557.59 L506.6 1546.84 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M525.522 1544.02 L535.245 1553.74 L532.217 1556.77 L506.911 1531.47 L509.94 1528.44 L512.722 1531.22 Q512.035 1528.64 512.689 1526.41 Q513.344 1524.15 515.357 1522.14 Q518.697 1518.8 523.427 1519.37 Q528.174 1519.93 532.495 1524.25 Q536.816 1528.57 537.373 1533.32 Q537.945 1538.05 534.606 1541.39 Q532.593 1543.4 530.351 1544.07 Q528.108 1544.71 525.522 1544.02 M529.369 1527.38 Q526.046 1524.05 522.789 1523.55 Q519.531 1523 517.142 1525.39 Q514.752 1527.78 515.276 1531.06 Q515.799 1534.3 519.122 1537.62 Q522.445 1540.94 525.702 1541.48 Q528.959 1541.99 531.349 1539.6 Q533.739 1537.21 533.215 1533.97 Q532.691 1530.7 529.369 1527.38 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M520.89 1503.22 L527.83 1496.28 L530.171 1498.62 L526.242 1502.54 L551.449 1527.75 L555.377 1523.82 L557.718 1526.16 L550.778 1533.1 L520.89 1503.22 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M550.86 1476.91 L554.084 1480.14 Q551.302 1481.12 549.19 1482.35 Q547.079 1483.57 545.524 1485.13 Q542.823 1487.83 542.398 1490.35 Q541.988 1492.85 543.92 1494.79 Q545.54 1496.41 547.341 1496.28 Q549.141 1496.11 552.366 1493.9 L554.772 1492.31 Q559.175 1489.32 562.71 1489.35 Q566.246 1489.35 569.225 1492.33 Q572.777 1495.88 572.22 1500.11 Q571.68 1504.31 567.081 1508.91 Q565.346 1510.65 562.989 1512.22 Q560.648 1513.77 557.784 1515.1 L554.379 1511.69 Q557.522 1510.81 560.026 1509.45 Q562.53 1508.09 564.396 1506.23 Q567.228 1503.4 567.654 1500.74 Q568.079 1498.09 566.017 1496.03 Q564.216 1494.23 562.088 1494.33 Q559.977 1494.41 556.949 1496.42 L554.543 1498.04 Q550.107 1501.01 546.882 1501.09 Q543.658 1501.17 540.859 1498.37 Q537.618 1495.13 538.027 1490.99 Q538.453 1486.83 542.463 1482.82 Q544.182 1481.1 546.277 1479.63 Q548.372 1478.16 550.86 1476.91 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M556.31 1469.86 L559.633 1466.53 L574.479 1481.38 Q578.407 1485.31 581.566 1485.62 Q584.709 1485.91 587.901 1482.72 Q591.076 1479.55 590.782 1476.4 Q590.471 1473.25 586.542 1469.32 L571.697 1454.47 L575.019 1451.15 L590.274 1466.4 Q595.054 1471.18 595.119 1476 Q595.201 1480.79 590.585 1485.41 Q585.953 1490.04 581.141 1489.97 Q576.345 1489.89 571.566 1485.11 L556.31 1469.86 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M604.891 1466.42 L611.831 1459.48 L613.697 1461.35 L603.909 1471.13 L602.108 1469.33 Q602.158 1468.27 602.272 1466.32 Q602.911 1455.7 601.372 1454.16 Q600.292 1453.08 598.786 1453.28 Q597.264 1453.46 595.872 1454.85 Q595.021 1455.7 594.317 1456.99 Q593.597 1458.27 592.991 1460.02 L590.978 1458.01 Q591.78 1456.29 592.631 1454.98 Q593.499 1453.65 594.432 1452.72 Q596.805 1450.35 599.31 1450 Q601.814 1449.66 603.582 1451.43 Q605.857 1453.7 605.087 1463.77 Q604.957 1465.47 604.891 1466.42 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M600.537 1423.57 L630.425 1453.46 L623.485 1460.4 L621.145 1458.06 L625.057 1454.14 L599.85 1428.94 L595.938 1432.85 L593.597 1430.51 L600.537 1423.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M613.844 1410.33 Q615.416 1416.28 618.035 1421.03 Q620.654 1425.78 624.435 1429.56 Q628.216 1433.34 632.995 1435.99 Q637.775 1438.61 643.7 1440.18 L641.081 1442.8 Q634.779 1441.41 629.836 1438.92 Q624.909 1436.42 621.243 1432.75 Q617.593 1429.1 615.105 1424.19 Q612.617 1419.28 611.226 1412.95 L613.844 1410.33 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M643.34 1426.14 L648.741 1420.74 L630.098 1402.09 L625.4 1409.15 L622.389 1406.14 L627.054 1399.11 L630.36 1395.81 L652.015 1417.46 L657.416 1412.06 L660.199 1414.84 L646.122 1428.92 L643.34 1426.14 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M640.541 1383.63 L643.16 1381.01 Q649.478 1382.42 654.388 1384.91 Q659.315 1387.38 662.965 1391.03 Q666.632 1394.7 669.12 1399.64 Q671.624 1404.57 673.015 1410.87 L670.396 1413.49 Q668.825 1407.56 666.19 1402.8 Q663.554 1398 659.773 1394.22 Q655.992 1390.44 651.229 1387.84 Q646.482 1385.22 640.541 1383.63 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M870.631 1581.86 L873.937 1578.56 L898.375 1603 L895.068 1606.3 L870.631 1581.86 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M899.93 1570.41 Q899.128 1570.62 898.391 1571.09 Q897.654 1571.54 896.934 1572.26 Q894.381 1574.81 894.675 1577.85 Q894.97 1580.87 898.08 1583.98 L907.737 1593.63 L904.709 1596.66 L886.377 1578.33 L889.405 1575.3 L892.253 1578.15 Q891.533 1575.53 892.253 1573.21 Q892.957 1570.87 895.134 1568.69 Q895.445 1568.38 895.87 1568.05 Q896.28 1567.71 896.82 1567.33 L899.93 1570.41 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M913.122 1557.21 Q912.32 1557.43 911.584 1557.9 Q910.847 1558.34 910.127 1559.06 Q907.574 1561.62 907.868 1564.66 Q908.163 1567.67 911.273 1570.78 L920.93 1580.44 L917.902 1583.47 L899.57 1565.14 L902.598 1562.11 L905.446 1564.96 Q904.725 1562.34 905.446 1560.01 Q906.15 1557.67 908.326 1555.5 Q908.637 1555.18 909.063 1554.86 Q909.472 1554.51 910.012 1554.14 L913.122 1557.21 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M936.823 1544.71 L938.297 1546.18 L924.449 1560.03 Q927.755 1562.94 931.062 1562.91 Q934.368 1562.84 937.364 1559.85 Q939.099 1558.11 940.293 1556.07 Q941.505 1554.01 942.258 1551.55 L945.106 1554.4 Q944.173 1556.71 942.83 1558.77 Q941.488 1560.83 939.737 1562.58 Q935.35 1566.97 930.227 1566.99 Q925.12 1566.99 920.766 1562.63 Q916.265 1558.13 916.052 1553.07 Q915.839 1547.98 919.964 1543.86 Q923.663 1540.16 928.197 1540.4 Q932.731 1540.62 936.823 1544.71 M932.928 1546.84 Q930.423 1544.4 927.592 1544.28 Q924.776 1544.15 922.55 1546.38 Q920.03 1548.9 919.931 1551.85 Q919.85 1554.78 922.207 1557.59 L932.928 1546.84 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M951.849 1544.02 L961.572 1553.74 L958.544 1556.77 L933.239 1531.47 L936.267 1528.44 L939.049 1531.22 Q938.362 1528.64 939.017 1526.41 Q939.671 1524.15 941.685 1522.14 Q945.024 1518.8 949.754 1519.37 Q954.501 1519.93 958.822 1524.25 Q963.143 1528.57 963.7 1533.32 Q964.273 1538.05 960.934 1541.39 Q958.92 1543.4 956.678 1544.07 Q954.435 1544.71 951.849 1544.02 M955.696 1527.38 Q952.373 1524.05 949.116 1523.55 Q945.859 1523 943.469 1525.39 Q941.079 1527.78 941.603 1531.06 Q942.127 1534.3 945.449 1537.62 Q948.772 1540.94 952.029 1541.48 Q955.287 1541.99 957.676 1539.6 Q960.066 1537.21 959.542 1533.97 Q959.019 1530.7 955.696 1527.38 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M947.217 1503.22 L954.157 1496.28 L956.498 1498.62 L952.57 1502.54 L977.776 1527.75 L981.705 1523.82 L984.045 1526.16 L977.105 1533.1 L947.217 1503.22 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M977.187 1476.91 L980.412 1480.14 Q977.629 1481.12 975.518 1482.35 Q973.406 1483.57 971.851 1485.13 Q969.15 1487.83 968.725 1490.35 Q968.316 1492.85 970.247 1494.79 Q971.868 1496.41 973.668 1496.28 Q975.469 1496.11 978.693 1493.9 L981.099 1492.31 Q985.502 1489.32 989.038 1489.35 Q992.573 1489.35 995.552 1492.33 Q999.104 1495.88 998.548 1500.11 Q998.007 1504.31 993.408 1508.91 Q991.673 1510.65 989.316 1512.22 Q986.975 1513.77 984.111 1515.1 L980.706 1511.69 Q983.849 1510.81 986.353 1509.45 Q988.858 1508.09 990.724 1506.23 Q993.555 1503.4 993.981 1500.74 Q994.406 1498.09 992.344 1496.03 Q990.544 1494.23 988.416 1494.33 Q986.304 1494.41 983.276 1496.42 L980.87 1498.04 Q976.434 1501.01 973.21 1501.09 Q969.985 1501.17 967.186 1498.37 Q963.945 1495.13 964.355 1490.99 Q964.78 1486.83 968.79 1482.82 Q970.509 1481.1 972.604 1479.63 Q974.699 1478.16 977.187 1476.91 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M982.638 1469.86 L985.96 1466.53 L1000.81 1481.38 Q1004.73 1485.31 1007.89 1485.62 Q1011.04 1485.91 1014.23 1482.72 Q1017.4 1479.55 1017.11 1476.4 Q1016.8 1473.25 1012.87 1469.32 L998.024 1454.47 L1001.35 1451.15 L1016.6 1466.4 Q1021.38 1471.18 1021.45 1476 Q1021.53 1480.79 1016.91 1485.41 Q1012.28 1490.04 1007.47 1489.97 Q1002.67 1489.89 997.893 1485.11 L982.638 1469.86 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1031.22 1466.42 L1038.16 1459.48 L1040.02 1461.35 L1030.24 1471.13 L1028.44 1469.33 Q1028.48 1468.27 1028.6 1466.32 Q1029.24 1455.7 1027.7 1454.16 Q1026.62 1453.08 1025.11 1453.28 Q1023.59 1453.46 1022.2 1454.85 Q1021.35 1455.7 1020.64 1456.99 Q1019.92 1458.27 1019.32 1460.02 L1017.31 1458.01 Q1018.11 1456.29 1018.96 1454.98 Q1019.83 1453.65 1020.76 1452.72 Q1023.13 1450.35 1025.64 1450 Q1028.14 1449.66 1029.91 1451.43 Q1032.18 1453.7 1031.41 1463.77 Q1031.28 1465.47 1031.22 1466.42 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1026.86 1423.57 L1056.75 1453.46 L1049.81 1460.4 L1047.47 1458.06 L1051.38 1454.14 L1026.18 1428.94 L1022.26 1432.85 L1019.92 1430.51 L1026.86 1423.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1040.17 1410.33 Q1041.74 1416.28 1044.36 1421.03 Q1046.98 1425.78 1050.76 1429.56 Q1054.54 1433.34 1059.32 1435.99 Q1064.1 1438.61 1070.03 1440.18 L1067.41 1442.8 Q1061.11 1441.41 1056.16 1438.92 Q1051.24 1436.42 1047.57 1432.75 Q1043.92 1429.1 1041.43 1424.19 Q1038.94 1419.28 1037.55 1412.95 L1040.17 1410.33 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1071.94 1423.86 L1083.48 1412.32 L1086.26 1415.11 L1070.75 1430.62 L1067.96 1427.84 Q1067.9 1424.01 1067.87 1417.5 Q1067.83 1410.95 1067.72 1409.16 Q1067.52 1405.79 1066.92 1403.94 Q1066.31 1402.06 1065.12 1400.87 Q1063.17 1398.92 1060.57 1399.07 Q1057.98 1399.2 1055.79 1401.39 Q1054.23 1402.94 1053.04 1405.22 Q1051.86 1407.48 1050.99 1410.54 L1047.65 1407.2 Q1048.85 1404.4 1050.17 1402.26 Q1051.5 1400.11 1052.94 1398.67 Q1056.74 1394.88 1060.89 1394.52 Q1065.05 1394.15 1068.23 1397.33 Q1069.73 1398.84 1070.52 1400.77 Q1071.3 1402.67 1071.65 1405.99 Q1071.71 1406.87 1071.79 1411.34 Q1071.86 1415.79 1071.94 1423.86 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1066.87 1383.63 L1069.49 1381.01 Q1075.81 1382.42 1080.72 1384.91 Q1085.64 1387.38 1089.29 1391.03 Q1092.96 1394.7 1095.45 1399.64 Q1097.95 1404.57 1099.34 1410.87 L1096.72 1413.49 Q1095.15 1407.56 1092.52 1402.8 Q1089.88 1398 1086.1 1394.22 Q1082.32 1390.44 1077.56 1387.84 Q1072.81 1385.22 1066.87 1383.63 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M791.315 1686.99 L786.572 1674.8 L776.801 1692.63 L769.894 1692.63 L783.707 1667.42 L777.915 1652.43 Q776.355 1648.42 771.454 1648.42 L769.894 1648.42 L769.894 1643.39 L772.122 1643.45 Q780.334 1643.67 782.403 1648.99 L787.113 1661.18 L796.885 1643.36 L803.791 1643.36 L789.978 1668.56 L795.771 1683.56 Q797.33 1687.57 802.232 1687.57 L803.791 1687.57 L803.791 1692.59 L801.563 1692.53 Q793.352 1692.31 791.315 1686.99 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M833.296 1649.44 L874.101 1649.44 L874.101 1654.78 L833.296 1654.78 L833.296 1649.44 M833.296 1662.42 L874.101 1662.42 L874.101 1667.83 L833.296 1667.83 L833.296 1662.42 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M928.177 1653.41 Q932.792 1654.4 935.37 1657.52 Q937.98 1660.64 937.98 1665.22 Q937.98 1672.26 933.142 1676.11 Q928.305 1679.96 919.393 1679.96 Q916.401 1679.96 913.218 1679.35 Q910.067 1678.78 906.693 1677.6 L906.693 1671.4 Q909.367 1672.96 912.549 1673.75 Q915.732 1674.55 919.202 1674.55 Q925.249 1674.55 928.4 1672.16 Q931.583 1669.77 931.583 1665.22 Q931.583 1661.02 928.623 1658.67 Q925.695 1656.28 920.443 1656.28 L914.905 1656.28 L914.905 1650.99 L920.697 1650.99 Q925.44 1650.99 927.954 1649.12 Q930.469 1647.21 930.469 1643.64 Q930.469 1639.98 927.859 1638.04 Q925.281 1636.07 920.443 1636.07 Q917.801 1636.07 914.777 1636.64 Q911.754 1637.21 908.125 1638.42 L908.125 1632.69 Q911.786 1631.67 914.968 1631.17 Q918.183 1630.66 921.016 1630.66 Q928.336 1630.66 932.601 1634 Q936.866 1637.31 936.866 1642.97 Q936.866 1646.92 934.607 1649.66 Q932.347 1652.36 928.177 1653.41 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M950.234 1631.52 L975.474 1631.52 L975.474 1636.93 L956.123 1636.93 L956.123 1648.58 Q957.523 1648.1 958.924 1647.88 Q960.324 1647.62 961.724 1647.62 Q969.682 1647.62 974.329 1651.98 Q978.976 1656.34 978.976 1663.79 Q978.976 1671.46 974.201 1675.73 Q969.427 1679.96 960.738 1679.96 Q957.746 1679.96 954.627 1679.45 Q951.539 1678.94 948.229 1677.92 L948.229 1671.46 Q951.094 1673.02 954.149 1673.78 Q957.205 1674.55 960.61 1674.55 Q966.117 1674.55 969.331 1671.65 Q972.546 1668.76 972.546 1663.79 Q972.546 1658.82 969.331 1655.93 Q966.117 1653.03 960.61 1653.03 Q958.032 1653.03 955.454 1653.6 Q952.908 1654.18 950.234 1655.39 L950.234 1631.52 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip252)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="196.574,968.043 1552.3,968.043 "/>
<polyline clip-path="url(#clip252)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="196.574,441.78 1552.3,441.78 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="196.574,1332.61 196.574,408.361 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="196.574,968.043 215.472,968.043 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="196.574,441.78 215.472,441.78 "/>
<path clip-path="url(#clip250)" d="M47.6634 987.836 L55.3023 987.836 L55.3023 961.47 L46.9921 963.137 L46.9921 958.878 L55.256 957.211 L59.9319 957.211 L59.9319 987.836 L67.5707 987.836 L67.5707 991.771 L47.6634 991.771 L47.6634 987.836 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M87.0151 960.29 Q83.404 960.29 81.5753 963.855 Q79.7697 967.396 79.7697 974.526 Q79.7697 981.632 81.5753 985.197 Q83.404 988.739 87.0151 988.739 Q90.6493 988.739 92.4548 985.197 Q94.2835 981.632 94.2835 974.526 Q94.2835 967.396 92.4548 963.855 Q90.6493 960.29 87.0151 960.29 M87.0151 956.586 Q92.8252 956.586 95.8808 961.193 Q98.9594 965.776 98.9594 974.526 Q98.9594 983.253 95.8808 987.859 Q92.8252 992.442 87.0151 992.442 Q81.2049 992.442 78.1262 987.859 Q75.0707 983.253 75.0707 974.526 Q75.0707 965.776 78.1262 961.193 Q81.2049 956.586 87.0151 956.586 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M98.9594 950.687 L123.071 950.687 L123.071 953.885 L98.9594 953.885 L98.9594 950.687 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M142.782 949.22 Q145.509 949.803 147.032 951.647 Q148.574 953.49 148.574 956.198 Q148.574 960.355 145.716 962.63 Q142.857 964.906 137.591 964.906 Q135.823 964.906 133.942 964.549 Q132.08 964.21 130.086 963.514 L130.086 959.847 Q131.666 960.768 133.547 961.239 Q135.428 961.709 137.478 961.709 Q141.051 961.709 142.913 960.298 Q144.794 958.888 144.794 956.198 Q144.794 953.715 143.045 952.324 Q141.315 950.913 138.211 950.913 L134.939 950.913 L134.939 947.791 L138.362 947.791 Q141.164 947.791 142.65 946.681 Q144.136 945.553 144.136 943.446 Q144.136 941.284 142.593 940.136 Q141.07 938.97 138.211 938.97 Q136.65 938.97 134.863 939.309 Q133.077 939.647 130.933 940.362 L130.933 936.977 Q133.096 936.375 134.976 936.074 Q136.876 935.773 138.55 935.773 Q142.876 935.773 145.396 937.748 Q147.916 939.704 147.916 943.051 Q147.916 945.384 146.581 947.001 Q145.245 948.6 142.782 949.22 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M77.8687 461.572 L85.5075 461.572 L85.5075 435.206 L77.1974 436.873 L77.1974 432.614 L85.4612 430.947 L90.1371 430.947 L90.1371 461.572 L97.776 461.572 L97.776 465.507 L77.8687 465.507 L77.8687 461.572 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M117.22 434.026 Q113.609 434.026 111.781 437.591 Q109.975 441.132 109.975 448.262 Q109.975 455.368 111.781 458.933 Q113.609 462.475 117.22 462.475 Q120.855 462.475 122.66 458.933 Q124.489 455.368 124.489 448.262 Q124.489 441.132 122.66 437.591 Q120.855 434.026 117.22 434.026 M117.22 430.322 Q123.03 430.322 126.086 434.929 Q129.165 439.512 129.165 448.262 Q129.165 456.989 126.086 461.595 Q123.03 466.179 117.22 466.179 Q111.41 466.179 108.331 461.595 Q105.276 456.989 105.276 448.262 Q105.276 439.512 108.331 434.929 Q111.41 430.322 117.22 430.322 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M138.87 412.518 Q135.936 412.518 134.45 415.415 Q132.983 418.292 132.983 424.085 Q132.983 429.859 134.45 432.755 Q135.936 435.633 138.87 435.633 Q141.822 435.633 143.289 432.755 Q144.775 429.859 144.775 424.085 Q144.775 418.292 143.289 415.415 Q141.822 412.518 138.87 412.518 M138.87 409.509 Q143.59 409.509 146.073 413.252 Q148.574 416.976 148.574 424.085 Q148.574 431.176 146.073 434.918 Q143.59 438.642 138.87 438.642 Q134.149 438.642 131.647 434.918 Q129.165 431.176 129.165 424.085 Q129.165 416.976 131.647 413.252 Q134.149 409.509 138.87 409.509 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M763.865 73.5887 Q754.508 72.0899 750.173 68.1605 Q744.867 63.3399 744.867 53.4962 L744.867 27.2059 L752.401 27.2059 L752.401 53.2127 Q752.401 60.6258 755.845 63.7045 Q758.842 66.3781 763.865 66.9452 L763.865 27.2059 L771.278 27.2059 L771.278 66.9047 Q776.585 66.3376 779.299 63.664 Q782.743 60.2613 782.743 53.1722 L782.743 27.2059 L790.277 27.2059 L790.277 53.4557 Q790.277 63.664 784.971 68.12 Q780.19 72.1304 771.278 73.5482 L771.278 89.8329 L763.865 89.8329 L763.865 73.5887 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M837.349 86.3491 L837.349 92.1419 L794.247 92.1419 L794.247 86.3491 L837.349 86.3491 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M851.567 65.7705 L851.567 89.8329 L844.073 89.8329 L844.073 27.2059 L851.567 27.2059 L851.567 34.0924 Q853.917 30.0415 857.482 28.0971 Q861.087 26.1121 866.07 26.1121 Q874.333 26.1121 879.478 32.6746 Q884.663 39.2371 884.663 49.9314 Q884.663 60.6258 879.478 67.1883 Q874.333 73.7508 866.07 73.7508 Q861.087 73.7508 857.482 71.8063 Q853.917 69.8214 851.567 65.7705 M876.926 49.9314 Q876.926 41.7081 873.523 37.0496 Q870.161 32.3505 864.247 32.3505 Q858.332 32.3505 854.93 37.0496 Q851.567 41.7081 851.567 49.9314 Q851.567 58.1548 854.93 62.8538 Q858.332 67.5124 864.247 67.5124 Q870.161 67.5124 873.523 62.8538 Q876.926 58.1548 876.926 49.9314 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M897.019 9.54393 L904.472 9.54393 L904.472 72.576 L897.019 72.576 L897.019 9.54393 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M919.298 54.671 L919.298 27.2059 L926.752 27.2059 L926.752 54.3874 Q926.752 60.8284 929.264 64.0691 Q931.775 67.2693 936.798 67.2693 Q942.834 67.2693 946.318 63.421 Q949.842 59.5726 949.842 52.9291 L949.842 27.2059 L957.296 27.2059 L957.296 72.576 L949.842 72.576 L949.842 65.6084 Q947.128 69.7404 943.523 71.7658 Q939.958 73.7508 935.219 73.7508 Q927.4 73.7508 923.349 68.8897 Q919.298 64.0286 919.298 54.671 M938.054 26.1121 L938.054 26.1121 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1001.57 28.5427 L1001.57 35.5912 Q998.413 33.9709 995.01 33.1607 Q991.607 32.3505 987.961 32.3505 Q982.412 32.3505 979.616 34.0519 Q976.862 35.7533 976.862 39.156 Q976.862 41.7486 978.847 43.2475 Q980.832 44.7058 986.827 46.0426 L989.379 46.6097 Q997.319 48.3111 1000.64 51.4303 Q1004 54.509 1004 60.0587 Q1004 66.3781 998.98 70.0644 Q993.997 73.7508 985.247 73.7508 Q981.601 73.7508 977.632 73.0216 Q973.702 72.3329 969.327 70.9151 L969.327 63.2184 Q973.459 65.3654 977.469 66.4591 Q981.48 67.5124 985.409 67.5124 Q990.675 67.5124 993.511 65.73 Q996.347 63.9071 996.347 60.6258 Q996.347 57.5877 994.281 55.9673 Q992.255 54.3469 985.328 52.8481 L982.736 52.2405 Q975.809 50.7821 972.73 47.7845 Q969.651 44.7463 969.651 39.4801 Q969.651 33.0797 974.188 29.5959 Q978.725 26.1121 987.07 26.1121 Q991.202 26.1121 994.848 26.7198 Q998.494 27.3274 1001.57 28.5427 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><circle clip-path="url(#clip252)" cx="277.577" cy="495.707" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip252)" cx="362.842" cy="767.047" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip252)" cx="448.107" cy="1016.77" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip252)" cx="533.373" cy="1117.62" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip252)" cx="618.638" cy="1306.45" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip252)" cx="703.904" cy="495.756" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip252)" cx="789.169" cy="655.084" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip252)" cx="874.435" cy="773.147" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip252)" cx="959.7" cy="866.202" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip252)" cx="1044.97" cy="966.599" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip252)" cx="1130.23" cy="656.045" r="14.4" fill="#3da44d" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip252)" cx="1300.76" cy="882.628" r="14.4" fill="#3da44d" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip252)" cx="1471.29" cy="968.227" r="14.4" fill="#3da44d" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip250)" d="M661.869 367.552 L1087 367.552 L1087 108.352 L661.869 108.352  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="661.869,367.552 1087,367.552 1087,108.352 661.869,108.352 661.869,367.552 "/>
<circle clip-path="url(#clip250)" cx="722.124" cy="160.192" r="20.48" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="4.55111"/>
<path clip-path="url(#clip250)" d="M782.378 142.912 L787.054 142.912 L787.054 177.472 L782.378 177.472 L782.378 142.912 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M811.197 155.528 Q810.48 155.111 809.623 154.926 Q808.79 154.718 807.771 154.718 Q804.16 154.718 802.216 157.079 Q800.294 159.417 800.294 163.815 L800.294 177.472 L796.012 177.472 L796.012 151.546 L800.294 151.546 L800.294 155.574 Q801.637 153.213 803.79 152.079 Q805.943 150.921 809.021 150.921 Q809.461 150.921 809.993 150.991 Q810.526 151.037 811.174 151.153 L811.197 155.528 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M829.854 155.528 Q829.137 155.111 828.28 154.926 Q827.447 154.718 826.429 154.718 Q822.817 154.718 820.873 157.079 Q818.952 159.417 818.952 163.815 L818.952 177.472 L814.669 177.472 L814.669 151.546 L818.952 151.546 L818.952 155.574 Q820.294 153.213 822.447 152.079 Q824.6 150.921 827.679 150.921 Q828.118 150.921 828.651 150.991 Q829.183 151.037 829.831 151.153 L829.854 155.528 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M855.456 163.444 L855.456 165.528 L835.873 165.528 Q836.151 169.926 838.512 172.241 Q840.896 174.532 845.132 174.532 Q847.586 174.532 849.878 173.93 Q852.192 173.329 854.461 172.125 L854.461 176.153 Q852.169 177.125 849.762 177.634 Q847.354 178.143 844.878 178.143 Q838.674 178.143 835.04 174.532 Q831.429 170.921 831.429 164.764 Q831.429 158.398 834.854 154.671 Q838.304 150.921 844.137 150.921 Q849.368 150.921 852.401 154.301 Q855.456 157.657 855.456 163.444 M851.197 162.194 Q851.151 158.699 849.229 156.616 Q847.331 154.532 844.183 154.532 Q840.618 154.532 838.466 156.546 Q836.336 158.56 836.012 162.218 L851.197 162.194 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M866.567 173.583 L866.567 187.333 L862.285 187.333 L862.285 151.546 L866.567 151.546 L866.567 155.482 Q867.91 153.167 869.947 152.056 Q872.007 150.921 874.854 150.921 Q879.576 150.921 882.516 154.671 Q885.479 158.421 885.479 164.532 Q885.479 170.643 882.516 174.393 Q879.576 178.143 874.854 178.143 Q872.007 178.143 869.947 177.032 Q867.91 175.898 866.567 173.583 M881.058 164.532 Q881.058 159.833 879.113 157.171 Q877.192 154.486 873.813 154.486 Q870.433 154.486 868.489 157.171 Q866.567 159.833 866.567 164.532 Q866.567 169.231 868.489 171.917 Q870.433 174.579 873.813 174.579 Q877.192 174.579 879.113 171.917 Q881.058 169.231 881.058 164.532 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M892.146 141.454 L901.961 141.454 L901.961 144.764 L896.405 144.764 L896.405 180.412 L901.961 180.412 L901.961 183.722 L892.146 183.722 L892.146 141.454 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M931.937 144.046 L931.937 148.607 Q929.275 147.333 926.914 146.708 Q924.553 146.083 922.354 146.083 Q918.535 146.083 916.451 147.565 Q914.391 149.046 914.391 151.778 Q914.391 154.069 915.757 155.25 Q917.146 156.407 920.988 157.125 L923.812 157.704 Q929.044 158.699 931.521 161.222 Q934.021 163.722 934.021 167.935 Q934.021 172.958 930.641 175.551 Q927.285 178.143 920.78 178.143 Q918.326 178.143 915.548 177.588 Q912.794 177.032 909.831 175.944 L909.831 171.13 Q912.678 172.727 915.41 173.537 Q918.141 174.347 920.78 174.347 Q924.785 174.347 926.96 172.773 Q929.136 171.199 929.136 168.282 Q929.136 165.736 927.562 164.301 Q926.011 162.866 922.447 162.148 L919.599 161.593 Q914.368 160.551 912.03 158.329 Q909.692 156.106 909.692 152.148 Q909.692 147.565 912.91 144.926 Q916.15 142.287 921.822 142.287 Q924.252 142.287 926.775 142.727 Q929.298 143.167 931.937 144.046 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M940.78 142.912 L945.479 142.912 L945.479 163.907 Q945.479 169.463 947.493 171.917 Q949.507 174.347 954.02 174.347 Q958.511 174.347 960.525 171.917 Q962.539 169.463 962.539 163.907 L962.539 142.912 L967.238 142.912 L967.238 164.486 Q967.238 171.245 963.882 174.694 Q960.548 178.143 954.02 178.143 Q947.47 178.143 944.113 174.694 Q940.78 171.245 940.78 164.486 L940.78 142.912 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M977.562 174.833 L987.377 174.833 L987.377 177.472 L973.534 177.472 L973.534 174.926 Q974.321 174.208 975.78 172.912 Q983.743 165.852 983.743 163.676 Q983.743 162.148 982.539 161.222 Q981.335 160.273 979.368 160.273 Q978.164 160.273 976.752 160.69 Q975.34 161.083 973.673 161.894 L973.673 159.046 Q975.456 158.398 976.983 158.074 Q978.534 157.75 979.854 157.75 Q983.21 157.75 985.224 159.278 Q987.238 160.806 987.238 163.306 Q987.238 166.523 979.576 173.097 Q978.28 174.208 977.562 174.833 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1004.78 141.454 L1004.78 183.722 L994.969 183.722 L994.969 180.412 L1000.5 180.412 L1000.5 144.764 L994.969 144.764 L994.969 141.454 L1004.78 141.454 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1023.56 141.5 Q1020.46 146.824 1018.95 152.032 Q1017.45 157.241 1017.45 162.588 Q1017.45 167.935 1018.95 173.19 Q1020.48 178.421 1023.56 183.722 L1019.85 183.722 Q1016.38 178.282 1014.65 173.028 Q1012.93 167.773 1012.93 162.588 Q1012.93 157.426 1014.65 152.194 Q1016.36 146.963 1019.85 141.5 L1023.56 141.5 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1042.42 145.991 Q1038.81 145.991 1036.98 149.556 Q1035.18 153.097 1035.18 160.227 Q1035.18 167.333 1036.98 170.898 Q1038.81 174.44 1042.42 174.44 Q1046.06 174.44 1047.86 170.898 Q1049.69 167.333 1049.69 160.227 Q1049.69 153.097 1047.86 149.556 Q1046.06 145.991 1042.42 145.991 M1042.42 142.287 Q1048.23 142.287 1051.29 146.894 Q1054.37 151.477 1054.37 160.227 Q1054.37 168.954 1051.29 173.56 Q1048.23 178.143 1042.42 178.143 Q1036.61 178.143 1033.53 173.56 Q1030.48 168.954 1030.48 160.227 Q1030.48 151.477 1033.53 146.894 Q1036.61 142.287 1042.42 142.287 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1061.31 141.5 L1065.02 141.5 Q1068.49 146.963 1070.2 152.194 Q1071.94 157.426 1071.94 162.588 Q1071.94 167.773 1070.2 173.028 Q1068.49 178.282 1065.02 183.722 L1061.31 183.722 Q1064.39 178.421 1065.89 173.19 Q1067.42 167.935 1067.42 162.588 Q1067.42 157.241 1065.89 152.032 Q1064.39 146.824 1061.31 141.5 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><circle clip-path="url(#clip250)" cx="722.124" cy="212.032" r="20.48" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="4.55111"/>
<path clip-path="url(#clip250)" d="M782.378 194.752 L787.054 194.752 L787.054 229.312 L782.378 229.312 L782.378 194.752 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M811.197 207.368 Q810.48 206.951 809.623 206.766 Q808.79 206.558 807.771 206.558 Q804.16 206.558 802.216 208.919 Q800.294 211.257 800.294 215.655 L800.294 229.312 L796.012 229.312 L796.012 203.386 L800.294 203.386 L800.294 207.414 Q801.637 205.053 803.79 203.919 Q805.943 202.761 809.021 202.761 Q809.461 202.761 809.993 202.831 Q810.526 202.877 811.174 202.993 L811.197 207.368 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M829.854 207.368 Q829.137 206.951 828.28 206.766 Q827.447 206.558 826.429 206.558 Q822.817 206.558 820.873 208.919 Q818.952 211.257 818.952 215.655 L818.952 229.312 L814.669 229.312 L814.669 203.386 L818.952 203.386 L818.952 207.414 Q820.294 205.053 822.447 203.919 Q824.6 202.761 827.679 202.761 Q828.118 202.761 828.651 202.831 Q829.183 202.877 829.831 202.993 L829.854 207.368 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M855.456 215.284 L855.456 217.368 L835.873 217.368 Q836.151 221.766 838.512 224.081 Q840.896 226.372 845.132 226.372 Q847.586 226.372 849.878 225.77 Q852.192 225.169 854.461 223.965 L854.461 227.993 Q852.169 228.965 849.762 229.474 Q847.354 229.983 844.878 229.983 Q838.674 229.983 835.04 226.372 Q831.429 222.761 831.429 216.604 Q831.429 210.238 834.854 206.511 Q838.304 202.761 844.137 202.761 Q849.368 202.761 852.401 206.141 Q855.456 209.497 855.456 215.284 M851.197 214.034 Q851.151 210.539 849.229 208.456 Q847.331 206.372 844.183 206.372 Q840.618 206.372 838.466 208.386 Q836.336 210.4 836.012 214.058 L851.197 214.034 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M866.567 225.423 L866.567 239.173 L862.285 239.173 L862.285 203.386 L866.567 203.386 L866.567 207.322 Q867.91 205.007 869.947 203.896 Q872.007 202.761 874.854 202.761 Q879.576 202.761 882.516 206.511 Q885.479 210.261 885.479 216.372 Q885.479 222.483 882.516 226.233 Q879.576 229.983 874.854 229.983 Q872.007 229.983 869.947 228.872 Q867.91 227.738 866.567 225.423 M881.058 216.372 Q881.058 211.673 879.113 209.011 Q877.192 206.326 873.813 206.326 Q870.433 206.326 868.489 209.011 Q866.567 211.673 866.567 216.372 Q866.567 221.071 868.489 223.757 Q870.433 226.419 873.813 226.419 Q877.192 226.419 879.113 223.757 Q881.058 221.071 881.058 216.372 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M892.146 193.294 L901.961 193.294 L901.961 196.604 L896.405 196.604 L896.405 232.252 L901.961 232.252 L901.961 235.562 L892.146 235.562 L892.146 193.294 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M931.937 195.886 L931.937 200.447 Q929.275 199.173 926.914 198.548 Q924.553 197.923 922.354 197.923 Q918.535 197.923 916.451 199.405 Q914.391 200.886 914.391 203.618 Q914.391 205.909 915.757 207.09 Q917.146 208.247 920.988 208.965 L923.812 209.544 Q929.044 210.539 931.521 213.062 Q934.021 215.562 934.021 219.775 Q934.021 224.798 930.641 227.391 Q927.285 229.983 920.78 229.983 Q918.326 229.983 915.548 229.428 Q912.794 228.872 909.831 227.784 L909.831 222.97 Q912.678 224.567 915.41 225.377 Q918.141 226.187 920.78 226.187 Q924.785 226.187 926.96 224.613 Q929.136 223.039 929.136 220.122 Q929.136 217.576 927.562 216.141 Q926.011 214.706 922.447 213.988 L919.599 213.433 Q914.368 212.391 912.03 210.169 Q909.692 207.946 909.692 203.988 Q909.692 199.405 912.91 196.766 Q916.15 194.127 921.822 194.127 Q924.252 194.127 926.775 194.567 Q929.298 195.007 931.937 195.886 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M940.78 194.752 L945.479 194.752 L945.479 215.747 Q945.479 221.303 947.493 223.757 Q949.507 226.187 954.02 226.187 Q958.511 226.187 960.525 223.757 Q962.539 221.303 962.539 215.747 L962.539 194.752 L967.238 194.752 L967.238 216.326 Q967.238 223.085 963.882 226.534 Q960.548 229.983 954.02 229.983 Q947.47 229.983 944.113 226.534 Q940.78 223.085 940.78 216.326 L940.78 194.752 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M977.562 226.673 L987.377 226.673 L987.377 229.312 L973.534 229.312 L973.534 226.766 Q974.321 226.048 975.78 224.752 Q983.743 217.692 983.743 215.516 Q983.743 213.988 982.539 213.062 Q981.335 212.113 979.368 212.113 Q978.164 212.113 976.752 212.53 Q975.34 212.923 973.673 213.734 L973.673 210.886 Q975.456 210.238 976.983 209.914 Q978.534 209.59 979.854 209.59 Q983.21 209.59 985.224 211.118 Q987.238 212.646 987.238 215.146 Q987.238 218.363 979.576 224.937 Q978.28 226.048 977.562 226.673 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1004.78 193.294 L1004.78 235.562 L994.969 235.562 L994.969 232.252 L1000.5 232.252 L1000.5 196.604 L994.969 196.604 L994.969 193.294 L1004.78 193.294 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1023.56 193.34 Q1020.46 198.664 1018.95 203.872 Q1017.45 209.081 1017.45 214.428 Q1017.45 219.775 1018.95 225.03 Q1020.48 230.261 1023.56 235.562 L1019.85 235.562 Q1016.38 230.122 1014.65 224.868 Q1012.93 219.613 1012.93 214.428 Q1012.93 209.266 1014.65 204.034 Q1016.36 198.803 1019.85 193.34 L1023.56 193.34 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1033.23 225.377 L1040.87 225.377 L1040.87 199.011 L1032.56 200.678 L1032.56 196.419 L1040.83 194.752 L1045.5 194.752 L1045.5 225.377 L1053.14 225.377 L1053.14 229.312 L1033.23 229.312 L1033.23 225.377 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1061.31 193.34 L1065.02 193.34 Q1068.49 198.803 1070.2 204.034 Q1071.94 209.266 1071.94 214.428 Q1071.94 219.613 1070.2 224.868 Q1068.49 230.122 1065.02 235.562 L1061.31 235.562 Q1064.39 230.261 1065.89 225.03 Q1067.42 219.775 1067.42 214.428 Q1067.42 209.081 1065.89 203.872 Q1064.39 198.664 1061.31 193.34 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><circle clip-path="url(#clip250)" cx="722.124" cy="263.872" r="20.48" fill="#3da44d" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="4.55111"/>
<path clip-path="url(#clip250)" d="M782.378 246.592 L787.054 246.592 L787.054 281.152 L782.378 281.152 L782.378 246.592 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M811.197 259.208 Q810.48 258.791 809.623 258.606 Q808.79 258.398 807.771 258.398 Q804.16 258.398 802.216 260.759 Q800.294 263.097 800.294 267.495 L800.294 281.152 L796.012 281.152 L796.012 255.226 L800.294 255.226 L800.294 259.254 Q801.637 256.893 803.79 255.759 Q805.943 254.601 809.021 254.601 Q809.461 254.601 809.993 254.671 Q810.526 254.717 811.174 254.833 L811.197 259.208 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M829.854 259.208 Q829.137 258.791 828.28 258.606 Q827.447 258.398 826.429 258.398 Q822.817 258.398 820.873 260.759 Q818.952 263.097 818.952 267.495 L818.952 281.152 L814.669 281.152 L814.669 255.226 L818.952 255.226 L818.952 259.254 Q820.294 256.893 822.447 255.759 Q824.6 254.601 827.679 254.601 Q828.118 254.601 828.651 254.671 Q829.183 254.717 829.831 254.833 L829.854 259.208 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M855.456 267.124 L855.456 269.208 L835.873 269.208 Q836.151 273.606 838.512 275.921 Q840.896 278.212 845.132 278.212 Q847.586 278.212 849.878 277.61 Q852.192 277.009 854.461 275.805 L854.461 279.833 Q852.169 280.805 849.762 281.314 Q847.354 281.823 844.878 281.823 Q838.674 281.823 835.04 278.212 Q831.429 274.601 831.429 268.444 Q831.429 262.078 834.854 258.351 Q838.304 254.601 844.137 254.601 Q849.368 254.601 852.401 257.981 Q855.456 261.337 855.456 267.124 M851.197 265.874 Q851.151 262.379 849.229 260.296 Q847.331 258.212 844.183 258.212 Q840.618 258.212 838.466 260.226 Q836.336 262.24 836.012 265.898 L851.197 265.874 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M866.567 277.263 L866.567 291.013 L862.285 291.013 L862.285 255.226 L866.567 255.226 L866.567 259.162 Q867.91 256.847 869.947 255.736 Q872.007 254.601 874.854 254.601 Q879.576 254.601 882.516 258.351 Q885.479 262.101 885.479 268.212 Q885.479 274.323 882.516 278.073 Q879.576 281.823 874.854 281.823 Q872.007 281.823 869.947 280.712 Q867.91 279.578 866.567 277.263 M881.058 268.212 Q881.058 263.513 879.113 260.851 Q877.192 258.166 873.813 258.166 Q870.433 258.166 868.489 260.851 Q866.567 263.513 866.567 268.212 Q866.567 272.911 868.489 275.597 Q870.433 278.259 873.813 278.259 Q877.192 278.259 879.113 275.597 Q881.058 272.911 881.058 268.212 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M892.146 245.134 L901.961 245.134 L901.961 248.444 L896.405 248.444 L896.405 284.092 L901.961 284.092 L901.961 287.402 L892.146 287.402 L892.146 245.134 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M931.937 247.726 L931.937 252.287 Q929.275 251.013 926.914 250.388 Q924.553 249.763 922.354 249.763 Q918.535 249.763 916.451 251.245 Q914.391 252.726 914.391 255.458 Q914.391 257.749 915.757 258.93 Q917.146 260.087 920.988 260.805 L923.812 261.384 Q929.044 262.379 931.521 264.902 Q934.021 267.402 934.021 271.615 Q934.021 276.638 930.641 279.231 Q927.285 281.823 920.78 281.823 Q918.326 281.823 915.548 281.268 Q912.794 280.712 909.831 279.624 L909.831 274.81 Q912.678 276.407 915.41 277.217 Q918.141 278.027 920.78 278.027 Q924.785 278.027 926.96 276.453 Q929.136 274.879 929.136 271.962 Q929.136 269.416 927.562 267.981 Q926.011 266.546 922.447 265.828 L919.599 265.273 Q914.368 264.231 912.03 262.009 Q909.692 259.786 909.692 255.828 Q909.692 251.245 912.91 248.606 Q916.15 245.967 921.822 245.967 Q924.252 245.967 926.775 246.407 Q929.298 246.847 931.937 247.726 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M940.78 246.592 L945.479 246.592 L945.479 267.587 Q945.479 273.143 947.493 275.597 Q949.507 278.027 954.02 278.027 Q958.511 278.027 960.525 275.597 Q962.539 273.143 962.539 267.587 L962.539 246.592 L967.238 246.592 L967.238 268.166 Q967.238 274.925 963.882 278.374 Q960.548 281.823 954.02 281.823 Q947.47 281.823 944.113 278.374 Q940.78 274.925 940.78 268.166 L940.78 246.592 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M977.562 278.513 L987.377 278.513 L987.377 281.152 L973.534 281.152 L973.534 278.606 Q974.321 277.888 975.78 276.592 Q983.743 269.532 983.743 267.356 Q983.743 265.828 982.539 264.902 Q981.335 263.953 979.368 263.953 Q978.164 263.953 976.752 264.37 Q975.34 264.763 973.673 265.574 L973.673 262.726 Q975.456 262.078 976.983 261.754 Q978.534 261.43 979.854 261.43 Q983.21 261.43 985.224 262.958 Q987.238 264.486 987.238 266.986 Q987.238 270.203 979.576 276.777 Q978.28 277.888 977.562 278.513 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1004.78 245.134 L1004.78 287.402 L994.969 287.402 L994.969 284.092 L1000.5 284.092 L1000.5 248.444 L994.969 248.444 L994.969 245.134 L1004.78 245.134 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1023.56 245.18 Q1020.46 250.504 1018.95 255.712 Q1017.45 260.921 1017.45 266.268 Q1017.45 271.615 1018.95 276.87 Q1020.48 282.101 1023.56 287.402 L1019.85 287.402 Q1016.38 281.962 1014.65 276.708 Q1012.93 271.453 1012.93 266.268 Q1012.93 261.106 1014.65 255.874 Q1016.36 250.643 1019.85 245.18 L1023.56 245.18 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1036.45 277.217 L1052.77 277.217 L1052.77 281.152 L1030.83 281.152 L1030.83 277.217 Q1033.49 274.462 1038.07 269.833 Q1042.68 265.18 1043.86 263.837 Q1046.1 261.314 1046.98 259.578 Q1047.89 257.819 1047.89 256.129 Q1047.89 253.374 1045.94 251.638 Q1044.02 249.902 1040.92 249.902 Q1038.72 249.902 1036.27 250.666 Q1033.83 251.43 1031.06 252.981 L1031.06 248.259 Q1033.88 247.125 1036.33 246.546 Q1038.79 245.967 1040.83 245.967 Q1046.2 245.967 1049.39 248.652 Q1052.58 251.337 1052.58 255.828 Q1052.58 257.958 1051.77 259.879 Q1050.99 261.777 1048.88 264.37 Q1048.3 265.041 1045.2 268.259 Q1042.1 271.453 1036.45 277.217 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1061.31 245.18 L1065.02 245.18 Q1068.49 250.643 1070.2 255.874 Q1071.94 261.106 1071.94 266.268 Q1071.94 271.453 1070.2 276.708 Q1068.49 281.962 1065.02 287.402 L1061.31 287.402 Q1064.39 282.101 1065.89 276.87 Q1067.42 271.615 1067.42 266.268 Q1067.42 260.921 1065.89 255.712 Q1064.39 250.504 1061.31 245.18 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip250)" style="stroke:#c271d2; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="676.933,315.712 767.314,315.712 "/>
<path clip-path="url(#clip250)" d="M796.22 335.4 Q794.415 340.029 792.702 341.441 Q790.989 342.853 788.119 342.853 L784.716 342.853 L784.716 339.288 L787.216 339.288 Q788.975 339.288 789.947 338.455 Q790.92 337.622 792.1 334.52 L792.864 332.575 L782.378 307.066 L786.892 307.066 L794.994 327.344 L803.095 307.066 L807.609 307.066 L796.22 335.4 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M826.938 302.506 L815.132 320.955 L826.938 320.955 L826.938 302.506 M825.711 298.432 L831.591 298.432 L831.591 320.955 L836.521 320.955 L836.521 324.844 L831.591 324.844 L831.591 332.992 L826.938 332.992 L826.938 324.844 L811.336 324.844 L811.336 320.33 L825.711 298.432 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1797.04 1332.61 L3152.76 1332.61 L3152.76 408.361 L1797.04 408.361  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip253">
    <rect x="1797" y="408" width="1357" height="925"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip253)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1835.4,1332.61 1835.4,408.361 "/>
<polyline clip-path="url(#clip253)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2261.73,1332.61 2261.73,408.361 "/>
<polyline clip-path="url(#clip253)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2688.06,1332.61 2688.06,408.361 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1797.04,1332.61 3152.76,1332.61 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1835.4,1332.61 1835.4,1346.87 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2261.73,1332.61 2261.73,1346.87 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2688.06,1332.61 2688.06,1346.87 "/>
<path clip-path="url(#clip250)" d="M1585.82 1614.49 L1589.12 1611.18 L1613.56 1635.62 L1610.25 1638.92 L1585.82 1614.49 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1615.11 1603.03 Q1614.31 1603.24 1613.58 1603.72 Q1612.84 1604.16 1612.12 1604.88 Q1609.57 1607.43 1609.86 1610.48 Q1610.15 1613.49 1613.26 1616.6 L1622.92 1626.25 L1619.89 1629.28 L1601.56 1610.95 L1604.59 1607.92 L1607.44 1610.77 Q1606.72 1608.15 1607.44 1605.83 Q1608.14 1603.49 1610.32 1601.31 Q1610.63 1601 1611.05 1600.67 Q1611.46 1600.33 1612 1599.95 L1615.11 1603.03 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1628.31 1589.84 Q1627.5 1590.05 1626.77 1590.52 Q1626.03 1590.97 1625.31 1591.69 Q1622.76 1594.24 1623.05 1597.28 Q1623.35 1600.3 1626.46 1603.41 L1636.11 1613.06 L1633.09 1616.09 L1614.75 1597.76 L1617.78 1594.73 L1620.63 1597.58 Q1619.91 1594.96 1620.63 1592.63 Q1621.33 1590.29 1623.51 1588.12 Q1623.82 1587.81 1624.25 1587.48 Q1624.66 1587.14 1625.2 1586.76 L1628.31 1589.84 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1652.01 1577.33 L1653.48 1578.8 L1639.63 1592.65 Q1642.94 1595.56 1646.25 1595.53 Q1649.55 1595.47 1652.55 1592.47 Q1654.28 1590.74 1655.48 1588.69 Q1656.69 1586.63 1657.44 1584.17 L1660.29 1587.02 Q1659.36 1589.33 1658.02 1591.39 Q1656.67 1593.45 1654.92 1595.2 Q1650.53 1599.59 1645.41 1599.61 Q1640.3 1599.61 1635.95 1595.25 Q1631.45 1590.75 1631.24 1585.69 Q1631.02 1580.6 1635.15 1576.48 Q1638.85 1572.78 1643.38 1573.03 Q1647.92 1573.24 1652.01 1577.33 M1648.11 1579.46 Q1645.61 1577.02 1642.78 1576.91 Q1639.96 1576.77 1637.73 1579 Q1635.21 1581.52 1635.12 1584.47 Q1635.03 1587.4 1637.39 1590.21 L1648.11 1579.46 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1667.03 1576.64 L1676.76 1586.37 L1673.73 1589.39 L1648.42 1564.09 L1651.45 1561.06 L1654.23 1563.84 Q1653.55 1561.26 1654.2 1559.03 Q1654.86 1556.77 1656.87 1554.76 Q1660.21 1551.42 1664.94 1551.99 Q1669.69 1552.55 1674.01 1556.87 Q1678.33 1561.19 1678.88 1565.94 Q1679.46 1570.67 1676.12 1574.01 Q1674.1 1576.02 1671.86 1576.69 Q1669.62 1577.33 1667.03 1576.64 M1670.88 1560 Q1667.56 1556.67 1664.3 1556.17 Q1661.04 1555.63 1658.65 1558.02 Q1656.26 1560.41 1656.79 1563.68 Q1657.31 1566.92 1660.63 1570.24 Q1663.96 1573.57 1667.21 1574.11 Q1670.47 1574.61 1672.86 1572.22 Q1675.25 1569.83 1674.73 1566.59 Q1674.2 1563.32 1670.88 1560 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1662.4 1535.84 L1669.34 1528.9 L1671.68 1531.24 L1667.75 1535.17 L1692.96 1560.37 L1696.89 1556.44 L1699.23 1558.79 L1692.29 1565.73 L1662.4 1535.84 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1692.37 1509.53 L1695.6 1512.76 Q1692.81 1513.74 1690.7 1514.97 Q1688.59 1516.2 1687.04 1517.75 Q1684.33 1520.45 1683.91 1522.97 Q1683.5 1525.48 1685.43 1527.41 Q1687.05 1529.03 1688.85 1528.9 Q1690.65 1528.73 1693.88 1526.52 L1696.28 1524.94 Q1700.69 1521.94 1704.22 1521.97 Q1707.76 1521.97 1710.74 1524.95 Q1714.29 1528.5 1713.73 1532.73 Q1713.19 1536.93 1708.59 1541.53 Q1706.86 1543.27 1704.5 1544.84 Q1702.16 1546.39 1699.3 1547.72 L1695.89 1544.32 Q1699.03 1543.43 1701.54 1542.07 Q1704.04 1540.72 1705.91 1538.85 Q1708.74 1536.02 1709.17 1533.37 Q1709.59 1530.71 1707.53 1528.65 Q1705.73 1526.85 1703.6 1526.95 Q1701.49 1527.03 1698.46 1529.04 L1696.05 1530.67 Q1691.62 1533.63 1688.39 1533.71 Q1685.17 1533.79 1682.37 1530.99 Q1679.13 1527.75 1679.54 1523.61 Q1679.96 1519.45 1683.97 1515.44 Q1685.69 1513.72 1687.79 1512.25 Q1689.88 1510.78 1692.37 1509.53 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1697.82 1502.48 L1701.15 1499.16 L1715.99 1514 Q1719.92 1517.93 1723.08 1518.24 Q1726.22 1518.54 1729.41 1515.34 Q1732.59 1512.17 1732.29 1509.03 Q1731.98 1505.87 1728.05 1501.94 L1713.21 1487.09 L1716.53 1483.77 L1731.79 1499.03 Q1736.57 1503.81 1736.63 1508.62 Q1736.71 1513.41 1732.1 1518.03 Q1727.46 1522.66 1722.65 1522.6 Q1717.86 1522.51 1713.08 1517.73 L1697.82 1502.48 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1746.4 1499.04 L1753.34 1492.1 L1755.21 1493.97 L1745.42 1503.76 L1743.62 1501.96 Q1743.67 1500.89 1743.78 1498.94 Q1744.42 1488.32 1742.88 1486.78 Q1741.8 1485.7 1740.3 1485.9 Q1738.78 1486.08 1737.38 1487.47 Q1736.53 1488.32 1735.83 1489.61 Q1735.11 1490.89 1734.5 1492.64 L1732.49 1490.63 Q1733.29 1488.91 1734.14 1487.6 Q1735.01 1486.27 1735.94 1485.34 Q1738.32 1482.97 1740.82 1482.62 Q1743.33 1482.28 1745.09 1484.05 Q1747.37 1486.32 1746.6 1496.39 Q1746.47 1498.09 1746.4 1499.04 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1742.05 1456.19 L1771.94 1486.08 L1765 1493.02 L1762.66 1490.68 L1766.57 1486.77 L1741.36 1461.56 L1737.45 1465.47 L1735.11 1463.13 L1742.05 1456.19 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1755.36 1442.95 Q1756.93 1448.91 1759.55 1453.65 Q1762.17 1458.4 1765.95 1462.18 Q1769.73 1465.96 1774.51 1468.61 Q1779.29 1471.23 1785.21 1472.8 L1782.59 1475.42 Q1776.29 1474.03 1771.35 1471.54 Q1766.42 1469.04 1762.75 1465.37 Q1759.1 1461.72 1756.62 1456.81 Q1754.13 1451.9 1752.74 1445.57 L1755.36 1442.95 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1784.85 1458.76 L1790.25 1453.36 L1771.61 1434.72 L1766.91 1441.77 L1763.9 1438.76 L1768.57 1431.74 L1771.87 1428.43 L1793.53 1450.08 L1798.93 1444.68 L1801.71 1447.47 L1787.63 1461.54 L1784.85 1458.76 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1788.88 1411.42 L1791.66 1408.64 L1810.7 1444.7 L1807.91 1447.48 L1788.88 1411.42 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1819.75 1423.86 L1831.29 1412.32 L1834.07 1415.11 L1818.55 1430.62 L1815.77 1427.84 Q1815.71 1424.01 1815.67 1417.5 Q1815.64 1410.95 1815.53 1409.16 Q1815.33 1405.79 1814.72 1403.94 Q1814.12 1402.06 1812.92 1400.87 Q1810.98 1398.92 1808.37 1399.07 Q1805.79 1399.2 1803.59 1401.39 Q1802.04 1402.94 1800.84 1405.22 Q1799.66 1407.48 1798.8 1410.54 L1795.46 1407.2 Q1796.65 1404.4 1797.98 1402.26 Q1799.3 1400.11 1800.75 1398.67 Q1804.54 1394.88 1808.7 1394.52 Q1812.86 1394.15 1816.03 1397.33 Q1817.54 1398.84 1818.32 1400.77 Q1819.11 1402.67 1819.45 1405.99 Q1819.52 1406.87 1819.6 1411.34 Q1819.67 1415.79 1819.75 1423.86 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1814.67 1383.63 L1817.29 1381.01 Q1823.61 1382.42 1828.52 1384.91 Q1833.45 1387.38 1837.1 1391.03 Q1840.77 1394.7 1843.25 1399.64 Q1845.76 1404.57 1847.15 1410.87 L1844.53 1413.49 Q1842.96 1407.56 1840.32 1402.8 Q1837.69 1398 1833.91 1394.22 Q1830.13 1390.44 1825.36 1387.84 Q1820.62 1385.22 1814.67 1383.63 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2012.14 1614.49 L2015.45 1611.18 L2039.89 1635.62 L2036.58 1638.92 L2012.14 1614.49 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2041.44 1603.03 Q2040.64 1603.24 2039.9 1603.72 Q2039.17 1604.16 2038.45 1604.88 Q2035.89 1607.43 2036.19 1610.48 Q2036.48 1613.49 2039.59 1616.6 L2049.25 1626.25 L2046.22 1629.28 L2027.89 1610.95 L2030.92 1607.92 L2033.76 1610.77 Q2033.04 1608.15 2033.76 1605.83 Q2034.47 1603.49 2036.65 1601.31 Q2036.96 1601 2037.38 1600.67 Q2037.79 1600.33 2038.33 1599.95 L2041.44 1603.03 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2054.63 1589.84 Q2053.83 1590.05 2053.1 1590.52 Q2052.36 1590.97 2051.64 1591.69 Q2049.09 1594.24 2049.38 1597.28 Q2049.67 1600.3 2052.78 1603.41 L2062.44 1613.06 L2059.41 1616.09 L2041.08 1597.76 L2044.11 1594.73 L2046.96 1597.58 Q2046.24 1594.96 2046.96 1592.63 Q2047.66 1590.29 2049.84 1588.12 Q2050.15 1587.81 2050.57 1587.48 Q2050.98 1587.14 2051.52 1586.76 L2054.63 1589.84 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2078.34 1577.33 L2079.81 1578.8 L2065.96 1592.65 Q2069.27 1595.56 2072.57 1595.53 Q2075.88 1595.47 2078.88 1592.47 Q2080.61 1590.74 2081.81 1588.69 Q2083.02 1586.63 2083.77 1584.17 L2086.62 1587.02 Q2085.68 1589.33 2084.34 1591.39 Q2083 1593.45 2081.25 1595.2 Q2076.86 1599.59 2071.74 1599.61 Q2066.63 1599.61 2062.28 1595.25 Q2057.78 1590.75 2057.56 1585.69 Q2057.35 1580.6 2061.48 1576.48 Q2065.18 1572.78 2069.71 1573.03 Q2074.24 1573.24 2078.34 1577.33 M2074.44 1579.46 Q2071.94 1577.02 2069.1 1576.91 Q2066.29 1576.77 2064.06 1579 Q2061.54 1581.52 2061.44 1584.47 Q2061.36 1587.4 2063.72 1590.21 L2074.44 1579.46 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2093.36 1576.64 L2103.08 1586.37 L2100.06 1589.39 L2074.75 1564.09 L2077.78 1561.06 L2080.56 1563.84 Q2079.87 1561.26 2080.53 1559.03 Q2081.18 1556.77 2083.2 1554.76 Q2086.54 1551.42 2091.27 1551.99 Q2096.01 1552.55 2100.33 1556.87 Q2104.66 1561.19 2105.21 1565.94 Q2105.78 1570.67 2102.45 1574.01 Q2100.43 1576.02 2098.19 1576.69 Q2095.95 1577.33 2093.36 1576.64 M2097.21 1560 Q2093.88 1556.67 2090.63 1556.17 Q2087.37 1555.63 2084.98 1558.02 Q2082.59 1560.41 2083.11 1563.68 Q2083.64 1566.92 2086.96 1570.24 Q2090.28 1573.57 2093.54 1574.11 Q2096.8 1574.61 2099.19 1572.22 Q2101.58 1569.83 2101.05 1566.59 Q2100.53 1563.32 2097.21 1560 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2088.73 1535.84 L2095.67 1528.9 L2098.01 1531.24 L2094.08 1535.17 L2119.29 1560.37 L2123.22 1556.44 L2125.56 1558.79 L2118.62 1565.73 L2088.73 1535.84 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2118.7 1509.53 L2121.92 1512.76 Q2119.14 1513.74 2117.03 1514.97 Q2114.92 1516.2 2113.36 1517.75 Q2110.66 1520.45 2110.24 1522.97 Q2109.83 1525.48 2111.76 1527.41 Q2113.38 1529.03 2115.18 1528.9 Q2116.98 1528.73 2120.2 1526.52 L2122.61 1524.94 Q2127.01 1521.94 2130.55 1521.97 Q2134.09 1521.97 2137.06 1524.95 Q2140.62 1528.5 2140.06 1532.73 Q2139.52 1536.93 2134.92 1541.53 Q2133.18 1543.27 2130.83 1544.84 Q2128.49 1546.39 2125.62 1547.72 L2122.22 1544.32 Q2125.36 1543.43 2127.87 1542.07 Q2130.37 1540.72 2132.24 1538.85 Q2135.07 1536.02 2135.49 1533.37 Q2135.92 1530.71 2133.86 1528.65 Q2132.06 1526.85 2129.93 1526.95 Q2127.82 1527.03 2124.79 1529.04 L2122.38 1530.67 Q2117.95 1533.63 2114.72 1533.71 Q2111.5 1533.79 2108.7 1530.99 Q2105.46 1527.75 2105.87 1523.61 Q2106.29 1519.45 2110.3 1515.44 Q2112.02 1513.72 2114.12 1512.25 Q2116.21 1510.78 2118.7 1509.53 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2124.15 1502.48 L2127.47 1499.16 L2142.32 1514 Q2146.25 1517.93 2149.41 1518.24 Q2152.55 1518.54 2155.74 1515.34 Q2158.92 1512.17 2158.62 1509.03 Q2158.31 1505.87 2154.38 1501.94 L2139.54 1487.09 L2142.86 1483.77 L2158.11 1499.03 Q2162.89 1503.81 2162.96 1508.62 Q2163.04 1513.41 2158.42 1518.03 Q2153.79 1522.66 2148.98 1522.6 Q2144.18 1522.51 2139.4 1517.73 L2124.15 1502.48 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2172.73 1499.04 L2179.67 1492.1 L2181.54 1493.97 L2171.75 1503.76 L2169.95 1501.96 Q2170 1500.89 2170.11 1498.94 Q2170.75 1488.32 2169.21 1486.78 Q2168.13 1485.7 2166.62 1485.9 Q2165.1 1486.08 2163.71 1487.47 Q2162.86 1488.32 2162.16 1489.61 Q2161.44 1490.89 2160.83 1492.64 L2158.82 1490.63 Q2159.62 1488.91 2160.47 1487.6 Q2161.34 1486.27 2162.27 1485.34 Q2164.64 1482.97 2167.15 1482.62 Q2169.65 1482.28 2171.42 1484.05 Q2173.7 1486.32 2172.93 1496.39 Q2172.8 1498.09 2172.73 1499.04 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2168.38 1456.19 L2198.26 1486.08 L2191.32 1493.02 L2188.98 1490.68 L2192.9 1486.77 L2167.69 1461.56 L2163.78 1465.47 L2161.44 1463.13 L2168.38 1456.19 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2181.68 1442.95 Q2183.25 1448.91 2185.87 1453.65 Q2188.49 1458.4 2192.27 1462.18 Q2196.05 1465.96 2200.83 1468.61 Q2205.61 1471.23 2211.54 1472.8 L2208.92 1475.42 Q2202.62 1474.03 2197.68 1471.54 Q2192.75 1469.04 2189.08 1465.37 Q2185.43 1461.72 2182.94 1456.81 Q2180.46 1451.9 2179.06 1445.57 L2181.68 1442.95 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2210.23 1438.92 Q2213.11 1437.06 2216.04 1437.33 Q2218.99 1437.6 2221.34 1439.95 Q2224.96 1443.57 2224.45 1448.04 Q2223.95 1452.51 2219.36 1457.09 Q2217.82 1458.63 2215.88 1459.95 Q2213.96 1461.28 2211.62 1462.41 L2208.43 1459.22 Q2210.61 1458.65 2212.65 1457.42 Q2214.7 1456.19 2216.48 1454.41 Q2219.59 1451.3 2219.98 1448.45 Q2220.39 1445.58 2218.05 1443.24 Q2215.89 1441.08 2213.16 1441.39 Q2210.43 1441.67 2207.73 1444.37 L2204.88 1447.22 L2202.16 1444.5 L2205.14 1441.52 Q2207.58 1439.09 2207.91 1436.83 Q2208.22 1434.55 2206.38 1432.72 Q2204.5 1430.84 2202.16 1431.18 Q2199.82 1431.49 2197.33 1433.98 Q2195.97 1435.34 2194.71 1437.19 Q2193.45 1439.04 2192.21 1441.52 L2189.26 1438.58 Q2190.62 1436.17 2192 1434.27 Q2193.39 1432.36 2194.84 1430.9 Q2198.61 1427.14 2202.52 1426.66 Q2206.42 1426.17 2209.33 1429.08 Q2211.36 1431.11 2211.6 1433.68 Q2211.83 1436.24 2210.23 1438.92 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2215.21 1411.42 L2217.99 1408.64 L2237.02 1444.7 L2234.24 1447.48 L2215.21 1411.42 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2246.08 1423.86 L2257.62 1412.32 L2260.4 1415.11 L2244.88 1430.62 L2242.1 1427.84 Q2242.03 1424.01 2242 1417.5 Q2241.97 1410.95 2241.85 1409.16 Q2241.66 1405.79 2241.05 1403.94 Q2240.45 1402.06 2239.25 1400.87 Q2237.3 1398.92 2234.7 1399.07 Q2232.11 1399.2 2229.92 1401.39 Q2228.37 1402.94 2227.17 1405.22 Q2225.99 1407.48 2225.12 1410.54 L2221.79 1407.2 Q2222.98 1404.4 2224.31 1402.26 Q2225.63 1400.11 2227.07 1398.67 Q2230.87 1394.88 2235.03 1394.52 Q2239.18 1394.15 2242.36 1397.33 Q2243.87 1398.84 2244.65 1400.77 Q2245.44 1402.67 2245.78 1405.99 Q2245.85 1406.87 2245.93 1411.34 Q2245.99 1415.79 2246.08 1423.86 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2241 1383.63 L2243.62 1381.01 Q2249.94 1382.42 2254.85 1384.91 Q2259.78 1387.38 2263.43 1391.03 Q2267.09 1394.7 2269.58 1399.64 Q2272.08 1404.57 2273.48 1410.87 L2270.86 1413.49 Q2269.29 1407.56 2266.65 1402.8 Q2264.02 1398 2260.23 1394.22 Q2256.45 1390.44 2251.69 1387.84 Q2246.94 1385.22 2241 1383.63 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2438.47 1614.49 L2441.78 1611.18 L2466.21 1635.62 L2462.91 1638.92 L2438.47 1614.49 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2467.77 1603.03 Q2466.97 1603.24 2466.23 1603.72 Q2465.49 1604.16 2464.77 1604.88 Q2462.22 1607.43 2462.51 1610.48 Q2462.81 1613.49 2465.92 1616.6 L2475.58 1626.25 L2472.55 1629.28 L2454.22 1610.95 L2457.24 1607.92 L2460.09 1610.77 Q2459.37 1608.15 2460.09 1605.83 Q2460.8 1603.49 2462.97 1601.31 Q2463.28 1601 2463.71 1600.67 Q2464.12 1600.33 2464.66 1599.95 L2467.77 1603.03 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2480.96 1589.84 Q2480.16 1590.05 2479.42 1590.52 Q2478.69 1590.97 2477.97 1591.69 Q2475.41 1594.24 2475.71 1597.28 Q2476 1600.3 2479.11 1603.41 L2488.77 1613.06 L2485.74 1616.09 L2467.41 1597.76 L2470.44 1594.73 L2473.28 1597.58 Q2472.56 1594.96 2473.28 1592.63 Q2473.99 1590.29 2476.17 1588.12 Q2476.48 1587.81 2476.9 1587.48 Q2477.31 1587.14 2477.85 1586.76 L2480.96 1589.84 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2504.66 1577.33 L2506.14 1578.8 L2492.29 1592.65 Q2495.59 1595.56 2498.9 1595.53 Q2502.21 1595.47 2505.2 1592.47 Q2506.94 1590.74 2508.13 1588.69 Q2509.34 1586.63 2510.1 1584.17 L2512.94 1587.02 Q2512.01 1589.33 2510.67 1591.39 Q2509.33 1593.45 2507.58 1595.2 Q2503.19 1599.59 2498.07 1599.61 Q2492.96 1599.61 2488.61 1595.25 Q2484.1 1590.75 2483.89 1585.69 Q2483.68 1580.6 2487.8 1576.48 Q2491.5 1572.78 2496.04 1573.03 Q2500.57 1573.24 2504.66 1577.33 M2500.77 1579.46 Q2498.26 1577.02 2495.43 1576.91 Q2492.62 1576.77 2490.39 1579 Q2487.87 1581.52 2487.77 1584.47 Q2487.69 1587.4 2490.05 1590.21 L2500.77 1579.46 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2519.69 1576.64 L2529.41 1586.37 L2526.38 1589.39 L2501.08 1564.09 L2504.11 1561.06 L2506.89 1563.84 Q2506.2 1561.26 2506.86 1559.03 Q2507.51 1556.77 2509.52 1554.76 Q2512.86 1551.42 2517.59 1551.99 Q2522.34 1552.55 2526.66 1556.87 Q2530.98 1561.19 2531.54 1565.94 Q2532.11 1570.67 2528.77 1574.01 Q2526.76 1576.02 2524.52 1576.69 Q2522.27 1577.33 2519.69 1576.64 M2523.53 1560 Q2520.21 1556.67 2516.95 1556.17 Q2513.7 1555.63 2511.31 1558.02 Q2508.92 1560.41 2509.44 1563.68 Q2509.97 1566.92 2513.29 1570.24 Q2516.61 1573.57 2519.87 1574.11 Q2523.13 1574.61 2525.52 1572.22 Q2527.91 1569.83 2527.38 1566.59 Q2526.86 1563.32 2523.53 1560 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2515.06 1535.84 L2522 1528.9 L2524.34 1531.24 L2520.41 1535.17 L2545.62 1560.37 L2549.54 1556.44 L2551.88 1558.79 L2544.94 1565.73 L2515.06 1535.84 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2545.03 1509.53 L2548.25 1512.76 Q2545.47 1513.74 2543.36 1514.97 Q2541.25 1516.2 2539.69 1517.75 Q2536.99 1520.45 2536.56 1522.97 Q2536.15 1525.48 2538.09 1527.41 Q2539.71 1529.03 2541.51 1528.9 Q2543.31 1528.73 2546.53 1526.52 L2548.94 1524.94 Q2553.34 1521.94 2556.88 1521.97 Q2560.41 1521.97 2563.39 1524.95 Q2566.94 1528.5 2566.39 1532.73 Q2565.85 1536.93 2561.25 1541.53 Q2559.51 1543.27 2557.16 1544.84 Q2554.81 1546.39 2551.95 1547.72 L2548.55 1544.32 Q2551.69 1543.43 2554.19 1542.07 Q2556.7 1540.72 2558.56 1538.85 Q2561.39 1536.02 2561.82 1533.37 Q2562.25 1530.71 2560.18 1528.65 Q2558.38 1526.85 2556.25 1526.95 Q2554.14 1527.03 2551.12 1529.04 L2548.71 1530.67 Q2544.27 1533.63 2541.05 1533.71 Q2537.82 1533.79 2535.03 1530.99 Q2531.78 1527.75 2532.19 1523.61 Q2532.62 1519.45 2536.63 1515.44 Q2538.35 1513.72 2540.44 1512.25 Q2542.54 1510.78 2545.03 1509.53 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2550.48 1502.48 L2553.8 1499.16 L2568.65 1514 Q2572.57 1517.93 2575.73 1518.24 Q2578.88 1518.54 2582.07 1515.34 Q2585.24 1512.17 2584.95 1509.03 Q2584.64 1505.87 2580.71 1501.94 L2565.86 1487.09 L2569.19 1483.77 L2584.44 1499.03 Q2589.22 1503.81 2589.29 1508.62 Q2589.37 1513.41 2584.75 1518.03 Q2580.12 1522.66 2575.31 1522.6 Q2570.51 1522.51 2565.73 1517.73 L2550.48 1502.48 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2599.06 1499.04 L2606 1492.1 L2607.86 1493.97 L2598.08 1503.76 L2596.27 1501.96 Q2596.32 1500.89 2596.44 1498.94 Q2597.08 1488.32 2595.54 1486.78 Q2594.46 1485.7 2592.95 1485.9 Q2591.43 1486.08 2590.04 1487.47 Q2589.19 1488.32 2588.48 1489.61 Q2587.76 1490.89 2587.16 1492.64 L2585.14 1490.63 Q2585.95 1488.91 2586.8 1487.6 Q2587.67 1486.27 2588.6 1485.34 Q2590.97 1482.97 2593.48 1482.62 Q2595.98 1482.28 2597.75 1484.05 Q2600.02 1486.32 2599.25 1496.39 Q2599.12 1498.09 2599.06 1499.04 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2594.7 1456.19 L2624.59 1486.08 L2617.65 1493.02 L2615.31 1490.68 L2619.22 1486.77 L2594.02 1461.56 L2590.1 1465.47 L2587.76 1463.13 L2594.7 1456.19 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2608.01 1442.95 Q2609.58 1448.91 2612.2 1453.65 Q2614.82 1458.4 2618.6 1462.18 Q2622.38 1465.96 2627.16 1468.61 Q2631.94 1471.23 2637.87 1472.8 L2635.25 1475.42 Q2628.95 1474.03 2624 1471.54 Q2619.08 1469.04 2615.41 1465.37 Q2611.76 1461.72 2609.27 1456.81 Q2606.78 1451.9 2605.39 1445.57 L2608.01 1442.95 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2615.31 1437.65 L2628.29 1424.67 L2631.07 1427.45 L2621.12 1437.4 L2627.11 1443.39 Q2627.59 1442.42 2628.19 1441.59 Q2628.78 1440.74 2629.5 1440.02 Q2633.59 1435.93 2638.23 1435.78 Q2642.86 1435.63 2646.69 1439.46 Q2650.63 1443.41 2650.37 1448.06 Q2650.09 1452.69 2645.62 1457.16 Q2644.09 1458.69 2642.22 1460.04 Q2640.37 1461.36 2638.14 1462.54 L2634.82 1459.22 Q2637.1 1458.55 2639.06 1457.37 Q2641.03 1456.19 2642.78 1454.44 Q2645.61 1451.61 2645.77 1448.46 Q2645.94 1445.32 2643.38 1442.77 Q2640.83 1440.21 2637.69 1440.38 Q2634.54 1440.54 2631.71 1443.37 Q2630.39 1444.7 2629.35 1446.32 Q2628.34 1447.92 2627.59 1449.92 L2615.31 1437.65 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2641.53 1411.42 L2644.32 1408.64 L2663.35 1444.7 L2660.57 1447.48 L2641.53 1411.42 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2672.4 1423.86 L2683.94 1412.32 L2686.73 1415.11 L2671.21 1430.62 L2668.43 1427.84 Q2668.36 1424.01 2668.33 1417.5 Q2668.29 1410.95 2668.18 1409.16 Q2667.98 1405.79 2667.38 1403.94 Q2666.77 1402.06 2665.58 1400.87 Q2663.63 1398.92 2661.03 1399.07 Q2658.44 1399.2 2656.25 1401.39 Q2654.69 1402.94 2653.5 1405.22 Q2652.32 1407.48 2651.45 1410.54 L2648.11 1407.2 Q2649.31 1404.4 2650.63 1402.26 Q2651.96 1400.11 2653.4 1398.67 Q2657.2 1394.88 2661.35 1394.52 Q2665.51 1394.15 2668.69 1397.33 Q2670.19 1398.84 2670.98 1400.77 Q2671.76 1402.67 2672.11 1405.99 Q2672.17 1406.87 2672.26 1411.34 Q2672.32 1415.79 2672.4 1423.86 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2667.33 1383.63 L2669.95 1381.01 Q2676.27 1382.42 2681.18 1384.91 Q2686.1 1387.38 2689.75 1391.03 Q2693.42 1394.7 2695.91 1399.64 Q2698.41 1404.57 2699.8 1410.87 L2697.18 1413.49 Q2695.61 1407.56 2692.98 1402.8 Q2690.34 1398 2686.56 1394.22 Q2682.78 1390.44 2678.02 1387.84 Q2673.27 1385.22 2667.33 1383.63 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2391.15 1719.61 L2386.41 1707.42 L2376.64 1725.25 L2369.73 1725.25 L2383.55 1700.04 L2377.75 1685.05 Q2376.2 1681.04 2371.29 1681.04 L2369.73 1681.04 L2369.73 1676.01 L2371.96 1676.07 Q2380.17 1676.3 2382.24 1681.61 L2386.95 1693.8 L2396.72 1675.98 L2403.63 1675.98 L2389.82 1701.19 L2395.61 1716.18 Q2397.17 1720.19 2402.07 1720.19 L2403.63 1720.19 L2403.63 1725.22 L2401.4 1725.15 Q2393.19 1724.93 2391.15 1719.61 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2433.14 1682.06 L2473.94 1682.06 L2473.94 1687.4 L2433.14 1687.4 L2433.14 1682.06 M2433.14 1695.04 L2473.94 1695.04 L2473.94 1700.45 L2433.14 1700.45 L2433.14 1695.04 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2508.6 1664.14 L2533.84 1664.14 L2533.84 1669.55 L2514.49 1669.55 L2514.49 1681.2 Q2515.89 1680.72 2517.29 1680.5 Q2518.69 1680.24 2520.09 1680.24 Q2528.05 1680.24 2532.7 1684.6 Q2537.34 1688.96 2537.34 1696.41 Q2537.34 1704.08 2532.57 1708.35 Q2527.79 1712.58 2519.11 1712.58 Q2516.11 1712.58 2512.99 1712.07 Q2509.91 1711.56 2506.6 1710.54 L2506.6 1704.08 Q2509.46 1705.64 2512.52 1706.41 Q2515.57 1707.17 2518.98 1707.17 Q2524.48 1707.17 2527.7 1704.27 Q2530.91 1701.38 2530.91 1696.41 Q2530.91 1691.45 2527.7 1688.55 Q2524.48 1685.65 2518.98 1685.65 Q2516.4 1685.65 2513.82 1686.23 Q2511.28 1686.8 2508.6 1688.01 L2508.6 1664.14 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2563.76 1689.09 Q2559.18 1689.09 2556.54 1691.54 Q2553.93 1693.99 2553.93 1698.29 Q2553.93 1702.59 2556.54 1705.04 Q2559.18 1707.49 2563.76 1707.49 Q2568.34 1707.49 2570.99 1705.04 Q2573.63 1702.55 2573.63 1698.29 Q2573.63 1693.99 2570.99 1691.54 Q2568.38 1689.09 2563.76 1689.09 M2557.33 1686.35 Q2553.19 1685.34 2550.87 1682.5 Q2548.58 1679.67 2548.58 1675.6 Q2548.58 1669.9 2552.62 1666.59 Q2556.69 1663.28 2563.76 1663.28 Q2570.86 1663.28 2574.9 1666.59 Q2578.94 1669.9 2578.94 1675.6 Q2578.94 1679.67 2576.62 1682.5 Q2574.33 1685.34 2570.22 1686.35 Q2574.87 1687.44 2577.45 1690.59 Q2580.06 1693.74 2580.06 1698.29 Q2580.06 1705.2 2575.82 1708.89 Q2571.62 1712.58 2563.76 1712.58 Q2555.9 1712.58 2551.67 1708.89 Q2547.46 1705.2 2547.46 1698.29 Q2547.46 1693.74 2550.07 1690.59 Q2552.68 1687.44 2557.33 1686.35 M2554.98 1676.2 Q2554.98 1679.89 2557.27 1681.96 Q2559.59 1684.03 2563.76 1684.03 Q2567.9 1684.03 2570.22 1681.96 Q2572.58 1679.89 2572.58 1676.2 Q2572.58 1672.51 2570.22 1670.44 Q2567.9 1668.37 2563.76 1668.37 Q2559.59 1668.37 2557.27 1670.44 Q2554.98 1672.51 2554.98 1676.2 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip253)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1797.04,1236.7 3152.76,1236.7 "/>
<polyline clip-path="url(#clip253)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1797.04,1103.92 3152.76,1103.92 "/>
<polyline clip-path="url(#clip253)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1797.04,971.141 3152.76,971.141 "/>
<polyline clip-path="url(#clip253)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1797.04,838.359 3152.76,838.359 "/>
<polyline clip-path="url(#clip253)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1797.04,705.578 3152.76,705.578 "/>
<polyline clip-path="url(#clip253)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1797.04,572.796 3152.76,572.796 "/>
<polyline clip-path="url(#clip253)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1797.04,440.015 3152.76,440.015 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1797.04,1332.61 1797.04,408.361 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1797.04,1236.7 1815.93,1236.7 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1797.04,1103.92 1815.93,1103.92 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1797.04,971.141 1815.93,971.141 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1797.04,838.359 1815.93,838.359 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1797.04,705.578 1815.93,705.578 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1797.04,572.796 1815.93,572.796 "/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1797.04,440.015 1815.93,440.015 "/>
<path clip-path="url(#clip250)" d="M1647.47 1256.5 L1655.1 1256.5 L1655.1 1230.13 L1646.79 1231.8 L1646.79 1227.54 L1655.06 1225.87 L1659.73 1225.87 L1659.73 1256.5 L1667.37 1256.5 L1667.37 1260.43 L1647.47 1260.43 L1647.47 1256.5 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1686.82 1228.95 Q1683.21 1228.95 1681.38 1232.51 Q1679.57 1236.06 1679.57 1243.19 Q1679.57 1250.29 1681.38 1253.86 Q1683.21 1257.4 1686.82 1257.4 Q1690.45 1257.4 1692.26 1253.86 Q1694.09 1250.29 1694.09 1243.19 Q1694.09 1236.06 1692.26 1232.51 Q1690.45 1228.95 1686.82 1228.95 M1686.82 1225.25 Q1692.63 1225.25 1695.68 1229.85 Q1698.76 1234.44 1698.76 1243.19 Q1698.76 1251.91 1695.68 1256.52 Q1692.63 1261.1 1686.82 1261.1 Q1681.01 1261.1 1677.93 1256.52 Q1674.87 1251.91 1674.87 1243.19 Q1674.87 1234.44 1677.93 1229.85 Q1681.01 1225.25 1686.82 1225.25 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1698.76 1219.35 L1722.87 1219.35 L1722.87 1222.55 L1698.76 1222.55 L1698.76 1219.35 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1739.67 1217.47 Q1737.11 1217.47 1735.61 1219.22 Q1734.12 1220.97 1734.12 1224.01 Q1734.12 1227.04 1735.61 1228.81 Q1737.11 1230.56 1739.67 1230.56 Q1742.23 1230.56 1743.71 1228.81 Q1745.22 1227.04 1745.22 1224.01 Q1745.22 1220.97 1743.71 1219.22 Q1742.23 1217.47 1739.67 1217.47 M1747.21 1205.56 L1747.21 1209.02 Q1745.78 1208.35 1744.31 1207.99 Q1742.87 1207.63 1741.44 1207.63 Q1737.68 1207.63 1735.68 1210.17 Q1733.71 1212.71 1733.42 1217.84 Q1734.53 1216.21 1736.21 1215.34 Q1737.88 1214.46 1739.89 1214.46 Q1744.13 1214.46 1746.57 1217.03 Q1749.04 1219.59 1749.04 1224.01 Q1749.04 1228.34 1746.48 1230.95 Q1743.92 1233.57 1739.67 1233.57 Q1734.8 1233.57 1732.22 1229.84 Q1729.64 1226.1 1729.64 1219.01 Q1729.64 1212.35 1732.8 1208.4 Q1735.96 1204.43 1741.29 1204.43 Q1742.72 1204.43 1744.16 1204.72 Q1745.63 1205 1747.21 1205.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1648.41 1123.71 L1656.05 1123.71 L1656.05 1097.35 L1647.74 1099.02 L1647.74 1094.76 L1656 1093.09 L1660.67 1093.09 L1660.67 1123.71 L1668.31 1123.71 L1668.31 1127.65 L1648.41 1127.65 L1648.41 1123.71 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1687.76 1096.17 Q1684.15 1096.17 1682.32 1099.73 Q1680.51 1103.27 1680.51 1110.4 Q1680.51 1117.51 1682.32 1121.08 Q1684.15 1124.62 1687.76 1124.62 Q1691.39 1124.62 1693.2 1121.08 Q1695.03 1117.51 1695.03 1110.4 Q1695.03 1103.27 1693.2 1099.73 Q1691.39 1096.17 1687.76 1096.17 M1687.76 1092.46 Q1693.57 1092.46 1696.62 1097.07 Q1699.7 1101.65 1699.7 1110.4 Q1699.7 1119.13 1696.62 1123.74 Q1693.57 1128.32 1687.76 1128.32 Q1681.95 1128.32 1678.87 1123.74 Q1675.81 1119.13 1675.81 1110.4 Q1675.81 1101.65 1678.87 1097.07 Q1681.95 1092.46 1687.76 1092.46 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1699.7 1086.57 L1723.81 1086.57 L1723.81 1089.76 L1699.7 1089.76 L1699.7 1086.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1732.05 1072.16 L1746.97 1072.16 L1746.97 1075.36 L1735.53 1075.36 L1735.53 1082.24 Q1736.36 1081.96 1737.19 1081.83 Q1738.01 1081.68 1738.84 1081.68 Q1743.54 1081.68 1746.29 1084.25 Q1749.04 1086.83 1749.04 1091.23 Q1749.04 1095.76 1746.21 1098.28 Q1743.39 1100.78 1738.26 1100.78 Q1736.49 1100.78 1734.65 1100.48 Q1732.82 1100.18 1730.87 1099.58 L1730.87 1095.76 Q1732.56 1096.68 1734.37 1097.14 Q1736.17 1097.59 1738.18 1097.59 Q1741.44 1097.59 1743.34 1095.88 Q1745.24 1094.16 1745.24 1091.23 Q1745.24 1088.3 1743.34 1086.59 Q1741.44 1084.87 1738.18 1084.87 Q1736.66 1084.87 1735.14 1085.21 Q1733.63 1085.55 1732.05 1086.27 L1732.05 1072.16 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1647.2 990.933 L1654.84 990.933 L1654.84 964.568 L1646.53 966.234 L1646.53 961.975 L1654.8 960.308 L1659.47 960.308 L1659.47 990.933 L1667.11 990.933 L1667.11 994.868 L1647.2 994.868 L1647.2 990.933 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1686.55 963.387 Q1682.94 963.387 1681.11 966.952 Q1679.31 970.493 1679.31 977.623 Q1679.31 984.73 1681.11 988.294 Q1682.94 991.836 1686.55 991.836 Q1690.19 991.836 1691.99 988.294 Q1693.82 984.73 1693.82 977.623 Q1693.82 970.493 1691.99 966.952 Q1690.19 963.387 1686.55 963.387 M1686.55 959.683 Q1692.36 959.683 1695.42 964.29 Q1698.5 968.873 1698.5 977.623 Q1698.5 986.35 1695.42 990.956 Q1692.36 995.54 1686.55 995.54 Q1680.74 995.54 1677.67 990.956 Q1674.61 986.35 1674.61 977.623 Q1674.61 968.873 1677.67 964.29 Q1680.74 959.683 1686.55 959.683 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1698.5 953.785 L1722.61 953.785 L1722.61 956.982 L1698.5 956.982 L1698.5 953.785 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1741.25 942.688 L1731.66 957.678 L1741.25 957.678 L1741.25 942.688 M1740.25 939.378 L1745.03 939.378 L1745.03 957.678 L1749.04 957.678 L1749.04 960.838 L1745.03 960.838 L1745.03 967.458 L1741.25 967.458 L1741.25 960.838 L1728.57 960.838 L1728.57 957.17 L1740.25 939.378 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1648.12 858.152 L1655.76 858.152 L1655.76 831.786 L1647.45 833.453 L1647.45 829.193 L1655.72 827.527 L1660.39 827.527 L1660.39 858.152 L1668.03 858.152 L1668.03 862.087 L1648.12 862.087 L1648.12 858.152 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1687.48 830.606 Q1683.86 830.606 1682.04 834.17 Q1680.23 837.712 1680.23 844.842 Q1680.23 851.948 1682.04 855.513 Q1683.86 859.054 1687.48 859.054 Q1691.11 859.054 1692.92 855.513 Q1694.74 851.948 1694.74 844.842 Q1694.74 837.712 1692.92 834.17 Q1691.11 830.606 1687.48 830.606 M1687.48 826.902 Q1693.29 826.902 1696.34 831.508 Q1699.42 836.092 1699.42 844.842 Q1699.42 853.568 1696.34 858.175 Q1693.29 862.758 1687.48 862.758 Q1681.67 862.758 1678.59 858.175 Q1675.53 853.568 1675.53 844.842 Q1675.53 836.092 1678.59 831.508 Q1681.67 826.902 1687.48 826.902 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1699.42 821.003 L1723.53 821.003 L1723.53 824.201 L1699.42 824.201 L1699.42 821.003 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1743.24 819.536 Q1745.97 820.119 1747.49 821.962 Q1749.04 823.806 1749.04 826.514 Q1749.04 830.67 1746.18 832.946 Q1743.32 835.222 1738.05 835.222 Q1736.28 835.222 1734.4 834.865 Q1732.54 834.526 1730.55 833.83 L1730.55 830.163 Q1732.13 831.084 1734.01 831.554 Q1735.89 832.025 1737.94 832.025 Q1741.51 832.025 1743.37 830.614 Q1745.25 829.203 1745.25 826.514 Q1745.25 824.031 1743.51 822.639 Q1741.78 821.229 1738.67 821.229 L1735.4 821.229 L1735.4 818.107 L1738.82 818.107 Q1741.62 818.107 1743.11 816.997 Q1744.6 815.869 1744.6 813.762 Q1744.6 811.599 1743.05 810.452 Q1741.53 809.286 1738.67 809.286 Q1737.11 809.286 1735.32 809.624 Q1733.54 809.963 1731.39 810.678 L1731.39 807.292 Q1733.56 806.69 1735.44 806.39 Q1737.34 806.089 1739.01 806.089 Q1743.34 806.089 1745.86 808.063 Q1748.38 810.019 1748.38 813.367 Q1748.38 815.699 1747.04 817.317 Q1745.71 818.916 1743.24 819.536 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1648.9 725.37 L1656.53 725.37 L1656.53 699.005 L1648.22 700.671 L1648.22 696.412 L1656.49 694.745 L1661.16 694.745 L1661.16 725.37 L1668.8 725.37 L1668.8 729.305 L1648.9 729.305 L1648.9 725.37 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1688.25 697.824 Q1684.64 697.824 1682.81 701.389 Q1681 704.93 1681 712.06 Q1681 719.166 1682.81 722.731 Q1684.64 726.273 1688.25 726.273 Q1691.88 726.273 1693.69 722.731 Q1695.52 719.166 1695.52 712.06 Q1695.52 704.93 1693.69 701.389 Q1691.88 697.824 1688.25 697.824 M1688.25 694.12 Q1694.06 694.12 1697.11 698.727 Q1700.19 703.31 1700.19 712.06 Q1700.19 720.787 1697.11 725.393 Q1694.06 729.977 1688.25 729.977 Q1682.44 729.977 1679.36 725.393 Q1676.3 720.787 1676.3 712.06 Q1676.3 703.31 1679.36 698.727 Q1682.44 694.12 1688.25 694.12 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1700.19 688.222 L1724.3 688.222 L1724.3 691.419 L1700.19 691.419 L1700.19 688.222 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1735.78 698.698 L1749.04 698.698 L1749.04 701.895 L1731.21 701.895 L1731.21 698.698 Q1733.37 696.459 1737.09 692.698 Q1740.83 688.918 1741.79 687.827 Q1743.62 685.777 1744.33 684.366 Q1745.07 682.937 1745.07 681.564 Q1745.07 679.326 1743.49 677.915 Q1741.93 676.504 1739.41 676.504 Q1737.62 676.504 1735.63 677.125 Q1733.65 677.746 1731.39 679.006 L1731.39 675.169 Q1733.69 674.247 1735.68 673.777 Q1737.68 673.307 1739.33 673.307 Q1743.69 673.307 1746.29 675.489 Q1748.88 677.671 1748.88 681.319 Q1748.88 683.05 1748.23 684.611 Q1747.59 686.153 1745.88 688.259 Q1745.41 688.805 1742.88 691.419 Q1740.36 694.014 1735.78 698.698 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1648.59 592.589 L1656.23 592.589 L1656.23 566.223 L1647.92 567.89 L1647.92 563.63 L1656.19 561.964 L1660.86 561.964 L1660.86 592.589 L1668.5 592.589 L1668.5 596.524 L1648.59 596.524 L1648.59 592.589 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1687.95 565.042 Q1684.33 565.042 1682.51 568.607 Q1680.7 572.149 1680.7 579.279 Q1680.7 586.385 1682.51 589.95 Q1684.33 593.491 1687.95 593.491 Q1691.58 593.491 1693.39 589.95 Q1695.21 586.385 1695.21 579.279 Q1695.21 572.149 1693.39 568.607 Q1691.58 565.042 1687.95 565.042 M1687.95 561.339 Q1693.76 561.339 1696.81 565.945 Q1699.89 570.529 1699.89 579.279 Q1699.89 588.005 1696.81 592.612 Q1693.76 597.195 1687.95 597.195 Q1682.14 597.195 1679.06 592.612 Q1676 588.005 1676 579.279 Q1676 570.529 1679.06 565.945 Q1682.14 561.339 1687.95 561.339 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1699.89 555.44 L1724 555.44 L1724 558.637 L1699.89 558.637 L1699.89 555.44 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1732.86 565.916 L1739.07 565.916 L1739.07 544.494 L1732.32 545.848 L1732.32 542.388 L1739.03 541.033 L1742.83 541.033 L1742.83 565.916 L1749.04 565.916 L1749.04 569.113 L1732.86 569.113 L1732.86 565.916 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1678.33 459.807 L1685.97 459.807 L1685.97 433.442 L1677.66 435.108 L1677.66 430.849 L1685.92 429.182 L1690.6 429.182 L1690.6 459.807 L1698.24 459.807 L1698.24 463.742 L1678.33 463.742 L1678.33 459.807 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1717.68 432.261 Q1714.07 432.261 1712.24 435.826 Q1710.44 439.367 1710.44 446.497 Q1710.44 453.603 1712.24 457.168 Q1714.07 460.71 1717.68 460.71 Q1721.32 460.71 1723.12 457.168 Q1724.95 453.603 1724.95 446.497 Q1724.95 439.367 1723.12 435.826 Q1721.32 432.261 1717.68 432.261 M1717.68 428.557 Q1723.49 428.557 1726.55 433.164 Q1729.63 437.747 1729.63 446.497 Q1729.63 455.224 1726.55 459.83 Q1723.49 464.414 1717.68 464.414 Q1711.87 464.414 1708.79 459.83 Q1705.74 455.224 1705.74 446.497 Q1705.74 437.747 1708.79 433.164 Q1711.87 428.557 1717.68 428.557 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M1739.33 410.753 Q1736.4 410.753 1734.91 413.65 Q1733.44 416.527 1733.44 422.32 Q1733.44 428.094 1734.91 430.99 Q1736.4 433.868 1739.33 433.868 Q1742.28 433.868 1743.75 430.99 Q1745.24 428.094 1745.24 422.32 Q1745.24 416.527 1743.75 413.65 Q1742.28 410.753 1739.33 410.753 M1739.33 407.744 Q1744.05 407.744 1746.53 411.487 Q1749.04 415.211 1749.04 422.32 Q1749.04 429.411 1746.53 433.153 Q1744.05 436.877 1739.33 436.877 Q1734.61 436.877 1732.11 433.153 Q1729.63 429.411 1729.63 422.32 Q1729.63 415.211 1732.11 411.487 Q1734.61 407.744 1739.33 407.744 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2323.96 73.5887 Q2314.6 72.0899 2310.27 68.1605 Q2304.96 63.3399 2304.96 53.4962 L2304.96 27.2059 L2312.49 27.2059 L2312.49 53.2127 Q2312.49 60.6258 2315.94 63.7045 Q2318.94 66.3781 2323.96 66.9452 L2323.96 27.2059 L2331.37 27.2059 L2331.37 66.9047 Q2336.68 66.3376 2339.39 63.664 Q2342.84 60.2613 2342.84 53.1722 L2342.84 27.2059 L2350.37 27.2059 L2350.37 53.4557 Q2350.37 63.664 2345.06 68.12 Q2340.28 72.1304 2331.37 73.5482 L2331.37 89.8329 L2323.96 89.8329 L2323.96 73.5887 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2397.44 86.3491 L2397.44 92.1419 L2354.34 92.1419 L2354.34 86.3491 L2397.44 86.3491 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2439.77 35.9153 Q2442.57 30.8922 2446.46 28.5022 Q2450.35 26.1121 2455.61 26.1121 Q2462.7 26.1121 2466.55 31.0947 Q2470.4 36.0368 2470.4 45.1919 L2470.4 72.576 L2462.9 72.576 L2462.9 45.4349 Q2462.9 38.913 2460.6 35.7533 Q2458.29 32.5936 2453.55 32.5936 Q2447.75 32.5936 2444.39 36.4419 Q2441.03 40.2903 2441.03 46.9338 L2441.03 72.576 L2433.54 72.576 L2433.54 45.4349 Q2433.54 38.8725 2431.23 35.7533 Q2428.92 32.5936 2424.1 32.5936 Q2418.39 32.5936 2415.02 36.4824 Q2411.66 40.3308 2411.66 46.9338 L2411.66 72.576 L2404.17 72.576 L2404.17 27.2059 L2411.66 27.2059 L2411.66 34.2544 Q2414.21 30.082 2417.78 28.0971 Q2421.34 26.1121 2426.24 26.1121 Q2431.19 26.1121 2434.63 28.6237 Q2438.11 31.1352 2439.77 35.9153 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2485.27 27.2059 L2492.72 27.2059 L2492.72 72.576 L2485.27 72.576 L2485.27 27.2059 M2485.27 9.54393 L2492.72 9.54393 L2492.72 18.9825 L2485.27 18.9825 L2485.27 9.54393 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2546.03 45.1919 L2546.03 72.576 L2538.58 72.576 L2538.58 45.4349 Q2538.58 38.994 2536.06 35.7938 Q2533.55 32.5936 2528.53 32.5936 Q2522.49 32.5936 2519.01 36.4419 Q2515.53 40.2903 2515.53 46.9338 L2515.53 72.576 L2508.03 72.576 L2508.03 27.2059 L2515.53 27.2059 L2515.53 34.2544 Q2518.2 30.163 2521.8 28.1376 Q2525.45 26.1121 2530.19 26.1121 Q2538.01 26.1121 2542.02 30.9732 Q2546.03 35.7938 2546.03 45.1919 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2560.13 54.671 L2560.13 27.2059 L2567.58 27.2059 L2567.58 54.3874 Q2567.58 60.8284 2570.09 64.0691 Q2572.6 67.2693 2577.63 67.2693 Q2583.66 67.2693 2587.15 63.421 Q2590.67 59.5726 2590.67 52.9291 L2590.67 27.2059 L2598.12 27.2059 L2598.12 72.576 L2590.67 72.576 L2590.67 65.6084 Q2587.96 69.7404 2584.35 71.7658 Q2580.79 73.7508 2576.05 73.7508 Q2568.23 73.7508 2564.18 68.8897 Q2560.13 64.0286 2560.13 54.671 M2578.88 26.1121 L2578.88 26.1121 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2642.4 28.5427 L2642.4 35.5912 Q2639.24 33.9709 2635.84 33.1607 Q2632.44 32.3505 2628.79 32.3505 Q2623.24 32.3505 2620.44 34.0519 Q2617.69 35.7533 2617.69 39.156 Q2617.69 41.7486 2619.67 43.2475 Q2621.66 44.7058 2627.66 46.0426 L2630.21 46.6097 Q2638.15 48.3111 2641.47 51.4303 Q2644.83 54.509 2644.83 60.0587 Q2644.83 66.3781 2639.81 70.0644 Q2634.83 73.7508 2626.08 73.7508 Q2622.43 73.7508 2618.46 73.0216 Q2614.53 72.3329 2610.16 70.9151 L2610.16 63.2184 Q2614.29 65.3654 2618.3 66.4591 Q2622.31 67.5124 2626.24 67.5124 Q2631.5 67.5124 2634.34 65.73 Q2637.17 63.9071 2637.17 60.6258 Q2637.17 57.5877 2635.11 55.9673 Q2633.08 54.3469 2626.16 52.8481 L2623.56 52.2405 Q2616.64 50.7821 2613.56 47.7845 Q2610.48 44.7463 2610.48 39.4801 Q2610.48 33.0797 2615.02 29.5959 Q2619.55 26.1121 2627.9 26.1121 Q2632.03 26.1121 2635.68 26.7198 Q2639.32 27.3274 2642.4 28.5427 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><circle clip-path="url(#clip253)" cx="1878.04" cy="460.897" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="1915.93" cy="665.591" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="1953.83" cy="834.264" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="1991.72" cy="892.522" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="2029.62" cy="1001.37" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="2067.52" cy="1044.41" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="2105.41" cy="1098.42" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="2143.31" cy="1171.23" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="2181.2" cy="1227.91" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="2219.1" cy="1306.45" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="2304.36" cy="581.429" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="2389.63" cy="737.411" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="2474.9" cy="809.348" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="2560.16" cy="911.94" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="2645.43" cy="988.95" r="14.4" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="2730.69" cy="815.512" r="14.4" fill="#3da44d" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="2901.22" cy="976.106" r="14.4" fill="#3da44d" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip253)" cx="3071.75" cy="1105.8" r="14.4" fill="#3da44d" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<path clip-path="url(#clip250)" d="M2239.26 367.552 L2710.53 367.552 L2710.53 108.352 L2239.26 108.352  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<polyline clip-path="url(#clip250)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2239.26,367.552 2710.53,367.552 2710.53,108.352 2239.26,108.352 2239.26,367.552 "/>
<circle clip-path="url(#clip250)" cx="2299.52" cy="160.192" r="20.48" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="4.55111"/>
<path clip-path="url(#clip250)" d="M2359.77 142.912 L2364.45 142.912 L2364.45 177.472 L2359.77 177.472 L2359.77 142.912 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2388.59 155.528 Q2387.87 155.111 2387.02 154.926 Q2386.18 154.718 2385.17 154.718 Q2381.55 154.718 2379.61 157.079 Q2377.69 159.417 2377.69 163.815 L2377.69 177.472 L2373.41 177.472 L2373.41 151.546 L2377.69 151.546 L2377.69 155.574 Q2379.03 153.213 2381.18 152.079 Q2383.34 150.921 2386.42 150.921 Q2386.85 150.921 2387.39 150.991 Q2387.92 151.037 2388.57 151.153 L2388.59 155.528 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2407.25 155.528 Q2406.53 155.111 2405.67 154.926 Q2404.84 154.718 2403.82 154.718 Q2400.21 154.718 2398.27 157.079 Q2396.35 159.417 2396.35 163.815 L2396.35 177.472 L2392.06 177.472 L2392.06 151.546 L2396.35 151.546 L2396.35 155.574 Q2397.69 153.213 2399.84 152.079 Q2401.99 150.921 2405.07 150.921 Q2405.51 150.921 2406.04 150.991 Q2406.58 151.037 2407.23 151.153 L2407.25 155.528 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2432.85 163.444 L2432.85 165.528 L2413.27 165.528 Q2413.54 169.926 2415.91 172.241 Q2418.29 174.532 2422.53 174.532 Q2424.98 174.532 2427.27 173.93 Q2429.59 173.329 2431.85 172.125 L2431.85 176.153 Q2429.56 177.125 2427.16 177.634 Q2424.75 178.143 2422.27 178.143 Q2416.07 178.143 2412.43 174.532 Q2408.82 170.921 2408.82 164.764 Q2408.82 158.398 2412.25 154.671 Q2415.7 150.921 2421.53 150.921 Q2426.76 150.921 2429.79 154.301 Q2432.85 157.657 2432.85 163.444 M2428.59 162.194 Q2428.54 158.699 2426.62 156.616 Q2424.73 154.532 2421.58 154.532 Q2418.01 154.532 2415.86 156.546 Q2413.73 158.56 2413.41 162.218 L2428.59 162.194 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2443.96 173.583 L2443.96 187.333 L2439.68 187.333 L2439.68 151.546 L2443.96 151.546 L2443.96 155.482 Q2445.3 153.167 2447.34 152.056 Q2449.4 150.921 2452.25 150.921 Q2456.97 150.921 2459.91 154.671 Q2462.87 158.421 2462.87 164.532 Q2462.87 170.643 2459.91 174.393 Q2456.97 178.143 2452.25 178.143 Q2449.4 178.143 2447.34 177.032 Q2445.3 175.898 2443.96 173.583 M2458.45 164.532 Q2458.45 159.833 2456.51 157.171 Q2454.59 154.486 2451.21 154.486 Q2447.83 154.486 2445.88 157.171 Q2443.96 159.833 2443.96 164.532 Q2443.96 169.231 2445.88 171.917 Q2447.83 174.579 2451.21 174.579 Q2454.59 174.579 2456.51 171.917 Q2458.45 169.231 2458.45 164.532 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2469.54 141.454 L2479.35 141.454 L2479.35 144.764 L2473.8 144.764 L2473.8 180.412 L2479.35 180.412 L2479.35 183.722 L2469.54 183.722 L2469.54 141.454 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2509.33 144.046 L2509.33 148.607 Q2506.67 147.333 2504.31 146.708 Q2501.95 146.083 2499.75 146.083 Q2495.93 146.083 2493.85 147.565 Q2491.78 149.046 2491.78 151.778 Q2491.78 154.069 2493.15 155.25 Q2494.54 156.407 2498.38 157.125 L2501.21 157.704 Q2506.44 158.699 2508.91 161.222 Q2511.41 163.722 2511.41 167.935 Q2511.41 172.958 2508.03 175.551 Q2504.68 178.143 2498.17 178.143 Q2495.72 178.143 2492.94 177.588 Q2490.19 177.032 2487.22 175.944 L2487.22 171.13 Q2490.07 172.727 2492.8 173.537 Q2495.53 174.347 2498.17 174.347 Q2502.18 174.347 2504.35 172.773 Q2506.53 171.199 2506.53 168.282 Q2506.53 165.736 2504.96 164.301 Q2503.41 162.866 2499.84 162.148 L2496.99 161.593 Q2491.76 160.551 2489.42 158.329 Q2487.09 156.106 2487.09 152.148 Q2487.09 147.565 2490.3 144.926 Q2493.54 142.287 2499.22 142.287 Q2501.65 142.287 2504.17 142.727 Q2506.69 143.167 2509.33 144.046 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2518.17 142.912 L2522.87 142.912 L2522.87 163.907 Q2522.87 169.463 2524.89 171.917 Q2526.9 174.347 2531.41 174.347 Q2535.9 174.347 2537.92 171.917 Q2539.93 169.463 2539.93 163.907 L2539.93 142.912 L2544.63 142.912 L2544.63 164.486 Q2544.63 171.245 2541.28 174.694 Q2537.94 178.143 2531.41 178.143 Q2524.86 178.143 2521.51 174.694 Q2518.17 171.245 2518.17 164.486 L2518.17 142.912 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2554.96 174.833 L2564.77 174.833 L2564.77 177.472 L2550.93 177.472 L2550.93 174.926 Q2551.72 174.208 2553.17 172.912 Q2561.14 165.852 2561.14 163.676 Q2561.14 162.148 2559.93 161.222 Q2558.73 160.273 2556.76 160.273 Q2555.56 160.273 2554.15 160.69 Q2552.73 161.083 2551.07 161.894 L2551.07 159.046 Q2552.85 158.398 2554.38 158.074 Q2555.93 157.75 2557.25 157.75 Q2560.6 157.75 2562.62 159.278 Q2564.63 160.806 2564.63 163.306 Q2564.63 166.523 2556.97 173.097 Q2555.67 174.208 2554.96 174.833 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2582.18 141.454 L2582.18 183.722 L2572.36 183.722 L2572.36 180.412 L2577.9 180.412 L2577.9 144.764 L2572.36 144.764 L2572.36 141.454 L2582.18 141.454 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2600.95 141.5 Q2597.85 146.824 2596.34 152.032 Q2594.84 157.241 2594.84 162.588 Q2594.84 167.935 2596.34 173.19 Q2597.87 178.421 2600.95 183.722 L2597.25 183.722 Q2593.78 178.282 2592.04 173.028 Q2590.33 167.773 2590.33 162.588 Q2590.33 157.426 2592.04 152.194 Q2593.75 146.963 2597.25 141.5 L2600.95 141.5 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2610.63 173.537 L2618.27 173.537 L2618.27 147.171 L2609.96 148.838 L2609.96 144.579 L2618.22 142.912 L2622.9 142.912 L2622.9 173.537 L2630.53 173.537 L2630.53 177.472 L2610.63 177.472 L2610.63 173.537 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2646.95 142.912 L2650.88 142.912 L2638.84 181.87 L2634.91 181.87 L2646.95 142.912 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2659.98 173.537 L2676.3 173.537 L2676.3 177.472 L2654.35 177.472 L2654.35 173.537 Q2657.02 170.782 2661.6 166.153 Q2666.21 161.5 2667.39 160.157 Q2669.63 157.634 2670.51 155.898 Q2671.41 154.139 2671.41 152.449 Q2671.41 149.694 2669.47 147.958 Q2667.55 146.222 2664.45 146.222 Q2662.25 146.222 2659.79 146.986 Q2657.36 147.75 2654.58 149.301 L2654.58 144.579 Q2657.41 143.445 2659.86 142.866 Q2662.32 142.287 2664.35 142.287 Q2669.72 142.287 2672.92 144.972 Q2676.11 147.657 2676.11 152.148 Q2676.11 154.278 2675.3 156.199 Q2674.52 158.097 2672.41 160.69 Q2671.83 161.361 2668.73 164.579 Q2665.63 167.773 2659.98 173.537 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2684.84 141.5 L2688.54 141.5 Q2692.02 146.963 2693.73 152.194 Q2695.46 157.426 2695.46 162.588 Q2695.46 167.773 2693.73 173.028 Q2692.02 178.282 2688.54 183.722 L2684.84 183.722 Q2687.92 178.421 2689.42 173.19 Q2690.95 167.935 2690.95 162.588 Q2690.95 157.241 2689.42 152.032 Q2687.92 146.824 2684.84 141.5 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><circle clip-path="url(#clip250)" cx="2299.52" cy="212.032" r="20.48" fill="#e26f46" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="4.55111"/>
<path clip-path="url(#clip250)" d="M2359.77 194.752 L2364.45 194.752 L2364.45 229.312 L2359.77 229.312 L2359.77 194.752 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2388.59 207.368 Q2387.87 206.951 2387.02 206.766 Q2386.18 206.558 2385.17 206.558 Q2381.55 206.558 2379.61 208.919 Q2377.69 211.257 2377.69 215.655 L2377.69 229.312 L2373.41 229.312 L2373.41 203.386 L2377.69 203.386 L2377.69 207.414 Q2379.03 205.053 2381.18 203.919 Q2383.34 202.761 2386.42 202.761 Q2386.85 202.761 2387.39 202.831 Q2387.92 202.877 2388.57 202.993 L2388.59 207.368 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2407.25 207.368 Q2406.53 206.951 2405.67 206.766 Q2404.84 206.558 2403.82 206.558 Q2400.21 206.558 2398.27 208.919 Q2396.35 211.257 2396.35 215.655 L2396.35 229.312 L2392.06 229.312 L2392.06 203.386 L2396.35 203.386 L2396.35 207.414 Q2397.69 205.053 2399.84 203.919 Q2401.99 202.761 2405.07 202.761 Q2405.51 202.761 2406.04 202.831 Q2406.58 202.877 2407.23 202.993 L2407.25 207.368 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2432.85 215.284 L2432.85 217.368 L2413.27 217.368 Q2413.54 221.766 2415.91 224.081 Q2418.29 226.372 2422.53 226.372 Q2424.98 226.372 2427.27 225.77 Q2429.59 225.169 2431.85 223.965 L2431.85 227.993 Q2429.56 228.965 2427.16 229.474 Q2424.75 229.983 2422.27 229.983 Q2416.07 229.983 2412.43 226.372 Q2408.82 222.761 2408.82 216.604 Q2408.82 210.238 2412.25 206.511 Q2415.7 202.761 2421.53 202.761 Q2426.76 202.761 2429.79 206.141 Q2432.85 209.497 2432.85 215.284 M2428.59 214.034 Q2428.54 210.539 2426.62 208.456 Q2424.73 206.372 2421.58 206.372 Q2418.01 206.372 2415.86 208.386 Q2413.73 210.4 2413.41 214.058 L2428.59 214.034 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2443.96 225.423 L2443.96 239.173 L2439.68 239.173 L2439.68 203.386 L2443.96 203.386 L2443.96 207.322 Q2445.3 205.007 2447.34 203.896 Q2449.4 202.761 2452.25 202.761 Q2456.97 202.761 2459.91 206.511 Q2462.87 210.261 2462.87 216.372 Q2462.87 222.483 2459.91 226.233 Q2456.97 229.983 2452.25 229.983 Q2449.4 229.983 2447.34 228.872 Q2445.3 227.738 2443.96 225.423 M2458.45 216.372 Q2458.45 211.673 2456.51 209.011 Q2454.59 206.326 2451.21 206.326 Q2447.83 206.326 2445.88 209.011 Q2443.96 211.673 2443.96 216.372 Q2443.96 221.071 2445.88 223.757 Q2447.83 226.419 2451.21 226.419 Q2454.59 226.419 2456.51 223.757 Q2458.45 221.071 2458.45 216.372 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2469.54 193.294 L2479.35 193.294 L2479.35 196.604 L2473.8 196.604 L2473.8 232.252 L2479.35 232.252 L2479.35 235.562 L2469.54 235.562 L2469.54 193.294 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2509.33 195.886 L2509.33 200.447 Q2506.67 199.173 2504.31 198.548 Q2501.95 197.923 2499.75 197.923 Q2495.93 197.923 2493.85 199.405 Q2491.78 200.886 2491.78 203.618 Q2491.78 205.909 2493.15 207.09 Q2494.54 208.247 2498.38 208.965 L2501.21 209.544 Q2506.44 210.539 2508.91 213.062 Q2511.41 215.562 2511.41 219.775 Q2511.41 224.798 2508.03 227.391 Q2504.68 229.983 2498.17 229.983 Q2495.72 229.983 2492.94 229.428 Q2490.19 228.872 2487.22 227.784 L2487.22 222.97 Q2490.07 224.567 2492.8 225.377 Q2495.53 226.187 2498.17 226.187 Q2502.18 226.187 2504.35 224.613 Q2506.53 223.039 2506.53 220.122 Q2506.53 217.576 2504.96 216.141 Q2503.41 214.706 2499.84 213.988 L2496.99 213.433 Q2491.76 212.391 2489.42 210.169 Q2487.09 207.946 2487.09 203.988 Q2487.09 199.405 2490.3 196.766 Q2493.54 194.127 2499.22 194.127 Q2501.65 194.127 2504.17 194.567 Q2506.69 195.007 2509.33 195.886 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2518.17 194.752 L2522.87 194.752 L2522.87 215.747 Q2522.87 221.303 2524.89 223.757 Q2526.9 226.187 2531.41 226.187 Q2535.9 226.187 2537.92 223.757 Q2539.93 221.303 2539.93 215.747 L2539.93 194.752 L2544.63 194.752 L2544.63 216.326 Q2544.63 223.085 2541.28 226.534 Q2537.94 229.983 2531.41 229.983 Q2524.86 229.983 2521.51 226.534 Q2518.17 223.085 2518.17 216.326 L2518.17 194.752 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2554.96 226.673 L2564.77 226.673 L2564.77 229.312 L2550.93 229.312 L2550.93 226.766 Q2551.72 226.048 2553.17 224.752 Q2561.14 217.692 2561.14 215.516 Q2561.14 213.988 2559.93 213.062 Q2558.73 212.113 2556.76 212.113 Q2555.56 212.113 2554.15 212.53 Q2552.73 212.923 2551.07 213.734 L2551.07 210.886 Q2552.85 210.238 2554.38 209.914 Q2555.93 209.59 2557.25 209.59 Q2560.6 209.59 2562.62 211.118 Q2564.63 212.646 2564.63 215.146 Q2564.63 218.363 2556.97 224.937 Q2555.67 226.048 2554.96 226.673 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2582.18 193.294 L2582.18 235.562 L2572.36 235.562 L2572.36 232.252 L2577.9 232.252 L2577.9 196.604 L2572.36 196.604 L2572.36 193.294 L2582.18 193.294 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2600.95 193.34 Q2597.85 198.664 2596.34 203.872 Q2594.84 209.081 2594.84 214.428 Q2594.84 219.775 2596.34 225.03 Q2597.87 230.261 2600.95 235.562 L2597.25 235.562 Q2593.78 230.122 2592.04 224.868 Q2590.33 219.613 2590.33 214.428 Q2590.33 209.266 2592.04 204.034 Q2593.75 198.803 2597.25 193.34 L2600.95 193.34 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2623.98 210.678 Q2627.34 211.396 2629.21 213.664 Q2631.11 215.933 2631.11 219.266 Q2631.11 224.382 2627.59 227.183 Q2624.08 229.983 2617.59 229.983 Q2615.42 229.983 2613.1 229.544 Q2610.81 229.127 2608.36 228.27 L2608.36 223.757 Q2610.3 224.891 2612.62 225.47 Q2614.93 226.048 2617.46 226.048 Q2621.85 226.048 2624.15 224.312 Q2626.46 222.576 2626.46 219.266 Q2626.46 216.21 2624.31 214.497 Q2622.18 212.761 2618.36 212.761 L2614.33 212.761 L2614.33 208.919 L2618.54 208.919 Q2621.99 208.919 2623.82 207.553 Q2625.65 206.164 2625.65 203.572 Q2625.65 200.91 2623.75 199.497 Q2621.88 198.062 2618.36 198.062 Q2616.44 198.062 2614.24 198.479 Q2612.04 198.896 2609.4 199.775 L2609.4 195.609 Q2612.06 194.868 2614.38 194.497 Q2616.71 194.127 2618.77 194.127 Q2624.1 194.127 2627.2 196.558 Q2630.3 198.965 2630.3 203.085 Q2630.3 205.956 2628.66 207.946 Q2627.02 209.914 2623.98 210.678 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2646.95 194.752 L2650.88 194.752 L2638.84 233.71 L2634.91 233.71 L2646.95 194.752 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2659.98 225.377 L2676.3 225.377 L2676.3 229.312 L2654.35 229.312 L2654.35 225.377 Q2657.02 222.622 2661.6 217.993 Q2666.21 213.34 2667.39 211.997 Q2669.63 209.474 2670.51 207.738 Q2671.41 205.979 2671.41 204.289 Q2671.41 201.534 2669.47 199.798 Q2667.55 198.062 2664.45 198.062 Q2662.25 198.062 2659.79 198.826 Q2657.36 199.59 2654.58 201.141 L2654.58 196.419 Q2657.41 195.285 2659.86 194.706 Q2662.32 194.127 2664.35 194.127 Q2669.72 194.127 2672.92 196.812 Q2676.11 199.497 2676.11 203.988 Q2676.11 206.118 2675.3 208.039 Q2674.52 209.937 2672.41 212.53 Q2671.83 213.201 2668.73 216.419 Q2665.63 219.613 2659.98 225.377 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2684.84 193.34 L2688.54 193.34 Q2692.02 198.803 2693.73 204.034 Q2695.46 209.266 2695.46 214.428 Q2695.46 219.613 2693.73 224.868 Q2692.02 230.122 2688.54 235.562 L2684.84 235.562 Q2687.92 230.261 2689.42 225.03 Q2690.95 219.775 2690.95 214.428 Q2690.95 209.081 2689.42 203.872 Q2687.92 198.664 2684.84 193.34 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><circle clip-path="url(#clip250)" cx="2299.52" cy="263.872" r="20.48" fill="#3da44d" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="4.55111"/>
<path clip-path="url(#clip250)" d="M2359.77 246.592 L2364.45 246.592 L2364.45 281.152 L2359.77 281.152 L2359.77 246.592 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2388.59 259.208 Q2387.87 258.791 2387.02 258.606 Q2386.18 258.398 2385.17 258.398 Q2381.55 258.398 2379.61 260.759 Q2377.69 263.097 2377.69 267.495 L2377.69 281.152 L2373.41 281.152 L2373.41 255.226 L2377.69 255.226 L2377.69 259.254 Q2379.03 256.893 2381.18 255.759 Q2383.34 254.601 2386.42 254.601 Q2386.85 254.601 2387.39 254.671 Q2387.92 254.717 2388.57 254.833 L2388.59 259.208 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2407.25 259.208 Q2406.53 258.791 2405.67 258.606 Q2404.84 258.398 2403.82 258.398 Q2400.21 258.398 2398.27 260.759 Q2396.35 263.097 2396.35 267.495 L2396.35 281.152 L2392.06 281.152 L2392.06 255.226 L2396.35 255.226 L2396.35 259.254 Q2397.69 256.893 2399.84 255.759 Q2401.99 254.601 2405.07 254.601 Q2405.51 254.601 2406.04 254.671 Q2406.58 254.717 2407.23 254.833 L2407.25 259.208 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2432.85 267.124 L2432.85 269.208 L2413.27 269.208 Q2413.54 273.606 2415.91 275.921 Q2418.29 278.212 2422.53 278.212 Q2424.98 278.212 2427.27 277.61 Q2429.59 277.009 2431.85 275.805 L2431.85 279.833 Q2429.56 280.805 2427.16 281.314 Q2424.75 281.823 2422.27 281.823 Q2416.07 281.823 2412.43 278.212 Q2408.82 274.601 2408.82 268.444 Q2408.82 262.078 2412.25 258.351 Q2415.7 254.601 2421.53 254.601 Q2426.76 254.601 2429.79 257.981 Q2432.85 261.337 2432.85 267.124 M2428.59 265.874 Q2428.54 262.379 2426.62 260.296 Q2424.73 258.212 2421.58 258.212 Q2418.01 258.212 2415.86 260.226 Q2413.73 262.24 2413.41 265.898 L2428.59 265.874 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2443.96 277.263 L2443.96 291.013 L2439.68 291.013 L2439.68 255.226 L2443.96 255.226 L2443.96 259.162 Q2445.3 256.847 2447.34 255.736 Q2449.4 254.601 2452.25 254.601 Q2456.97 254.601 2459.91 258.351 Q2462.87 262.101 2462.87 268.212 Q2462.87 274.323 2459.91 278.073 Q2456.97 281.823 2452.25 281.823 Q2449.4 281.823 2447.34 280.712 Q2445.3 279.578 2443.96 277.263 M2458.45 268.212 Q2458.45 263.513 2456.51 260.851 Q2454.59 258.166 2451.21 258.166 Q2447.83 258.166 2445.88 260.851 Q2443.96 263.513 2443.96 268.212 Q2443.96 272.911 2445.88 275.597 Q2447.83 278.259 2451.21 278.259 Q2454.59 278.259 2456.51 275.597 Q2458.45 272.911 2458.45 268.212 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2469.54 245.134 L2479.35 245.134 L2479.35 248.444 L2473.8 248.444 L2473.8 284.092 L2479.35 284.092 L2479.35 287.402 L2469.54 287.402 L2469.54 245.134 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2509.33 247.726 L2509.33 252.287 Q2506.67 251.013 2504.31 250.388 Q2501.95 249.763 2499.75 249.763 Q2495.93 249.763 2493.85 251.245 Q2491.78 252.726 2491.78 255.458 Q2491.78 257.749 2493.15 258.93 Q2494.54 260.087 2498.38 260.805 L2501.21 261.384 Q2506.44 262.379 2508.91 264.902 Q2511.41 267.402 2511.41 271.615 Q2511.41 276.638 2508.03 279.231 Q2504.68 281.823 2498.17 281.823 Q2495.72 281.823 2492.94 281.268 Q2490.19 280.712 2487.22 279.624 L2487.22 274.81 Q2490.07 276.407 2492.8 277.217 Q2495.53 278.027 2498.17 278.027 Q2502.18 278.027 2504.35 276.453 Q2506.53 274.879 2506.53 271.962 Q2506.53 269.416 2504.96 267.981 Q2503.41 266.546 2499.84 265.828 L2496.99 265.273 Q2491.76 264.231 2489.42 262.009 Q2487.09 259.786 2487.09 255.828 Q2487.09 251.245 2490.3 248.606 Q2493.54 245.967 2499.22 245.967 Q2501.65 245.967 2504.17 246.407 Q2506.69 246.847 2509.33 247.726 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2518.17 246.592 L2522.87 246.592 L2522.87 267.587 Q2522.87 273.143 2524.89 275.597 Q2526.9 278.027 2531.41 278.027 Q2535.9 278.027 2537.92 275.597 Q2539.93 273.143 2539.93 267.587 L2539.93 246.592 L2544.63 246.592 L2544.63 268.166 Q2544.63 274.925 2541.28 278.374 Q2537.94 281.823 2531.41 281.823 Q2524.86 281.823 2521.51 278.374 Q2518.17 274.925 2518.17 268.166 L2518.17 246.592 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2554.96 278.513 L2564.77 278.513 L2564.77 281.152 L2550.93 281.152 L2550.93 278.606 Q2551.72 277.888 2553.17 276.592 Q2561.14 269.532 2561.14 267.356 Q2561.14 265.828 2559.93 264.902 Q2558.73 263.953 2556.76 263.953 Q2555.56 263.953 2554.15 264.37 Q2552.73 264.763 2551.07 265.574 L2551.07 262.726 Q2552.85 262.078 2554.38 261.754 Q2555.93 261.43 2557.25 261.43 Q2560.6 261.43 2562.62 262.958 Q2564.63 264.486 2564.63 266.986 Q2564.63 270.203 2556.97 276.777 Q2555.67 277.888 2554.96 278.513 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2582.18 245.134 L2582.18 287.402 L2572.36 287.402 L2572.36 284.092 L2577.9 284.092 L2577.9 248.444 L2572.36 248.444 L2572.36 245.134 L2582.18 245.134 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2600.95 245.18 Q2597.85 250.504 2596.34 255.712 Q2594.84 260.921 2594.84 266.268 Q2594.84 271.615 2596.34 276.87 Q2597.87 282.101 2600.95 287.402 L2597.25 287.402 Q2593.78 281.962 2592.04 276.708 Q2590.33 271.453 2590.33 266.268 Q2590.33 261.106 2592.04 255.874 Q2593.75 250.643 2597.25 245.18 L2600.95 245.18 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2609.86 246.592 L2628.22 246.592 L2628.22 250.527 L2614.15 250.527 L2614.15 258.999 Q2615.16 258.652 2616.18 258.49 Q2617.2 258.305 2618.22 258.305 Q2624.01 258.305 2627.39 261.476 Q2630.77 264.648 2630.77 270.064 Q2630.77 275.643 2627.29 278.745 Q2623.82 281.823 2617.5 281.823 Q2615.33 281.823 2613.06 281.453 Q2610.81 281.083 2608.4 280.342 L2608.4 275.643 Q2610.49 276.777 2612.71 277.333 Q2614.93 277.888 2617.41 277.888 Q2621.41 277.888 2623.75 275.782 Q2626.09 273.675 2626.09 270.064 Q2626.09 266.453 2623.75 264.347 Q2621.41 262.24 2617.41 262.24 Q2615.53 262.24 2613.66 262.657 Q2611.81 263.074 2609.86 263.953 L2609.86 246.592 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2646.95 246.592 L2650.88 246.592 L2638.84 285.55 L2634.91 285.55 L2646.95 246.592 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2659.98 277.217 L2676.3 277.217 L2676.3 281.152 L2654.35 281.152 L2654.35 277.217 Q2657.02 274.462 2661.6 269.833 Q2666.21 265.18 2667.39 263.837 Q2669.63 261.314 2670.51 259.578 Q2671.41 257.819 2671.41 256.129 Q2671.41 253.374 2669.47 251.638 Q2667.55 249.902 2664.45 249.902 Q2662.25 249.902 2659.79 250.666 Q2657.36 251.43 2654.58 252.981 L2654.58 248.259 Q2657.41 247.125 2659.86 246.546 Q2662.32 245.967 2664.35 245.967 Q2669.72 245.967 2672.92 248.652 Q2676.11 251.337 2676.11 255.828 Q2676.11 257.958 2675.3 259.879 Q2674.52 261.777 2672.41 264.37 Q2671.83 265.041 2668.73 268.259 Q2665.63 271.453 2659.98 277.217 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2684.84 245.18 L2688.54 245.18 Q2692.02 250.643 2693.73 255.874 Q2695.46 261.106 2695.46 266.268 Q2695.46 271.453 2693.73 276.708 Q2692.02 281.962 2688.54 287.402 L2684.84 287.402 Q2687.92 282.101 2689.42 276.87 Q2690.95 271.615 2690.95 266.268 Q2690.95 260.921 2689.42 255.712 Q2687.92 250.504 2684.84 245.18 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip250)" style="stroke:#c271d2; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2254.33,315.712 2344.71,315.712 "/>
<path clip-path="url(#clip250)" d="M2373.61 335.4 Q2371.81 340.029 2370.1 341.441 Q2368.38 342.853 2365.51 342.853 L2362.11 342.853 L2362.11 339.288 L2364.61 339.288 Q2366.37 339.288 2367.34 338.455 Q2368.31 337.622 2369.49 334.52 L2370.26 332.575 L2359.77 307.066 L2364.29 307.066 L2372.39 327.344 L2380.49 307.066 L2385 307.066 L2373.61 335.4 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip250)" d="M2404.33 302.506 L2392.53 320.955 L2404.33 320.955 L2404.33 302.506 M2403.1 298.432 L2408.98 298.432 L2408.98 320.955 L2413.91 320.955 L2413.91 324.844 L2408.98 324.844 L2408.98 332.992 L2404.33 332.992 L2404.33 324.844 L2388.73 324.844 L2388.73 320.33 L2403.1 298.432 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /></svg>

```

As we can see, the groundstate can be found in the non-trivial SPT phase, $\ket{\psi_-}$. We
can obtain an intuitive understanding of $\ket{\psi_+}$ by considering the following
diagram. If we denote the MPS tensors that make up the groundstate as $A_-$, we can
construct a state in the trivial SPT phase that approximates the groundstate as follows:

![spt-tensors.svg](spt-tensors.svg)

In other words, we can factorize a purely virtual isomorphism of $S = 1/2$ in order to
obtain the groundstate. This then also explains the degeneracies in the entanglement
spectrum as well as in the transfer matrix spectrum. Finally, we can further confirm this
intuition by looking at the entanglement entropy of the groundstate. As we can see, the
entanglement entropy of the state in the wrong SPT phase is exactly $log(2)$ higher than the
one in the right SPT phase, which is exactly what we would expect from the diagram above.

````julia
S_minus = sum(real, entropy(ψ_minus))
S_plus = sum(real, entropy(ψ_plus))
println("S_minus + log(2) = $(S_minus + log(2))")
println("S_plus = $S_plus")
````

````
S_minus + log(2) = 1.5486227235452001
S_plus = 1.5450323530414614

````

---

*This page was generated using [Literate.jl](https://github.com/fredrikekre/Literate.jl).*

