```@meta
EditURL = "../../../../../examples/classic2d/1.hard-hexagon/main.jl"
```

[![](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/maartenvd/MPSKit.jl/gh-pages?filepath=dev/examples/classic2d/1.hard-hexagon/main.ipynb)
[![](https://img.shields.io/badge/show-nbviewer-579ACA.svg)](https://nbviewer.jupyter.org/github/maartenvd/MPSKit.jl/blob/gh-pages/dev/examples/classic2d/1.hard-hexagon/main.ipynb)
[![](https://img.shields.io/badge/download-project-orange)](https://minhaskamal.github.io/DownGit/#/home?url=https://github.com/maartenvd/MPSKit.jl/examples/tree/gh-pages/dev/examples/classic2d/1.hard-hexagon)

# [The Hard Hexagon model](@id demo_hardhexagon)

![logo](hexagon.svg)

Tensor networks are a natural way to do statistical mechanics on a lattice.
As an example of this we will extract the central charge of the hard hexagon model.
This model is known to have central charge 0.8, and has very peculiar non-local (anyonic) symmetries.
Because TensorKit supports anyonic symmetries, so does MPSKit.
To follow the tutorial you need the following packages.

````julia
using MPSKit, MPSKitModels, TensorKit, Plots, Polynomials
````

The [hard hexagon model](https://en.wikipedia.org/wiki/Hard_hexagon_model) is a 2-dimensional lattice model of a gas, where particles are allowed to be on the vertices of a triangular lattice, but no two particles may be adjacent.
This can be encoded in a transfer matrix with a local MPO tensor using anyonic symmetries, and the resulting MPO has been implemented in MPSKitModels.

In order to use these anyonic symmetries, we need to generalise the notion of the bond dimension and define how it interacts with the symmetry. Thus, we implement away of converting integers to symmetric spaces of the given dimension, which provides a crude guess for how the final MPS would distribute its Schmidt spectrum.

````julia
mpo = hard_hexagon()
P = space(mpo.opp[1], 2)
function virtual_space(D::Integer)
    _D = round(Int, D / sum(dim, values(FibonacciAnyon)))
    return Vect[FibonacciAnyon](sector => _D for sector in (:I, :τ))
end

@assert isapprox(dim(virtual_space(100)), 100; atol=3)
````

## The leading boundary

One way to study statistical mechanics in infinite systems with tensor networks is by approximating the dominant eigenvector of the transfer matrix by an MPS.
This dominant eigenvector contains a lot of hidden information.
For example, the free energy can be extracted by computing the expectation value of the mpo.
Additionally, we can compute the entanglement entropy as well as the correlation length of the state:

````julia
D = 10
V = virtual_space(D)
ψ₀ = InfiniteMPS([P], [V])
ψ, envs, = leading_boundary(ψ₀, mpo, VUMPS(; verbose=false))
F = real(first(expectation_value(ψ, mpo)))
S = real(first(entropy(ψ)))
ξ = correlation_length(ψ)
println("F = $F\tS = $S\tξ = $ξ")
````

````
F = 0.8839037051703853	S = 1.2807829621983249	ξ = 13.84968258247082

````

## The scaling hypothesis

The dominant eigenvector is of course only an approximation. The finite bond dimension enforces a finite correlation length, which effectively introduces a length scale in the system. This can be exploited to formulate a [scaling hypothesis](https://arxiv.org/pdf/0812.2903.pdf), which in turn allows to extract the central charge.

First we need to know the entropy and correlation length at a bunch of different bond dimensions. Our approach will be to re-use the previous approximated dominant eigenvector, and then expanding its bond dimension and re-running VUMPS.
According to the scaling hypothesis we should have ``S \propto \frac{c}{6} log(ξ)``. Therefore we should find ``c`` using

````julia
function scaling_simulations(ψ₀, mpo, Ds; verbose=false, tol=1e-6)
    entropies = similar(Ds, Float64)
    correlations = similar(Ds, Float64)
    alg = VUMPS(; verbose=verbose, tol_galerkin=tol)

    ψ, envs, = leading_boundary(ψ₀, mpo, alg)
    entropies[1] = real(entropy(ψ)[1])
    correlations[1] = correlation_length(ψ)

    for (i, d) in enumerate(diff(Ds))
        ψ, envs = changebonds(ψ, mpo, OptimalExpand(; trscheme=truncdim(d)), envs)
        ψ, envs, = leading_boundary(ψ, mpo, alg, envs)
        entropies[i + 1] = real(entropy(ψ)[1])
        correlations[i + 1] = correlation_length(ψ)
    end
    return entropies, correlations
end

bond_dimensions = 10:5:25
ψ₀ = InfiniteMPS([P], [virtual_space(bond_dimensions[1])])
Ss, ξs = scaling_simulations(ψ₀, mpo, bond_dimensions)

f = fit(log.(ξs), 6 * Ss, 1)
c = f.coeffs[2]
````

````
0.8025379870206183
````

````julia
p = plot(; xlabel="logarithmic correlation length", ylabel="entanglement entropy")
p = plot(log.(ξs), Ss; seriestype=:scatter, label=nothing)
plot!(p, ξ -> f(ξ) / 6; label="fit")
````

```@raw html
<?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="600" height="400" viewBox="0 0 2400 1600">
<defs>
  <clipPath id="clip530">
    <rect x="0" y="0" width="2400" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip530)" d="M0 1600 L2400 1600 L2400 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip531">
    <rect x="480" y="0" width="1681" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip530)" d="M184.191 1486.45 L2352.76 1486.45 L2352.76 47.2441 L184.191 47.2441  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip532">
    <rect x="184" y="47" width="2170" height="1440"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip532)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="401.914,1486.45 401.914,47.2441 "/>
<polyline clip-path="url(#clip532)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="722.706,1486.45 722.706,47.2441 "/>
<polyline clip-path="url(#clip532)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1043.5,1486.45 1043.5,47.2441 "/>
<polyline clip-path="url(#clip532)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1364.29,1486.45 1364.29,47.2441 "/>
<polyline clip-path="url(#clip532)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1685.08,1486.45 1685.08,47.2441 "/>
<polyline clip-path="url(#clip532)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2005.87,1486.45 2005.87,47.2441 "/>
<polyline clip-path="url(#clip532)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2326.67,1486.45 2326.67,47.2441 "/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="184.191,1486.45 2352.76,1486.45 "/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="401.914,1486.45 401.914,1467.55 "/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="722.706,1486.45 722.706,1467.55 "/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1043.5,1486.45 1043.5,1467.55 "/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1364.29,1486.45 1364.29,1467.55 "/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1685.08,1486.45 1685.08,1467.55 "/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2005.87,1486.45 2005.87,1467.55 "/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2326.67,1486.45 2326.67,1467.55 "/>
<path clip-path="url(#clip530)" d="M358.57 1544.91 L374.889 1544.91 L374.889 1548.85 L352.945 1548.85 L352.945 1544.91 Q355.607 1542.16 360.19 1537.53 Q364.796 1532.88 365.977 1531.53 Q368.222 1529.01 369.102 1527.27 Q370.005 1525.51 370.005 1523.82 Q370.005 1521.07 368.06 1519.33 Q366.139 1517.6 363.037 1517.6 Q360.838 1517.6 358.384 1518.36 Q355.954 1519.13 353.176 1520.68 L353.176 1515.95 Q356 1514.82 358.454 1514.24 Q360.908 1513.66 362.945 1513.66 Q368.315 1513.66 371.509 1516.35 Q374.704 1519.03 374.704 1523.52 Q374.704 1525.65 373.894 1527.57 Q373.107 1529.47 371 1532.07 Q370.421 1532.74 367.32 1535.95 Q364.218 1539.15 358.57 1544.91 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M384.704 1542.97 L389.588 1542.97 L389.588 1548.85 L384.704 1548.85 L384.704 1542.97 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M398.593 1514.29 L420.815 1514.29 L420.815 1516.28 L408.268 1548.85 L403.384 1548.85 L415.19 1518.22 L398.593 1518.22 L398.593 1514.29 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M429.981 1514.29 L448.338 1514.29 L448.338 1518.22 L434.264 1518.22 L434.264 1526.7 Q435.282 1526.35 436.301 1526.19 Q437.319 1526 438.338 1526 Q444.125 1526 447.504 1529.17 Q450.884 1532.34 450.884 1537.76 Q450.884 1543.34 447.412 1546.44 Q443.94 1549.52 437.62 1549.52 Q435.444 1549.52 433.176 1549.15 Q430.93 1548.78 428.523 1548.04 L428.523 1543.34 Q430.606 1544.47 432.828 1545.03 Q435.051 1545.58 437.528 1545.58 Q441.532 1545.58 443.87 1543.48 Q446.208 1541.37 446.208 1537.76 Q446.208 1534.15 443.87 1532.04 Q441.532 1529.94 437.528 1529.94 Q435.653 1529.94 433.778 1530.35 Q431.926 1530.77 429.981 1531.65 L429.981 1514.29 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M688.933 1530.21 Q692.29 1530.93 694.165 1533.2 Q696.063 1535.47 696.063 1538.8 Q696.063 1543.92 692.544 1546.72 Q689.026 1549.52 682.544 1549.52 Q680.369 1549.52 678.054 1549.08 Q675.762 1548.66 673.308 1547.81 L673.308 1543.29 Q675.253 1544.43 677.568 1545.01 Q679.882 1545.58 682.406 1545.58 Q686.804 1545.58 689.095 1543.85 Q691.41 1542.11 691.41 1538.8 Q691.41 1535.75 689.257 1534.03 Q687.128 1532.3 683.308 1532.3 L679.281 1532.3 L679.281 1528.45 L683.494 1528.45 Q686.943 1528.45 688.771 1527.09 Q690.6 1525.7 690.6 1523.11 Q690.6 1520.45 688.702 1519.03 Q686.827 1517.6 683.308 1517.6 Q681.387 1517.6 679.188 1518.01 Q676.989 1518.43 674.35 1519.31 L674.35 1515.14 Q677.012 1514.4 679.327 1514.03 Q681.665 1513.66 683.725 1513.66 Q689.049 1513.66 692.151 1516.09 Q695.253 1518.5 695.253 1522.62 Q695.253 1525.49 693.609 1527.48 Q691.966 1529.45 688.933 1530.21 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M704.929 1542.97 L709.813 1542.97 L709.813 1548.85 L704.929 1548.85 L704.929 1542.97 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M729.998 1517.37 Q726.387 1517.37 724.558 1520.93 Q722.753 1524.47 722.753 1531.6 Q722.753 1538.71 724.558 1542.27 Q726.387 1545.82 729.998 1545.82 Q733.632 1545.82 735.438 1542.27 Q737.266 1538.71 737.266 1531.6 Q737.266 1524.47 735.438 1520.93 Q733.632 1517.37 729.998 1517.37 M729.998 1513.66 Q735.808 1513.66 738.864 1518.27 Q741.942 1522.85 741.942 1531.6 Q741.942 1540.33 738.864 1544.94 Q735.808 1549.52 729.998 1549.52 Q724.188 1549.52 721.109 1544.94 Q718.054 1540.33 718.054 1531.6 Q718.054 1522.85 721.109 1518.27 Q724.188 1513.66 729.998 1513.66 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M760.16 1517.37 Q756.549 1517.37 754.72 1520.93 Q752.914 1524.47 752.914 1531.6 Q752.914 1538.71 754.72 1542.27 Q756.549 1545.82 760.16 1545.82 Q763.794 1545.82 765.6 1542.27 Q767.428 1538.71 767.428 1531.6 Q767.428 1524.47 765.6 1520.93 Q763.794 1517.37 760.16 1517.37 M760.16 1513.66 Q765.97 1513.66 769.025 1518.27 Q772.104 1522.85 772.104 1531.6 Q772.104 1540.33 769.025 1544.94 Q765.97 1549.52 760.16 1549.52 Q754.35 1549.52 751.271 1544.94 Q748.215 1540.33 748.215 1531.6 Q748.215 1522.85 751.271 1518.27 Q754.35 1513.66 760.16 1513.66 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M1010.22 1530.21 Q1013.58 1530.93 1015.45 1533.2 Q1017.35 1535.47 1017.35 1538.8 Q1017.35 1543.92 1013.83 1546.72 Q1010.32 1549.52 1003.83 1549.52 Q1001.66 1549.52 999.343 1549.08 Q997.052 1548.66 994.598 1547.81 L994.598 1543.29 Q996.542 1544.43 998.857 1545.01 Q1001.17 1545.58 1003.7 1545.58 Q1008.09 1545.58 1010.38 1543.85 Q1012.7 1542.11 1012.7 1538.8 Q1012.7 1535.75 1010.55 1534.03 Q1008.42 1532.3 1004.6 1532.3 L1000.57 1532.3 L1000.57 1528.45 L1004.78 1528.45 Q1008.23 1528.45 1010.06 1527.09 Q1011.89 1525.7 1011.89 1523.11 Q1011.89 1520.45 1009.99 1519.03 Q1008.12 1517.6 1004.6 1517.6 Q1002.68 1517.6 1000.48 1518.01 Q998.279 1518.43 995.64 1519.31 L995.64 1515.14 Q998.302 1514.4 1000.62 1514.03 Q1002.95 1513.66 1005.01 1513.66 Q1010.34 1513.66 1013.44 1516.09 Q1016.54 1518.5 1016.54 1522.62 Q1016.54 1525.49 1014.9 1527.48 Q1013.26 1529.45 1010.22 1530.21 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M1026.22 1542.97 L1031.1 1542.97 L1031.1 1548.85 L1026.22 1548.85 L1026.22 1542.97 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M1045.32 1544.91 L1061.63 1544.91 L1061.63 1548.85 L1039.69 1548.85 L1039.69 1544.91 Q1042.35 1542.16 1046.94 1537.53 Q1051.54 1532.88 1052.72 1531.53 Q1054.97 1529.01 1055.85 1527.27 Q1056.75 1525.51 1056.75 1523.82 Q1056.75 1521.07 1054.81 1519.33 Q1052.88 1517.6 1049.78 1517.6 Q1047.58 1517.6 1045.13 1518.36 Q1042.7 1519.13 1039.92 1520.68 L1039.92 1515.95 Q1042.75 1514.82 1045.2 1514.24 Q1047.65 1513.66 1049.69 1513.66 Q1055.06 1513.66 1058.26 1516.35 Q1061.45 1519.03 1061.45 1523.52 Q1061.45 1525.65 1060.64 1527.57 Q1059.85 1529.47 1057.75 1532.07 Q1057.17 1532.74 1054.07 1535.95 Q1050.96 1539.15 1045.32 1544.91 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M1071.5 1514.29 L1089.85 1514.29 L1089.85 1518.22 L1075.78 1518.22 L1075.78 1526.7 Q1076.8 1526.35 1077.82 1526.19 Q1078.83 1526 1079.85 1526 Q1085.64 1526 1089.02 1529.17 Q1092.4 1532.34 1092.4 1537.76 Q1092.4 1543.34 1088.93 1546.44 Q1085.45 1549.52 1079.13 1549.52 Q1076.96 1549.52 1074.69 1549.15 Q1072.44 1548.78 1070.04 1548.04 L1070.04 1543.34 Q1072.12 1544.47 1074.34 1545.03 Q1076.57 1545.58 1079.04 1545.58 Q1083.05 1545.58 1085.38 1543.48 Q1087.72 1541.37 1087.72 1537.76 Q1087.72 1534.15 1085.38 1532.04 Q1083.05 1529.94 1079.04 1529.94 Q1077.17 1529.94 1075.29 1530.35 Q1073.44 1530.77 1071.5 1531.65 L1071.5 1514.29 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M1330.52 1530.21 Q1333.87 1530.93 1335.75 1533.2 Q1337.65 1535.47 1337.65 1538.8 Q1337.65 1543.92 1334.13 1546.72 Q1330.61 1549.52 1324.13 1549.52 Q1321.95 1549.52 1319.64 1549.08 Q1317.35 1548.66 1314.89 1547.81 L1314.89 1543.29 Q1316.84 1544.43 1319.15 1545.01 Q1321.47 1545.58 1323.99 1545.58 Q1328.39 1545.58 1330.68 1543.85 Q1332.99 1542.11 1332.99 1538.8 Q1332.99 1535.75 1330.84 1534.03 Q1328.71 1532.3 1324.89 1532.3 L1320.86 1532.3 L1320.86 1528.45 L1325.08 1528.45 Q1328.53 1528.45 1330.36 1527.09 Q1332.18 1525.7 1332.18 1523.11 Q1332.18 1520.45 1330.29 1519.03 Q1328.41 1517.6 1324.89 1517.6 Q1322.97 1517.6 1320.77 1518.01 Q1318.57 1518.43 1315.93 1519.31 L1315.93 1515.14 Q1318.6 1514.4 1320.91 1514.03 Q1323.25 1513.66 1325.31 1513.66 Q1330.63 1513.66 1333.73 1516.09 Q1336.84 1518.5 1336.84 1522.62 Q1336.84 1525.49 1335.19 1527.48 Q1333.55 1529.45 1330.52 1530.21 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M1346.51 1542.97 L1351.4 1542.97 L1351.4 1548.85 L1346.51 1548.85 L1346.51 1542.97 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M1361.63 1514.29 L1379.98 1514.29 L1379.98 1518.22 L1365.91 1518.22 L1365.91 1526.7 Q1366.93 1526.35 1367.95 1526.19 Q1368.97 1526 1369.98 1526 Q1375.77 1526 1379.15 1529.17 Q1382.53 1532.34 1382.53 1537.76 Q1382.53 1543.34 1379.06 1546.44 Q1375.59 1549.52 1369.27 1549.52 Q1367.09 1549.52 1364.82 1549.15 Q1362.58 1548.78 1360.17 1548.04 L1360.17 1543.34 Q1362.25 1544.47 1364.48 1545.03 Q1366.7 1545.58 1369.17 1545.58 Q1373.18 1545.58 1375.52 1543.48 Q1377.85 1541.37 1377.85 1537.76 Q1377.85 1534.15 1375.52 1532.04 Q1373.18 1529.94 1369.17 1529.94 Q1367.3 1529.94 1365.42 1530.35 Q1363.57 1530.77 1361.63 1531.65 L1361.63 1514.29 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M1401.74 1517.37 Q1398.13 1517.37 1396.3 1520.93 Q1394.5 1524.47 1394.5 1531.6 Q1394.5 1538.71 1396.3 1542.27 Q1398.13 1545.82 1401.74 1545.82 Q1405.38 1545.82 1407.18 1542.27 Q1409.01 1538.71 1409.01 1531.6 Q1409.01 1524.47 1407.18 1520.93 Q1405.38 1517.37 1401.74 1517.37 M1401.74 1513.66 Q1407.55 1513.66 1410.61 1518.27 Q1413.69 1522.85 1413.69 1531.6 Q1413.69 1540.33 1410.61 1544.94 Q1407.55 1549.52 1401.74 1549.52 Q1395.93 1549.52 1392.85 1544.94 Q1389.8 1540.33 1389.8 1531.6 Q1389.8 1522.85 1392.85 1518.27 Q1395.93 1513.66 1401.74 1513.66 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M1651.81 1530.21 Q1655.16 1530.93 1657.04 1533.2 Q1658.94 1535.47 1658.94 1538.8 Q1658.94 1543.92 1655.42 1546.72 Q1651.9 1549.52 1645.42 1549.52 Q1643.24 1549.52 1640.93 1549.08 Q1638.64 1548.66 1636.18 1547.81 L1636.18 1543.29 Q1638.13 1544.43 1640.44 1545.01 Q1642.76 1545.58 1645.28 1545.58 Q1649.68 1545.58 1651.97 1543.85 Q1654.28 1542.11 1654.28 1538.8 Q1654.28 1535.75 1652.13 1534.03 Q1650 1532.3 1646.18 1532.3 L1642.15 1532.3 L1642.15 1528.45 L1646.37 1528.45 Q1649.82 1528.45 1651.64 1527.09 Q1653.47 1525.7 1653.47 1523.11 Q1653.47 1520.45 1651.58 1519.03 Q1649.7 1517.6 1646.18 1517.6 Q1644.26 1517.6 1642.06 1518.01 Q1639.86 1518.43 1637.22 1519.31 L1637.22 1515.14 Q1639.89 1514.4 1642.2 1514.03 Q1644.54 1513.66 1646.6 1513.66 Q1651.92 1513.66 1655.02 1516.09 Q1658.13 1518.5 1658.13 1522.62 Q1658.13 1525.49 1656.48 1527.48 Q1654.84 1529.45 1651.81 1530.21 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M1667.8 1542.97 L1672.69 1542.97 L1672.69 1548.85 L1667.8 1548.85 L1667.8 1542.97 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M1681.69 1514.29 L1703.91 1514.29 L1703.91 1516.28 L1691.37 1548.85 L1686.48 1548.85 L1698.29 1518.22 L1681.69 1518.22 L1681.69 1514.29 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M1713.08 1514.29 L1731.44 1514.29 L1731.44 1518.22 L1717.36 1518.22 L1717.36 1526.7 Q1718.38 1526.35 1719.4 1526.19 Q1720.42 1526 1721.44 1526 Q1727.22 1526 1730.6 1529.17 Q1733.98 1532.34 1733.98 1537.76 Q1733.98 1543.34 1730.51 1546.44 Q1727.04 1549.52 1720.72 1549.52 Q1718.54 1549.52 1716.27 1549.15 Q1714.03 1548.78 1711.62 1548.04 L1711.62 1543.34 Q1713.7 1544.47 1715.93 1545.03 Q1718.15 1545.58 1720.63 1545.58 Q1724.63 1545.58 1726.97 1543.48 Q1729.31 1541.37 1729.31 1537.76 Q1729.31 1534.15 1726.97 1532.04 Q1724.63 1529.94 1720.63 1529.94 Q1718.75 1529.94 1716.88 1530.35 Q1715.02 1530.77 1713.08 1531.65 L1713.08 1514.29 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M1971.43 1518.36 L1959.62 1536.81 L1971.43 1536.81 L1971.43 1518.36 M1970.2 1514.29 L1976.08 1514.29 L1976.08 1536.81 L1981.01 1536.81 L1981.01 1540.7 L1976.08 1540.7 L1976.08 1548.85 L1971.43 1548.85 L1971.43 1540.7 L1955.83 1540.7 L1955.83 1536.19 L1970.2 1514.29 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M1988.74 1542.97 L1993.63 1542.97 L1993.63 1548.85 L1988.74 1548.85 L1988.74 1542.97 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M2013.81 1517.37 Q2010.2 1517.37 2008.37 1520.93 Q2006.57 1524.47 2006.57 1531.6 Q2006.57 1538.71 2008.37 1542.27 Q2010.2 1545.82 2013.81 1545.82 Q2017.45 1545.82 2019.25 1542.27 Q2021.08 1538.71 2021.08 1531.6 Q2021.08 1524.47 2019.25 1520.93 Q2017.45 1517.37 2013.81 1517.37 M2013.81 1513.66 Q2019.62 1513.66 2022.68 1518.27 Q2025.76 1522.85 2025.76 1531.6 Q2025.76 1540.33 2022.68 1544.94 Q2019.62 1549.52 2013.81 1549.52 Q2008 1549.52 2004.93 1544.94 Q2001.87 1540.33 2001.87 1531.6 Q2001.87 1522.85 2004.93 1518.27 Q2008 1513.66 2013.81 1513.66 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M2043.98 1517.37 Q2040.36 1517.37 2038.54 1520.93 Q2036.73 1524.47 2036.73 1531.6 Q2036.73 1538.71 2038.54 1542.27 Q2040.36 1545.82 2043.98 1545.82 Q2047.61 1545.82 2049.42 1542.27 Q2051.24 1538.71 2051.24 1531.6 Q2051.24 1524.47 2049.42 1520.93 Q2047.61 1517.37 2043.98 1517.37 M2043.98 1513.66 Q2049.79 1513.66 2052.84 1518.27 Q2055.92 1522.85 2055.92 1531.6 Q2055.92 1540.33 2052.84 1544.94 Q2049.79 1549.52 2043.98 1549.52 Q2038.17 1549.52 2035.09 1544.94 Q2032.03 1540.33 2032.03 1531.6 Q2032.03 1522.85 2035.09 1518.27 Q2038.17 1513.66 2043.98 1513.66 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M2292.72 1518.36 L2280.91 1536.81 L2292.72 1536.81 L2292.72 1518.36 M2291.49 1514.29 L2297.37 1514.29 L2297.37 1536.81 L2302.3 1536.81 L2302.3 1540.7 L2297.37 1540.7 L2297.37 1548.85 L2292.72 1548.85 L2292.72 1540.7 L2277.12 1540.7 L2277.12 1536.19 L2291.49 1514.29 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M2310.03 1542.97 L2314.92 1542.97 L2314.92 1548.85 L2310.03 1548.85 L2310.03 1542.97 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M2329.13 1544.91 L2345.45 1544.91 L2345.45 1548.85 L2323.51 1548.85 L2323.51 1544.91 Q2326.17 1542.16 2330.75 1537.53 Q2335.36 1532.88 2336.54 1531.53 Q2338.78 1529.01 2339.66 1527.27 Q2340.57 1525.51 2340.57 1523.82 Q2340.57 1521.07 2338.62 1519.33 Q2336.7 1517.6 2333.6 1517.6 Q2331.4 1517.6 2328.95 1518.36 Q2326.52 1519.13 2323.74 1520.68 L2323.74 1515.95 Q2326.56 1514.82 2329.02 1514.24 Q2331.47 1513.66 2333.51 1513.66 Q2338.88 1513.66 2342.07 1516.35 Q2345.27 1519.03 2345.27 1523.52 Q2345.27 1525.65 2344.46 1527.57 Q2343.67 1529.47 2341.56 1532.07 Q2340.98 1532.74 2337.88 1535.95 Q2334.78 1539.15 2329.13 1544.91 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M2355.31 1514.29 L2373.67 1514.29 L2373.67 1518.22 L2359.59 1518.22 L2359.59 1526.7 Q2360.61 1526.35 2361.63 1526.19 Q2362.65 1526 2363.67 1526 Q2369.46 1526 2372.83 1529.17 Q2376.21 1532.34 2376.21 1537.76 Q2376.21 1543.34 2372.74 1546.44 Q2369.27 1549.52 2362.95 1549.52 Q2360.77 1549.52 2358.51 1549.15 Q2356.26 1548.78 2353.85 1548.04 L2353.85 1543.34 Q2355.94 1544.47 2358.16 1545.03 Q2360.38 1545.58 2362.86 1545.58 Q2366.86 1545.58 2369.2 1543.48 Q2371.54 1541.37 2371.54 1537.76 Q2371.54 1534.15 2369.2 1532.04 Q2366.86 1529.94 2362.86 1529.94 Q2360.98 1529.94 2359.11 1530.35 Q2357.26 1530.77 2355.31 1531.65 L2355.31 1514.29 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip532)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="184.191,1323.89 2352.76,1323.89 "/>
<polyline clip-path="url(#clip532)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="184.191,1007.22 2352.76,1007.22 "/>
<polyline clip-path="url(#clip532)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="184.191,690.562 2352.76,690.562 "/>
<polyline clip-path="url(#clip532)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="184.191,373.9 2352.76,373.9 "/>
<polyline clip-path="url(#clip532)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="184.191,57.2385 2352.76,57.2385 "/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="184.191,1486.45 184.191,47.2441 "/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="184.191,1323.89 203.088,1323.89 "/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="184.191,1007.22 203.088,1007.22 "/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="184.191,690.562 203.088,690.562 "/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="184.191,373.9 203.088,373.9 "/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="184.191,57.2385 203.088,57.2385 "/>
<path clip-path="url(#clip530)" d="M51.6634 1337.23 L59.3023 1337.23 L59.3023 1310.86 L50.9921 1312.53 L50.9921 1308.27 L59.256 1306.61 L63.9319 1306.61 L63.9319 1337.23 L71.5707 1337.23 L71.5707 1341.17 L51.6634 1341.17 L51.6634 1337.23 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M81.0151 1335.29 L85.8993 1335.29 L85.8993 1341.17 L81.0151 1341.17 L81.0151 1335.29 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M110.251 1322.53 Q113.608 1323.25 115.483 1325.52 Q117.381 1327.79 117.381 1331.12 Q117.381 1336.23 113.862 1339.04 Q110.344 1341.84 103.862 1341.84 Q101.686 1341.84 99.3715 1341.4 Q97.0798 1340.98 94.6262 1340.12 L94.6262 1335.61 Q96.5706 1336.74 98.8854 1337.32 Q101.2 1337.9 103.723 1337.9 Q108.121 1337.9 110.413 1336.17 Q112.728 1334.43 112.728 1331.12 Q112.728 1328.06 110.575 1326.35 Q108.446 1324.61 104.626 1324.61 L100.598 1324.61 L100.598 1320.77 L104.811 1320.77 Q108.26 1320.77 110.089 1319.41 Q111.918 1318.02 111.918 1315.42 Q111.918 1312.76 110.02 1311.35 Q108.145 1309.92 104.626 1309.92 Q102.705 1309.92 100.506 1310.33 Q98.3067 1310.75 95.6678 1311.63 L95.6678 1307.46 Q98.3298 1306.72 100.645 1306.35 Q102.983 1305.98 105.043 1305.98 Q110.367 1305.98 113.469 1308.41 Q116.57 1310.82 116.57 1314.94 Q116.57 1317.81 114.927 1319.8 Q113.283 1321.77 110.251 1322.53 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M136.246 1309.68 Q132.635 1309.68 130.807 1313.25 Q129.001 1316.79 129.001 1323.92 Q129.001 1331.03 130.807 1334.59 Q132.635 1338.13 136.246 1338.13 Q139.881 1338.13 141.686 1334.59 Q143.515 1331.03 143.515 1323.92 Q143.515 1316.79 141.686 1313.25 Q139.881 1309.68 136.246 1309.68 M136.246 1305.98 Q142.056 1305.98 145.112 1310.59 Q148.191 1315.17 148.191 1323.92 Q148.191 1332.65 145.112 1337.25 Q142.056 1341.84 136.246 1341.84 Q130.436 1341.84 127.357 1337.25 Q124.302 1332.65 124.302 1323.92 Q124.302 1315.17 127.357 1310.59 Q130.436 1305.98 136.246 1305.98 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M52.6588 1020.57 L60.2976 1020.57 L60.2976 994.203 L51.9875 995.869 L51.9875 991.61 L60.2513 989.943 L64.9272 989.943 L64.9272 1020.57 L72.5661 1020.57 L72.5661 1024.5 L52.6588 1024.5 L52.6588 1020.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M82.0105 1018.62 L86.8947 1018.62 L86.8947 1024.5 L82.0105 1024.5 L82.0105 1018.62 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M111.246 1005.87 Q114.603 1006.59 116.478 1008.86 Q118.376 1011.12 118.376 1014.46 Q118.376 1019.57 114.858 1022.37 Q111.339 1025.17 104.858 1025.17 Q102.682 1025.17 100.367 1024.73 Q98.0752 1024.32 95.6215 1023.46 L95.6215 1018.95 Q97.566 1020.08 99.8808 1020.66 Q102.196 1021.24 104.719 1021.24 Q109.117 1021.24 111.408 1019.5 Q113.723 1017.77 113.723 1014.46 Q113.723 1011.4 111.571 1009.69 Q109.441 1007.95 105.621 1007.95 L101.594 1007.95 L101.594 1004.11 L105.807 1004.11 Q109.256 1004.11 111.084 1002.74 Q112.913 1001.36 112.913 998.763 Q112.913 996.101 111.015 994.689 Q109.14 993.254 105.621 993.254 Q103.7 993.254 101.501 993.67 Q99.3021 994.087 96.6632 994.967 L96.6632 990.8 Q99.3252 990.059 101.64 989.689 Q103.978 989.318 106.038 989.318 Q111.362 989.318 114.464 991.749 Q117.566 994.156 117.566 998.277 Q117.566 1001.15 115.922 1003.14 Q114.279 1005.11 111.246 1005.87 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M127.288 989.943 L145.644 989.943 L145.644 993.879 L131.57 993.879 L131.57 1002.35 Q132.589 1002 133.607 1001.84 Q134.626 1001.66 135.644 1001.66 Q141.431 1001.66 144.811 1004.83 Q148.191 1008 148.191 1013.42 Q148.191 1018.99 144.718 1022.1 Q141.246 1025.17 134.927 1025.17 Q132.751 1025.17 130.482 1024.8 Q128.237 1024.43 125.83 1023.69 L125.83 1018.99 Q127.913 1020.13 130.135 1020.68 Q132.357 1021.24 134.834 1021.24 Q138.839 1021.24 141.177 1019.13 Q143.515 1017.03 143.515 1013.42 Q143.515 1009.8 141.177 1007.7 Q138.839 1005.59 134.834 1005.59 Q132.959 1005.59 131.084 1006.01 Q129.232 1006.42 127.288 1007.3 L127.288 989.943 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M51.6634 703.907 L59.3023 703.907 L59.3023 677.541 L50.9921 679.208 L50.9921 674.948 L59.256 673.282 L63.9319 673.282 L63.9319 703.907 L71.5707 703.907 L71.5707 707.842 L51.6634 707.842 L51.6634 703.907 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M81.0151 701.962 L85.8993 701.962 L85.8993 707.842 L81.0151 707.842 L81.0151 701.962 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M108.932 677.356 L97.1261 695.805 L108.932 695.805 L108.932 677.356 M107.705 673.282 L113.584 673.282 L113.584 695.805 L118.515 695.805 L118.515 699.694 L113.584 699.694 L113.584 707.842 L108.932 707.842 L108.932 699.694 L93.3299 699.694 L93.3299 695.18 L107.705 673.282 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M136.246 676.36 Q132.635 676.36 130.807 679.925 Q129.001 683.467 129.001 690.596 Q129.001 697.703 130.807 701.268 Q132.635 704.809 136.246 704.809 Q139.881 704.809 141.686 701.268 Q143.515 697.703 143.515 690.596 Q143.515 683.467 141.686 679.925 Q139.881 676.36 136.246 676.36 M136.246 672.657 Q142.056 672.657 145.112 677.263 Q148.191 681.847 148.191 690.596 Q148.191 699.323 145.112 703.93 Q142.056 708.513 136.246 708.513 Q130.436 708.513 127.357 703.93 Q124.302 699.323 124.302 690.596 Q124.302 681.847 127.357 677.263 Q130.436 672.657 136.246 672.657 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M52.6588 387.245 L60.2976 387.245 L60.2976 360.879 L51.9875 362.546 L51.9875 358.287 L60.2513 356.62 L64.9272 356.62 L64.9272 387.245 L72.5661 387.245 L72.5661 391.18 L52.6588 391.18 L52.6588 387.245 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M82.0105 385.301 L86.8947 385.301 L86.8947 391.18 L82.0105 391.18 L82.0105 385.301 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M109.927 360.694 L98.1215 379.143 L109.927 379.143 L109.927 360.694 M108.7 356.62 L114.58 356.62 L114.58 379.143 L119.51 379.143 L119.51 383.032 L114.58 383.032 L114.58 391.18 L109.927 391.18 L109.927 383.032 L94.3252 383.032 L94.3252 378.518 L108.7 356.62 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M127.288 356.62 L145.644 356.62 L145.644 360.555 L131.57 360.555 L131.57 369.027 Q132.589 368.68 133.607 368.518 Q134.626 368.333 135.644 368.333 Q141.431 368.333 144.811 371.504 Q148.191 374.676 148.191 380.092 Q148.191 385.671 144.718 388.773 Q141.246 391.851 134.927 391.851 Q132.751 391.851 130.482 391.481 Q128.237 391.111 125.83 390.37 L125.83 385.671 Q127.913 386.805 130.135 387.361 Q132.357 387.916 134.834 387.916 Q138.839 387.916 141.177 385.81 Q143.515 383.703 143.515 380.092 Q143.515 376.481 141.177 374.375 Q138.839 372.268 134.834 372.268 Q132.959 372.268 131.084 372.685 Q129.232 373.102 127.288 373.981 L127.288 356.62 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M51.6634 70.5834 L59.3023 70.5834 L59.3023 44.2178 L50.9921 45.8844 L50.9921 41.6252 L59.256 39.9585 L63.9319 39.9585 L63.9319 70.5834 L71.5707 70.5834 L71.5707 74.5185 L51.6634 74.5185 L51.6634 70.5834 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M81.0151 68.6389 L85.8993 68.6389 L85.8993 74.5185 L81.0151 74.5185 L81.0151 68.6389 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M96.1308 39.9585 L114.487 39.9585 L114.487 43.8937 L100.413 43.8937 L100.413 52.3659 Q101.432 52.0186 102.45 51.8566 Q103.469 51.6714 104.487 51.6714 Q110.274 51.6714 113.654 54.8427 Q117.033 58.014 117.033 63.4306 Q117.033 69.0093 113.561 72.1111 Q110.089 75.1898 103.77 75.1898 Q101.594 75.1898 99.3252 74.8194 Q97.0798 74.4491 94.6724 73.7083 L94.6724 69.0093 Q96.7558 70.1435 98.978 70.6991 Q101.2 71.2547 103.677 71.2547 Q107.682 71.2547 110.02 69.1482 Q112.358 67.0417 112.358 63.4306 Q112.358 59.8195 110.02 57.7131 Q107.682 55.6066 103.677 55.6066 Q101.802 55.6066 99.927 56.0233 Q98.0752 56.4399 96.1308 57.3195 L96.1308 39.9585 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M136.246 43.0372 Q132.635 43.0372 130.807 46.602 Q129.001 50.1437 129.001 57.2732 Q129.001 64.3797 130.807 67.9445 Q132.635 71.4861 136.246 71.4861 Q139.881 71.4861 141.686 67.9445 Q143.515 64.3797 143.515 57.2732 Q143.515 50.1437 141.686 46.602 Q139.881 43.0372 136.246 43.0372 M136.246 39.3335 Q142.056 39.3335 145.112 43.94 Q148.191 48.5233 148.191 57.2732 Q148.191 66 145.112 70.6065 Q142.056 75.1898 136.246 75.1898 Q130.436 75.1898 127.357 70.6065 Q124.302 66 124.302 57.2732 Q124.302 48.5233 127.357 43.94 Q130.436 39.3335 136.246 39.3335 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><circle clip-path="url(#clip532)" cx="245.565" cy="1445.72" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip532)" cx="1413.27" cy="665.382" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip532)" cx="1820.81" cy="421.1" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip532)" cx="2291.38" cy="87.9763" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<polyline clip-path="url(#clip532)" style="stroke:#e26f46; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="245.565,1445.39 258.885,1436.6 382.041,1355.3 456.054,1306.44 518.63,1265.13 586.605,1220.25 649.273,1178.88 716.459,1134.52 794.3,1083.14 863.477,1037.47 924.138,997.421 990.276,953.759 1056.81,909.837 1130.36,861.276 1200.35,815.072 1273.12,767.03 1334.38,726.589 1409.17,677.216 1477.68,631.986 1540.96,590.213 1605.06,547.898 1676.89,500.475 1741.98,457.503 1816.51,408.302 1885.52,362.746 1953.55,317.833 2019.6,274.227 2087.32,229.525 2161.5,180.549 2269.27,109.402 2291.38,94.8066 "/>
<path clip-path="url(#clip530)" d="M256.476 198.898 L519.559 198.898 L519.559 95.2176 L256.476 95.2176  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<polyline clip-path="url(#clip530)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="256.476,198.898 519.559,198.898 519.559,95.2176 256.476,95.2176 256.476,198.898 "/>
<polyline clip-path="url(#clip530)" style="stroke:#e26f46; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="280.571,147.058 425.142,147.058 "/>
<path clip-path="url(#clip530)" d="M465.742 128.319 L465.742 131.861 L461.668 131.861 Q459.376 131.861 458.474 132.787 Q457.594 133.713 457.594 136.12 L457.594 138.412 L464.608 138.412 L464.608 141.722 L457.594 141.722 L457.594 164.338 L453.312 164.338 L453.312 141.722 L449.238 141.722 L449.238 138.412 L453.312 138.412 L453.312 136.606 Q453.312 132.278 455.325 130.31 Q457.339 128.319 461.714 128.319 L465.742 128.319 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M469.307 138.412 L473.566 138.412 L473.566 164.338 L469.307 164.338 L469.307 138.412 M469.307 128.319 L473.566 128.319 L473.566 133.713 L469.307 133.713 L469.307 128.319 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip530)" d="M486.691 131.051 L486.691 138.412 L495.464 138.412 L495.464 141.722 L486.691 141.722 L486.691 155.796 Q486.691 158.967 487.548 159.87 Q488.427 160.773 491.089 160.773 L495.464 160.773 L495.464 164.338 L491.089 164.338 Q486.159 164.338 484.284 162.509 Q482.409 160.657 482.409 155.796 L482.409 141.722 L479.284 141.722 L479.284 138.412 L482.409 138.412 L482.409 131.051 L486.691 131.051 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /></svg>

```

---

*This page was generated using [Literate.jl](https://github.com/fredrikekre/Literate.jl).*

